#!/usr/bin/env python3
# Copyright (C) 2019 Checkmk GmbH - License: GNU General Public License v2
# This file is part of Checkmk (https://checkmk.com). It is subject to the terms and
# conditions defined in the file COPYING, which is part of this source code package.


# mypy: disable-error-code="var-annotated"

from cmk.base.check_api import LegacyCheckDefinition
from cmk.base.config import check_info


def parse_bi_aggregation_connection(string_table):
    import ast

    fields = ["missing_sites", "missing_aggr", "generic_errors"]
    parsed = {}
    for line in string_table:
        connection_info = ast.literal_eval(line[0])
        for field in fields:
            if connection_info[field]:
                parsed.setdefault(field, set()).update(connection_info[field])

    return parsed


def discover_bi_aggregation_connection(parsed):
    yield None, None


def check_bi_aggregation_connection(_no_item, _no_params, parsed):
    if parsed.get("missing_sites"):
        yield (
            1,
            "Unable to query data from site(s): %s" % ", ".join(parsed["missing_sites"]),
        )
    if parsed.get("missing_aggr"):
        yield (
            1,
            "Unable to display aggregations because of missing data: %s"
            % ", ".join(parsed["missing_aggr"]),
        )
    if parsed.get("generic_errors"):
        yield (
            1,
            "Error during data collection: %s" % ", ".join(parsed["generic_errors"]),
        )

    if not parsed:
        yield 0, "No connection problems"


check_info["bi_aggregation_connection"] = LegacyCheckDefinition(
    parse_function=parse_bi_aggregation_connection,
    service_name="BI Datasource Connection",
    discovery_function=discover_bi_aggregation_connection,
    check_function=check_bi_aggregation_connection,
)
