#!/usr/bin/env python3
# Copyright (C) 2019 Checkmk GmbH - License: GNU General Public License v2
# This file is part of Checkmk (https://checkmk.com). It is subject to the terms and
# conditions defined in the file COPYING, which is part of this source code package.


from cmk.base.check_api import LegacyCheckDefinition
from cmk.base.config import check_info

from cmk.agent_based.v2 import SNMPTree, StringTable
from cmk.plugins.lib.bvip import DETECT_BVIP


def inventory_bvip_link(info):
    if info:
        return [(None, {})]
    return []


def check_bvip_link(_no_item, params, info):
    count = 0
    states = {
        0: "No Link",
        1: "10 MBit - HalfDuplex",
        2: "10 MBit - FullDuplex",
        3: "100 Mbit - HalfDuplex",
        4: "100 Mbit - FullDuplex",
        5: "1 Gbit - FullDuplex",
        7: "Wifi",
    }
    for line in info:
        count += 1
        link_status = int(line[0])
        if link_status in params["ok_states"]:
            state = 0
        elif link_status in params["crit_states"]:
            state = 2
        elif link_status in params["warn_states"]:
            state = 1
        else:
            state = 3
        yield (
            state,
            "{}: State: {}".format(
                count,
                states.get(link_status, "Not Implemented (%s)" % link_status),
            ),
        )


def parse_bvip_link(string_table: StringTable) -> StringTable:
    return string_table


check_info["bvip_link"] = LegacyCheckDefinition(
    parse_function=parse_bvip_link,
    detect=DETECT_BVIP,
    fetch=SNMPTree(
        base=".1.3.6.1.4.1.3967.1.5.1.8",
        oids=["1"],
    ),
    service_name="Network Link",
    discovery_function=inventory_bvip_link,
    check_function=check_bvip_link,
    check_ruleset_name="bvip_link",
    check_default_parameters={
        "ok_states": [0, 4, 5],
        "warn_states": [7],
        "crit_states": [1, 2, 3],
    },
)
