#!/usr/bin/env python3
# Copyright (C) 2019 Checkmk GmbH - License: GNU General Public License v2
# This file is part of Checkmk (https://checkmk.com). It is subject to the terms and
# conditions defined in the file COPYING, which is part of this source code package.


from cmk.base.check_api import LegacyCheckDefinition
from cmk.base.check_legacy_includes.humidity import check_humidity
from cmk.base.config import check_info

from cmk.agent_based.v2 import SNMPTree, StringTable
from cmk.plugins.lib.knuerr import DETECT_KNUERR


def inventory_knuerr_rms_humidity(info):
    yield None, {}


def check_knuerr_rms_humidity(_no_item, params, info):
    _name, reading = info[0]
    return check_humidity(float(reading) / 10, params)


def parse_knuerr_rms_humidity(string_table: StringTable) -> StringTable | None:
    return string_table or None


check_info["knuerr_rms_humidity"] = LegacyCheckDefinition(
    parse_function=parse_knuerr_rms_humidity,
    detect=DETECT_KNUERR,
    fetch=SNMPTree(
        base=".1.3.6.1.4.1.3711.15.1.1.1.2",
        oids=["2", "4"],
    ),
    service_name="Humidity",
    discovery_function=inventory_knuerr_rms_humidity,
    check_function=check_knuerr_rms_humidity,
    check_ruleset_name="single_humidity",
    check_default_parameters={
        "levels_lower": (40, 30),
        "levels": (70, 75),
    },
)
