#!/usr/bin/env python3
# Copyright (C) 2023 Checkmk GmbH - License: GNU General Public License v2
# This file is part of Checkmk (https://checkmk.com). It is subject to the terms and
# conditions defined in the file COPYING, which is part of this source code package.


from collections import defaultdict

from cmk.base.plugins.agent_based.agent_based_api.v1 import register, SNMPTree

from cmk.plugins.lib.cisco_ucs import DETECT, Fault, FaultSeverity

from .agent_based_api.v1.type_defs import StringTable


def parse_cisco_ucs_fault(string_table: StringTable) -> dict[str, list[Fault]]:
    faults = defaultdict(list)
    for (
        fault_object_id,
        fault_ack,
        fault_code,
        fault_description,
        fault_severity,
    ) in string_table:
        faults[fault_object_id].append(
            Fault(
                acknowledge=(int(fault_ack) == 1),
                code=fault_code,
                description=fault_description,
                severity=FaultSeverity(fault_severity),
            )
        )

    return faults


register.snmp_section(
    name="cisco_ucs_fault",
    parse_function=parse_cisco_ucs_fault,
    fetch=SNMPTree(
        base=".1.3.6.1.4.1.9.9.719.1.1.1.1",
        oids=[
            "5",  # .1.3.6.1.4.1.9.9.719.1.1.1.1.5 cucsFaultAffectedObjectId
            "6",  # .1.3.6.1.4.1.9.9.719.1.1.1.1.6 cucsFaultAck
            "9",  # .1.3.6.1.4.1.9.9.719.1.1.1.1.9 cucsFaultCode
            "11",  # .1.3.6.1.4.1.9.9.719.1.1.1.1.11 cucsFaultDescription
            "20",  # .1.3.6.1.4.1.9.9.719.1.1.1.1.20 cucsFaultSeverity
        ],
    ),
    detect=DETECT,
)
