#!/usr/bin/env python3
# Copyright (C) 2019 Checkmk GmbH - License: GNU General Public License v2
# This file is part of Checkmk (https://checkmk.com). It is subject to the terms and
# conditions defined in the file COPYING, which is part of this source code package.

from typing import Any

from cmk.plugins.lib.oracle import SectionPerformance

from .agent_based_api.v1 import register
from .agent_based_api.v1.type_defs import StringTable


def parse_oracle_performance(string_table: StringTable) -> SectionPerformance:
    def _try_parse_int(s):
        try:
            return int(s)
        except ValueError:
            return None

    parsed: dict[str, dict[str, dict[str, Any]]] = {}
    for line in string_table:
        if len(line) < 3:
            continue
        parsed.setdefault(line[0], {})
        parsed[line[0]].setdefault(line[1], {})
        counters = line[3:]
        if len(counters) == 1:
            parsed[line[0]][line[1]].setdefault(line[2], _try_parse_int(counters[0]))
        else:
            parsed[line[0]][line[1]].setdefault(line[2], list(map(_try_parse_int, counters)))

    return parsed


register.agent_section(
    name="oracle_performance",
    parse_function=parse_oracle_performance,
)
