# Check Protocols
This is preliminary internal information based on actual Core build.  

In any case, provided information is not full and must be proofed with corresponding set of unit-tests.



#### Described:
1. Text(UTF-8) protocol itself
2. Communication channels
   1. Type - pipe and socket
   2. Usage - read/write
3. Call stack used to invoke protocol starting from main loop
4. Logging(if it is important)
5. Inter-helper operation(if important)



#### Used delimiters:
- []    - optional
- <>    - mandatory
- ''    - string
- 1, 2  - possible variant
- where - description of parameters in previous line
 


## Alert Helper
### Channels
Main Channel:  socket read/write, stdin == stdout
Error Channel: pipe   read only

### Main Channel
Synopsis: The Core fills Alert spool with data using AlertHelper::handler and flushes the spool to stdout  using AlertHelper::communicate.
Seems that the process is synchronous.

    main loop -> communicate:
        input = read stdout
        if input == '*'
            write stdin eventSpool.nextEvent() // in fact stdout
        else
            error && restart
    
    main loop -> handle()
    writes to spool table of string:
        "<name>=[value]\n"
        where
            name  - any of [ALERTTYPE, ...]
            value - corresponding text
        examples of first line:    
        1. "ALERTTYPE=STATECHANGE\n"
        2. "ALERTTYPE=CHECKRESULT\n"

### Error Channel(alerts)
Synopsis: Redirects processed data from stderr to the NotifyHelper

    main loop -> checkError 
        loop till data presented 
            input = readLine stderr
            where:
                input(1): "STARTED <host>;[service];<handler name>"
                input(2): "STOPPED <host>;[service];<handler name>;<exit code>;[output]"
                where
                    host    - name of the host
                    service - name of service
                    output  - text
            processAlertHelperResponse(input)
                write log processed(input)
                if input(2)
                    notify NotifyHelper with NotifyInfo(object, type, "", "", extra)
                        where
                            object - Core->getObject*(host, service)
                            type   - "ALERTHANDLER(<exit code>)"
                            extra  - map<string, string> = {
                                {"ALERTHANDLERNAME",   handler name}
                                {"ALERTHANDLERSTATE",  exit code}
                                {"ALERTHANDLEROUTPUT", output }
                            }

        

## Notify Helper
### Channels
Main Channel:  socket read/write, stdin == stdout == stderr

### Main Channel
Synopsis: Similar approach as with AlertHelper. But to fill spool the Core uses member-functions broadcast and/or notify.

    main loop -> communicate:
        input = read stdout
        if input == '*'
            write stdin _spool.pop_front()
        else
            error && restart
    
    main loop -> broadcast | notify
        if rule based
            notifyRBN(Contact[], NotificationInfo) :
                write log "check-mk-notify" NotificationInfo // emitHistoryEntry
                push spool
                    format:
                    <CONTACTS>=<Contact[0].name>,<Contact[1].name>,...\n
                    <NotificationInfo NAME0>=<NotificationInfo.value0>\n
                    ...
                    "\n"
        else
            notifyContact(Contact, NotificationInfo):
                write log Contact.info NotificationInfo // emitHistoryEntry
                push spool:
                    format:
                    <CONTACTNAME>=<Contact.name>
                    <CONTACTALIAS>=<Contact.attribute("alias")>
                    <CONTACTEMAIL>=<Contact.attribute("email")>
                    <CONTACTPAGER>=<Contact.attribute("pager")>
                    //contact custom attributes in format, name is uppercased(!)
                    <'CONTACT_'Contact.customattribute.name0()>=<Contact.customattribute.value0()>\n
                    ...
                    <NotificationInfo NAME1>=<NotificationInfo.value1>\n
                    ...
                    "\n"





## RRD Helper
### Channels
Main Channel:  socket read/write, stdin == stdout == stderr

### Main Channel
Synopsis: Receives metric data from the stdin, decodes process and writes those data back to stdin

Reload is signaled with "*\n" written in stdout.


    main loop -> RRDHelper::communicate:
        input = read line stdin 
            where
                input(1) "CREATED <payload>"
                input(2) all other data

        if input(1)
            updateMetrics(payload)
            where
                payload(1) "cmc_single <host>;[service];[var1];[var2];[var3]"
                payload(1) "pnp_multiple <host>;_HOST_;[var]"
        else
            log error

    main loop -> RRDHelper::processPerfData(perf_data, object):
        1. RRDHelper::processMultiple(perf_data, object, object.rrd_info)
            or
        2. RRDHelper::processSingle(perf_data, object, object.rrd_info)
            ...
            if new metric
                create new RRD File
                    write stdin "<'pnp_multiple'|'cmc_single'>;<object.specname()>;<metric1.mangled_name>;<metric1.value>;...\n"
                    where
                        metricX - is build from perf_data 

            else
                call RRD CacheD() //to be analyzed later
            ...

    main loop -> RRDHelper::reload:
        write stdout "*\n"
        
## Check Helper
### Channels
Main Channel:  socket read/write, stdin == stdout
Error Channel: pipe   read only

### Input from check:
A python checks send to us always(?) the same data:

    "<status>\n<length>\n<payload>"
        where:
            status  - 3-digit error code, return_code
            length  - length of payload(0 filled)
            payload - <check_result>...<check_result><finish_line>
                where
                check_result:
                    "[\tcached_at=<since_epoch>\tcached_interval=<seconds>]\t<code>\t<host>\t<service>\t<data>\n"...
                        where
                        since_epoch - decimal digit
                        seconds     - decimal digit
                        code        - decimal digit
                        host        - host name
                        service     - service description
                        data
                            format:
                            "<all_output>[|<perf_data>]"
                                where
                                all_output is "<all_output_real>[\001<long_output>]"
                                perf_data is "<name1>=<value1_1>;[value1_2];...[<name2>=<value2_1>;[value2_2]...]..."
                                    where
                                    name  - perf counter name
                                    value - float
                finish_line:
                    "<host>\t<text>\n"
                    where
                        host - name, 'heute'
                        test - 'OK - [agent] Version: 2020.04.01, OS: linux, execution time 1.4 sec | execution_time=1.401 user_time=0.180 system_time=0.030 children_user_time=0.000 children_system_time=0.000 cmk_time_agent=1.203'



### Main Channel
Starts processing sending the command to stdin and read answer from stdout.

Restart is signaled with "*\n" written in stdout.

    main loop -> communicate:
        CheckHelper::getResult() 
            read stdout 13 bytes
            decode 12 byte -> status  + length
            read stdout payload(length)
            process payload line by line(see section 'Input from check')

    main loop -> AnyCheckerHelperPool.migrate:
            write stdin "*\n"

    main loop -> CheckHelperPool::runScheduledChecks -> CheckHelperPool::tryToRunCheck
        CheckHelper::runCheck
            write stdin message
            format:
                "[<generic_host_name>\n]<command_line>\n<timeout>\n"
                    where
                    generic_host_name - text
                    command_line      - text, "heute 127.0.0.1" 
                    timeout           - number, 60
        
### Error Channel(alerts)
Just logging error from stderr.

    main loop -> checkError -> fetchHelperErrors
        read line stdErr
        write to log every line

        


