// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef CarbonConfig_h
#define CarbonConfig_h

#include <netinet/in.h>

#include <chrono>
#include <cstdint>
#include <string>
#include <utility>

class Metric;

/// \sa core_cmc::cmc_graphite_config()
class CarbonConnectionConfig {
public:
    enum class Mangling { underscore, c_style };
    CarbonConnectionConfig(in_addr_t ip, uint16_t port,
                           std::chrono::microseconds retry_interval,
                           std::string connection_prefix, Mangling mangling)
        : ip_{ip}
        , port_{port}
        , retry_interval_{retry_interval}
        , connection_prefix_{std::move(connection_prefix)}
        , mangling_{mangling} {}

    in_addr_t ip_;
    uint16_t port_;
    std::chrono::microseconds retry_interval_;
    std::string connection_prefix_;
    Mangling mangling_;

    [[nodiscard]] std::string path(
        const std::string &host_name,
        const std::string &service_description) const;
    [[nodiscard]] std::string path(const std::string &host_name,
                                   const std::string &service_description,
                                   const Metric &metric) const;
    [[nodiscard]] std::string path(const std::string &host_name,
                                   const std::string &service_description,
                                   const std::string &metric_name) const;

    bool operator==(const CarbonConnectionConfig &other) const;
    bool operator!=(const CarbonConnectionConfig &other) const {
        return !(*this == other);
    }

private:
    [[nodiscard]] std::string canonicalize(const std::string &str) const;
};

namespace carbon::protocol {
struct Update;
}  // namespace carbon::protocol

/// \sa CMCHostConfigBase::_cmc_graphite_metrics()
class CarbonSendMetricParts {
public:
    [[nodiscard]] bool anyState() const {
        return state || scheduled_downtime_depth || acknowledged;
    }

    bool value;
    bool uom;
    bool warn;
    bool crit;
    bool min;
    bool max;
    bool state;
    bool scheduled_downtime_depth;
    bool acknowledged;

    bool operator==(const CarbonSendMetricParts &other) const;
    bool operator!=(const CarbonSendMetricParts &other) const {
        return !(*this == other);
    }

private:
    [[nodiscard]] bool anyMetric() const {
        return value || uom || warn || crit || min || max;
    }
    friend struct carbon::protocol::Update;
};

#endif
