// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef CheckResult_h
#define CheckResult_h

#include <chrono>
#include <iosfwd>
#include <string>

class Host;
enum class HostState;
class Object;

// TODO(sp): Make real classes out of these and move them elsewhere.
class CheckResult {
public:
    CheckResult(Host *host, HostState state, std::string output);

    static CheckResult createActive(std::istream &is, Object *object,
                                    int return_code);
    static CheckResult createPassive(std::istream &is, Object *object);

    CheckResult createCopyFor(Object *object) const;

    Object *_object;
    int _state;
    std::string _output;
    std::string _long_output;
    std::string _perf_data;
    std::chrono::system_clock::time_point _cached_at;
    std::chrono::seconds _cache_interval;

private:
    CheckResult(Object *object, int state, std::string output,
                std::string long_output, std::string perf_data,
                std::chrono::system_clock::time_point cached_at,
                std::chrono::seconds cache_interval);
};

std::ostream &operator<<(std::ostream &os, const CheckResult &c);

#endif  // CheckResult_h
