// Copyright (C) 2023 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef CmcComment_h
#define CmcComment_h

#include "cmc/CmcHost.h"
#include "cmc/CmcService.h"
#include "cmc/Comment.h"
#include "cmc/Object.h"
#include "livestatus/Interface.h"

class CmcComment : public IComment {
public:
    explicit CmcComment(const Comment &comment)
        : comment_{comment}
        , host_{CmcHost{*comment._object->host()}}
        , service_{comment._object->service() == nullptr
                       ? nullptr
                       : std::make_unique<CmcService>(
                             *comment._object->service())} {}

    [[nodiscard]] int32_t id() const override { return comment_._id; }

    [[nodiscard]] std::string author() const override {
        return comment_._author;
    }

    [[nodiscard]] std::string comment() const override {
        return comment_._comment;
    }

    [[nodiscard]] CommentType entry_type() const override {
        return static_cast<CommentType>(comment_._entry_type);
    }

    [[nodiscard]] std::chrono::system_clock::time_point entry_time()
        const override {
        return comment_._entry_time;
    }

    [[nodiscard]] bool isService() const override {
        return comment_._object->isService();
    }

    [[nodiscard]] bool persistent() const override {
        return comment_._persistent;
    }

    [[nodiscard]] CommentSource source() const override {
        return static_cast<CommentSource>(comment_._source);
    }

    [[nodiscard]] bool expires() const override { return comment_.expires(); }

    [[nodiscard]] std::chrono::system_clock::time_point expire_time()
        const override {
        return comment_._expire_time;
    }

    [[nodiscard]] const IHost &host() const override { return host_; }

    [[nodiscard]] const IService *service() const override {
        return service_ ? service_.get() : nullptr;
    }

private:
    const Comment &comment_;
    const CmcHost host_;
    const std::unique_ptr<const IService> service_;
};

#endif  // CmcComment_h
