// Copyright (C) 2023 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef CmcContact_h
#define CmcContact_h

#include <cstdint>
#include <functional>
#include <string>

#include "livestatus/Interface.h"
class Contact;

class CmcContact : public IContact {
public:
    explicit CmcContact(const Contact &contact) : contact_{contact} {}

    [[nodiscard]] std::string name() const override;
    [[nodiscard]] std::string alias() const override;
    [[nodiscard]] std::string email() const override;
    [[nodiscard]] std::string pager() const override;
    [[nodiscard]] std::string hostNotificationPeriod() const override;
    [[nodiscard]] std::string serviceNotificationPeriod() const override;
    [[nodiscard]] std::string address(int32_t index) const override;
    [[nodiscard]] bool canSubmitCommands() const override;
    [[nodiscard]] bool isHostNotificationsEnabled() const override;
    [[nodiscard]] bool isServiceNotificationsEnabled() const override;
    [[nodiscard]] bool isInHostNotificationPeriod() const override;
    [[nodiscard]] bool isInServiceNotificationPeriod() const override;
    [[nodiscard]] Attributes customVariables() const override;
    [[nodiscard]] Attributes tags() const override;
    [[nodiscard]] Attributes labels() const override;
    [[nodiscard]] Attributes labelSources() const override;
    [[nodiscard]] uint32_t modifiedAttributes() const override;
    bool all_of_labels(
        const std::function<bool(const Attribute &)> &pred) const override;

private:
    const Contact &contact_;
};

#endif  // CmcContact_h
