// Copyright (C) 2023 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef CmcDowntime_h
#define CmcDowntime_h

#include "cmc/CmcHost.h"
#include "cmc/CmcService.h"
#include "cmc/Downtime.h"
#include "cmc/Object.h"
#include "livestatus/Interface.h"

class CmcDowntime : public IDowntime {
public:
    explicit CmcDowntime(const Downtime &downtime)
        : downtime_{downtime}
        , host_{CmcHost{*downtime._object->host()}}
        , service_{downtime._object->service() == nullptr
                       ? nullptr
                       : std::make_unique<CmcService>(
                             *downtime._object->service())} {}

    [[nodiscard]] int32_t id() const override { return downtime_._id; }

    [[nodiscard]] std::string author() const override {
        return downtime_._author;
    }

    [[nodiscard]] std::string comment() const override {
        return downtime_._comment;
    }

    [[nodiscard]] bool origin_is_rule() const override {
        return downtime_._origin_is_rule;
    }

    [[nodiscard]] std::chrono::system_clock::time_point entry_time()
        const override {
        return downtime_._entry_time;
    }

    [[nodiscard]] std::chrono::system_clock::time_point start_time()
        const override {
        return downtime_._start_time;
    }

    [[nodiscard]] std::chrono::system_clock::time_point end_time()
        const override {
        return downtime_._end_time;
    }

    [[nodiscard]] bool isService() const override {
        return downtime_._object->isService();
    }

    [[nodiscard]] bool fixed() const override { return downtime_._fixed; }

    [[nodiscard]] std::chrono::nanoseconds duration() const override {
        return downtime_._duration;
    }

    [[nodiscard]] RecurringKind recurring() const override {
        switch (downtime_._cycle_time.getKind()) {
            case CycleTime::Kind::none:
                return RecurringKind::none;
            case CycleTime::Kind::hourly:
                return RecurringKind::hourly;
            case CycleTime::Kind::daily:
                return RecurringKind::daily;
            case CycleTime::Kind::weekly:
                return RecurringKind::weekly;
            case CycleTime::Kind::biweekly:
                return RecurringKind::biweekly;
            case CycleTime::Kind::every_4weeks:
                return RecurringKind::every_4weeks;
            case CycleTime::Kind::nth_weekday:
                return RecurringKind::nth_weekday;
            case CycleTime::Kind::nth_weekday_from_end:
                return RecurringKind::nth_weekday_from_end;
            case CycleTime::Kind::day_of_month:
                return RecurringKind::day_of_month;
            case CycleTime::Kind::every_5min:
                return RecurringKind::every_5min;
        }
        // unreachable
        return {};
    }

    [[nodiscard]] bool pending() const override {
        return downtime_._status == Downtime::Status::pending;
    }

    [[nodiscard]] int32_t triggered_by() const override { return 0; };

    [[nodiscard]] const IHost &host() const override { return host_; }

    [[nodiscard]] const IService *service() const override {
        return service_ ? service_.get() : nullptr;
    }

private:
    const Downtime &downtime_;
    const CmcHost host_;
    const std::unique_ptr<const IService> service_;
};

#endif  // CmcDowntime_h
