// Copyright (C) 2023 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef CmcGlobalFlags_h
#define CmcGlobalFlags_h

#include "cmc/GlobalState.h"
#include "livestatus/Interface.h"

class CmcGlobalFlags : public IGlobalFlags {
public:
    explicit CmcGlobalFlags(const GlobalState &state) : state_{state} {}

    [[nodiscard]] bool enable_notifications() const override {
        return state_.getEnableNotifications();
    }

    [[nodiscard]] bool execute_service_checks() const override {
        return state_.getExecuteServiceChecks();
    }

    [[nodiscard]] bool accept_passive_service_checks() const override {
        return state_.getExecuteServiceChecks();
    }

    [[nodiscard]] bool execute_host_checks() const override {
        return state_.getExecuteHostChecks();
    }

    [[nodiscard]] bool accept_passive_hostchecks() const override {
        return state_.getExecuteHostChecks();
    }

    [[nodiscard]] bool obsess_over_services() const override { return false; }

    [[nodiscard]] bool obsess_over_hosts() const override { return false; }

    [[nodiscard]] bool check_service_freshness() const override { return true; }

    [[nodiscard]] bool check_host_freshness() const override { return true; }

    [[nodiscard]] bool enable_flap_detection() const override {
        return state_.getEnableFlapDetection();
    }

    [[nodiscard]] bool process_performance_data() const override {
        return state_.getProcessPerformanceData();
    }

    [[nodiscard]] bool enable_event_handlers() const override {
        return state_.getEnableAlertHandlers();
    }

    [[nodiscard]] bool check_external_commands() const override { return true; }

private:
    const GlobalState &state_;
};

#endif  // CmcGlobalFlags_h
