// Copyright (C) 2023 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef CmcPaths_h
#define CmcPaths_h

#include "cmc/GlobalConfig.h"
#include "livestatus/Interface.h"

class CmcPaths : public IPaths {
public:
    explicit CmcPaths(const GlobalConfig &global_config)
        : global_config_{global_config} {}

    [[nodiscard]] std::filesystem::path log_file() const override {
        return global_config_.general_.log_file_;
    }

    [[nodiscard]] std::filesystem::path crash_reports_directory()
        const override {
        return global_config_.general_.crash_reports_directory_;
    }

    [[nodiscard]] std::filesystem::path license_usage_history_file()
        const override {
        return global_config_.general_.license_usage_history_file_;
    }

    [[nodiscard]] std::filesystem::path inventory_directory() const override {
        return global_config_.general_.inventory_directory_;
    }

    [[nodiscard]] std::filesystem::path structured_status_directory()
        const override {
        return global_config_.general_.structured_status_directory_;
    }

    [[nodiscard]] std::filesystem::path robotmk_html_log_directory()
        const override {
        return global_config_.general_.robotmk_html_log_directory_;
    }

    [[nodiscard]] std::filesystem::path logwatch_directory() const override {
        return global_config_.general_.logwatch_directory_;
    }

    [[nodiscard]] std::filesystem::path prediction_directory() const override {
        return global_config_.general_.prediction_directory_;
    }

    [[nodiscard]] std::filesystem::path event_console_status_socket()
        const override {
        return global_config_.general_.event_console_status_socket_;
    }

    [[nodiscard]] std::filesystem::path livestatus_socket() const override {
        return global_config_.livestatus_.socket_;
    }

    [[nodiscard]] std::filesystem::path history_file() const override {
        return global_config_.history_.file_;
    }

    [[nodiscard]] std::filesystem::path history_archive_directory()
        const override {
        return global_config_.history_.archive_directory_;
    }

    [[nodiscard]] std::filesystem::path rrd_multiple_directory()
        const override {
        return global_config_.rrd_.multiple_directory_;
    }

    [[nodiscard]] std::filesystem::path rrdcached_socket() const override {
        return global_config_.rrd_.rrdcached_socket_;
    }

private:
    const GlobalConfig &global_config_;
};

#endif  // CmcPaths_h
