// Copyright (C) 2023 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef CmcTimeperiod_h
#define CmcTimeperiod_h

#include "cmc/Timeperiod.h"
#include "livestatus/Interface.h"

class CmcTimeperiod : public ITimeperiod {
public:
    explicit CmcTimeperiod(const Timeperiod &timeperiod)
        : timeperiod_{timeperiod} {}
    [[nodiscard]] std::string name() const override {
        return timeperiod_.name();
    }
    [[nodiscard]] std::string alias() const override {
        return timeperiod_.alias();
    }
    [[nodiscard]] bool isActive() const override {
        return timeperiod_.isActive();
    }
    [[nodiscard]] std::vector<std::chrono::system_clock::time_point>
    transitions(std::chrono::seconds timezone_offset) const override {
        std::vector<std::chrono::system_clock::time_point> result;
        std::transform(
            timeperiod_.begin(), timeperiod_.end(), std::back_inserter(result),
            [timezone_offset](std::chrono::system_clock::time_point v) {
                return timezone_offset + v;
            });
        return result;
    }

    [[nodiscard]] int32_t numTransitions() const override {
        return timeperiod_.numTransitions();
    }

    [[nodiscard]] int32_t nextTransitionId() const override {
        return timeperiod_.nextTransition();
    }

    [[nodiscard]] std::chrono::system_clock::time_point nextTransitionTime()
        const override {
        return timeperiod_.nextTransitionTime();
    }

private:
    const Timeperiod &timeperiod_;
};

#endif  // CmcTimeperiod_h
