// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef Comment_h
#define Comment_h

#include <chrono>
#include <cstdint>
#include <iosfwd>
#include <string>

class Object;
class World;

class Comment {
public:
    // queried in comments table
    enum class Type : uint32_t {
        user = 1,
        downtime = 2,
        flapping = 3,
        acknowledgement = 4
    };

    // queried in comments table
    enum class Source : uint32_t {
        // default, even for ACKNOWLEDGE_HOST_PROBLEM / ACKNOWLEDGE_SVC_PROBLEM
        internal = 0,
        // only for user comments, i.e. via ADD_HOST_COMMENT / ADD_SVC_COMMENT
        external = 1
    };

    // modified in Comments::migrate
    const Object *_object;
    const uint32_t _id;
    const std::chrono::system_clock::time_point _entry_time;
    const std::string _author;
    const std::string _comment;
    const Type _entry_type;
    // modified in Comments::unlocked_removeAcknowledgements
    std::chrono::system_clock::time_point _expire_time;
    const bool _persistent;
    const bool _sticky;
    const Source _source;

    [[nodiscard]] bool operator==(const Comment &other) const {
        return _object == other._object && _id == other._id &&
               _entry_time == other._entry_time && _author == other._author &&
               _comment == other._comment && _entry_type == other._entry_type &&
               _expire_time == other._expire_time &&
               _persistent == other._persistent && _sticky == other._sticky &&
               _source == other._source;
    }
    [[nodiscard]] bool operator!=(const Comment &other) const {
        return !(*this == other);
    }
    [[nodiscard]] bool expires() const;
    [[nodiscard]] bool isExpired(
        std::chrono::system_clock::time_point when) const;
    bool migrate(const World &world);
};

std::ostream &operator<<(std::ostream &os, const Comment::Type &t);
std::ostream &operator<<(std::ostream &os, const Comment::Source &s);
std::ostream &operator<<(std::ostream &os, const Comment &c);

#endif  // Comment_h
