// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef Comments_h
#define Comments_h

#include <chrono>
#include <cstddef>
#include <cstdint>
#include <functional>
#include <memory>
#include <mutex>
#include <string>
#include <unordered_map>
#include <unordered_set>
#include <utility>

#include "cmc/Comment.h"

class Logger;
class MonitoringLog;
class Object;
class Triggers;
class World;

class Comments {
    using container_type =
        std::unordered_map<uint32_t, std::unique_ptr<Comment>>;

public:
    using key_type = container_type::key_type;
    using value_type = container_type::value_type;
    using size_type = container_type::size_type;
    Comments(Triggers &triggers, Logger *logger, MonitoringLog &monitoring_log)
        : triggers_{triggers}
        , logger_{logger}
        , monitoring_log_{monitoring_log} {}
    bool migrate(const World &world);
    void expire(std::chrono::time_point<std::chrono::system_clock> now);
    void removeAcknowledgements(
        const std::unordered_set<const Object *> &objects,
        const std::string &how);
    void insert(std::unique_ptr<Comment> comment);
    size_t remove(const std::unordered_set<key_type> &ids);
    void clear();
    std::pair<std::string, std::string> findAcknowledgement(
        const Object &object) const;
    bool all_of_unlocked(
        const std::function<bool(const Comment &)> &pred) const;
    bool all_of(const std::function<bool(const Comment &)> &pred) const;
    [[nodiscard]] size_type size() const;
    [[nodiscard]] bool empty() const { return size() == 0; }
    uint32_t next_id_ = 1;

private:
    container_type comments_;
    mutable std::mutex lock_;
    Triggers &triggers_;
    mutable Logger *logger_;
    MonitoringLog &monitoring_log_;

    size_t unlocked_remove(const std::unordered_set<key_type> &ids);
    void unlocked_removeAcknowledgements(
        const std::unordered_set<const Object *> &objects,
        const std::string &how);
};

#endif  // Comments_h
