// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef ContactGroup_h
#define ContactGroup_h

#include <functional>
#include <string>
#include <unordered_set>
#include <utility>
#include <vector>

#include "cmc/CmcContactGroup.h"
class IContactGroup;

class ContactGroup {
public:
    ContactGroup(std::string name, std::string alias)
        : name_{std::move(name)}
        , alias_{std::move(alias)}
        , icontactgroup_{*this} {}
    // icontactgroup_ points back to ourselves, so the defaulted copy/move
    // operations are wrong. Instead of implementing them, we're lazy...
    ContactGroup(const ContactGroup &) = delete;
    ContactGroup &operator=(const ContactGroup &) = delete;

    const IContactGroup &icontactgroup() const { return icontactgroup_; }
    std::string name() const { return name_; }
    std::string alias() const { return alias_; }
    void insert(const std::string &contact_name);
    bool isMember(const std::string &contact_name) const;
    std::vector<std::string> contactNames() const;
    bool operator==(const ContactGroup &other) const;
    bool operator!=(const ContactGroup &other) const {
        return !(*this == other);
    }

private:
    std::string name_;
    std::string alias_;
    std::unordered_set<std::string> contact_names_;
    CmcContactGroup icontactgroup_;
};

#endif  // ContactGroup_h
