// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef ContactList_h
#define ContactList_h

#include <string>
#include <unordered_set>
#include <vector>

class ContactGroup;
class World;

class ContactList {
public:
    ContactList(std::unordered_set<std::string> contact_names,
                std::vector<std::string> &contact_groups, const World *world);

    bool isMember(const std::string &contact_name) const;
    std::vector<std::string> contactNames() const;

    bool isMember(const ContactGroup *group) const;
    std::vector<std::string> groupNames() const;
    std::vector<const ContactGroup *> groups() const;

    bool operator==(const ContactList &other) const;
    bool operator!=(const ContactList &other) const {
        return !(*this == other);
    }

private:
    // NOTE: contact_names_ is redundant, it just contains all contacts in all
    // _groups. It's here only for efficiency reasons.
    std::unordered_set<std::string> contact_names_;
    std::unordered_set<const ContactGroup *> _groups;
};

#endif  // ContactList_h
