// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef CycleTime_h
#define CycleTime_h

#include <chrono>
#include <cstdint>
#include <iosfwd>
class Logger;

namespace detail {
std::chrono::seconds dst_shift_between(std::chrono::system_clock::time_point a,
                                       std::chrono::system_clock::time_point b);
}  // namespace detail

class CycleTime {
public:
    // queried in downtimes table
    enum class Kind : uint32_t {
        none = 0,
        hourly = 1,
        daily = 2,
        weekly = 3,
        biweekly = 4,
        every_4weeks = 5,
        nth_weekday = 6,
        nth_weekday_from_end = 7,
        day_of_month = 8,
        every_5min = 999  // just for testing
    };

    CycleTime(uint16_t kind_code, Logger *logger)
        : _kind(toKind(kind_code, logger)), _logger(logger) {}
    CycleTime(Kind kind, Logger *logger) : _kind(kind), _logger(logger) {}
    [[nodiscard]] uint16_t getKindCode() const { return fromKind(_kind); }
    [[nodiscard]] Kind getKind() const { return _kind; }
    [[nodiscard]] bool isRecurring() const { return _kind != Kind::none; }
    [[nodiscard]] std::chrono::seconds next(
        std::chrono::system_clock::time_point from) const;

    friend bool operator==(const CycleTime &lhs, const CycleTime &rhs) {
        return lhs._kind == rhs._kind;
    }

    friend std::ostream &operator<<(std::ostream &os, const CycleTime &c);

private:
    Kind _kind;
    Logger *_logger;

    static Kind toKind(uint16_t i, Logger *logger);
    static constexpr uint16_t fromKind(Kind kind) {
        return static_cast<uint16_t>(kind);
    }
};

inline bool operator!=(const CycleTime &lhs, const CycleTime &rhs) {
    return !(lhs == rhs);
}

#endif  // CycleTime_h
