// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef Downtimes_h
#define Downtimes_h

#include <chrono>
#include <cstddef>
#include <cstdint>
#include <functional>
#include <memory>
#include <mutex>
#include <unordered_map>
#include <unordered_set>

#include "cmc/Downtime.h"

class Core;
class Logger;
class Triggers;
class World;

class Downtimes {
    using container_type =
        std::unordered_map<uint32_t, std::unique_ptr<Downtime>>;

public:
    using key_type = container_type::key_type;
    using value_type = container_type::value_type;
    using size_type = container_type::size_type;
    Downtimes(Triggers &triggers, Logger *logger);
    bool migrate(const World &world);
    void expire(std::chrono::time_point<std::chrono::system_clock> now);
    void insert(std::unique_ptr<Downtime> downtime);
    bool modify(
        const key_type &id,
        const std::function<std::unique_ptr<Downtime>(const Downtime &)> &f);
    size_t remove(const std::unordered_set<key_type> &ids);
    void clear();
    bool all_of_unlocked(
        const std::function<bool(const Downtime &)> &pred) const;
    bool all_of(const std::function<bool(const Downtime &)> &pred) const;
    bool all_of(const std::function<bool(Downtime &)> &pred);
    void handleChangedDowntimeRules(std::chrono::system_clock::time_point now,
                                    Core &core);
    [[nodiscard]] size_type size() const;
    // validateDepths: not locked
    void validateDepths(const World *world);
    uint32_t next_id_ = 1;

private:
    container_type downtimes_;
    Triggers &triggers_;
    mutable Logger *logger_;
    mutable std::mutex lock_;
};

#endif
