// Copyright (C) 2022 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef EventSpooler_h
#define EventSpooler_h

#include <cstddef>
#include <deque>
#include <functional>
#include <mutex>
#include <string>

class Logger;

class EventSpooler {
public:
    using payload = std::string;

    explicit EventSpooler(Logger *logger);
    void spool(const payload &event);
    payload unspool();
    void clear();
    size_t size() const;
    bool empty() const;
    void for_each(const std::function<void(const payload &)> &func) const;

private:
    Logger *logger_;
    mutable std::mutex lock_;  // protects events_
    std::deque<payload> events_;

    void log(const std::string &action, const payload &event);
};

#endif
