// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef FetcherHelperChannel_h
#define FetcherHelperChannel_h

#include <sys/types.h>

#include <chrono>
#include <cstddef>
#include <iosfwd>
#include <optional>
#include <string>
#include <variant>

#include "cmc/MessagePayload.h"
#include "cmc/SerialToken.h"
class Logger;
enum class LogLevel;

class FetcherMessageHeader {
public:
    static constexpr size_t size = 40;
    enum class Kind { result, log, end_of_reply };

    explicit FetcherMessageHeader(std::istream &is);

    [[nodiscard]] Kind kind() const { return kind_; }
    [[nodiscard]] std::optional<LogLevel> log_level() const {
        return log_level_;
    }
    [[nodiscard]] size_t payload_length() const { return payload_length_; }

private:
    Kind kind_;
    std::optional<LogLevel> log_level_;
    size_t payload_length_;
};

namespace fetcher::protocol {
struct Request {
    config_serial_t serial_;
    std::string host_;
    std::string mode_;
    std::chrono::seconds timeout_;
};

struct Incomplete {};

struct Failure {
    int error;
};

struct Result {
    MessagePayload payload;
};

struct Log {
    LogLevel log_level;
    MessagePayload message;
};

struct EndOfReply {};

using Message = std::variant<Incomplete, Failure, Result, Log, EndOfReply>;
}  // namespace fetcher::protocol

std::ostream &operator<<(std::ostream &os, const fetcher::protocol::Request &r);

class FetcherHelperChannel {
public:
    explicit FetcherHelperChannel(Logger *logger) : logger_{logger} {}
    void reset();

    ssize_t send(int std_in, const fetcher::protocol::Request &request) const;
    fetcher::protocol::Message receive(int std_out);

private:
    mutable Logger *logger_;
    std::optional<MessagePayloadReceiver> header_;
    std::optional<FetcherMessageHeader> parsed_header_;
    std::optional<MessagePayloadReceiver> payload_;

    fetcher::protocol::Message buildMessage();
};

#endif  // FetcherHelperChannel_h
