// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef FetcherReply_h
#define FetcherReply_h

#include <chrono>
#include <memory>
#include <queue>
#include <utility>

#include "cmc/MessagePayload.h"
#include "cmc/SerialToken.h"
class Logger;
class Object;
class World;

class FetcherReply {
public:
    FetcherReply(MessagePayload payload,
                 std::chrono::nanoseconds remaining_time,
                 SerialToken serial_token, Object *object)
        : payload_{std::move(payload)}
        , remaining_time_{remaining_time}
        , serial_token_{std::move(serial_token)}
        , object_{object} {}

    bool migrate(const World &world);

    MessagePayload payload_;
    std::chrono::nanoseconds remaining_time_;
    SerialToken serial_token_;
    Object *object_;
};

// TODO(sp) Delegate
class FetcherReplyQueue : public std::queue<std::unique_ptr<FetcherReply>> {
public:
    explicit FetcherReplyQueue(Logger *logger) : logger_{logger} {}
    bool migrate(const World &world);

private:
    Logger *logger_;
};

#endif  // FetcherReply_h
