// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef Histcache_h
#define Histcache_h

#include <chrono>
#include <cstddef>
#include <deque>
#include <mutex>

#include "cmc/HistcacheEntry.h"
class Logger;

class Histcache {
public:
    std::mutex _lock;

    HistcacheEntry *oldestEntry();
    HistcacheEntry youngestEntry();
    HistcacheEntry *entry(size_t i) { return &_cache[i]; }
    int findEntryBefore(std::chrono::system_clock::time_point since);
    size_t size() { return _cache.size(); }
    void prependEntry(const HistcacheEntry &hce);  // add new oldest entry
    void appendEntry(const HistcacheEntry &hce);   // add new newest entry
    void mergeOldStates();
    void finalize();  // merge where possible, complete plugin outputs

    void dump(Logger *logger);  // for debugging

private:
    // Entries are sorted from old to new. New entries are appended.
    std::deque<HistcacheEntry> _cache;
};

#endif  // Histcache_h
