// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef HistcacheEntry_h
#define HistcacheEntry_h

#include <chrono>
#include <cstdint>
#include <string>
#include <string_view>

class Logger;

class HistcacheEntry {
public:
    struct Bits {
        int8_t _state{};
        bool _flapping{};
        bool _in_downtime{};
        bool _know_state{};
        bool _know_downtime{};
        bool _know_flapping{};
    };

    // NOTE: We are *not* the owner of the two strings below, they are owned by
    // the _strings hash in StateHistoryThread.
    std::string_view _plugin_output;
    std::string_view _long_plugin_output;
    std::chrono::system_clock::time_point _timestamp{};
    Bits _bits;

    void dump(int index, std::chrono::system_clock::duration delta_time,
              Logger *logger) const;
};

inline bool operator==(const HistcacheEntry::Bits &lhs,
                       const HistcacheEntry::Bits &rhs) {
    return lhs._state == rhs._state &&                  //
           lhs._flapping == rhs._flapping &&            //
           lhs._in_downtime == rhs._in_downtime &&      //
           lhs._know_state == rhs._know_state &&        //
           lhs._know_downtime == rhs._know_downtime &&  //
           lhs._know_flapping == rhs._know_flapping;
}

inline bool operator!=(const HistcacheEntry::Bits &lhs,
                       const HistcacheEntry::Bits &rhs) {
    return !(lhs == rhs);
}

inline bool operator==(const HistcacheEntry &lhs, const HistcacheEntry &rhs) {
    return lhs._plugin_output == rhs._plugin_output &&
           lhs._long_plugin_output == rhs._long_plugin_output &&
           lhs._timestamp == rhs._timestamp &&  //
           lhs._bits == rhs._bits;
}

inline bool operator!=(const HistcacheEntry &lhs, const HistcacheEntry &rhs) {
    return !(lhs == rhs);
}

#endif  // HistcacheEntry_h
