// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef ICMPReceiver_h
#define ICMPReceiver_h

#include <netinet/in.h>

#include <chrono>
#include <cstddef>
#include <functional>
#include <string>
#include <vector>

#include "cmc/ProcessHelper.h"

class CheckResult;
class Logger;
class Poller;
class SmartPingConfig;
class World;

class ICMPReceiver : public ProcessHelper {
public:
    using result_handler_t = std::function<void(
        std::chrono::system_clock::time_point, const CheckResult &)>;

    explicit ICMPReceiver(std::string name, Logger *logger,
                          result_handler_t result_handler);
    ~ICMPReceiver() override;

    /// Return true if the current config was modified.
    bool updateConfig(const World *world);

private:
    const World *_world = nullptr;
    result_handler_t result_handler_;

    std::vector<char> _buffer;
    size_t _start = 0;

    // AbstractHelper/ProcessHelper API
    void start_() override;
    void stop_() override;
    void setUpPoller_(Poller &poller) const override;
    void communicate_(const Poller &poller) override;

    bool updateConfig(const SmartPingConfig &smart_ping);
    void readResults();
    in_addr_t nextResult();

    void do_stop();

    void handleStdOut();
    void handleStdErr();
};

#endif  // ICMPReceiver_h
