// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef ICMPSender_h
#define ICMPSender_h

#include <netinet/in.h>

#include <string>
#include <vector>

#include "cmc/ProcessHelper.h"

class Core;
class Host;
class Logger;
template <typename T>
class Schedule;
class SmartPingConfig;
class Poller;
class World;

class ICMPSender : public ProcessHelper {
public:
    explicit ICMPSender(std::string name, Logger *);
    ~ICMPSender() override;

    bool updateConfig(const World *world);
    void schedule(Schedule<Host *> &schedule, Core &core);

private:
    std::vector<char> _queue;

    // AbstractHelper/ProcessHelper API
    void start_() override;
    void stop_() override;
    void setUpPoller_(Poller &poller) const override;
    void communicate_(const Poller &poller) override;

    void handleStdIn();
    void handleStdErr();

    [[nodiscard]] bool queueFull() const;
    [[nodiscard]] bool queueEmpty() const;
    void queuePing(in_addr_t a);

    bool updateConfig(const SmartPingConfig &smart_ping);
    void do_stop();
};

#endif  // ICMPSender_h
