// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef InfluxDBSender_h
#define InfluxDBSender_h

#include <cstddef>
#include <memory>
#include <string>
#include <utility>
#include <vector>

#include "cmc/InfluxDBConfig.h"

class Logger;
namespace influxdb {
struct LineProtocol;
}  // namespace influxdb

namespace influxdb {

class SenderImpl {
public:
    virtual ~SenderImpl() = default;

    virtual bool get(const std::string &uri,
                     const influxdb::Headers &headers) = 0;

    virtual bool get_noauth(const std::string &uri) = 0;

    virtual std::pair<bool, std::size_t> post(
        const std::string &uri, const influxdb::Headers &headers,
        const std::string &content, const std::string &content_type) = 0;

    [[nodiscard]] virtual bool connected() const = 0;
};

class Sender {
    constexpr static auto post_uri_ = "write?";
    constexpr static auto ping_uri_ = "/ping";
    constexpr static auto content_type_ = "gzip";

public:
    Sender(const influxdb::ConnectionConfig &, Logger *logger);
    [[nodiscard]] bool ping() const;
    [[nodiscard]] std::pair<bool, std::size_t> post(
        const SenderConfig &sender_config,
        const std::vector<LineProtocol> &) const;
    [[nodiscard]] bool connected() const;

private:
    const influxdb::ConnectionConfig config_;
    std::unique_ptr<SenderImpl> impl_;
    [[nodiscard]] std::pair<bool, std::size_t> post(
        const SenderConfig &sender_config, const std::string &) const;
};

}  // namespace influxdb

#endif
