// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef Livestatus_h
#define Livestatus_h

#include <cstddef>
#include <cstdint>
#include <list>
#include <memory>
#include <string>

#include "cmc/AbstractHelper.h"
#include "cmc/LivestatusThread.h"
class Core;
class Poller;

class Livestatus : public AbstractHelper {
public:
    explicit Livestatus(Core *core);
    ~Livestatus() override;
    [[nodiscard]] size_t numThreads() const { return _threads.size(); }
    void adaptThreadCount(uint32_t target);

private:
    Core *_core;
    int _sock;  // UNIX socket for client access
    std::string _socket_path;
    using threads = std::list<std::unique_ptr<LivestatusThread>>;
    threads _threads;

    // AbstractHelper API
    void start_() override;
    void stop_() override;
    void setUpPoller_(Poller &poller) const override;
    void communicate_(const Poller &poller) override;

    int sock() const;
    void acceptClient();
    void do_stop();

    void createUnixSocket();
    void removeUnixSocket();
    threads::iterator getFreeLivestatusThread();
    threads::const_iterator getFreeLivestatusThread() const;
    std::string getThreadID();
    void createThread();
    void removeThread(threads::iterator it);
};

#endif  // Livestatus_h
