// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef LivestatusExternalCommand_h
#define LivestatusExternalCommand_h

#include <algorithm>
#include <cstddef>
#include <functional>
#include <string>

#include "asio/local/stream_protocol.hpp"
#include "cmc/AbstractHelper.h"
#include "livestatus/Queue.h"
namespace asio {
class io_context;
}  // namespace asio
class Logger;
class Poller;

class LivestatusExternalCommand : public AbstractHelper {
    // Command queue for commands received via livestatus
    using CommandSpool_t = Queue<std::string>;
    using continuation_type = std::function<void(const std::string &)>;
    using socket_type = asio::local::stream_protocol::socket;

public:
    LivestatusExternalCommand(asio::io_context &, continuation_type, Logger *);
    ~LivestatusExternalCommand() override;

    void spoolCommand(const std::string &command);
    [[nodiscard]] bool active() const;
    [[nodiscard]] size_t queueSize() const;
    [[nodiscard]] size_t commandCount() const;

private:
    size_t _num_queued_commands_max = 0;

    socket_type _command_pop;
    socket_type _command_push;
    CommandSpool_t _command_spool;
    continuation_type _continuation;

    // AbstractHelper API
    void start_() override;
    void stop_() override;
    void setUpPoller_(Poller &poller) const override;
    void communicate_(const Poller &poller) override;
    int command_pop_fd() const;

    void handleExternalCommands();
    void do_stop();
};

#endif
