// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef LivestatusLocalCommand_h
#define LivestatusLocalCommand_h

#include <cstddef>
#include <filesystem>
#include <functional>
#include <string>

#include "cmc/AbstractHelper.h"
class LivestatusConfig;
class Logger;
class Poller;
class World;

class LivestatusLocalCommand : public AbstractHelper {
    using continuation_type = std::function<void(const std::string &)>;

public:
    LivestatusLocalCommand(continuation_type, std::filesystem::path endpoint,
                           Logger *);
    LivestatusLocalCommand(continuation_type, Logger *);
    ~LivestatusLocalCommand() override;
    bool updateConfig(const World *world);
    void answerCommandRequest(const std::string &command);

private:
    continuation_type continuation_;
    std::filesystem::path endpoint_;
    int pipe_ = -1;
    char buffer_[8192];
    size_t buffer_size_{0};

    // AbstractHelper API
    void start_() override;
    void stop_() override;
    void setUpPoller_(Poller &poller) const override;
    void communicate_(const Poller &poller) override;

    void do_start();
    void do_stop();
    void handleCommandPipe();
    int socket() const;

    static std::string findCommand(const char *begin, const char *end,
                                   bool pipe_closed);
    void queuePipedCommands(bool pipe_closed);
    bool updateConfig(const LivestatusConfig &livestatus);
};

#endif
