// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef LivestatusThread_h
#define LivestatusThread_h

#include <pthread.h>

#include <atomic>
#include <mutex>
#include <string>
#include <vector>

#include "livestatus/POSIXUtils.h"
class Core;
class InputBuffer;
class Logger;
class OutputBuffer;

class LivestatusThread {
public:
    LivestatusThread(Core *core, std::string thread_id);
    ~LivestatusThread();
    void prepareForShutdown();
    [[nodiscard]] std::string getThreadID() const { return _thread_id; }
    bool hasClient() const;
    void acceptClient(int fd);
    void run();

private:
    Core *_core;
    std::string _thread_id;

    mutable std::mutex _client_fd_mutex;
    int _client_fd;

    // TODO(sp) Instead of fiddling around with atomics, mutexes and semaphores,
    // the CMC should really simply use a queue of file descriptors, just like
    // the NEB.
    std::atomic<bool> _should_terminate;
    pthread_t _thread;
    Semaphore _semaphore;
    Logger *const _logger;

    void handleClient();
    void logRequest(const std::string &line,
                    const std::vector<std::string> &lines);
    bool answerRequest(InputBuffer &input, OutputBuffer &output);
    bool handleGet(InputBuffer &input, OutputBuffer &output,
                   const std::string &line, const std::string &table_name);

    int client_fd() const;
    void client_fd(int value);

    bool shouldTerminate() const;
    void shouldTerminate(bool value);
};

#endif  // LivestatusThread_h
