// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef Macro_h
#define Macro_h

#include <chrono>
#include <cstdint>
#include <sstream>
#include <string>
#include <vector>

class Entity;
class Object;

class Macro {
public:
    Macro(std::string name, std::string value);

    // convenience constructors
    Macro(std::string name, uint32_t value);
    Macro(std::string name, std::chrono::system_clock::time_point value);
    Macro(std::string name, const std::vector<std::string> &value);

    friend std::ostream &operator<<(std::ostream &os, const Macro &m);

private:
    std::string _name;
    std::string _value;
};

class CustomMacros {
public:
    CustomMacros(std::string prefix, const Entity &entity);
    friend std::ostream &operator<<(std::ostream &os, const CustomMacros &cm);

private:
    std::string _prefix;
    const Entity &_entity;
};

class ObjectMacros {
public:
    explicit ObjectMacros(const Object &object);
    friend std::ostream &operator<<(std::ostream &os, const ObjectMacros &om);

private:
    const Object &_object;
};

#endif  // Macro_h
