// Copyright (C) 2020 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef MessagePayload_h
#define MessagePayload_h

#include <cstddef>
#include <string_view>
#include <vector>

struct iovec;

class MessagePayload {
public:
    explicit MessagePayload(size_t size) : content_(size) {}
    explicit MessagePayload(std::string_view str)
        : content_{str.cbegin(), str.cend()} {}

    // We do not want to copy a potentially large payload around, just move it.
    MessagePayload(const MessagePayload &) = delete;
    MessagePayload &operator=(const MessagePayload &) = delete;
    MessagePayload(MessagePayload &&) = default;
    MessagePayload &operator=(MessagePayload &&) = default;

    explicit operator std::string_view() const {
        return {content_.data(), content_.size()};
    }

    [[nodiscard]] char *data() { return content_.data(); }

private:
    std::vector<char> content_;
};

class MessagePayloadSender {
public:
    explicit MessagePayloadSender(std::vector<MessagePayload> payloads);
    int send(int fd);  // returns errno, EAGAIN when not complete

private:
    std::vector<MessagePayload> content_;
    size_t total_size_;
    size_t bytes_sent_;

    [[nodiscard]] std::vector<iovec> buildIovs() const;
};

class MessagePayloadReceiver {
public:
    enum class status { complete, partial };
    explicit MessagePayloadReceiver(size_t size) : content{size} {}
    status receive(int fd);
    MessagePayload content;

private:
    size_t bytes_received_{0};
};

#endif  // MessagePayload_h
