// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef MonitoringHistory_h
#define MonitoringHistory_h

#include <chrono>
#include <fstream>
#include <functional>
#include <string>

class HistoryConfig;
class Logger;

class MonitoringHistory {
public:
    MonitoringHistory(Logger *logger, std::function<void()> after_publish);
    ~MonitoringHistory();

    void open(const HistoryConfig &hc);
    void close();
    void log(const std::string &message);
    [[nodiscard]] bool needLogfileRotation(const HistoryConfig &hc) const;
    [[nodiscard]] bool needLogfileRotationTime(const HistoryConfig &hc) const;
    [[nodiscard]] bool needLogfileRotationSize(const HistoryConfig &hc) const;

    Logger *logger_;
    std::function<void()> after_publish_;
    std::ofstream stream_;
    std::chrono::system_clock::time_point last_rotation_;
};

#endif  // MonitoringHistory_h
