// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef MonitoringLog_h
#define MonitoringLog_h

#include <functional>
#include <string>
#include <utility>

enum class LogStateType;
struct NotificationInfo;
class Object;

class MonitoringLog {
public:
    explicit MonitoringLog(std::function<void(const std::string &)> sink);

    void acknowledgeAlert(const Object &object, const std::string &state_type,
                          const std::string &author,
                          const std::string &comment);
    void alert(const Object &object);
    void downtimeAlert(const Object &object, const std::string &state_type,
                       const std::string &comment);
    void flappingAlert(const Object &object);
    void state(const Object &object, LogStateType log_state_type);
    void vanished(const Object &object);
    void timeperiodTransition(const std::string &name, int from, int to);
    void coreStarting();
    void coreStopping();
    void logVersion();
    void logInitialStates();
    void info(const std::string &line);
    void extCommand(const std::string &command);
    void notification(const std::string &contact_name,
                      const NotificationInfo &info);
    void alertHandlerStarted(const Object &object,
                             const std::string &handler_name);
    void alertHandlerStopped(const Object &object,
                             const std::string &handler_name,
                             const std::string &exit_code,
                             const std::string &output);
    void sink(std::function<void(const std::string &)> f) {
        sink_ = std::move(f);
    }
    // See also `livestatus::LogEntry::encode()`
    static std::string decode(const std::string &str);

private:
    std::function<void(const std::string &)> sink_;
};

#endif  // MonitoringLog_h
