// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef NotifyHelper_h
#define NotifyHelper_h

#include <functional>
#include <iosfwd>
#include <map>
#include <string>
#include <unordered_set>
#include <utility>
#include <vector>

#include "cmc/ProcessHelper.h"
#include "cmc/Producer.h"

class Contact;
class EventSpooler;
class Logger;
class MonitoringLog;
class Object;
class Poller;
class World;

// TODO(sp) Add struct for author/comment? Or use "newtypes"?
using CommentsFinder =
    std::function<std::pair<std::string, std::string>(const Object &)>;

struct NotificationInfo {
    NotificationInfo(const Object &object, std::string type, std::string author,
                     std::string comment,
                     std::map<std::string, std::string> extra_macros)
        : _object(object)
        , _type(std::move(type))
        , _author(std::move(author))
        , _comment(std::move(comment))
        , _extra_macros(std::move(extra_macros)) {}

    const Object &_object;
    const std::string _type;
    const std::string _author;
    const std::string _comment;
    const std::map<std::string, std::string> _extra_macros;
};

class NotifyHelper : public ProcessHelper {
public:
    NotifyHelper(std::string name, Logger *logger,
                 CommentsFinder comments_finder, MonitoringLog &monitoring_log,
                 EventSpooler &spooler);
    ~NotifyHelper() override;

    bool updateConfig(const World *world);
    void tryToSendEvent();
    void notify(const NotificationInfo &info);
    void broadcast(const NotificationInfo &info);

private:
    std::unordered_set<const Contact *> _contacts;
    CommentsFinder _comments_finder;
    MonitoringLog &monitoring_log_;
    ChunkProducer _stdout_consumer;
    bool _helper_ready;
    EventSpooler &spooler_;

    // AbstractHelper/ProcessHelper API
    void start_() override;
    void stop_() override;
    void setUpPoller_(Poller &poller) const override;
    void communicate_(const Poller &poller) override;

    void handleStdOut();

    void do_stop();

    void do_notify(const std::vector<std::string> &contact_names,
                   const NotificationInfo &info);

    void addMacros(std::ostream &os, const NotificationInfo &info);
};

#endif  // NotifyHelper_h
