// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef PNPXMLWriter_h
#define PNPXMLWriter_h

#include <chrono>
#include <filesystem>
#include <fstream>
#include <map>
#include <mutex>
#include <random>
#include <string>

class Logger;
class Metric;
class Object;
class PerformanceData;
class RRDConfig;

class PNPXMLWriter {
public:
    explicit PNPXMLWriter(Logger *logger);

    bool updateConfig(const RRDConfig &rrd);
    void start();
    void stop();
    void restart();
    Logger *logger();

    void process(const PerformanceData &perf_data, const Object *object);

private:
    class WriteTimeCache {
    public:
        void clear();

        std::filesystem::file_time_type last_write_time(
            const std::filesystem::path &path);
        void forget(const std::filesystem::path &path);

    private:
        // The mutex protects _write_times.
        std::mutex _mutex;
        std::map<std::filesystem::path, std::filesystem::file_time_type>
            _write_times;
    };

    std::filesystem::file_time_type _last_world_change;
    std::chrono::seconds _update_delay{0};
    bool _update_on_restart = false;

    std::default_random_engine _random_engine;
    WriteTimeCache _write_time_cache;
    Logger *const _logger;

    bool isUpToDate(const Object *object);
    std::chrono::nanoseconds spreadDelay();
    void open(std::ofstream &os, const Object *object);
    static void add(std::ostream &os, const Object *object,
                    const Metric &metric, const std::string &pnp_template);
    void close(std::ofstream &os, const PerformanceData &perf_data,
               const Object *object);

    static std::filesystem::path pathFor(const Object *object);
    static std::filesystem::path newPathFor(const Object *object);
};

[[nodiscard]] inline Logger *PNPXMLWriter::logger() { return _logger; }

inline void PNPXMLWriter::restart() {
    stop();
    start();
}

#endif  // PNPXMLWriter_h
