// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef PbConfigLoader_h
#define PbConfigLoader_h

#include <cstdint>
#include <filesystem>
#include <map>
#include <memory>
#include <string>
#include <utility>

namespace checkmk::cmc::config::v1 {
class AlertHandler;
class Carbon;
class CarbonConnection;
class CarbonSendMetricParts;
class Checking;
class Contact;
class ContactGroup;
class ContactList;
class Core;
class Entity;
class General;
class Global;
enum GroupAuthorization : int;
class History;
class Host;
class InfluxDb;
class InfluxDbConnection;
class InfluxDbSender;
class Livestatus;
enum LogLevel : int;
class NotificationHandler;
class NotificationOptions;
class Object;
class ObjectGroup;
class Offsets;
class Path;
class PersistentRecurringDowntime;
class RRD;
enum RRDFormat : int;
class Service;
enum ServiceAuthorization : int;
class SmartPing;
class StringPool;
class Timeperiod;
}  // namespace checkmk::cmc::config::v1

class AlertHandlerConfig;
class CarbonConfig;
class CarbonConnectionConfig;
class CarbonSendMetricParts;
class CheckingConfig;
class Contact;
class ContactGroup;
class ContactList;
class Core;
class Entity;
class GeneralConfig;
class GlobalConfig;
class HistoryConfig;
class Host;
class InfluxDbConfig;
class Logger;
class LivestatusConfig;
class NotificationHandlerConfig;
class Object;
class DowntimeRule;
class RegExp;
class RRDConfig;
class SmartPingConfig;
class Service;
class Timeperiod;
class World;
enum class GroupAuthorization;
enum class HostState;
enum class LogLevel;
enum class NotificationOptions : uint32_t;
enum class RRDFormat;
enum class ServiceAuthorization;
enum class ServiceState;
namespace influxdb {
struct ConnectionConfig;
struct SenderConfig;
}  // namespace influxdb

struct PoolOffset {
    uint32_t offset;
};

class PbConfigLoader {
public:
    explicit PbConfigLoader(const checkmk::cmc::config::v1::Core &config);

    [[nodiscard]] GlobalConfig makeGlobalConfig(
        const checkmk::cmc::config::v1::Global &global_config) const;

    [[nodiscard]] GeneralConfig makeGeneral(
        const checkmk::cmc::config::v1::General &general) const;
    [[nodiscard]] AlertHandlerConfig makeAlertHandlerConfig(
        const checkmk::cmc::config::v1::AlertHandler &alert_handler) const;
    [[nodiscard]] SmartPingConfig makeSmartPingConfig(
        const checkmk::cmc::config::v1::SmartPing &smartping) const;
    [[nodiscard]] CheckingConfig makeCheckingConfig(
        const checkmk::cmc::config::v1::Checking &checking) const;
    [[nodiscard]] LivestatusConfig makeLivestatusConfig(
        const checkmk::cmc::config::v1::Livestatus &livestatus) const;
    [[nodiscard]] NotificationHandlerConfig makeNotificationHandlerConfig(
        const checkmk::cmc::config::v1::NotificationHandler
            &notification_handler) const;
    [[nodiscard]] HistoryConfig makeHistoryConfig(
        const checkmk::cmc::config::v1::History &history) const;
    [[nodiscard]] RRDConfig makeRRDConfig(
        const checkmk::cmc::config::v1::RRD &rrd) const;
    [[nodiscard]] InfluxDbConfig makeInfluxDbConfig(
        const checkmk::cmc::config::v1::InfluxDb &influx_db) const;
    [[nodiscard]] CarbonConfig makeCarbonConfig(
        const checkmk::cmc::config::v1::Carbon &carbon) const;

    [[nodiscard]] std::unique_ptr<ContactGroup> makeContactGroup(
        const checkmk::cmc::config::v1::ContactGroup &contact_group) const;
    [[nodiscard]] ContactList makeContactList(
        const checkmk::cmc::config::v1::ContactList &contact_list,
        const World *world) const;
    [[nodiscard]] Timeperiod makeTimeperiod(
        const checkmk::cmc::config::v1::Timeperiod &timeperiod) const;
    [[nodiscard]] Entity makeEntity(
        const checkmk::cmc::config::v1::Entity &entity,
        PoolOffset pool_offset) const;
    [[nodiscard]] Entity makeEntity(
        const checkmk::cmc::config::v1::Entity &entity) const;
    [[nodiscard]] std::unique_ptr<Contact> makeContact(
        const checkmk::cmc::config::v1::Contact &contact, World *world) const;
    [[nodiscard]] std::unique_ptr<Host> makeHost(
        Core &core, World &world,
        const checkmk::cmc::config::v1::Host &host) const;
    void fillObject(Object &o, const checkmk::cmc::config::v1::Object &object,
                    PoolOffset pool_offset, World &world) const;
    [[nodiscard]] std::unique_ptr<Service> makeService(
        Core &core, World &world,
        const checkmk::cmc::config::v1::Service &service, Host &host,
        PoolOffset pool_offset) const;

    [[nodiscard]] std::string makeString(uint32_t ref) const;
    [[nodiscard]] std::string makeString(uint32_t ref,
                                         PoolOffset pool_offset) const;
    [[nodiscard]] std::filesystem::path makePath(
        const checkmk::cmc::config::v1::Path &path_ref) const;

    [[nodiscard]] LogLevel makeLogLevel(
        checkmk::cmc::config::v1::LogLevel log_level) const;
    [[nodiscard]] ServiceAuthorization makeServiceAuthorization(
        checkmk::cmc::config::v1::ServiceAuthorization sa) const;
    [[nodiscard]] GroupAuthorization makeGroupAuthorization(
        checkmk::cmc::config::v1::GroupAuthorization ga) const;
    [[nodiscard]] influxdb::ConnectionConfig makeInfluxDbConnection(
        const checkmk::cmc::config::v1::InfluxDbConnection &connection) const;
    [[nodiscard]] CarbonConnectionConfig makeCarbonConnection(
        const checkmk::cmc::config::v1::CarbonConnection &connection) const;
    [[nodiscard]] NotificationOptions makeNotificationOptions(
        const checkmk::cmc::config::v1::NotificationOptions &options) const;
    [[nodiscard]] RRDFormat makeRRDFormat(
        checkmk::cmc::config::v1::RRDFormat rrd_format) const;
    [[nodiscard]] CarbonSendMetricParts makeCarbonSendMetricParts(
        const checkmk::cmc::config::v1::CarbonSendMetricParts &metrics) const;
    [[nodiscard]] influxdb::SenderConfig makeInfluxDbSenderConfig(
        const checkmk::cmc::config::v1::InfluxDbSender &sender,
        PoolOffset pool_offset) const;
    [[nodiscard]] DowntimeRule makeDowntimeRule(
        const checkmk::cmc::config::v1::PersistentRecurringDowntime &downtime,
        PoolOffset pool_offset, Logger *logger) const;
    [[nodiscard]] HostState makeHostState(uint32_t host_state) const;
    [[nodiscard]] ServiceState makeServiceState(uint32_t service_state) const;
    [[nodiscard]] std::pair<std::string, std::string> makeObjectGroup(
        const checkmk::cmc::config::v1::ObjectGroup &group) const;

private:
    const checkmk::cmc::config::v1::StringPool &string_pool_;
    const checkmk::cmc::config::v1::Offsets &string_pool_offsets_;
    const checkmk::cmc::config::v1::Offsets &contact_list_pool_offsets_;
    mutable std::map<std::string, std::shared_ptr<RegExp>> regex_cache_;
    std::shared_ptr<RegExp> makeRegex(uint32_t ref, PoolOffset pool_offset,
                                      Logger *logger) const;
};

#endif  // PbConfigLoader_h
