// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include <chrono>

#include "google/protobuf/duration.pb.h"
#include "livestatus/ChronoUtils.h"

namespace mk {
// More helpful than the Google TimeUtil.
inline std::chrono::nanoseconds ToChronoNanos(
    const google::protobuf::Duration &duration) {
    return std::chrono::seconds{duration.seconds()} +
           std::chrono::nanoseconds{duration.nanos()};
}

inline google::protobuf::Duration ToProtoNanos(
    std::chrono::nanoseconds duration) {
    auto out = google::protobuf::Duration{};
    out.set_seconds(mk::ticks<std::chrono::seconds>(duration));
    out.set_nanos(mk::ticks<std::chrono::nanoseconds>(duration) %
                  1'000'000'000);
    return out;
}

inline std::chrono::seconds ToChronoSeconds(
    const google::protobuf::Duration &duration) {
    return std::chrono::duration_cast<std::chrono::seconds>(
        ToChronoNanos(duration));
}

inline google::protobuf::Duration ToProtoSeconds(
    std::chrono::seconds duration) {
    auto out = google::protobuf::Duration{};
    out.set_seconds(duration.count());
    return out;
}

inline std::chrono::microseconds ToChronoMicros(
    const google::protobuf::Duration &duration) {
    return std::chrono::duration_cast<std::chrono::microseconds>(
        ToChronoNanos(duration));
}
}  // namespace mk
