// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef PbStateLoader_h
#define PbStateLoader_h

namespace checkmk::cmc::state::v1 {
class Comment;
class Downtime;
class GlobalState;
class Hosts;
class State;
class StateFile;
}  // namespace checkmk::cmc::state::v1
class Core;
class Comment;
class Downtime;
class GlobalState;
class Logger;
class Object;
class ObjectResolver;
struct State;

struct Count {
    int &num_host_states_loaded;
    int &num_hosts_vanished;
    int &num_service_states_loaded;
    int &num_services_vanished;
    void reset() {
        num_host_states_loaded = num_hosts_vanished =
            num_service_states_loaded = num_services_vanished = 0;
    }
};

class PbStateLoader {
public:
    static void loadStateFile(
        Core &core, const ObjectResolver &resolver,
        const checkmk::cmc::state::v1::StateFile &state_file, Count count,
        Logger *logger);
    static void loadHosts(const ObjectResolver &resolver,
                          const checkmk::cmc::state::v1::Hosts &pb_hsts,
                          Count count, Logger *logger);
    [[nodiscard]] static GlobalState loadGlobalState(
        const checkmk::cmc::state::v1::GlobalState &global_state);
    [[nodiscard]] static Comment loadComment(
        const Object &object, const checkmk::cmc::state::v1::Comment &comment);
    [[nodiscard]] static Downtime loadDowntime(
        const Object &object, Core &core,
        const checkmk::cmc::state::v1::Downtime &downtime);
    [[nodiscard]] static State loadState(
        const checkmk::cmc::state::v1::State &state);
};

#endif  // PbStateLoader_h
