// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef Process_h
#define Process_h

#include <sys/types.h>

#include <filesystem>
#include <iosfwd>
#include <string>
#include <vector>
class Logger;

class Process {
public:
    Process(std::filesystem::path path, std::vector<std::string> args,
            int fd_in, int fd_out, int fd_err, Logger *logger);
    ~Process();

    Process(const Process &) = delete;
    Process &operator=(const Process &) = delete;
    Process(Process &&) = delete;
    Process &operator=(Process &&) = delete;

    // API adapted from boost::process::child
    [[nodiscard]] pid_t id() const;
    [[nodiscard]] bool joinable() const;
    [[nodiscard]] bool valid() const;
    bool detach();
    void terminate();
    void interrupt();
    void wait();
    void join();
    [[nodiscard]] int exitCode() const;

private:
    std::filesystem::path path_;
    std::vector<std::string> args_;
    int fd_in_ = -1;
    int fd_out_ = -1;
    int fd_err_ = -1;
    pid_t pid_ = -1;
    Logger *logger_;

    bool terminated_ = false;
    int status_ = -1;

    void run();
    void closeSockets();

    friend std::ostream &operator<<(std::ostream &os, const Process &);

    Logger *logger();
};

[[nodiscard]] inline pid_t Process::id() const { return pid_; }
[[nodiscard]] inline bool Process::joinable() const { return this->valid(); }
[[nodiscard]] inline bool Process::valid() const { return this->id() != -1; }
[[nodiscard]] inline Logger *Process::logger() { return logger_; }

#endif
