// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef ProcessHelper_h
#define ProcessHelper_h

#include <filesystem>
#include <optional>
#include <string>
#include <vector>

#include "cmc/AbstractHelper.h"
#include "cmc/Process.h"
class Logger;
class SocketPair;

class ProcessHelper : public AbstractHelper {
public:
    using args_type = std::vector<std::string>;
    ProcessHelper(std::string name, std::filesystem::path, args_type args,
                  Logger *);

    std::filesystem::path path() const;
    args_type args() const;

    bool hasSameConfig(const std::filesystem::path &path,
                       const args_type &args) const;

protected:
    bool spawnConnectedSubprocess();
    void despawn();
    bool updatePath(const std::filesystem::path &path);
    bool updateArgs(const args_type &args);
    const std::optional<Process> &process() const;
    std::optional<Process> &process();
    int stdIn() const;
    int stdOut() const;
    int stdErr() const;
    static void close(int &fd);
    void closeSockets();

private:
    std::filesystem::path path_;
    args_type args_;
    std::optional<Process> process_;
    int std_in_ = -1;
    int std_out_ = -1;
    int std_err_ = -1;

    bool spawn(const SocketPair &std_in, const SocketPair &std_out,
               const SocketPair &std_err);
    std::string pidStr() const;
    void setFds(int std_in, int std_out, int std_err);
    bool detach();
};

[[nodiscard]] inline std::filesystem::path ProcessHelper::path() const {
    return path_;
}
[[nodiscard]] inline ProcessHelper::args_type ProcessHelper::args() const {
    return args_;
}
inline bool ProcessHelper::updatePath(const std::filesystem::path &path) {
    bool changed = false;
    if (path_ != path) {
        path_ = path;
        changed = true;
    }
    return changed;
}
inline bool ProcessHelper::updateArgs(const args_type &args) {
    bool changed = false;
    if (args_ != args) {
        args_ = args;
        changed = true;
    }
    return changed;
}
[[nodiscard]] inline int ProcessHelper::stdIn() const { return std_in_; }
[[nodiscard]] inline int ProcessHelper::stdOut() const { return std_out_; }
[[nodiscard]] inline int ProcessHelper::stdErr() const { return std_err_; }
[[nodiscard]] inline const std::optional<Process> &ProcessHelper::process()
    const {
    return process_;
}
[[nodiscard]] inline std::optional<Process> &ProcessHelper::process() {
    return process_;
}

#endif
