// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef RRDFileLocator_h
#define RRDFileLocator_h

#include <filesystem>

#include "livestatus/Metric.h"
class Logger;
class Object;

class RRDFileLocator {
public:
    RRDFileLocator(Logger *logger, const std::filesystem::path &rrd_path);
    virtual ~RRDFileLocator() = default;

    std::filesystem::path directory(const Object *object) const;
    virtual std::filesystem::path path(
        const Object *object, const Metric::MangledName &name) const = 0;
    virtual std::filesystem::path metadata(const Object *object) const = 0;

protected:
    std::filesystem::path base(const Object *object) const;

private:
    std::filesystem::path rrd_path_;
};

class RRDFileLocatorSingle : public RRDFileLocator {
public:
    using RRDFileLocator::RRDFileLocator;
    std::filesystem::path path(const Object *object,
                               const Metric::MangledName &name) const override;
    std::filesystem::path metadata(const Object *object) const override;
};

class RRDFileLocatorMultiple : public RRDFileLocator {
public:
    using RRDFileLocator::RRDFileLocator;
    std::filesystem::path path(const Object *object,
                               const Metric::MangledName &name) const override;
    std::filesystem::path metadata(const Object *object) const override;
};

#endif  // RRDFileLocator_h
