// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef RRDHelper_h
#define RRDHelper_h

#include <chrono>
#include <cstddef>
#include <string>
#include <string_view>
#include <vector>

#include "cmc/PNPXMLWriter.h"
#include "cmc/ProcessHelper.h"
#include "cmc/RRDCacheDThread.h"

enum class Counter;
class GeneralConfig;
class Logger;
class Metric;
class Object;
class PerformanceData;
class Poller;
class RRDConfig;
enum class RRDFormat;
struct RRDInfo;
class World;

class RRDHelper : public ProcessHelper {
public:
    RRDHelper(std::string name, Counter overflow_counter, Counter queue_usage,
              Counter bytes_sent_counter, Logger *logger);
    ~RRDHelper() override;

    bool updateConfig(const World *world);
    void reload();

    void processPerfData(const PerformanceData &perf_data,
                         const Object *object);

private:
    bool pnp4nagios_enabled_{true};
    std::chrono::steady_clock::time_point _start;
    char _buffer[8192];
    size_t _buffer_size{0};
    const World *_world = nullptr;

    // AbstractHelper/ProcessHelper API
    void start_() override;
    void stop_() override;
    void setUpPoller_(Poller &poller) const override;
    void communicate_(const Poller &poller) override;

    // protocol method for start/reload/shutdown
    PNPXMLWriter _xml;
    RRDCacheDThread _rrdcached;
    void processSingle(const PerformanceData &perf_data, const Object *object,
                       const RRDInfo &info);
    void processMultiple(const PerformanceData &perf_data, const Object *object,
                         const RRDInfo &info);
    void create(const Object *object, RRDFormat rrd_format,
                const std::vector<Metric> &metrics);

    void handleStdOut();
    void handleStdErr();

    void handleIO(int fd);

    bool updateConfig(const GeneralConfig &general, const RRDConfig &rrd);

    void do_stop();

    void updateMetrics(std::string_view response);
};

#endif  // RRDHelper_h
