// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef RRDInfoCache_h
#define RRDInfoCache_h

#include <iosfwd>
#include <mutex>
#include <unordered_map>

#include "cmc/RRDInfo.h"
#include "livestatus/Metric.h"
class Logger;
class Object;
class World;

class RRDInfoCache {
public:
    RRDInfoCache(const World &world, Logger *logger);
    void migrate(const RRDInfoCache &from);
    RRDInfo rrdInfo(const Object *object);
    MetricLocation metricLocation(const Object *object,
                                  const Metric::MangledName &name);
    void forgetRRDInfo(const Object *object);

private:
    const World &_world;  // we are owned by this World
    Logger *logger_;

    using Cache = std::unordered_map<const Object *, RRDInfo>;

    // The mutex protects _cache.
    std::mutex _mutex;
    Cache _cache;

    Metric::Names getNamesFromInfo(const Object *object);
    Metric::Names getNamesFromRRDs(const Object *object);
};

std::ostream &operator<<(std::ostream &os, const RRDInfo &info);

#endif  // RRDInfoCache_h
