// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef RealTimeCheck_h
#define RealTimeCheck_h

#include <cstdint>
#include <string>

#include "cmc/AbstractHelper.h"
class CheckHelperPool;
class CheckingConfig;
class Logger;
class Poller;
class World;

class RealTimeCheck : public AbstractHelper {
public:
    RealTimeCheck(std::string name, CheckHelperPool &pool, Logger *logger);
    ~RealTimeCheck() override;
    // We use dynamically allocated resources (a socket) and our ContextLogger
    // captures 'this' => disable copy/assignment
    RealTimeCheck(const RealTimeCheck &) = delete;
    RealTimeCheck &operator=(const RealTimeCheck &) = delete;

    bool updateConfig(const World *world);

private:
    const World *_world = nullptr;
    uint16_t _port = 0;
    int _socket = -1;
    CheckHelperPool &_pool;

    // AbstractHelper API
    void start_() override;
    void stop_() override;
    void setUpPoller_(Poller &poller) const override;
    void communicate_(const Poller &poller) override;

    void do_stop();
    bool updateConfig(const CheckingConfig &checking);
    void receive();
};

#endif  // RealTimeCheck_h
