// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef SerialToken_h
#define SerialToken_h

#include <cstdint>
#include <iosfwd>
#include <mutex>
#include <string>
#include <unordered_map>
#include <unordered_set>
class Logger;
class SerialTokenFactory;

using config_serial_t = uint32_t;

class SerialToken {
public:
    ~SerialToken();

    SerialToken(const SerialToken &) = delete;
    SerialToken &operator=(const SerialToken &) = delete;

    SerialToken(SerialToken &&rhs) noexcept;
    SerialToken &operator=(SerialToken &&rhs) noexcept;

    [[nodiscard]] config_serial_t value() const;

private:
    config_serial_t value_;
    SerialTokenFactory *owner_;
    std::string creator_;

    friend class SerialTokenFactory;  // for the constructor
    SerialToken(config_serial_t value, SerialTokenFactory *owner,
                std::string creator);

    friend std::ostream &operator<<(std::ostream &os, const SerialToken &s);
};

class SerialTokenFactory {
public:
    explicit SerialTokenFactory(Logger *logger) : logger_(logger) {}
    SerialTokenFactory(const SerialTokenFactory &) = delete;
    SerialTokenFactory &operator=(const SerialTokenFactory &) = delete;
    SerialTokenFactory(SerialTokenFactory &&) = delete;
    SerialTokenFactory &operator=(SerialTokenFactory &&) = delete;

    [[nodiscard]] SerialToken create(const std::string &creator,
                                     config_serial_t serial);
    std::unordered_set<config_serial_t> used() const;

private:
    Logger *const logger_;
    mutable std::mutex lock_;
    std::unordered_map<config_serial_t, uint32_t> tokens_;

    friend class SerialToken;  // for release
    void release(SerialToken *token);

    friend std::ostream &operator<<(std::ostream &os,
                                    const SerialTokenFactory &s);
};

#endif  // SerialToken_h
