// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef Service_h
#define Service_h

#include <chrono>
#include <string>
#include <unordered_map>
#include <unordered_set>

#include "cmc/CmcService.h"
#include "cmc/Object.h"
#include "cmc/State.h"
#include "livestatus/Interface.h"

class Core;
class Entity;
class Host;
class ServiceGroup;
class Timeperiod;
class World;

class Service : public Object {
public:
    Service(Core &core, World &world, Host &host, const std::string &name,
            const Timeperiod &tp);
    Service(Core &core, World &world, Host &host, Entity &&entity);
    Service(const Service &) = delete;
    Service &operator=(const Service &) = delete;

    const IService &iservice() const;
    const std::unordered_set<ServiceGroup *> &groups() const {
        return _groups;
    };
    const Timeperiod *passive_check_period() const {
        return passive_check_period_;
    }
    ServiceState remap(ServiceState state) const;
    void dump();
    bool isHost() const override { return false; };
    const Host *host() const override { return &host_; };
    Host *host() override { return &host_; };
    const Service *service() const override { return this; };
    Service *service() override { return this; };
    std::string serviceDescription() const override { return name(); };
    std::chrono::system_clock::duration staleness_check_interval()
        const override;

    ServiceState getCurrentState() const {
        return static_cast<ServiceState>(state()->current_state_);
    }
    bool isCurrentStateOK() const override {
        return getCurrentState() == ServiceState::ok;
    }
    bool isPreviousHardStateOK() const override {
        return static_cast<ServiceState>(state()->hard_state_.previous_) ==
               ServiceState::ok;
    }
    void insertInGroup(ServiceGroup &group);

    bool operator==(const Service &other) const;
    bool operator!=(const Service &other) const { return !(*this == other); }

    // TODO(sk): get rid of those pesky public data members.
    Host &host_;
    std::unordered_set<ServiceGroup *> _groups;
    std::unordered_map<ServiceState, ServiceState> _state_mapping;
    const Timeperiod *passive_check_period_;

private:
    CmcService iservice_;
};

#endif  // Service_h
