// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#ifndef TableCachedStatehist_h
#define TableCachedStatehist_h

#include <pthread.h>
#include <sys/types.h>

#include <chrono>
#include <deque>
#include <memory>
#include <mutex>
#include <optional>
#include <string>

#include "cmc/StateHistoryThread.h"
#include "livestatus/Table.h"
class Column;
class Core;
class Histcache;
class Logger;
class ICore;
class Query;
class Object;
class User;

class TableCachedStatehist : public Table {
public:
    explicit TableCachedStatehist(ICore *mc);
    ~TableCachedStatehist() override;

    std::string name() const override;
    std::string namePrefix() const override;
    void answerQuery(Query &query, const User &user,
                     const ICore &core) override;
    [[nodiscard]] std::shared_ptr<Column> column(
        std::string colname) const override;

    void startBuildingCache(Core *core);  // starts async thread
    void stopBuildingCache();             // stops async thread
    void finishBuildingCache();           // collects finished thread
    void flushCache();
    void registerAlert(const Object &object, int st, const std::string &output,
                       const std::string &long_output);
    void registerDowntime(const Object &object, bool started);
    void registerFlapping(const Object &object, bool started);

    // TODO(sp) Ugly, remove this!
    Histcache *getOrCreateObjectHistcache(Object *object) {
        return _state_history_thread.getOrCreateObjectHistcache(object);
    }

private:
    bool _abort_query;

    // Timeline history of core itself (for unmonitored times). Entry[0] is The
    // time of the first start. 1 of the following stop, etc. The current length
    // of the list is odd if the core is currently running (during logfile
    // parsing)
    std::deque<std::chrono::system_clock::time_point> _core_startstops;
    bool _first_startstop_entry_is_running;
    std::mutex _startstop_mutex;

    std::chrono::system_clock::time_point _start_of_cache;

    // Thread for initial logfile parsing
    std::optional<pthread_t> _thread;
    Core *the_core_{};
    std::chrono::system_clock::time_point
        _parsed_since;  // Current start of parsing process

    StateHistoryThread _state_history_thread;
    friend class StateHistoryThread;
    friend void *histcache_thread_run(void *data);

    Logger *logger_core_;

    void dumpCoreStartstops() const;
    template <typename Init>
    void updateCache(const Object &object, Init f);
    void outputStateHistory(Query &query, const ICore &core, Object *object,
                            std::chrono::system_clock::time_point since,
                            std::chrono::system_clock::time_point until);
    ssize_t findLastCoreStartstopBefore(
        std::chrono::system_clock::time_point when);
};

#endif  // TableCachedStatehist_h
