// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include "cmc/CarbonConfig.h"

#include <iomanip>
#include <sstream>

#include "livestatus/Metric.h"

using namespace std::chrono_literals;

std::string CarbonConnectionConfig::path(
    const std::string &host_name,
    const std::string &service_description) const {
    return path(host_name, service_description, "");
}

std::string CarbonConnectionConfig::path(const std::string &host_name,
                                         const std::string &service_description,
                                         const Metric &metric) const {
    return path(host_name, service_description,
                mangling_ == CarbonConnectionConfig::Mangling::underscore
                    ? metric.mangled_name().string()
                    : metric.name().string());
}

std::string CarbonConnectionConfig::path(const std::string &host_name,
                                         const std::string &service_description,
                                         const std::string &metric_name) const {
    return (connection_prefix_ +  //
            canonicalize(host_name) + "." +
            canonicalize(service_description.empty() ? "HOST"
                                                     : service_description) +
            "." + canonicalize(metric_name));
}

std::string CarbonConnectionConfig::canonicalize(const std::string &str) const {
    std::ostringstream os;
    for (const char c : str) {
        const bool is_special = c == '.' || c == '/' || (c >= 0 && c <= ' ');
        switch (mangling_) {
            case Mangling::underscore:
                os << (is_special ? '_' : c);
                break;
            case Mangling::c_style:
                if (is_special || c == '\\') {
                    os << '\\' << std::oct << std::setw(3) << std::setfill('0')
                       << static_cast<int>(c) << std::dec;
                } else {
                    os << c;
                }
                break;
        }
    }
    return os.str();
}

bool CarbonConnectionConfig::operator==(
    const CarbonConnectionConfig &other) const {
    return ip_ == other.ip_ && port_ == other.port_ &&
           retry_interval_ == other.retry_interval_ &&
           connection_prefix_ == other.connection_prefix_ &&
           mangling_ == other.mangling_;
}

bool CarbonSendMetricParts::operator==(
    const CarbonSendMetricParts &other) const {
    return value == other.value && uom == other.uom && warn == other.warn &&
           crit == other.crit && min == other.min && max == other.max &&
           state == other.state &&
           scheduled_downtime_depth == other.scheduled_downtime_depth &&
           acknowledged == other.acknowledged;
}
