// Copyright (C) 2023 Checkmk GmbH - License: GNU General Public License v2
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include "cmc/CmcContact.h"

#include <algorithm>
#include <optional>
#include <unordered_map>
#include <utility>

#include "cmc/Contact.h"
#include "cmc/Timeperiod.h"

[[nodiscard]] std::string CmcContact::name() const { return contact_.name(); }

[[nodiscard]] std::string CmcContact::alias() const {
    return contact_.lookup({}, "alias");
}

[[nodiscard]] std::string CmcContact::email() const {
    return contact_.lookup({}, "email");
}

[[nodiscard]] std::string CmcContact::pager() const {
    return contact_.lookup({}, "pager");
}

[[nodiscard]] std::string CmcContact::hostNotificationPeriod() const {
    return contact_._notification_period->name();
}

[[nodiscard]] std::string CmcContact::serviceNotificationPeriod() const {
    return contact_._notification_period->name();
}

[[nodiscard]] std::string CmcContact::address(int32_t index) const {
    const std::string addr_with_index = "address" + std::to_string(index + 1);
    return contact_.lookup({}, addr_with_index);
}

[[nodiscard]] bool CmcContact::canSubmitCommands() const { return true; }

[[nodiscard]] bool CmcContact::isHostNotificationsEnabled() const {
    return contact_._notifications_enabled;
}

[[nodiscard]] bool CmcContact::isServiceNotificationsEnabled() const {
    return contact_._notifications_enabled;
}

[[nodiscard]] bool CmcContact::isInHostNotificationPeriod() const {
    return contact_._notification_period->isActive();
}

[[nodiscard]] bool CmcContact::isInServiceNotificationPeriod() const {
    return contact_._notification_period->isActive();
}

[[nodiscard]] Attributes CmcContact::customVariables() const {
    return contact_.attributes(AttributeKind::custom_variables);
}

[[nodiscard]] Attributes CmcContact::tags() const {
    return contact_.attributes(AttributeKind::tags);
}

[[nodiscard]] Attributes CmcContact::labels() const {
    return contact_.attributes(AttributeKind::labels);
}

[[nodiscard]] Attributes CmcContact::labelSources() const {
    return contact_.attributes(AttributeKind::label_sources);
}

[[nodiscard]] uint32_t CmcContact::modifiedAttributes() const { return 0; }

bool CmcContact::all_of_labels(
    const std::function<bool(const Attribute &)> &pred) const {
    // TODO(sp) Avoid construction of temporary map
    auto labels = contact_.attributes(AttributeKind::labels);
    return std::all_of(
        labels.cbegin(), labels.cend(),
        [&pred](const std::pair<std::string, std::string> &label) {
            return pred(Attribute{label.first, label.second});
        });
}
