// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include "cmc/Comment.h"

#include <compare>
#include <ostream>

#include "cmc/Object.h"
#include "cmc/World.h"
#include "livestatus/ChronoUtils.h"

bool Comment::expires() const {
    return _expire_time != std::chrono::system_clock::time_point{};
}

bool Comment::isExpired(std::chrono::system_clock::time_point when) const {
    return expires() && _expire_time <= when;
}

bool Comment::migrate(const World &world) {
    if (auto *migrated_object = world.correspondingObject(_object)) {
        _object = migrated_object;
        return true;
    }
    return false;
}

std::ostream &operator<<(std::ostream &os, const Comment::Type &t) {
    switch (t) {
        case Comment::Type::user:
            return os << "user comment";
        case Comment::Type::downtime:
            return os << "downtime comment";
        case Comment::Type::flapping:
            return os << "flapping comment";
        case Comment::Type::acknowledgement:
            return os << "acknowledgement";
    }
    return os << "unknown";  // unreachable
}

std::ostream &operator<<(std::ostream &os, const Comment::Source &s) {
    switch (s) {
        case Comment::Source::internal:
            return os << "internal";
        case Comment::Source::external:
            return os << "external";
    }
    return os << "unknown";  // unreachable
}

std::ostream &operator<<(std::ostream &os, const Comment &c) {
    os << (c._persistent ? "persistent" : "")                    //
       << (c._sticky ? "sticky" : "")                            //
       << " " << c._entry_type                                   //
       << " " << c._id                                           //
       << " for " << *c._object                                  //
       << " entered at " << FormattedTimePoint(c._entry_time)    //
       << (c._author.empty() ? "" : (" by " + c._author))        //
       << (c._comment.empty() ? "" : (" (" + c._comment + ")"))  //
       << " from " << c._source << " source";
    if (c.expires()) {
        os << ", expires at " << FormattedTimePoint(c._expire_time);
    }
    return os;
}
