// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include "cmc/ContactList.h"

#include <algorithm>
#include <functional>
#include <iterator>
#include <utility>

#include "cmc/ContactGroup.h"
#include "cmc/World.h"
#include "livestatus/Logger.h"

namespace {
template <typename T>
T sorted(T t) {
    std::sort(std::begin(t), std::end(t));
    return t;
}
}  // namespace

ContactList::ContactList(std::unordered_set<std::string> contact_names,
                         std::vector<std::string> &contact_groups,
                         const World *world)
    : contact_names_{std::move(contact_names)} {
    for (const auto &name : contact_groups) {
        if (auto *group = world->getContactGroup(name)) {
            _groups.insert(group);
        } else {
            Error(world->logger_)
                << "undefined contact group " << name << " in contact list";
        }
    }
}

bool ContactList::isMember(const std::string &contact_name) const {
    return contact_names_.contains(contact_name);
}

std::vector<std::string> ContactList::contactNames() const {
    std::vector<std::string> names;
    names.insert(names.end(), contact_names_.begin(), contact_names_.end());
    return names;
}

bool ContactList::isMember(const ContactGroup *group) const {
    return _groups.contains(group);
}

std::vector<std::string> ContactList::groupNames() const {
    std::vector<std::string> result;
    result.reserve(_groups.size());
    for (const auto *g : _groups) {
        result.push_back(g->name());
    }
    return result;
}

std::vector<const ContactGroup *> ContactList::groups() const {
    return {_groups.cbegin(), _groups.cend()};
}

bool ContactList::operator==(const ContactList &other) const {
    return contact_names_ == other.contact_names_ &&
           sorted(groupNames()) == sorted(other.groupNames());
}
