// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include "cmc/DowntimeRule.h"

#include <compare>
#include <ostream>
#include <utility>

#include "livestatus/ChronoUtils.h"

using namespace std::chrono_literals;

bool DowntimeRule::isFixed() const { return _flex_duration == 0s; }

namespace {
bool sameAlignment(const CycleTime &ct,
                   std::chrono::system_clock::time_point start_time_a,
                   std::chrono::system_clock::time_point start_time_b) {
    if (start_time_a > start_time_b) {
        std::swap(start_time_b, start_time_a);
    }

    while (start_time_a <= start_time_b) {
        if (start_time_a == start_time_b) {
            return true;
        }
        start_time_a += ct.next(start_time_a);
    }
    return false;
}
}  // namespace

bool DowntimeRule::isAligned(const DowntimeRule &other) const {
    return _cycle_time == other._cycle_time &&
           sameAlignment(_cycle_time, _start_time, other._start_time);
}

std::ostream &operator<<(std::ostream &os, const DowntimeRule &prd) {
    return os << "persistent recurring downtime"
              << ", starts at " << FormattedTimePoint(prd._start_time)
              << ", ends at " << FormattedTimePoint(prd._end_time)
              << ", duration " << mk::ticks<std::chrono::seconds>(prd._duration)
              << " sec, flexible length "
              << mk::ticks<std::chrono::seconds>(prd._flex_duration)
              << " sec, recurring " << prd._cycle_time
              << (prd._comment.empty() ? "" : (" (" + prd._comment + ")"));
}

bool DowntimeRule::operator==(const DowntimeRule &other) const {
    return _comment == other._comment && isFixed() == other.isFixed() &&
           (isFixed() || _flex_duration == other._duration) &&
           _duration == other._duration && isAligned(other);
}
