// Copyright (C) 2022 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include "cmc/EventSpooler.h"

#include "livestatus/Logger.h"

EventSpooler::EventSpooler(Logger *logger) : logger_{logger} {}

void EventSpooler::spool(const payload &event) {
    {
        const std::lock_guard lg{lock_};
        events_.push_back(event);
    }
    log("spooled", event);
}

EventSpooler::payload EventSpooler::unspool() {
    EventSpooler::payload event;
    {
        const std::lock_guard lg{lock_};
        event = events_.front();
        events_.pop_front();
    }
    log("unspooled", event);
    return event;
}

void EventSpooler::clear() {
    const std::lock_guard lg{lock_};
    events_.clear();
}

size_t EventSpooler::size() const {
    const std::lock_guard lg{lock_};
    return events_.size();
}

bool EventSpooler::empty() const { return size() == 0; }

void EventSpooler::for_each(
    const std::function<void(const EventSpooler::payload &)> &func) const {
    const std::lock_guard lg{lock_};
    for (const auto &event : events_) {
        func(event);
    }
}

void EventSpooler::log(const std::string &action, const payload &event) {
    if (logger_->isLoggable(LogLevel::debug)) {
        Debug(logger_) << action << " " << event.size() << " byte event: '"
                       << event << "'";
    }
}
