// Copyright (C) 2022 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include "cmc/FetcherReply.h"

#include "cmc/Object.h"
#include "cmc/World.h"
#include "livestatus/Logger.h"

bool FetcherReply::migrate(const World &world) {
    if (auto *migrated_object = world.correspondingObject(object_)) {
        object_ = migrated_object;
        return true;
    }
    return false;
}

bool FetcherReplyQueue::migrate(const World &world) {
    FetcherReplyQueue q{logger_};
    while (!empty()) {
        auto reply = std::move(front());
        pop();
        if (reply->migrate(world)) {
            q.push(std::move(reply));
        } else {
            Notice(logger_) << *reply->object_ << " vanished, removing reply";
        }
    }
    std::swap(*this, q);
    Notice(logger_) << "migrated " << size() << " replies";
    return true;
}
