// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include "cmc/GlobalConfig.h"

#include <algorithm>
#include <iomanip>
#include <sstream>

#include "livestatus/ChronoUtils.h"
#include "livestatus/Logger.h"

using namespace std::chrono_literals;

namespace {
class MillisecondsFormatter : public Formatter {
    void format(std::ostream &os, const LogRecord &record) override {
        auto tp = record.getTimePoint();
        os << FormattedTimePoint(record.getTimePoint()) << " "
           << std::setfill('0')  //
           << std::setw(3) << time_point_part<std::chrono::milliseconds>(tp)
           << "."  //
           << std::setw(3) << time_point_part<std::chrono::microseconds>(tp)
           << " [" << record.getLevel() << "] " << record.getMessage();
    }
};
}  // namespace

std::unique_ptr<Formatter> GlobalConfig::getFormatter() const {
    if (general_.log_microtime_) {
        return std::make_unique<MillisecondsFormatter>();
    }
    return std::make_unique<SimpleFormatter>();
}

bool InfluxDbConfig::operator==(const InfluxDbConfig &other) const {
    return std::is_permutation(connections_.begin(), connections_.end(),
                               other.connections_.begin(),
                               other.connections_.end()) &&
           log_level_ == other.log_level_;
}

bool CarbonConfig::operator==(const CarbonConfig &other) const {
    return std::is_permutation(connections_.begin(), connections_.end(),
                               other.connections_.begin(),
                               other.connections_.end()) &&
           log_level_ == other.log_level_;
}

bool HistoryConfig::operator==(const HistoryConfig &other) const {
    return max_cached_messages_ == other.max_cached_messages_ &&
           max_lines_per_file_ == other.max_lines_per_file_ &&
           cache_horizon_ == other.cache_horizon_ &&
           max_core_downtime_ == other.max_core_downtime_ &&
           file_ == other.file_ &&
           archive_directory_ == other.archive_directory_ &&
           rotation_interval_ == other.rotation_interval_ &&
           rotation_size_limit_ == other.rotation_size_limit_;
}

bool RRDConfig::operator==(const RRDConfig &other) const {
    return single_directory_ == other.single_directory_ &&
           multiple_directory_ == other.multiple_directory_ &&
           rrdcached_socket_ == other.rrdcached_socket_ &&
           log_level_ == other.log_level_ &&
           pnp4nagios_enabled_ == other.pnp4nagios_enabled_ &&
           pnp_update_delay_ == other.pnp_update_delay_ &&
           pnp_update_on_restart_ == other.pnp_update_on_restart_;
}
