// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include "cmc/InfluxDBConfig.h"

#include <sstream>

namespace influxdb {

bool SenderMetrics::operator==(const SenderMetrics &other) const {
    return metric_value == other.metric_value &&
           metric_hst_state == other.metric_hst_state &&
           metric_svc_state == other.metric_svc_state &&
           add_hst_state == other.add_hst_state &&
           add_svc_state == other.add_svc_state &&
           add_downtime == other.add_downtime &&
           add_acknowledgement == other.add_acknowledgement &&
           add_uom == other.add_uom && add_thresholds == other.add_thresholds &&
           add_min_max == other.add_min_max &&
           tag_hst_name == other.tag_hst_name &&
           tag_svc_name == other.tag_svc_name &&
           tag_hst_alias == other.tag_hst_alias &&
           tag_hst_tags == other.tag_hst_tags &&
           tag_hst_label == other.tag_hst_label &&
           tag_svc_label == other.tag_svc_label;
}

bool ConnectionConfig::operator==(
    const influxdb::ConnectionConfig &other) const {
    return id == other.id && enabled == other.enabled &&
           address == other.address && auth == other.auth &&
           api_path == other.api_path && token == other.token &&
           max_batch_size == other.max_batch_size &&
           max_batch_age == other.max_batch_age &&
           retry_interval == other.retry_interval;
}

bool Token::operator==(const influxdb::Token &other) const {
    return token_ == other.token_;
}

bool Address::operator==(const influxdb::Address &other) const {
    return protocol == other.protocol && host == other.host &&
           port == other.port;
}

bool Auth::operator==(const influxdb::Auth &other) const {
    return ca_cert_file == other.ca_cert_file &&
           use_certificate_check == other.use_certificate_check;
}

SenderConfig SenderConfig::make() {
    return {.connection = {},
            .org = {},
            .bucket = {},
            .parts = {.metric_value = false,
                      .metric_hst_state = false,
                      .metric_svc_state = false,
                      .add_hst_state = false,
                      .add_svc_state = false,
                      .add_downtime = false,
                      .add_acknowledgement = false,
                      .add_uom = false,
                      .add_thresholds = false,
                      .add_min_max = false,
                      .tag_hst_name = false,
                      .tag_svc_name = false,
                      .tag_hst_alias = false,
                      .tag_hst_tags = false,
                      .tag_hst_label = false,
                      .tag_svc_label = false}};
}

bool SenderConfig::operator==(const SenderConfig &other) const {
    return connection == other.connection && org == other.org &&
           bucket == other.bucket && parts == other.parts;
}

Headers::operator std::string() const {
    // The same syntax as curl is nice for debugging.
    std::stringstream line{};
    line << " --header \"Authorization: " << token << "\"";
    line << " --header \"org: " << org << "\"";
    for (const auto &[k, v] : extra) {
        line << " --header \"" << k << ": " << v << "\"";
    }
    return line.str();
}

Token::operator std::string() const {
    auto stream = std::stringstream{};
    stream << "Token " << token_;
    return stream.str();
}

std::string Address::to_string() const {
    std::ostringstream out;
    out << *this;
    return out.str();
}

}  // namespace influxdb

std::ostream &operator<<(std::ostream &out, const influxdb::Address &addr) {
    return out << addr.protocol << "://" << addr.host << ":" << addr.port;
}

std::ostream &operator<<(std::ostream &out, const influxdb::Headers &h) {
    return out << std::string{h};
}

std::ostream &operator<<(std::ostream &out, const influxdb::Token &t) {
    return out << std::string{t};
}
