// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include "cmc/ObjectResolver.h"

#include <functional>
#include <utility>

#include "cmc/Host.h"
#include "cmc/Object.h"
#include "cmc/Service.h"
#include "cmc/World.h"

// If there is a file "renamed_hosts" then we read that file and keep the
// information for reference. It is being created when hosts have been renamed,
// but the status file still refers to the old names.
ObjectResolver::ObjectResolver(
    const World *world,
    std::unordered_map<std::string, std::string> renamed_hosts)
    : _world{world}, _renamed_hosts{std::move(renamed_hosts)} {}

Host *ObjectResolver::hostRef(const std::string &host_name) const {
    auto it = _renamed_hosts.find(host_name);
    return _world->getHost(it == _renamed_hosts.end() ? host_name : it->second);
}

Object *ObjectResolver::objectRef(
    const std::string &host_name,
    const std::string &service_description) const {
    Object *hst = hostRef(host_name);
    return hst != nullptr && !service_description.empty()
               ? _world->getService(hst->name(), service_description)
               : hst;
}
