// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include "cmc/PbCMC.h"

#include "cycletime/v1/types.pb.h"

namespace pb = checkmk::cmc::cycletime::v1;

namespace mk {
CycleTime::Kind ToCMCCycleTime(pb::CycleTime cycle_time) {
    switch (cycle_time) {
        case pb::CycleTime::CYCLE_TIME_NONE:
            return CycleTime::Kind::none;
        case pb::CycleTime::CYCLE_TIME_HOURLY:
            return CycleTime::Kind::hourly;
        case pb::CycleTime::CYCLE_TIME_DAILY:
            return CycleTime::Kind::daily;
        case pb::CycleTime::CYCLE_TIME_WEEKLY:
            return CycleTime::Kind::weekly;
        case pb::CycleTime::CYCLE_TIME_BIWEEKLY:
            return CycleTime::Kind::biweekly;
        case pb::CycleTime::CYCLE_TIME_EVERY_4WEEKS:
            return CycleTime::Kind::every_4weeks;
        case pb::CycleTime::CYCLE_TIME_NTH_WEEKDAY:
            return CycleTime::Kind::nth_weekday;
        case pb::CycleTime::CYCLE_TIME_NTH_WEEKDAY_FROM_END:
            return CycleTime::Kind::nth_weekday_from_end;
        case pb::CycleTime::CYCLE_TIME_DAY_OF_MONTH:
            return CycleTime::Kind::day_of_month;
        case pb::CycleTime::CYCLE_TIME_EVERY_5MIN:
            return CycleTime::Kind::every_5min;
        default:
            // not possible, but now we have no unified policy what to do
            // with bad cycletime: abort or exception may be better
            return CycleTime::Kind::none;
    }
}

pb::CycleTime ToProtoCycleTime(CycleTime::Kind ct) {
    switch (ct) {
        case CycleTime::Kind::none:
            return pb::CycleTime::CYCLE_TIME_NONE;
        case CycleTime::Kind::hourly:
            return pb::CycleTime::CYCLE_TIME_HOURLY;
        case CycleTime::Kind::daily:
            return pb::CycleTime::CYCLE_TIME_DAILY;
        case CycleTime::Kind::weekly:
            return pb::CycleTime::CYCLE_TIME_WEEKLY;
        case CycleTime::Kind::biweekly:
            return pb::CycleTime::CYCLE_TIME_BIWEEKLY;
        case CycleTime::Kind::every_4weeks:
            return pb::CycleTime::CYCLE_TIME_EVERY_4WEEKS;
        case CycleTime::Kind::nth_weekday:
            return pb::CycleTime::CYCLE_TIME_NTH_WEEKDAY;
        case CycleTime::Kind::nth_weekday_from_end:
            return pb::CycleTime::CYCLE_TIME_NTH_WEEKDAY_FROM_END;
        case CycleTime::Kind::day_of_month:
            return pb::CycleTime::CYCLE_TIME_DAY_OF_MONTH;
        case CycleTime::Kind::every_5min:
            return pb::CycleTime::CYCLE_TIME_EVERY_5MIN;
    }
    return {};
}
}  // namespace mk
