// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include "cmc/PoolSizeLogger.h"

#include <sys/types.h>

#include <cstdlib>

#include "livestatus/ChronoUtils.h"
#include "livestatus/Logger.h"

PoolSizeLogger::PoolSizeLogger(const std::function<size_t()> &size,
                               Logger *logger)
    : size_(size)
    , logger_(logger)
    , start_(std::chrono::steady_clock::now())
    , initial_num_helpers_(size()) {}

PoolSizeLogger::~PoolSizeLogger() {
    const ssize_t change = static_cast<ssize_t>(size_()) - initial_num_helpers_;
    if (change != 0) {
        Notice(logger_) << (change > 0 ? "started" : "stopped") << " "
                        << std::abs(change) << " helper"
                        << (std::abs(change) > 1 ? "s" : "") << " in "
                        << elapsed_ms_since(start_) << " ms";
    }
}
