// Copyright (C) 2021 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include "cmc/Producer.h"

#include <unistd.h>

#include <array>
#include <cerrno>
#include <utility>

#include "cmc/finally.h"
#include "livestatus/Logger.h"

LineProducer::LineProducer(consumer lineConsumer)
    : lineConsumer_{std::move(lineConsumer)} {}

void LineProducer::operator()(std::string_view chunk) {
    while (true) {
        auto eol = chunk.find('\n');
        if (eol == std::string::npos) {
            break;
        }
        auto line = chunk.substr(0, eol);
        if (!buffer.empty()) {
            buffer += line;
            line = buffer;
        }
        auto cleanup = mk::finally([&]() { std::string().swap(buffer); });
        lineConsumer_(line);
        chunk = chunk.substr(eol + 1);
    }
    buffer += chunk;
}

ChunkProducer::ChunkProducer(consumer chunkConsumer)
    : chunkConsumer_{std::move(chunkConsumer)} {}

void ChunkProducer::operator()(int fd) {
    std::array<char, 4096> buffer;
    while (true) {
        auto bytes_read = ::read(fd, buffer.data(), buffer.size());
        if (bytes_read == -1) {
            if (errno != EAGAIN) {
                throw generic_error("could not read reply chunk");
            }
            break;
        }
        if (bytes_read == 0) {
            break;
        }
        chunkConsumer_(
            std::string_view{buffer.data(), static_cast<size_t>(bytes_read)});
    }
}
