// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include "cmc/RRDFileLocator.h"

#include <string>

#include "cmc/Host.h"
#include "cmc/Object.h"
#include "livestatus/Logger.h"
#include "livestatus/PnpUtils.h"

namespace {
std::filesystem::path canonicalize(Logger *logger,
                                   const std::filesystem::path &path) {
    try {
        return path.empty() ? path : std::filesystem::canonical(path);
    } catch (const std::filesystem::filesystem_error &e) {
        Warning(logger) << e.what();
        return path;
    }
}
}  // namespace

// -------------------------------------------------------------------------------------------------

// Note: We need to determine the physical path to RRD files to avoid a bug
// in rrdcached when both /omd and /opt/omd are being used.
RRDFileLocator::RRDFileLocator(Logger *logger,
                               const std::filesystem::path &rrd_path)
    : rrd_path_(canonicalize(logger, rrd_path)) {}

std::filesystem::path RRDFileLocator::directory(const Object *object) const {
    return rrd_path_ / pnp_cleanup(object->host()->name());
}

std::filesystem::path RRDFileLocator::base(const Object *object) const {
    return directory(object) / pnp_cleanup(object->serviceDescription());
}

// -------------------------------------------------------------------------------------------------

std::filesystem::path RRDFileLocatorSingle::path(
    const Object *object, const Metric::MangledName & /*name*/) const {
    return base(object) += ".rrd";
}

std::filesystem::path RRDFileLocatorSingle::metadata(
    const Object *object) const {
    return base(object) += ".info";
}

// -------------------------------------------------------------------------------------------------

std::filesystem::path RRDFileLocatorMultiple::path(
    const Object *object, const Metric::MangledName &name) const {
    return base(object) += "_" + name.string() + ".rrd";
}

std::filesystem::path RRDFileLocatorMultiple::metadata(
    const Object *object) const {
    return base(object) += ".xml";
}
