// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include "cmc/Service.h"

#include <algorithm>
#include <utility>

#include "cmc/Entity.h"
#include "cmc/Host.h"
#include "cmc/ObjectGroup.h"
#include "cmc/Timeperiod.h"

// Used for creation of temporary fake services for PROCESS_SVC_PERFDATA
Service::Service(Core &core, World &world, Host &host, const std::string &name,
                 const Timeperiod &tp)
    : Object{core, world, name, tp}
    , host_{host}
    , passive_check_period_{&tp}
    , iservice_{*this} {}

Service::Service(Core &core, World &world, Host &host, Entity &&entity)
    : Object{core, world, std::move(entity)}, host_{host}, iservice_{*this} {}

const IService &Service::iservice() const { return iservice_; }

ServiceState Service::remap(ServiceState state) const {
    return _state_mapping.at(state);
}

std::chrono::system_clock::duration Service::staleness_check_interval() const {
    return _check_interval;
};

void Service::insertInGroup(ServiceGroup &group) {
    group.insert(this);
    _groups.insert(&group);
}

bool Service::operator==(const Service &other) const {
    return Object::operator==(other) && host_.name() == other.host_.name() &&
           std::is_permutation(
               _groups.begin(), _groups.end(), other._groups.begin(),
               other._groups.end(),
               [&](const auto *l, const auto *r) { return *l == *r; }) &&

           std::all_of(_state_mapping.begin(), _state_mapping.end(),
                       [&](const auto &l) {
                           return l.second == other._state_mapping.at(l.first);
                       }) &&
           passive_check_period_ != nullptr &&
           *passive_check_period_ == *other.passive_check_period_;
}
