// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

// Define global variables for Livestatus, that are
// in module.c in the original version

#include "cmc/cmc.h"

#include "cmc/Host.h"
#include "cmc/Object.h"
#include "livestatus/Interface.h"
#include "livestatus/LogEntry.h"

namespace {
ServiceState returnCodeToServiceState(int return_code) {
    return (0 <= return_code && return_code <= 3)
               ? static_cast<ServiceState>(return_code)
               : ServiceState::unknown;
}
}  // namespace

HostState returnCodeToHostState(const Host *host, int return_code) {
    // OK/WARN => UP, CRIT/UNKNOWN => DOWN or UNREACHABLE
    return return_code <= 1
               ? HostState::up
               : (host->getReachability() == Host::Reachability::unreachable
                      ? HostState::unreachable
                      : HostState::down);
}

int returnCodeToState(Object *object, int return_code) {
    return object->isHost()
               ? static_cast<int>(
                     returnCodeToHostState(object->host(), return_code))
               : static_cast<int>(returnCodeToServiceState(return_code));
}
