// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include "PbUtils.h"

namespace cfg = checkmk::cmc::config::v1;

namespace test {
std::size_t string_ref(cfg::Core &pbcore, const std::string &entry) {
    const std::size_t idx = pbcore.string_pool().entries().size();
    pbcore.mutable_string_pool()->add_entries(entry);
    return idx;
};
}  // namespace test

cfg::Core makeConfig() {
    cfg::Core config;
    config.mutable_contact_list_pool_offsets()->add_entries(0);
    config.mutable_string_pool_offsets()->add_entries(0);
    config.mutable_contact_list_pool()->add_entries();
    return config;
}

cfg::Host addHost(cfg::Core &pbcore, const std::string &hostname) {
    auto ref = [&pbcore](const std::string &entry) {
        return test::string_ref(pbcore, entry);
    };

    // requirements
    if (pbcore.timeperiods().empty()) {
        auto timeperiod = cfg::Timeperiod{};
        timeperiod.set_name_ref(ref("timeperiod"));
        timeperiod.set_alias_ref(ref("alias"));
        *pbcore.add_timeperiods() = timeperiod;
    }

    auto pbobject = cfg::Object{};
    pbobject.set_check_period_ref(ref("timeperiod"));
    pbobject.set_service_period_ref(ref("timeperiod"));
    pbobject.set_notification_period_ref(ref("timeperiod"));

    auto pbentity = cfg::Entity{};
    pbentity.set_name_ref(ref(hostname));
    *pbobject.mutable_entity() = pbentity;

    auto pbhost = cfg::Host{};
    *pbhost.mutable_object() = pbobject;

    *pbcore.add_hosts() = pbhost;
    return pbhost;
}

cfg::Service addService(cfg::Core &pbcore, cfg::Host &pbhost,
                        const std::string &servicename) {
    auto ref = [&pbcore](const std::string &entry) {
        return test::string_ref(pbcore, entry);
    };

    auto pbobject = cfg::Object{};

    auto pbentity = cfg::Entity{};
    pbentity.set_name_ref(ref(servicename));
    *pbobject.mutable_entity() = pbentity;

    auto pbsvc = cfg::Service{};
    *pbsvc.mutable_object() = pbobject;

    *pbhost.add_services() = pbsvc;

    return pbsvc;
}
