// Copyright (C) 2019 Checkmk GmbH - License: Check_MK Enterprise License
// This file is part of Checkmk (https://checkmk.com). It is subject to the
// terms and conditions defined in the file COPYING, which is part of this
// source code package.

#include <cassert>
#include <filesystem>
#include <optional>
#include <string>
#include <utility>
#include <vector>

#include "cmc/Process.h"
#include "gtest/gtest.h"
#include "livestatus/Logger.h"

using namespace std::string_literals;

class SocketFixture : public ::testing::Test {
public:
    void TearDown() override {
        if (p_) {
            process().terminate();
            process().wait();
        }
        p_.reset();
    }
    void run(std::filesystem::path path, std::vector<std::string> args) {
        p_.emplace(std::move(path), std::move(args), -1, -1, -1, logger());
    }
    void run(std::filesystem::path path) { run(std::move(path), {}); }
    Process &process() {
        assert(p_);
        return *p_;
    }

protected:
    [[nodiscard]] Logger *logger() const { return logger_; }

private:
    std::optional<Process> p_;
    Logger *logger_{Logger::getLogger("test")};
};

TEST_F(SocketFixture, BinTrue) {
    run("/bin/true");

    EXPECT_FALSE(process().valid());
    EXPECT_FALSE(process().joinable());
    EXPECT_EQ(-1, process().id());

    process().detach();
    EXPECT_NE(-1, process().id());
    EXPECT_TRUE(process().valid());
    EXPECT_TRUE(process().joinable());

    process().wait();
    EXPECT_EQ(0, process().exitCode());
}

TEST_F(SocketFixture, BinFalse) {
    run("/bin/false");

    EXPECT_FALSE(process().valid());
    EXPECT_FALSE(process().joinable());
    EXPECT_EQ(-1, process().id());

    process().detach();
    EXPECT_NE(-1, process().id());
    EXPECT_TRUE(process().valid());
    EXPECT_TRUE(process().joinable());

    process().wait();
    EXPECT_EQ(1, process().exitCode());
}
