#!/usr/bin/env python3
# Copyright (C) 2019 Checkmk GmbH - License: GNU General Public License v2
# This file is part of Checkmk (https://checkmk.com). It is subject to the terms and
# conditions defined in the file COPYING, which is part of this source code package.

# fmt: off
# mypy: disable-error-code=var-annotated


checkname = "ibm_svc_mdisk"


info = [
    [
        "0",
        "stp5_300G_01-01",
        "online",
        "managed",
        "16",
        "stp5_300G_01",
        "1.1TB",
        "0000000000000000",
        "BLUBB5",
        "6  00a0b80006e1dbc0000f6f9513026a000000000000000000000000000000000",
        "generic_hdd",
    ],
    [
        "1",
        "Quorum_BLUBB3",
        "online",
        "managed",
        "0",
        "Quorum_2",
        "1.0GB",
        "0000000000000000",
        "BLUBB3",
        "600a0b80  00293eb800001f264c3e8a1f00000000000000000000000000000000",
        "generic_hdd",
    ],
    [
        "2",
        "stp6_300G_01-01",
        "online",
        "managed",
        "15",
        "stp6_300G_01",
        "1.1TB",
        "0000000000000000",
        "BLUBB6",
        "6  00a0b80006e8e3c00000f1651302b8800000000000000000000000000000000",
        "generic_hdd",
    ],
    [
        "3",
        "Quorum_blubb5",
        "online",
        "managed",
        "18",
        "Quorum_0",
        "1.0GB",
        "0000000000000001",
        "BLUBB5",
        "600a0b8  0006e1dcc0000f6905130225800000000000000000000000000000000",
        "generic_hdd",
    ],
    [
        "4",
        "Quorum_blubb6",
        "online",
        "managed",
        "17",
        "Quorum_1",
        "1.0GB",
        "0000000000000001",
        "BLUBB6",
        "600a0b8  0006e1d5e00000dcb5130228700000000000000000000000000000000",
        "generic_hdd",
    ],
    [
        "5",
        "stp5_300G_01-02",
        "online",
        "managed",
        "16",
        "stp5_300G_01",
        "1.1TB",
        "0000000000000002",
        "BLUBB5",
        "6  00a0b80006e1dbc0000f6fc51304bfc00000000000000000000000000000000",
        "generic_hdd",
    ],
    [
        "6",
        "stp6_300G_01-02",
        "online",
        "managed",
        "15",
        "stp6_300G_01",
        "1.1TB",
        "0000000000000002",
        "BLUBB6",
        "6  00a0b80006e8e3c00000f1951304f9a00000000000000000000000000000000",
        "generic_hdd",
    ],
    [
        "7",
        "stp5_300G_01-03",
        "online",
        "managed",
        "16",
        "stp5_300G_01",
        "1.1TB",
        "0000000000000003",
        "BLUBB5",
        "6  00a0b80006e1dcc0000f76951305bc000000000000000000000000000000000",
        "generic_hdd",
    ],
    [
        "8",
        "stp6_300G_01-03",
        "online",
        "managed",
        "15",
        "stp6_300G_01",
        "1.1TB",
        "0000000000000003",
        "BLUBB6",
        "6  00a0b80006e1d5e00000e9a51305a3200000000000000000000000000000000",
        "generic_hdd",
    ],
    [
        "9",
        "stp5_300G_01-04",
        "online",
        "managed",
        "16",
        "stp5_300G_01",
        "1.1TB",
        "0000000000000004",
        "BLUBB5",
        "6  00a0b80006e1dbc0000f7d051341cc000000000000000000000000000000000",
        "generic_hdd",
    ],
]


discovery = {
    "": [
        ("Quorum_BLUBB3", {}),
        ("Quorum_blubb5", {}),
        ("Quorum_blubb6", {}),
        ("stp5_300G_01-01", {}),
        ("stp5_300G_01-02", {}),
        ("stp5_300G_01-03", {}),
        ("stp5_300G_01-04", {}),
        ("stp6_300G_01-01", {}),
        ("stp6_300G_01-02", {}),
        ("stp6_300G_01-03", {}),
    ]
}


checks = {
    "": [
        (
            "Quorum_BLUBB3",
            {
                "array_mode": 0,
                "degraded_state": 1,
                "excluded_state": 2,
                "image_mode": 0,
                "managed_mode": 0,
                "offline_state": 2,
                "online_state": 0,
                "unmanaged_mode": 1,
            },
            [(0, "Status: online", []), (0, "Mode: managed", [])],
        ),
        (
            "Quorum_blubb5",
            {
                "array_mode": 0,
                "degraded_state": 1,
                "excluded_state": 2,
                "image_mode": 0,
                "managed_mode": 0,
                "offline_state": 2,
                "online_state": 0,
                "unmanaged_mode": 1,
            },
            [(0, "Status: online", []), (0, "Mode: managed", [])],
        ),
        (
            "Quorum_blubb6",
            {
                "array_mode": 0,
                "degraded_state": 1,
                "excluded_state": 2,
                "image_mode": 0,
                "managed_mode": 0,
                "offline_state": 2,
                "online_state": 0,
                "unmanaged_mode": 1,
            },
            [(0, "Status: online", []), (0, "Mode: managed", [])],
        ),
        (
            "stp5_300G_01-01",
            {
                "array_mode": 0,
                "degraded_state": 1,
                "excluded_state": 2,
                "image_mode": 0,
                "managed_mode": 0,
                "offline_state": 2,
                "online_state": 0,
                "unmanaged_mode": 1,
            },
            [(0, "Status: online", []), (0, "Mode: managed", [])],
        ),
        (
            "stp5_300G_01-02",
            {
                "array_mode": 0,
                "degraded_state": 1,
                "excluded_state": 2,
                "image_mode": 0,
                "managed_mode": 0,
                "offline_state": 2,
                "online_state": 0,
                "unmanaged_mode": 1,
            },
            [(0, "Status: online", []), (0, "Mode: managed", [])],
        ),
        (
            "stp5_300G_01-03",
            {
                "array_mode": 0,
                "degraded_state": 1,
                "excluded_state": 2,
                "image_mode": 0,
                "managed_mode": 0,
                "offline_state": 2,
                "online_state": 0,
                "unmanaged_mode": 1,
            },
            [(0, "Status: online", []), (0, "Mode: managed", [])],
        ),
        (
            "stp5_300G_01-04",
            {
                "array_mode": 0,
                "degraded_state": 1,
                "excluded_state": 2,
                "image_mode": 0,
                "managed_mode": 0,
                "offline_state": 2,
                "online_state": 0,
                "unmanaged_mode": 1,
            },
            [(0, "Status: online", []), (0, "Mode: managed", [])],
        ),
        (
            "stp6_300G_01-01",
            {
                "array_mode": 0,
                "degraded_state": 1,
                "excluded_state": 2,
                "image_mode": 0,
                "managed_mode": 0,
                "offline_state": 2,
                "online_state": 0,
                "unmanaged_mode": 1,
            },
            [(0, "Status: online", []), (0, "Mode: managed", [])],
        ),
        (
            "stp6_300G_01-02",
            {
                "array_mode": 0,
                "degraded_state": 1,
                "excluded_state": 2,
                "image_mode": 0,
                "managed_mode": 0,
                "offline_state": 2,
                "online_state": 0,
                "unmanaged_mode": 1,
            },
            [(0, "Status: online", []), (0, "Mode: managed", [])],
        ),
        (
            "stp6_300G_01-03",
            {
                "array_mode": 0,
                "degraded_state": 1,
                "excluded_state": 2,
                "image_mode": 0,
                "managed_mode": 0,
                "offline_state": 2,
                "online_state": 0,
                "unmanaged_mode": 1,
            },
            [(0, "Status: online", []), (0, "Mode: managed", [])],
        ),
    ]
}
