#!/usr/bin/env python3
# Copyright (C) 2019 Checkmk GmbH - License: GNU General Public License v2
# This file is part of Checkmk (https://checkmk.com). It is subject to the terms and
# conditions defined in the file COPYING, which is part of this source code package.

# fmt: off
# mypy: disable-error-code=var-annotated


checkname = "netapp_api_environment"

info = [
    [
        "sensor-name PSU2",
        "sensor-type fru",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value GOOD",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU1",
        "sensor-type fru",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value GOOD",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Fan3",
        "sensor-type fru",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value GOOD",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Fan2",
        "sensor-type fru",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value GOOD",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Fan1",
        "sensor-type fru",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value GOOD",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name SP Status",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value IPMI_HB_OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name mSATA Status",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name mSATA Pres",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value PRESENT",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name CPU0 Temp Margin",
        "sensor-type thermal",
        "threshold-sensor-value -78",
        "critical-high-threshold 0",
        "warning-high-threshold -10",
        "node-name dmc1-r019-na1a",
        "value-units C",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name In Flow Temp",
        "sensor-type thermal",
        "warning-low-threshold 5",
        "threshold-sensor-value 16",
        "critical-high-threshold 55",
        "warning-high-threshold 50",
        "node-name dmc1-r019-na1a",
        "value-units C",
        "threshold-sensor-state normal",
        "critical-low-threshold 0",
    ],
    [
        "sensor-name Out Flow Temp",
        "sensor-type thermal",
        "warning-low-threshold 5",
        "threshold-sensor-value 23",
        "critical-high-threshold 75",
        "warning-high-threshold 65",
        "node-name dmc1-r019-na1a",
        "value-units C",
        "threshold-sensor-state normal",
        "critical-low-threshold 0",
    ],
    [
        "sensor-name PCI Slot Temp",
        "sensor-type thermal",
        "warning-low-threshold 5",
        "threshold-sensor-value 21",
        "critical-high-threshold 70",
        "warning-high-threshold 60",
        "node-name dmc1-r019-na1a",
        "value-units C",
        "threshold-sensor-state normal",
        "critical-low-threshold 0",
    ],
    [
        "sensor-name Smart Bat Temp",
        "sensor-type thermal",
        "warning-low-threshold 5",
        "threshold-sensor-value 19",
        "critical-high-threshold 70",
        "warning-high-threshold 60",
        "node-name dmc1-r019-na1a",
        "value-units C",
        "threshold-sensor-state normal",
        "critical-low-threshold 0",
    ],
    [
        "sensor-name CPU0 Error",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value NORMAL",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name CPU0 Therm Trip",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value NORMAL",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name CPU0 Hot",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value NORMAL",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Memory0 Hot",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value NORMAL",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PCH Hot",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value NORMAL",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Ambient Temp 1",
        "sensor-type thermal",
        "warning-low-threshold 5",
        "threshold-sensor-value 15",
        "critical-high-threshold 52",
        "warning-high-threshold 47",
        "node-name dmc1-r019-na1a",
        "value-units C",
        "threshold-sensor-state normal",
        "critical-low-threshold 0",
    ],
    [
        "sensor-name Ambient Temp 2",
        "sensor-type thermal",
        "warning-low-threshold 5",
        "threshold-sensor-value 15",
        "critical-high-threshold 52",
        "warning-high-threshold 47",
        "node-name dmc1-r019-na1a",
        "value-units C",
        "threshold-sensor-state normal",
        "critical-low-threshold 0",
    ],
    [
        "sensor-name P5V STBY",
        "sensor-type voltage",
        "warning-low-threshold 4343",
        "threshold-sensor-value 5075",
        "critical-high-threshold 5807",
        "warning-high-threshold 5660",
        "node-name dmc1-r019-na1a",
        "value-units mV",
        "threshold-sensor-state normal",
        "critical-low-threshold 4245",
    ],
    [
        "sensor-name P3.3V STBY",
        "sensor-type voltage",
        "warning-low-threshold 3040",
        "threshold-sensor-value 3264",
        "critical-high-threshold 3664",
        "warning-high-threshold 3568",
        "node-name dmc1-r019-na1a",
        "value-units mV",
        "threshold-sensor-state normal",
        "critical-low-threshold 2960",
    ],
    [
        "sensor-name P1.8V STBY",
        "sensor-type voltage",
        "warning-low-threshold 1658",
        "threshold-sensor-value 1804",
        "critical-high-threshold 1969",
        "warning-high-threshold 1949",
        "node-name dmc1-r019-na1a",
        "value-units mV",
        "threshold-sensor-state normal",
        "critical-low-threshold 1629",
    ],
    [
        "sensor-name P1.2V STBY",
        "sensor-type voltage",
        "warning-low-threshold 1105",
        "threshold-sensor-value 1193",
        "critical-high-threshold 1319",
        "warning-high-threshold 1299",
        "node-name dmc1-r019-na1a",
        "value-units mV",
        "threshold-sensor-state normal",
        "critical-low-threshold 1086",
    ],
    [
        "sensor-name P0.9V STBY",
        "sensor-type voltage",
        "warning-low-threshold 853",
        "threshold-sensor-value 892",
        "critical-high-threshold 999",
        "warning-high-threshold 950",
        "node-name dmc1-r019-na1a",
        "value-units mV",
        "threshold-sensor-state normal",
        "critical-low-threshold 805",
    ],
    [
        "sensor-name P5V",
        "sensor-type voltage",
        "warning-low-threshold 4343",
        "threshold-sensor-value 5002",
        "critical-high-threshold 5807",
        "warning-high-threshold 5660",
        "node-name dmc1-r019-na1a",
        "value-units mV",
        "threshold-sensor-state normal",
        "critical-low-threshold 4245",
    ],
    [
        "sensor-name P3.3V",
        "sensor-type voltage",
        "warning-low-threshold 3040",
        "threshold-sensor-value 3296",
        "critical-high-threshold 3664",
        "warning-high-threshold 3568",
        "node-name dmc1-r019-na1a",
        "value-units mV",
        "threshold-sensor-state normal",
        "critical-low-threshold 2960",
    ],
    [
        "sensor-name PVDDQ DDR4 AB",
        "sensor-type voltage",
        "warning-low-threshold 19",
        "threshold-sensor-value 1212",
        "critical-high-threshold 2463",
        "warning-high-threshold 2454",
        "node-name dmc1-r019-na1a",
        "value-units mV",
        "threshold-sensor-state normal",
        "critical-low-threshold 9",
    ],
    [
        "sensor-name PVTT DDR4 AB",
        "sensor-type voltage",
        "warning-low-threshold 19",
        "threshold-sensor-value 591",
        "critical-high-threshold 2463",
        "warning-high-threshold 2454",
        "node-name dmc1-r019-na1a",
        "value-units mV",
        "threshold-sensor-state normal",
        "critical-low-threshold 9",
    ],
    [
        "sensor-name PVCCP CPU0",
        "sensor-type voltage",
        "warning-low-threshold 19",
        "threshold-sensor-value 1775",
        "critical-high-threshold 2463",
        "warning-high-threshold 2454",
        "node-name dmc1-r019-na1a",
        "value-units mV",
        "threshold-sensor-state normal",
        "critical-low-threshold 9",
    ],
    [
        "sensor-name P3.3V BATT",
        "sensor-type voltage",
        "warning-low-threshold 32",
        "threshold-sensor-value 3040",
        "critical-high-threshold 4064",
        "warning-high-threshold 4048",
        "node-name dmc1-r019-na1a",
        "value-units mV",
        "threshold-sensor-state normal",
        "critical-low-threshold 16",
    ],
    [
        "sensor-name P12V",
        "sensor-type voltage",
        "threshold-sensor-value 11842",
        "critical-high-threshold 15810",
        "node-name dmc1-r019-na1a",
        "value-units mV",
        "threshold-sensor-state normal",
        "critical-low-threshold 0",
    ],
    [
        "sensor-name P12V Curr",
        "sensor-type current",
        "threshold-sensor-value 9828",
        "critical-high-threshold 21420",
        "node-name dmc1-r019-na1a",
        "value-units mA",
        "threshold-sensor-state normal",
        "critical-low-threshold 0",
    ],
    [
        "sensor-name P12V STBY",
        "sensor-type voltage",
        "threshold-sensor-value 11842",
        "critical-high-threshold 15810",
        "node-name dmc1-r019-na1a",
        "value-units mV",
        "threshold-sensor-state normal",
        "critical-low-threshold 0",
    ],
    [
        "sensor-name P12V STBY Curr",
        "sensor-type current",
        "threshold-sensor-value 764",
        "critical-high-threshold 3182",
        "node-name dmc1-r019-na1a",
        "value-units mA",
        "threshold-sensor-state normal",
        "critical-low-threshold 0",
    ],
    [
        "sensor-name Sysfan1 Present",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value PRESENT",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Sysfan1 Fault",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Sysfan1 F1 Speed",
        "sensor-type fan",
        "warning-low-threshold 1560",
        "threshold-sensor-value 2880",
        "node-name dmc1-r019-na1a",
        "value-units RPM",
        "threshold-sensor-state normal",
        "critical-low-threshold 1470",
    ],
    [
        "sensor-name Sysfan1 F2 Speed",
        "sensor-type fan",
        "warning-low-threshold 1560",
        "threshold-sensor-value 6240",
        "node-name dmc1-r019-na1a",
        "value-units RPM",
        "threshold-sensor-state normal",
        "critical-low-threshold 1470",
    ],
    [
        "sensor-name Sysfan2 Present",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value PRESENT",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Sysfan2 Fault",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Sysfan2 F1 Speed",
        "sensor-type fan",
        "warning-low-threshold 1560",
        "threshold-sensor-value 2820",
        "node-name dmc1-r019-na1a",
        "value-units RPM",
        "threshold-sensor-state normal",
        "critical-low-threshold 1470",
    ],
    [
        "sensor-name Sysfan2 F2 Speed",
        "sensor-type fan",
        "warning-low-threshold 1560",
        "threshold-sensor-value 6300",
        "node-name dmc1-r019-na1a",
        "value-units RPM",
        "threshold-sensor-state normal",
        "critical-low-threshold 1470",
    ],
    [
        "sensor-name Sysfan3 Present",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value PRESENT",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Sysfan3 Fault",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Sysfan3 F1 Speed",
        "sensor-type fan",
        "warning-low-threshold 1560",
        "threshold-sensor-value 2820",
        "node-name dmc1-r019-na1a",
        "value-units RPM",
        "threshold-sensor-state normal",
        "critical-low-threshold 1470",
    ],
    [
        "sensor-name Sysfan3 F2 Speed",
        "sensor-type fan",
        "warning-low-threshold 1560",
        "threshold-sensor-value 6240",
        "node-name dmc1-r019-na1a",
        "value-units RPM",
        "threshold-sensor-state normal",
        "critical-low-threshold 1470",
    ],
    [
        "sensor-name PSU1 Present",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value PRESENT",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU1 Temp",
        "sensor-type thermal",
        "warning-low-threshold 5",
        "threshold-sensor-value 14",
        "critical-high-threshold 60",
        "warning-high-threshold 50",
        "node-name dmc1-r019-na1a",
        "value-units C",
        "threshold-sensor-state normal",
        "critical-low-threshold 0",
    ],
    [
        "sensor-name PSU1 Curr",
        "sensor-type current",
        "threshold-sensor-value 11000",
        "node-name dmc1-r019-na1a",
        "value-units mA",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU1 Fan1 Speed",
        "sensor-type fan",
        "warning-low-threshold 4600",
        "threshold-sensor-value 6800",
        "node-name dmc1-r019-na1a",
        "value-units RPM",
        "threshold-sensor-state normal",
        "critical-low-threshold 4500",
    ],
    [
        "sensor-name PSU1 Fan1 Fault",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU1 Fan2 Speed",
        "sensor-type fan",
        "warning-low-threshold 4600",
        "threshold-sensor-value 6800",
        "node-name dmc1-r019-na1a",
        "value-units RPM",
        "threshold-sensor-state normal",
        "critical-low-threshold 4500",
    ],
    [
        "sensor-name PSU1 Fan2 Fault",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU1 Pwr In OK",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU1 Pwr Out OK",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU1 FAULT",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU1 Over Temp",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU1 Over Volt",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU1 Over Curr",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU1 Crest Factor",
        "sensor-type current",
        "threshold-sensor-value 1384",
        "critical-high-threshold 2000",
        "warning-high-threshold 1728",
        "node-name dmc1-r019-na1a",
        "threshold-sensor-state normal",
        "critical-low-threshold 1000",
    ],
    [
        "sensor-name PSU1 InPwr Monitor",
        "sensor-type unknown",
        "threshold-sensor-value 147000",
        "node-name dmc1-r019-na1a",
        "value-units mW",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU2 Present",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value PRESENT",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU2 Temp",
        "sensor-type thermal",
        "warning-low-threshold 5",
        "threshold-sensor-value 14",
        "critical-high-threshold 60",
        "warning-high-threshold 50",
        "node-name dmc1-r019-na1a",
        "value-units C",
        "threshold-sensor-state normal",
        "critical-low-threshold 0",
    ],
    [
        "sensor-name PSU2 Curr",
        "sensor-type current",
        "threshold-sensor-value 12000",
        "node-name dmc1-r019-na1a",
        "value-units mA",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU2 Fan1 Speed",
        "sensor-type fan",
        "warning-low-threshold 4600",
        "threshold-sensor-value 7000",
        "node-name dmc1-r019-na1a",
        "value-units RPM",
        "threshold-sensor-state normal",
        "critical-low-threshold 4500",
    ],
    [
        "sensor-name PSU2 Fan1 Fault",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU2 Fan2 Speed",
        "sensor-type fan",
        "warning-low-threshold 4600",
        "threshold-sensor-value 6900",
        "node-name dmc1-r019-na1a",
        "value-units RPM",
        "threshold-sensor-state normal",
        "critical-low-threshold 4500",
    ],
    [
        "sensor-name PSU2 Fan2 Fault",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU2 Pwr In OK",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU2 Pwr Out OK",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU2 FAULT",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU2 Over Temp",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU2 Over Volt",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU2 Over Curr",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value OK",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name PSU2 Crest Factor",
        "sensor-type current",
        "threshold-sensor-value 1392",
        "critical-high-threshold 2000",
        "warning-high-threshold 1728",
        "node-name dmc1-r019-na1a",
        "threshold-sensor-state normal",
        "critical-low-threshold 1000",
    ],
    [
        "sensor-name PSU2 InPwr Monitor",
        "sensor-type unknown",
        "threshold-sensor-value 157000",
        "node-name dmc1-r019-na1a",
        "value-units mW",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Bat Present",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value PRESENT",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Bat Temp",
        "sensor-type thermal",
        "warning-low-threshold 5",
        "threshold-sensor-value 15",
        "critical-high-threshold 58",
        "warning-high-threshold 53",
        "node-name dmc1-r019-na1a",
        "value-units C",
        "threshold-sensor-state normal",
        "critical-low-threshold 0",
    ],
    [
        "sensor-name Bat Volt",
        "sensor-type voltage",
        "warning-low-threshold 5600",
        "threshold-sensor-value 8100",
        "critical-high-threshold 8600",
        "warning-high-threshold 8500",
        "node-name dmc1-r019-na1a",
        "value-units mV",
        "threshold-sensor-state normal",
        "critical-low-threshold 5500",
    ],
    [
        "sensor-name Bat Curr",
        "sensor-type current",
        "threshold-sensor-value 0",
        "critical-high-threshold 2600",
        "warning-high-threshold 2320",
        "node-name dmc1-r019-na1a",
        "value-units mA",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Bat Rem Cap",
        "sensor-type battery_life",
        "threshold-sensor-value 3328",
        "node-name dmc1-r019-na1a",
        "value-units mA*hr",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Bat Full Cap",
        "sensor-type battery_life",
        "threshold-sensor-value 3328",
        "node-name dmc1-r019-na1a",
        "value-units mA*hr",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Bat Charge Curr",
        "sensor-type current",
        "threshold-sensor-value 0",
        "critical-high-threshold 2300",
        "warning-high-threshold 2200",
        "node-name dmc1-r019-na1a",
        "value-units mA",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Bat Charge Volt",
        "sensor-type voltage",
        "threshold-sensor-value 8200",
        "critical-high-threshold 9000",
        "warning-high-threshold 8900",
        "node-name dmc1-r019-na1a",
        "value-units mV",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Bat Initial FCC",
        "sensor-type battery_life",
        "threshold-sensor-value 3200",
        "node-name dmc1-r019-na1a",
        "value-units mA*hr",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Bat Dstg Cycles",
        "sensor-type counter",
        "warning-low-threshold 5",
        "threshold-sensor-value 21",
        "node-name dmc1-r019-na1a",
        "value-units cycles",
        "threshold-sensor-state normal",
        "critical-low-threshold 2",
    ],
    [
        "sensor-name Bat Power Fault",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value GOOD",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Bat Dcharge FET",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value ON",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Bat Charge FET",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value ON",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Bat Cycle Count",
        "sensor-type counter",
        "threshold-sensor-value 1",
        "node-name dmc1-r019-na1a",
        "value-units cycles",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Partner Ctrl Pre",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value NOT_PRESENT",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
    [
        "sensor-name Attention",
        "sensor-type discrete",
        "node-name dmc1-r019-na1a",
        "discrete-sensor-value DEASSERT",
        "discrete-sensor-state normal",
        "threshold-sensor-state normal",
    ],
]


discovery = {
    "": [("dmc1-r019-na1a / PSU1 FAULT", None), ("dmc1-r019-na1a / PSU2 FAULT", None)],
    "current": [
        ("dmc1-r019-na1a / Bat Charge Curr", None),
        ("dmc1-r019-na1a / Bat Curr", None),
        ("dmc1-r019-na1a / P12V Curr", None),
        ("dmc1-r019-na1a / P12V STBY Curr", None),
        ("dmc1-r019-na1a / PSU1 Curr", None),
        ("dmc1-r019-na1a / PSU2 Curr", None),
    ],
    "fan_faults": [
        ("dmc1-r019-na1a / PSU1 Fan1 Fault", None),
        ("dmc1-r019-na1a / PSU1 Fan2 Fault", None),
        ("dmc1-r019-na1a / PSU2 Fan1 Fault", None),
        ("dmc1-r019-na1a / PSU2 Fan2 Fault", None),
        ("dmc1-r019-na1a / Sysfan1 Fault", None),
        ("dmc1-r019-na1a / Sysfan2 Fault", None),
        ("dmc1-r019-na1a / Sysfan3 Fault", None),
    ],
    "fans": [
        ("dmc1-r019-na1a / PSU1 Fan1 Speed", None),
        ("dmc1-r019-na1a / PSU1 Fan2 Speed", None),
        ("dmc1-r019-na1a / PSU2 Fan1 Speed", None),
        ("dmc1-r019-na1a / PSU2 Fan2 Speed", None),
        ("dmc1-r019-na1a / Sysfan1 F1 Speed", None),
        ("dmc1-r019-na1a / Sysfan1 F2 Speed", None),
        ("dmc1-r019-na1a / Sysfan2 F1 Speed", None),
        ("dmc1-r019-na1a / Sysfan2 F2 Speed", None),
        ("dmc1-r019-na1a / Sysfan3 F1 Speed", None),
        ("dmc1-r019-na1a / Sysfan3 F2 Speed", None),
    ],
    "temperature": [
        ("dmc1-r019-na1a / Ambient Temp 1", None),
        ("dmc1-r019-na1a / Ambient Temp 2", None),
        ("dmc1-r019-na1a / Bat Temp", None),
        ("dmc1-r019-na1a / CPU0 Temp Margin", None),
        ("dmc1-r019-na1a / In Flow Temp", None),
        ("dmc1-r019-na1a / Out Flow Temp", None),
        ("dmc1-r019-na1a / PCI Slot Temp", None),
        ("dmc1-r019-na1a / PSU1 Temp", None),
        ("dmc1-r019-na1a / PSU2 Temp", None),
        ("dmc1-r019-na1a / Smart Bat Temp", None),
    ],
    "voltage": [
        ("dmc1-r019-na1a / Bat Charge Volt", None),
        ("dmc1-r019-na1a / Bat Volt", None),
        ("dmc1-r019-na1a / P0.9V STBY", None),
        ("dmc1-r019-na1a / P1.2V STBY", None),
        ("dmc1-r019-na1a / P1.8V STBY", None),
        ("dmc1-r019-na1a / P12V STBY", None),
        ("dmc1-r019-na1a / P12V", None),
        ("dmc1-r019-na1a / P3.3V BATT", None),
        ("dmc1-r019-na1a / P3.3V STBY", None),
        ("dmc1-r019-na1a / P3.3V", None),
        ("dmc1-r019-na1a / P5V STBY", None),
        ("dmc1-r019-na1a / P5V", None),
        ("dmc1-r019-na1a / PVCCP CPU0", None),
        ("dmc1-r019-na1a / PVDDQ DDR4 AB", None),
        ("dmc1-r019-na1a / PVTT DDR4 AB", None),
    ],
}


checks = {
    "": [
        ("dmc1-r019-na1a / PSU1 FAULT", {}, [(0, "Sensor state: normal, Sensor value: OK", [])]),
        ("dmc1-r019-na1a / PSU2 FAULT", {}, [(0, "Sensor state: normal, Sensor value: OK", [])]),
    ],
    "current": [
        (
            "dmc1-r019-na1a / Bat Charge Curr",
            {},
            [(0, "0.00 a", [("current", 0.0, 2.2, 2.3, None, None)])],
        ),
        (
            "dmc1-r019-na1a / Bat Curr",
            {},
            [(0, "0.00 a", [("current", 0.0, 2.32, 2.6, None, None)])],
        ),
        (
            "dmc1-r019-na1a / P12V Curr",
            {},
            [(0, "9.83 a", [("current", 9.828, None, 21.42, None, None)])],
        ),
        (
            "dmc1-r019-na1a / P12V STBY Curr",
            {},
            [(0, "0.76 a", [("current", 0.764, None, 3.182, None, None)])],
        ),
        (
            "dmc1-r019-na1a / PSU1 Curr",
            {},
            [(0, "11.00 a", [("current", 11.0, None, None, None, None)])],
        ),
        (
            "dmc1-r019-na1a / PSU2 Curr",
            {},
            [(0, "12.00 a", [("current", 12.0, None, None, None, None)])],
        ),
    ],
    "fan_faults": [
        (
            "dmc1-r019-na1a / PSU1 Fan1 Fault",
            {},
            [(0, "Sensor state: normal, Sensor value: OK", [])],
        ),
        (
            "dmc1-r019-na1a / PSU1 Fan2 Fault",
            {},
            [(0, "Sensor state: normal, Sensor value: OK", [])],
        ),
        (
            "dmc1-r019-na1a / PSU2 Fan1 Fault",
            {},
            [(0, "Sensor state: normal, Sensor value: OK", [])],
        ),
        (
            "dmc1-r019-na1a / PSU2 Fan2 Fault",
            {},
            [(0, "Sensor state: normal, Sensor value: OK", [])],
        ),
        ("dmc1-r019-na1a / Sysfan1 Fault", {}, [(0, "Sensor state: normal, Sensor value: OK", [])]),
        ("dmc1-r019-na1a / Sysfan2 Fault", {}, [(0, "Sensor state: normal, Sensor value: OK", [])]),
        ("dmc1-r019-na1a / Sysfan3 Fault", {}, [(0, "Sensor state: normal, Sensor value: OK", [])]),
    ],
    "fans": [
        (
            "dmc1-r019-na1a / PSU1 Fan1 Speed",
            {},
            [(0, "6800 rpm", [("fan", 6800.0, None, None, None, None)])],
        ),
        (
            "dmc1-r019-na1a / PSU1 Fan2 Speed",
            {},
            [(0, "6800 rpm", [("fan", 6800.0, None, None, None, None)])],
        ),
        (
            "dmc1-r019-na1a / PSU2 Fan1 Speed",
            {},
            [(0, "7000 rpm", [("fan", 7000.0, None, None, None, None)])],
        ),
        (
            "dmc1-r019-na1a / PSU2 Fan2 Speed",
            {},
            [(0, "6900 rpm", [("fan", 6900.0, None, None, None, None)])],
        ),
        (
            "dmc1-r019-na1a / Sysfan1 F1 Speed",
            {},
            [(0, "2880 rpm", [("fan", 2880.0, None, None, None, None)])],
        ),
        (
            "dmc1-r019-na1a / Sysfan1 F2 Speed",
            {},
            [(0, "6240 rpm", [("fan", 6240.0, None, None, None, None)])],
        ),
        (
            "dmc1-r019-na1a / Sysfan2 F1 Speed",
            {},
            [(0, "2820 rpm", [("fan", 2820.0, None, None, None, None)])],
        ),
        (
            "dmc1-r019-na1a / Sysfan2 F2 Speed",
            {},
            [(0, "6300 rpm", [("fan", 6300.0, None, None, None, None)])],
        ),
        (
            "dmc1-r019-na1a / Sysfan3 F1 Speed",
            {},
            [(0, "2820 rpm", [("fan", 2820.0, None, None, None, None)])],
        ),
        (
            "dmc1-r019-na1a / Sysfan3 F2 Speed",
            {},
            [(0, "6240 rpm", [("fan", 6240.0, None, None, None, None)])],
        ),
    ],
    "temperature": [
        (
            "dmc1-r019-na1a / Ambient Temp 1",
            {},
            [(0, "15.0 \xb0C", [("temp", 15.0, 47.0, 52.0, None, None)])],
        ),
        (
            "dmc1-r019-na1a / Ambient Temp 2",
            {},
            [(0, "15.0 \xb0C", [("temp", 15.0, 47.0, 52.0, None, None)])],
        ),
        (
            "dmc1-r019-na1a / Bat Temp",
            {},
            [(0, "15.0 \xb0C", [("temp", 15.0, 53.0, 58.0, None, None)])],
        ),
        (
            "dmc1-r019-na1a / CPU0 Temp Margin",
            {},
            [(0, "-78.0 \xb0C", [("temp", -78.0, -10.0, 0.0, None, None)])],
        ),
        (
            "dmc1-r019-na1a / In Flow Temp",
            {},
            [(0, "16.0 \xb0C", [("temp", 16.0, 50.0, 55.0, None, None)])],
        ),
        (
            "dmc1-r019-na1a / Out Flow Temp",
            {},
            [(0, "23.0 \xb0C", [("temp", 23.0, 65.0, 75.0, None, None)])],
        ),
        (
            "dmc1-r019-na1a / PCI Slot Temp",
            {},
            [(0, "21.0 \xb0C", [("temp", 21.0, 60.0, 70.0, None, None)])],
        ),
        (
            "dmc1-r019-na1a / PSU1 Temp",
            {},
            [(0, "14.0 \xb0C", [("temp", 14.0, 50.0, 60.0, None, None)])],
        ),
        (
            "dmc1-r019-na1a / PSU2 Temp",
            {},
            [(0, "14.0 \xb0C", [("temp", 14.0, 50.0, 60.0, None, None)])],
        ),
        (
            "dmc1-r019-na1a / Smart Bat Temp",
            {},
            [(0, "19.0 \xb0C", [("temp", 19.0, 60.0, 70.0, None, None)])],
        ),
    ],
    "voltage": [
        (
            "dmc1-r019-na1a / Bat Charge Volt",
            {},
            [(0, "8.20 v", [("voltage", 8.2, 8.9, 9.0, None, None)])],
        ),
        (
            "dmc1-r019-na1a / Bat Volt",
            {},
            [(0, "8.10 v", [("voltage", 8.1, 8.5, 8.6, None, None)])],
        ),
        (
            "dmc1-r019-na1a / P0.9V STBY",
            {},
            [(0, "0.89 v", [("voltage", 0.892, 0.95, 0.999, None, None)])],
        ),
        (
            "dmc1-r019-na1a / P1.2V STBY",
            {},
            [(0, "1.19 v", [("voltage", 1.193, 1.299, 1.319, None, None)])],
        ),
        (
            "dmc1-r019-na1a / P1.8V STBY",
            {},
            [(0, "1.80 v", [("voltage", 1.804, 1.949, 1.969, None, None)])],
        ),
        (
            "dmc1-r019-na1a / P12V STBY",
            {},
            [(0, "11.84 v", [("voltage", 11.842, None, 15.81, None, None)])],
        ),
        (
            "dmc1-r019-na1a / P12V",
            {},
            [(0, "11.84 v", [("voltage", 11.842, None, 15.81, None, None)])],
        ),
        (
            "dmc1-r019-na1a / P3.3V BATT",
            {},
            [(0, "3.04 v", [("voltage", 3.04, 4.048, 4.064, None, None)])],
        ),
        (
            "dmc1-r019-na1a / P3.3V STBY",
            {},
            [(0, "3.26 v", [("voltage", 3.264, 3.568, 3.664, None, None)])],
        ),
        (
            "dmc1-r019-na1a / P3.3V",
            {},
            [(0, "3.30 v", [("voltage", 3.296, 3.568, 3.664, None, None)])],
        ),
        (
            "dmc1-r019-na1a / P5V STBY",
            {},
            [(0, "5.08 v", [("voltage", 5.075, 5.66, 5.807, None, None)])],
        ),
        (
            "dmc1-r019-na1a / P5V",
            {},
            [(0, "5.00 v", [("voltage", 5.002, 5.66, 5.807, None, None)])],
        ),
        (
            "dmc1-r019-na1a / PVCCP CPU0",
            {},
            [(0, "1.77 v", [("voltage", 1.775, 2.454, 2.463, None, None)])],
        ),
        (
            "dmc1-r019-na1a / PVDDQ DDR4 AB",
            {},
            [(0, "1.21 v", [("voltage", 1.212, 2.454, 2.463, None, None)])],
        ),
        (
            "dmc1-r019-na1a / PVTT DDR4 AB",
            {},
            [(0, "0.59 v", [("voltage", 0.591, 2.454, 2.463, None, None)])],
        ),
    ],
}
