#!/usr/bin/env python3
# Copyright (C) 2019 Checkmk GmbH - License: GNU General Public License v2
# This file is part of Checkmk (https://checkmk.com). It is subject to the terms and
# conditions defined in the file COPYING, which is part of this source code package.


from cmk.base.plugins.agent_based import ceph_df
from cmk.base.plugins.agent_based.agent_based_api.v1 import Service


def test_sanitize_line() -> None:
    assert ceph_df._sanitize_line(
        [
            "cephfs_data",
            "1",
            "N/A",
            "N/A",
            "1.6",
            "GiB",
            "1.97",
            "77",
            "GiB",
            "809",
            "809",
            "33",
            "B",
            "177",
            "KiB",
            "4.7",
            "GiB",
        ]
    ) == [
        "cephfs_data",
        "1",
        "N/A",
        "N/A",
        "1.6GiB",
        "1.97",
        "77GiB",
        "809",
        "809",
        "33B",
        "177KiB",
        "4.7GiB",
    ]


def test_discovery_1() -> None:
    assert sorted(
        ceph_df.discover_ceph_df(
            [],
            ceph_df.parse_ceph_df(
                [
                    ["GLOBAL:"],
                    ["SIZE", "AVAIL", "RAW", "USED", "%RAW", "USED", "OBJECTS"],
                    ["873TiB", "779TiB", "94.2TiB", "10.79", "11.26M"],
                    ["POOLS:"],
                    [
                        "NAME",
                        "ID",
                        "QUOTA",
                        "OBJECTS",
                        "QUOTA",
                        "BYTES",
                        "USED",
                        "%USED",
                        "MAX",
                        "AVAIL",
                        "OBJECTS",
                        "DIRTY",
                        "READ",
                        "WRITE",
                        "RAW",
                        "USED",
                    ],
                    [
                        ".rgw.root",
                        "1",
                        "N/A",
                        "N/A",
                        "11.1KiB",
                        "0",
                        "242TiB",
                        "61",
                        "61",
                        "11.7KiB",
                        "219B",
                        "33.4KiB",
                    ],
                    [
                        "default.rgw.control",
                        "2",
                        "N/A",
                        "N/A",
                        "0B",
                        "0",
                        "242TiB",
                        "8",
                        "8",
                        "0B",
                        "0B",
                        "0B",
                    ],
                    [
                        "default.rgw.meta",
                        "3",
                        "N/A",
                        "N/A",
                        "73.6KiB",
                        "0",
                        "242TiB",
                        "252",
                        "252",
                        "257KiB",
                        "6.96KiB",
                        "221KiB",
                    ],
                    [
                        "default.rgw.log",
                        "4",
                        "N/A",
                        "N/A",
                        "149B",
                        "0",
                        "242TiB",
                        "406",
                        "406",
                        "19.0MiB",
                        "12.7MiB",
                        "447B",
                    ],
                    [
                        "rbd-rub.ec",
                        "5",
                        "N/A",
                        "N/A",
                        "19.4TiB",
                        "3.43",
                        "544TiB",
                        "5086154",
                        "5.09M",
                        "12B",
                        "292MiB",
                        "25.8TiB",
                    ],
                    [
                        "rbd",
                        "6",
                        "N/A",
                        "N/A",
                        "21.5TiB",
                        "8.17",
                        "242TiB",
                        "5695802",
                        "5.70M",
                        "42.9MiB",
                        "403MiB",
                        "64.6TiB",
                    ],
                    [
                        "ceph-bench",
                        "7",
                        "N/A",
                        "N/A",
                        "6.21GiB",
                        "0",
                        "242TiB",
                        "1591",
                        "1.59k",
                        "0B",
                        "3.11KiB",
                        "18.6GiB",
                    ],
                    [
                        "rados-bench.ec",
                        "8",
                        "N/A",
                        "N/A",
                        "6.59GiB",
                        "0",
                        "544TiB",
                        "1684",
                        "1.68k",
                        "0B",
                        "3.29KiB",
                        "8.78GiB",
                    ],
                    [
                        "rados-bench-ude.ec",
                        "9",
                        "N/A",
                        "N/A",
                        "6.60GiB",
                        "0",
                        "544TiB",
                        "1687",
                        "1.69k",
                        "0B",
                        "3.29KiB",
                        "8.80GiB",
                    ],
                    [
                        "default.rgw.buckets.index",
                        "10",
                        "N/A",
                        "N/A",
                        "0B",
                        "0",
                        "242TiB",
                        "589",
                        "589",
                        "4.37MiB",
                        "59.4MiB",
                        "0B",
                    ],
                    [
                        "default.rgw.buckets.data",
                        "11",
                        "N/A",
                        "N/A",
                        "425GiB",
                        "0.17",
                        "242TiB",
                        "465820",
                        "465.82k",
                        "420KiB",
                        "1.40MiB",
                        "1.25TiB",
                    ],
                    [
                        "default.rgw.buckets.non-ec",
                        "12",
                        "N/A",
                        "N/A",
                        "0B",
                        "0",
                        "242TiB",
                        "5",
                        "5",
                        "339KiB",
                        "368KiB",
                        "0B",
                    ],
                    [
                        "scbench",
                        "13",
                        "N/A",
                        "N/A",
                        "2.32GiB",
                        "0",
                        "242TiB",
                        "596",
                        "596",
                        "1B",
                        "2.05KiB",
                        "6.97GiB",
                    ],
                    [
                        "rub-s3.ec",
                        "16",
                        "N/A",
                        "N/A",
                        "4.88KiB",
                        "0",
                        "272TiB",
                        "1000",
                        "1k",
                        "0B",
                        "1002B",
                        "6.51KiB",
                    ],
                ]
            ),
        )
    ) == [
        Service(item=".rgw.root"),
        Service(item="SUMMARY"),
        Service(item="ceph-bench"),
        Service(item="default.rgw.buckets.data"),
        Service(item="default.rgw.buckets.index"),
        Service(item="default.rgw.buckets.non-ec"),
        Service(item="default.rgw.control"),
        Service(item="default.rgw.log"),
        Service(item="default.rgw.meta"),
        Service(item="rados-bench-ude.ec"),
        Service(item="rados-bench.ec"),
        Service(item="rbd"),
        Service(item="rbd-rub.ec"),
        Service(item="rub-s3.ec"),
        Service(item="scbench"),
    ]


def test_discovery_2() -> None:
    assert sorted(
        ceph_df.discover_ceph_df(
            [],
            ceph_df.parse_ceph_df(
                [
                    ["GLOBAL:"],
                    ["SIZE", "AVAIL", "RAW", "USED", "%RAW", "USED", "OBJECTS"],
                    ["253", "GiB", "245", "GiB", "7.8", "GiB", "3.10", "839"],
                    ["POOLS:"],
                    [
                        "NAME",
                        "ID",
                        "QUOTA",
                        "OBJECTS",
                        "QUOTA",
                        "BYTES",
                        "USED",
                        "%USED",
                        "MAX",
                        "AVAIL",
                        "OBJECTS",
                        "DIRTY",
                        "READ",
                        "WRITE",
                        "RAW",
                        "USED",
                    ],
                    [
                        "cephfs_data",
                        "1",
                        "N/A",
                        "N/A",
                        "1.6",
                        "GiB",
                        "1.97",
                        "77",
                        "GiB",
                        "809",
                        "809",
                        "33",
                        "B",
                        "177",
                        "KiB",
                        "4.7",
                        "GiB",
                    ],
                    [
                        "cephfs_metadata",
                        "2",
                        "N/A",
                        "N/A",
                        "32",
                        "MiB",
                        "0.04",
                        "77",
                        "GiB",
                        "30",
                        "30",
                        "407",
                        "B",
                        "14",
                        "KiB",
                        "95",
                        "MiB",
                    ],
                ]
            ),
        )
    ) == [
        Service(item="SUMMARY"),
        Service(item="cephfs_data"),
        Service(item="cephfs_metadata"),
    ]


def test_discovery_3() -> None:
    assert sorted(
        ceph_df.discover_ceph_df(
            [],
            ceph_df.parse_ceph_df(
                [
                    ["GLOBAL:"],
                    ["SIZE", "AVAIL", "RAW", "USED", "%RAW", "USED", "OBJECTS"],
                    ["253", "GiB", "245", "GiB", "7.8", "GiB", "3.10", "839"],
                    ["POOLS:"],
                    [
                        "NAME",
                        "ID",
                        "QUOTA",
                        "OBJECTS",
                        "QUOTA",
                        "BYTES",
                        "USED",
                        "%USED",
                        "MAX",
                        "AVAIL",
                        "OBJECTS",
                        "DIRTY",
                        "READ",
                        "WRITE",
                        "RAW",
                        "USED",
                    ],
                    [
                        "cephfs_data",
                        "1",
                        "N/A",
                        "N/A",
                        "1.6",
                        "GiB",
                        "1.97",
                        "77",
                        "GiB",
                        "809",
                        "809",
                        "33",
                        "B",
                        "177",
                        "KiB",
                        "4.7",
                        "GiB",
                    ],
                    [
                        "cephfs_metadata",
                        "2",
                        "N/A",
                        "N/A",
                        "32",
                        "MiB",
                        "0.04",
                        "77",
                        "GiB",
                        "30",
                        "30",
                        "407",
                        "B",
                        "14",
                        "KiB",
                        "95",
                        "MiB",
                    ],
                ]
            ),
        )
    ) == [
        Service(item="SUMMARY"),
        Service(item="cephfs_data"),
        Service(item="cephfs_metadata"),
    ]


def test_discovery_4() -> None:
    assert sorted(
        ceph_df.discover_ceph_df(
            [],
            ceph_df.parse_ceph_df(
                [
                    ["GLOBAL:"],
                    ["SIZE", "AVAIL", "RAW", "USED", "%RAW", "USED", "OBJECTS"],
                    ["200T", "186T", "13808G", "6.74", "8774k"],
                    ["POOLS:"],
                    [
                        "NAME",
                        "ID",
                        "CATEGORY",
                        "QUOTA",
                        "OBJECTS",
                        "QUOTA",
                        "BYTES",
                        "USED",
                        "%USED",
                        "MAX",
                        "AVAIL",
                        "OBJECTS",
                        "DIRTY",
                        "READ",
                        "WRITE",
                        "RAW",
                        "USED",
                    ],
                    [
                        "seafile-commits",
                        "33",
                        "-",
                        "N/A",
                        "N/A",
                        "276M",
                        "0.04",
                        "744G",
                        "506506",
                        "494k",
                        "315k",
                        "496k",
                        "829M",
                    ],
                    [
                        "seafile-blocks",
                        "35",
                        "-",
                        "N/A",
                        "N/A",
                        "685G",
                        "0.56",
                        "119T",
                        "879162",
                        "858k",
                        "891k",
                        "1168k",
                        "1027G",
                    ],
                    [
                        "seafile-fs",
                        "36",
                        "-",
                        "N/A",
                        "N/A",
                        "11412M",
                        "1.47",
                        "744G",
                        "2502095",
                        "2443k",
                        "5782k",
                        "2660k",
                        "34237M",
                    ],
                    [
                        "seafile-blocks-cache",
                        "37",
                        "-",
                        "N/A",
                        "200G",
                        "149G",
                        "16.69",
                        "744G",
                        "198252",
                        "96433",
                        "5105k",
                        "1944k",
                        "447G",
                    ],
                    [
                        "rbd",
                        "49",
                        "-",
                        "N/A",
                        "N/A",
                        "3106G",
                        "2.47",
                        "119T",
                        "795700",
                        "777k",
                        "16212k",
                        "14942k",
                        "4660G",
                    ],
                    [
                        "rbd-cache",
                        "50",
                        "-",
                        "N/A",
                        "N/A",
                        "40652M",
                        "5.06",
                        "744G",
                        "10173",
                        "3565",
                        "50513k",
                        "558M",
                        "119G",
                    ],
                    [
                        "cephfs01_meta",
                        "53",
                        "-",
                        "N/A",
                        "N/A",
                        "131M",
                        "0.02",
                        "744G",
                        "24170",
                        "24170",
                        "30172",
                        "14199k",
                        "393M",
                    ],
                    [
                        "cephfs01",
                        "54",
                        "-",
                        "N/A",
                        "N/A",
                        "4643G",
                        "3.65",
                        "119T",
                        "4046530",
                        "3951k",
                        "72301",
                        "4396k",
                        "6965G",
                    ],
                    [
                        "cephfs01-cache",
                        "55",
                        "-",
                        "N/A",
                        "N/A",
                        "81681M",
                        "9.67",
                        "744G",
                        "22523",
                        "11189",
                        "86325",
                        "16059k",
                        "239G",
                    ],
                ]
            ),
        )
    ) == [
        Service(item="SUMMARY"),
        Service(item="cephfs01"),
        Service(item="cephfs01-cache"),
        Service(item="cephfs01_meta"),
        Service(item="rbd"),
        Service(item="rbd-cache"),
        Service(item="seafile-blocks"),
        Service(item="seafile-blocks-cache"),
        Service(item="seafile-commits"),
        Service(item="seafile-fs"),
    ]


def test_discovery_5() -> None:
    assert sorted(
        ceph_df.discover_ceph_df(
            [],
            ceph_df.parse_ceph_df(
                [
                    ["GLOBAL:"],
                    ["SIZE", "AVAIL", "RAW", "USED", "%RAW", "USED", "OBJECTS"],
                    ["200T", "186T", "13808G", "6.74", "8774k"],
                    ["POOLS:"],
                    [
                        "NAME",
                        "ID",
                        "CATEGORY",
                        "QUOTA",
                        "OBJECTS",
                        "QUOTA",
                        "BYTES",
                        "USED",
                        "%USED",
                        "MAX",
                        "AVAIL",
                        "OBJECTS",
                        "DIRTY",
                        "READ",
                        "WRITE",
                        "RAW",
                        "USED",
                    ],
                    [
                        "seafile-commits",
                        "33",
                        "-",
                        "N/A",
                        "N/A",
                        "276M",
                        "0.04",
                        "744G",
                        "506506",
                        "494k",
                        "315k",
                        "496k",
                        "829M",
                    ],
                    [
                        "seafile-blocks",
                        "35",
                        "-",
                        "N/A",
                        "N/A",
                        "685G",
                        "0.56",
                        "119T",
                        "879162",
                        "858k",
                        "891k",
                        "1168k",
                        "1027G",
                    ],
                    [
                        "seafile-fs",
                        "36",
                        "-",
                        "N/A",
                        "N/A",
                        "11412M",
                        "1.47",
                        "744G",
                        "2502095",
                        "2443k",
                        "5782k",
                        "2660k",
                        "34237M",
                    ],
                    [
                        "seafile-blocks-cache",
                        "37",
                        "-",
                        "N/A",
                        "200G",
                        "149G",
                        "16.69",
                        "744G",
                        "198252",
                        "96433",
                        "5105k",
                        "1944k",
                        "447G",
                    ],
                    [
                        "rbd",
                        "49",
                        "-",
                        "N/A",
                        "N/A",
                        "3106G",
                        "2.47",
                        "119T",
                        "795700",
                        "777k",
                        "16212k",
                        "14942k",
                        "4660G",
                    ],
                    [
                        "rbd-cache",
                        "50",
                        "-",
                        "N/A",
                        "N/A",
                        "40652M",
                        "5.06",
                        "744G",
                        "10173",
                        "3565",
                        "50513k",
                        "558M",
                        "119G",
                    ],
                    [
                        "cephfs01_meta",
                        "53",
                        "-",
                        "N/A",
                        "N/A",
                        "131M",
                        "0.02",
                        "744G",
                        "24170",
                        "24170",
                        "30172",
                        "14199k",
                        "393M",
                    ],
                    [
                        "cephfs01",
                        "54",
                        "-",
                        "N/A",
                        "N/A",
                        "4643G",
                        "3.65",
                        "119T",
                        "4046530",
                        "3951k",
                        "72301",
                        "4396k",
                        "6965G",
                    ],
                    [
                        "cephfs01-cache",
                        "55",
                        "-",
                        "N/A",
                        "N/A",
                        "81681M",
                        "9.67",
                        "744G",
                        "22523",
                        "11189",
                        "86325",
                        "16059k",
                        "239G",
                    ],
                ]
            ),
        )
    ) == [
        Service(item="SUMMARY"),
        Service(item="cephfs01"),
        Service(item="cephfs01-cache"),
        Service(item="cephfs01_meta"),
        Service(item="rbd"),
        Service(item="rbd-cache"),
        Service(item="seafile-blocks"),
        Service(item="seafile-blocks-cache"),
        Service(item="seafile-commits"),
        Service(item="seafile-fs"),
    ]


def test_discovery_octopus() -> None:
    assert sorted(
        ceph_df.discover_ceph_df(
            [],
            ceph_df.parse_ceph_df(
                [
                    ["---", "RAW", "STORAGE", "---"],
                    ["CLASS", "SIZE", "AVAIL", "USED", "RAW", "USED", "%RAW", "USED"],
                    [
                        "ssd",
                        "27",
                        "TiB",
                        "21",
                        "TiB",
                        "5.9",
                        "TiB",
                        "5.9",
                        "TiB",
                        "21.76",
                    ],
                    [
                        "TOTAL",
                        "27",
                        "TiB",
                        "21",
                        "TiB",
                        "5.9",
                        "TiB",
                        "5.9",
                        "TiB",
                        "21.76",
                    ],
                    ["---", "POOLS", "---"],
                    [
                        "POOL",
                        "ID",
                        "STORED",
                        "(DATA)",
                        "(OMAP)",
                        "OBJECTS",
                        "USED",
                        "(DATA)",
                        "(OMAP)",
                        "%USED",
                        "MAX",
                        "AVAIL",
                        "QUOTA",
                        "OBJECTS",
                        "QUOTA",
                        "BYTES",
                        "DIRTY",
                        "USED",
                        "COMPR",
                        "UNDER",
                        "COMPR",
                    ],
                    [
                        "ceph-customer",
                        "1",
                        "1.7",
                        "TiB",
                        "1.7",
                        "TiB",
                        "720",
                        "MiB",
                        "540.44k",
                        "4.5",
                        "TiB",
                        "4.5",
                        "TiB",
                        "2.1",
                        "GiB",
                        "18.92",
                        "6.5",
                        "TiB",
                        "N/A",
                        "N/A",
                        "540.44k",
                        "0",
                        "B",
                        "0",
                        "B",
                    ],
                    [
                        "ceph-sb",
                        "2",
                        "472",
                        "GiB",
                        "472",
                        "GiB",
                        "249",
                        "MiB",
                        "165.16k",
                        "1.4",
                        "TiB",
                        "1.4",
                        "TiB",
                        "747",
                        "MiB",
                        "6.51",
                        "6.5",
                        "TiB",
                        "N/A",
                        "N/A",
                        "165.16k",
                        "0",
                        "B",
                        "0",
                        "B",
                    ],
                    [
                        "device_health_metrics",
                        "4",
                        "31",
                        "MiB",
                        "0",
                        "B",
                        "31",
                        "MiB",
                        "32",
                        "92",
                        "MiB",
                        "0",
                        "B",
                        "92",
                        "MiB",
                        "0",
                        "6.5",
                        "TiB",
                        "N/A",
                        "N/A",
                        "32",
                        "0",
                        "B",
                        "0",
                        "B",
                    ],
                    [
                        "ceph-customer-ec32",
                        "6",
                        "5.9",
                        "GiB",
                        "5.9",
                        "GiB",
                        "0",
                        "B",
                        "1.59k",
                        "9.3",
                        "GiB",
                        "9.3",
                        "GiB",
                        "0",
                        "B",
                        "0.05",
                        "12",
                        "TiB",
                        "N/A",
                        "N/A",
                        "1.59k",
                        "1.3",
                        "GiB",
                        "2.6",
                        "GiB",
                    ],
                    [
                        "rbd_ec32",
                        "8",
                        "6.1",
                        "MiB",
                        "2.1",
                        "KiB",
                        "6.1",
                        "MiB",
                        "6",
                        "18",
                        "MiB",
                        "144",
                        "KiB",
                        "18",
                        "MiB",
                        "0",
                        "6.5",
                        "TiB",
                        "N/A",
                        "N/A",
                        "6",
                        "0",
                        "B",
                        "0",
                        "B",
                    ],
                ]
            ),
        )
    ) == [
        Service(item="SUMMARY"),
        Service(item="ceph-customer"),
        Service(item="ceph-customer-ec32"),
        Service(item="ceph-sb"),
        Service(item="device_health_metrics"),
        Service(item="rbd_ec32"),
    ]


def test_discovery_nautilus() -> None:
    assert sorted(
        ceph_df.discover_ceph_df(
            [],
            ceph_df.parse_ceph_df(
                [
                    ["RAW", "STORAGE:"],
                    ["CLASS", "SIZE", "AVAIL", "USED", "RAW", "USED", "%RAW", "USED"],
                    [
                        "ssd",
                        "84",
                        "TiB",
                        "81",
                        "TiB",
                        "2.9",
                        "TiB",
                        "3.0",
                        "TiB",
                        "3.52",
                    ],
                    [
                        "TOTAL",
                        "84",
                        "TiB",
                        "81",
                        "TiB",
                        "2.9",
                        "TiB",
                        "3.0",
                        "TiB",
                        "3.52",
                    ],
                    ["POOLS:"],
                    [
                        "POOL",
                        "ID",
                        "STORED",
                        "OBJECTS",
                        "USED",
                        "%USED",
                        "MAX",
                        "AVAIL",
                        "QUOTA",
                        "OBJECTS",
                        "QUOTA",
                        "BYTES",
                        "DIRTY",
                        "USED",
                        "COMPR",
                        "UNDER",
                        "COMPR",
                    ],
                    [
                        "glance-images",
                        "1",
                        "25",
                        "GiB",
                        "5.88k",
                        "75",
                        "GiB",
                        "0.10",
                        "25",
                        "TiB",
                        "N/A",
                        "N/A",
                        "5.88k",
                        "0",
                        "B",
                        "0",
                        "B",
                    ],
                    [
                        "cinder-volumes",
                        "2",
                        "616",
                        "GiB",
                        "158.31k",
                        "1.8",
                        "TiB",
                        "2.32",
                        "25",
                        "TiB",
                        "N/A",
                        "N/A",
                        "158.31k",
                        "0",
                        "B",
                        "0",
                        "B",
                    ],
                    [
                        "nova-vms",
                        "3",
                        "349",
                        "GiB",
                        "91.08k",
                        "1.0",
                        "TiB",
                        "1.32",
                        "25",
                        "TiB",
                        "N/A",
                        "N/A",
                        "91.08k",
                        "0",
                        "B",
                        "0",
                        "B",
                    ],
                    [
                        "cephfs_data",
                        "4",
                        "0",
                        "B",
                        "0",
                        "0",
                        "B",
                        "0",
                        "25",
                        "TiB",
                        "N/A",
                        "N/A",
                        "0",
                        "0",
                        "B",
                        "0",
                        "B",
                    ],
                    [
                        "cephfs_metadata",
                        "5",
                        "15",
                        "KiB",
                        "60",
                        "969",
                        "KiB",
                        "0",
                        "25",
                        "TiB",
                        "N/A",
                        "N/A",
                        "60",
                        "0",
                        "B",
                        "0",
                        "B",
                    ],
                    [
                        ".rgw.root",
                        "6",
                        "2.6",
                        "KiB",
                        "6",
                        "288",
                        "KiB",
                        "0",
                        "25",
                        "TiB",
                        "N/A",
                        "N/A",
                        "6",
                        "0",
                        "B",
                        "0",
                        "B",
                    ],
                    [
                        "default.rgw.control",
                        "7",
                        "0",
                        "B",
                        "8",
                        "0",
                        "B",
                        "0",
                        "25",
                        "TiB",
                        "N/A",
                        "N/A",
                        "8",
                        "0",
                        "B",
                        "0",
                        "B",
                    ],
                    [
                        "default.rgw.meta",
                        "8",
                        "0",
                        "B",
                        "0",
                        "0",
                        "B",
                        "0",
                        "25",
                        "TiB",
                        "N/A",
                        "N/A",
                        "0",
                        "0",
                        "B",
                        "0",
                        "B",
                    ],
                    [
                        "default.rgw.log",
                        "9",
                        "0",
                        "B",
                        "207",
                        "0",
                        "B",
                        "0",
                        "25",
                        "TiB",
                        "N/A",
                        "N/A",
                        "207",
                        "0",
                        "B",
                        "0",
                        "B",
                    ],
                ]
            ),
        )
    ) == [
        Service(item=".rgw.root"),
        Service(item="SUMMARY"),
        Service(item="cephfs_data"),
        Service(item="cephfs_metadata"),
        Service(item="cinder-volumes"),
        Service(item="default.rgw.control"),
        Service(item="default.rgw.log"),
        Service(item="default.rgw.meta"),
        Service(item="glance-images"),
        Service(item="nova-vms"),
    ]
