#!/usr/bin/env python3
# Copyright (C) 2019 Checkmk GmbH - License: GNU General Public License v2
# This file is part of Checkmk (https://checkmk.com). It is subject to the terms and
# conditions defined in the file COPYING, which is part of this source code package.

from cmk.plugins.lib import hp_msa


def test_parse_hp_msa_if() -> None:
    assert hp_msa.parse_hp_msa(
        [
            ["port", "3", "durable-id", "hostport_A1"],
            ["port", "3", "controller", "A"],
            ["port", "3", "controller-numeric", "1"],
            ["port", "3", "port", "A1"],
            ["port", "3", "url", "/ports/A1"],
            ["port", "3", "port-type", "FC"],
            ["port", "3", "port-type-numeric", "6"],
            ["port", "3", "media", "FC(P)"],
            ["port", "3", "target-id", "207000c0ff43a3dd"],
            ["port", "3", "status", "Up"],
            ["port", "3", "status-numeric", "0"],
            ["port", "3", "actual-speed", "8Gb"],
            ["port", "3", "actual-speed-numeric", "7"],
            ["port", "3", "configured-speed", "Auto"],
            ["port", "3", "configured-speed-numeric", "3"],
            ["port", "3", "fan-out", "1"],
            ["port", "3", "health", "OK"],
            ["port", "3", "health-numeric", "0"],
            ["port", "3", "health-reason"],
            ["port", "3", "health-recommendation"],
            ["fc-port", "4", "configured-topology", "PTP"],
            ["fc-port", "4", "configured-topology-numeric", "1"],
            ["fc-port", "4", "primary-loop-id", "N/A"],
            ["fc-port", "4", "sfp-status", "OK"],
            ["fc-port", "4", "sfp-status-numeric", "3"],
            ["fc-port", "4", "sfp-present", "Present"],
            ["fc-port", "4", "sfp-present-numeric", "1"],
            ["fc-port", "4", "sfp-vendor", "DHS"],
            ["fc-port", "4", "sfp-part-number", "FTLF8529P4BCV-2H"],
            ["fc-port", "4", "sfp-revision", "A"],
            ["fc-port", "4", "sfp-supported-speeds", "4G,8G,16G"],
            ["fc-port", "4", "sfp-supported-speeds-numeric", "112"],
            ["port", "5", "durable-id", "hostport_A2"],
            ["port", "5", "controller", "A"],
            ["port", "5", "controller-numeric", "1"],
            ["port", "5", "port", "A2"],
            ["port", "5", "url", "/ports/A2"],
            ["port", "5", "port-type", "FC"],
            ["port", "5", "port-type-numeric", "6"],
            ["port", "5", "media", "FC(-)"],
            ["port", "5", "target-id", "217000c0ff43a3dd"],
            ["port", "5", "status", "Disconnected"],
            ["port", "5", "status-numeric", "6"],
            ["port", "5", "actual-speed"],
            ["port", "5", "actual-speed-numeric", "255"],
            ["port", "5", "configured-speed", "Auto"],
            ["port", "5", "configured-speed-numeric", "3"],
            ["port", "5", "fan-out", "1"],
            ["port", "5", "health", "N/A"],
            ["port", "5", "health-numeric", "4"],
            [
                "port",
                "5",
                "health-reason",
                "There",
                "is",
                "no",
                "active",
                "connection",
                "to",
                "this",
                "host",
                "port.",
            ],
            [
                "port",
                "5",
                "health-recommendation",
                "-",
                "If",
                "this",
                "host",
                "port",
                "is",
                "intentionally",
                "unused,",
                "no",
                "action",
                "is",
                "required.",
                "-",
                "Otherwise,",
                "use",
                "an",
                "appropriate",
                "interface",
                "cable",
                "to",
                "connect",
                "this",
                "host",
                "port",
                "to",
                "a",
                "switch",
                "or",
                "host.",
                "-",
                "If",
                "a",
                "cable",
                "is",
                "connected,",
                "check",
                "the",
                "cable",
                "and",
                "the",
                "switch",
                "or",
                "host",
                "for",
                "problems.",
            ],
            ["fc-port", "6", "configured-topology", "PTP"],
            ["fc-port", "6", "configured-topology-numeric", "1"],
            ["fc-port", "6", "primary-loop-id", "N/A"],
            ["fc-port", "6", "sfp-status", "OK"],
            ["fc-port", "6", "sfp-status-numeric", "3"],
            ["fc-port", "6", "sfp-present", "Present"],
            ["fc-port", "6", "sfp-present-numeric", "1"],
            ["fc-port", "6", "sfp-vendor", "DHS"],
            ["fc-port", "6", "sfp-part-number", "FTLF8529P4BCV-2H"],
            ["fc-port", "6", "sfp-revision", "A"],
            ["fc-port", "6", "sfp-supported-speeds", "4G,8G,16G"],
            ["fc-port", "6", "sfp-supported-speeds-numeric", "112"],
            ["port", "7", "durable-id", "hostport_A3"],
            ["port", "7", "controller", "A"],
            ["port", "7", "controller-numeric", "1"],
            ["port", "7", "port", "A3"],
            ["port", "7", "url", "/ports/A3"],
            ["port", "7", "port-type", "FC"],
            ["port", "7", "port-type-numeric", "6"],
            ["port", "7", "media", "FC(-)"],
            ["port", "7", "target-id", "227000c0ff43a3dd"],
            ["port", "7", "status", "Disconnected"],
            ["port", "7", "status-numeric", "6"],
            ["port", "7", "actual-speed"],
            ["port", "7", "actual-speed-numeric", "255"],
            ["port", "7", "configured-speed", "Auto"],
            ["port", "7", "configured-speed-numeric", "3"],
            ["port", "7", "fan-out", "1"],
            ["port", "7", "health", "N/A"],
            ["port", "7", "health-numeric", "4"],
            [
                "port",
                "7",
                "health-reason",
                "There",
                "is",
                "no",
                "active",
                "connection",
                "to",
                "this",
                "host",
                "port.",
            ],
            [
                "port",
                "7",
                "health-recommendation",
                "-",
                "If",
                "this",
                "host",
                "port",
                "is",
                "intentionally",
                "unused,",
                "no",
                "action",
                "is",
                "required.",
                "-",
                "Otherwise,",
                "use",
                "an",
                "appropriate",
                "interface",
                "cable",
                "to",
                "connect",
                "this",
                "host",
                "port",
                "to",
                "a",
                "switch",
                "or",
                "host.",
                "-",
                "If",
                "a",
                "cable",
                "is",
                "connected,",
                "check",
                "the",
                "cable",
                "and",
                "the",
                "switch",
                "or",
                "host",
                "for",
                "problems.",
            ],
            ["fc-port", "8", "configured-topology", "PTP"],
            ["fc-port", "8", "configured-topology-numeric", "1"],
            ["fc-port", "8", "primary-loop-id", "N/A"],
            ["fc-port", "8", "sfp-status", "OK"],
            ["fc-port", "8", "sfp-status-numeric", "3"],
            ["fc-port", "8", "sfp-present", "Present"],
            ["fc-port", "8", "sfp-present-numeric", "1"],
            ["fc-port", "8", "sfp-vendor", "DHS"],
            ["fc-port", "8", "sfp-part-number", "FTLF8529P4BCV-2H"],
            ["fc-port", "8", "sfp-revision", "A"],
            ["fc-port", "8", "sfp-supported-speeds", "4G,8G,16G"],
            ["fc-port", "8", "sfp-supported-speeds-numeric", "112"],
            ["port", "9", "durable-id", "hostport_A4"],
            ["port", "9", "controller", "A"],
            ["port", "9", "controller-numeric", "1"],
            ["port", "9", "port", "A4"],
            ["port", "9", "url", "/ports/A4"],
            ["port", "9", "port-type", "FC"],
            ["port", "9", "port-type-numeric", "6"],
            ["port", "9", "media", "FC(-)"],
            ["port", "9", "target-id", "237000c0ff43a3dd"],
            ["port", "9", "status", "Disconnected"],
            ["port", "9", "status-numeric", "6"],
            ["port", "9", "actual-speed"],
            ["port", "9", "actual-speed-numeric", "255"],
            ["port", "9", "configured-speed", "Auto"],
            ["port", "9", "configured-speed-numeric", "3"],
            ["port", "9", "fan-out", "1"],
            ["port", "9", "health", "N/A"],
            ["port", "9", "health-numeric", "4"],
            [
                "port",
                "9",
                "health-reason",
                "There",
                "is",
                "no",
                "active",
                "connection",
                "to",
                "this",
                "host",
                "port.",
            ],
            [
                "port",
                "9",
                "health-recommendation",
                "-",
                "If",
                "this",
                "host",
                "port",
                "is",
                "intentionally",
                "unused,",
                "no",
                "action",
                "is",
                "required.",
                "-",
                "Otherwise,",
                "use",
                "an",
                "appropriate",
                "interface",
                "cable",
                "to",
                "connect",
                "this",
                "host",
                "port",
                "to",
                "a",
                "switch",
                "or",
                "host.",
                "-",
                "If",
                "a",
                "cable",
                "is",
                "connected,",
                "check",
                "the",
                "cable",
                "and",
                "the",
                "switch",
                "or",
                "host",
                "for",
                "problems.",
            ],
            ["fc-port", "10", "configured-topology", "PTP"],
            ["fc-port", "10", "configured-topology-numeric", "1"],
            ["fc-port", "10", "primary-loop-id", "N/A"],
            ["fc-port", "10", "sfp-status", "Not", "present"],
            ["fc-port", "10", "sfp-status-numeric", "2"],
            ["fc-port", "10", "sfp-present", "Not", "Present"],
            ["fc-port", "10", "sfp-present-numeric", "0"],
            ["fc-port", "10", "sfp-vendor"],
            ["fc-port", "10", "sfp-part-number"],
            ["fc-port", "10", "sfp-revision"],
            ["fc-port", "10", "sfp-supported-speeds", "N/A"],
            ["fc-port", "10", "sfp-supported-speeds-numeric", "0"],
            ["port", "16", "durable-id", "hostport_B1"],
            ["port", "16", "controller", "B"],
            ["port", "16", "controller-numeric", "0"],
            ["port", "16", "port", "B1"],
            ["port", "16", "url", "/ports/B1"],
            ["port", "16", "port-type", "FC"],
            ["port", "16", "port-type-numeric", "6"],
            ["port", "16", "media", "FC(P)"],
            ["port", "16", "target-id", "247000c0ff43a3dd"],
            ["port", "16", "status", "Up"],
            ["port", "16", "status-numeric", "0"],
            ["port", "16", "actual-speed", "16Gb"],
            ["port", "16", "actual-speed-numeric", "12"],
            ["port", "16", "configured-speed", "Auto"],
            ["port", "16", "configured-speed-numeric", "3"],
            ["port", "16", "fan-out", "1"],
            ["port", "16", "health", "OK"],
            ["port", "16", "health-numeric", "0"],
            ["port", "16", "health-reason"],
            ["port", "16", "health-recommendation"],
            ["fc-port", "17", "configured-topology", "PTP"],
            ["fc-port", "17", "configured-topology-numeric", "1"],
            ["fc-port", "17", "primary-loop-id", "N/A"],
            ["fc-port", "17", "sfp-status", "OK"],
            ["fc-port", "17", "sfp-status-numeric", "3"],
            ["fc-port", "17", "sfp-present", "Present"],
            ["fc-port", "17", "sfp-present-numeric", "1"],
            ["fc-port", "17", "sfp-vendor", "DHS"],
            ["fc-port", "17", "sfp-part-number", "FTLF8529P4BCV-2H"],
            ["fc-port", "17", "sfp-revision", "A"],
            ["fc-port", "17", "sfp-supported-speeds", "4G,8G,16G"],
            ["fc-port", "17", "sfp-supported-speeds-numeric", "112"],
            ["port", "18", "durable-id", "hostport_B2"],
            ["port", "18", "controller", "B"],
            ["port", "18", "controller-numeric", "0"],
            ["port", "18", "port", "B2"],
            ["port", "18", "url", "/ports/B2"],
            ["port", "18", "port-type", "FC"],
            ["port", "18", "port-type-numeric", "6"],
            ["port", "18", "media", "FC(-)"],
            ["port", "18", "target-id", "257000c0ff43a3dd"],
            ["port", "18", "status", "Disconnected"],
            ["port", "18", "status-numeric", "6"],
            ["port", "18", "actual-speed"],
            ["port", "18", "actual-speed-numeric", "255"],
            ["port", "18", "configured-speed", "Auto"],
            ["port", "18", "configured-speed-numeric", "3"],
            ["port", "18", "fan-out", "1"],
            ["port", "18", "health", "N/A"],
            ["port", "18", "health-numeric", "4"],
            [
                "port",
                "18",
                "health-reason",
                "There",
                "is",
                "no",
                "active",
                "connection",
                "to",
                "this",
                "host",
                "port.",
            ],
            [
                "port",
                "18",
                "health-recommendation",
                "-",
                "If",
                "this",
                "host",
                "port",
                "is",
                "intentionally",
                "unused,",
                "no",
                "action",
                "is",
                "required.",
                "-",
                "Otherwise,",
                "use",
                "an",
                "appropriate",
                "interface",
                "cable",
                "to",
                "connect",
                "this",
                "host",
                "port",
                "to",
                "a",
                "switch",
                "or",
                "host.",
                "-",
                "If",
                "a",
                "cable",
                "is",
                "connected,",
                "check",
                "the",
                "cable",
                "and",
                "the",
                "switch",
                "or",
                "host",
                "for",
                "problems.",
            ],
            ["fc-port", "19", "configured-topology", "PTP"],
            ["fc-port", "19", "configured-topology-numeric", "1"],
            ["fc-port", "19", "primary-loop-id", "N/A"],
            ["fc-port", "19", "sfp-status", "OK"],
            ["fc-port", "19", "sfp-status-numeric", "3"],
            ["fc-port", "19", "sfp-present", "Present"],
            ["fc-port", "19", "sfp-present-numeric", "1"],
            ["fc-port", "19", "sfp-vendor", "DHS"],
            ["fc-port", "19", "sfp-part-number", "FTLF8529P4BCV-2H"],
            ["fc-port", "19", "sfp-revision", "A"],
            ["fc-port", "19", "sfp-supported-speeds", "4G,8G,16G"],
            ["fc-port", "19", "sfp-supported-speeds-numeric", "112"],
            ["port", "20", "durable-id", "hostport_B3"],
            ["port", "20", "controller", "B"],
            ["port", "20", "controller-numeric", "0"],
            ["port", "20", "port", "B3"],
            ["port", "20", "url", "/ports/B3"],
            ["port", "20", "port-type", "FC"],
            ["port", "20", "port-type-numeric", "6"],
            ["port", "20", "media", "FC(-)"],
            ["port", "20", "target-id", "267000c0ff43a3dd"],
            ["port", "20", "status", "Disconnected"],
            ["port", "20", "status-numeric", "6"],
            ["port", "20", "actual-speed"],
            ["port", "20", "actual-speed-numeric", "255"],
            ["port", "20", "configured-speed", "Auto"],
            ["port", "20", "configured-speed-numeric", "3"],
            ["port", "20", "fan-out", "1"],
            ["port", "20", "health", "N/A"],
            ["port", "20", "health-numeric", "4"],
            [
                "port",
                "20",
                "health-reason",
                "There",
                "is",
                "no",
                "active",
                "connection",
                "to",
                "this",
                "host",
                "port.",
            ],
            [
                "port",
                "20",
                "health-recommendation",
                "-",
                "If",
                "this",
                "host",
                "port",
                "is",
                "intentionally",
                "unused,",
                "no",
                "action",
                "is",
                "required.",
                "-",
                "Otherwise,",
                "use",
                "an",
                "appropriate",
                "interface",
                "cable",
                "to",
                "connect",
                "this",
                "host",
                "port",
                "to",
                "a",
                "switch",
                "or",
                "host.",
                "-",
                "If",
                "a",
                "cable",
                "is",
                "connected,",
                "check",
                "the",
                "cable",
                "and",
                "the",
                "switch",
                "or",
                "host",
                "for",
                "problems.",
            ],
            ["fc-port", "21", "configured-topology", "PTP"],
            ["fc-port", "21", "configured-topology-numeric", "1"],
            ["fc-port", "21", "primary-loop-id", "N/A"],
            ["fc-port", "21", "sfp-status", "OK"],
            ["fc-port", "21", "sfp-status-numeric", "3"],
            ["fc-port", "21", "sfp-present", "Present"],
            ["fc-port", "21", "sfp-present-numeric", "1"],
            ["fc-port", "21", "sfp-vendor", "DHS"],
            ["fc-port", "21", "sfp-part-number", "FTLF8529P4BCV-2H"],
            ["fc-port", "21", "sfp-revision", "A"],
            ["fc-port", "21", "sfp-supported-speeds", "4G,8G,16G"],
            ["fc-port", "21", "sfp-supported-speeds-numeric", "112"],
            ["port", "22", "durable-id", "hostport_B4"],
            ["port", "22", "controller", "B"],
            ["port", "22", "controller-numeric", "0"],
            ["port", "22", "port", "B4"],
            ["port", "22", "url", "/ports/B4"],
            ["port", "22", "port-type", "FC"],
            ["port", "22", "port-type-numeric", "6"],
            ["port", "22", "media", "FC(-)"],
            ["port", "22", "target-id", "277000c0ff43a3dd"],
            ["port", "22", "status", "Disconnected"],
            ["port", "22", "status-numeric", "6"],
            ["port", "22", "actual-speed"],
            ["port", "22", "actual-speed-numeric", "255"],
            ["port", "22", "configured-speed", "Auto"],
            ["port", "22", "configured-speed-numeric", "3"],
            ["port", "22", "fan-out", "1"],
            ["port", "22", "health", "N/A"],
            ["port", "22", "health-numeric", "4"],
            [
                "port",
                "22",
                "health-reason",
                "There",
                "is",
                "no",
                "active",
                "connection",
                "to",
                "this",
                "host",
                "port.",
            ],
            [
                "port",
                "22",
                "health-recommendation",
                "-",
                "If",
                "this",
                "host",
                "port",
                "is",
                "intentionally",
                "unused,",
                "no",
                "action",
                "is",
                "required.",
                "-",
                "Otherwise,",
                "use",
                "an",
                "appropriate",
                "interface",
                "cable",
                "to",
                "connect",
                "this",
                "host",
                "port",
                "to",
                "a",
                "switch",
                "or",
                "host.",
                "-",
                "If",
                "a",
                "cable",
                "is",
                "connected,",
                "check",
                "the",
                "cable",
                "and",
                "the",
                "switch",
                "or",
                "host",
                "for",
                "problems.",
            ],
            ["fc-port", "23", "configured-topology", "PTP"],
            ["fc-port", "23", "configured-topology-numeric", "1"],
            ["fc-port", "23", "primary-loop-id", "N/A"],
            ["fc-port", "23", "sfp-status", "Not", "present"],
            ["fc-port", "23", "sfp-status-numeric", "2"],
            ["fc-port", "23", "sfp-present", "Not", "Present"],
            ["fc-port", "23", "sfp-present-numeric", "0"],
            ["fc-port", "23", "sfp-vendor"],
            ["fc-port", "23", "sfp-part-number"],
            ["fc-port", "23", "sfp-revision"],
            ["fc-port", "23", "sfp-supported-speeds", "N/A"],
            ["fc-port", "23", "sfp-supported-speeds-numeric", "0"],
            ["port", "1", "durable-id", "hostport_A1"],
            ["port", "1", "controller", "A"],
            ["port", "1", "controller-numeric", "1"],
            ["port", "1", "port", "A1"],
            ["port", "1", "url", "/ports/A1"],
            ["port", "1", "port-type", "FC"],
            ["port", "1", "port-type-numeric", "6"],
            ["port", "1", "media", "FC(P)"],
            ["port", "1", "target-id", "207000c0ff43a3dd"],
            ["port", "1", "status", "Up"],
            ["port", "1", "status-numeric", "0"],
            ["port", "1", "actual-speed", "8Gb"],
            ["port", "1", "actual-speed-numeric", "7"],
            ["port", "1", "configured-speed", "Auto"],
            ["port", "1", "configured-speed-numeric", "3"],
            ["port", "1", "fan-out", "1"],
            ["port", "1", "health", "OK"],
            ["port", "1", "health-numeric", "0"],
            ["port", "1", "health-reason"],
            ["port", "1", "health-recommendation"],
            ["fc-port", "2", "configured-topology", "PTP"],
            ["fc-port", "2", "configured-topology-numeric", "1"],
            ["fc-port", "2", "primary-loop-id", "N/A"],
            ["fc-port", "2", "sfp-status", "OK"],
            ["fc-port", "2", "sfp-status-numeric", "3"],
            ["fc-port", "2", "sfp-present", "Present"],
            ["fc-port", "2", "sfp-present-numeric", "1"],
            ["fc-port", "2", "sfp-vendor", "DHS"],
            ["fc-port", "2", "sfp-part-number", "FTLF8529P4BCV-2H"],
            ["fc-port", "2", "sfp-revision", "A"],
            ["fc-port", "2", "sfp-supported-speeds", "4G,8G,16G"],
            ["fc-port", "2", "sfp-supported-speeds-numeric", "112"],
            ["port", "3", "durable-id", "hostport_A2"],
            ["port", "3", "controller", "A"],
            ["port", "3", "controller-numeric", "1"],
            ["port", "3", "port", "A2"],
            ["port", "3", "url", "/ports/A2"],
            ["port", "3", "port-type", "FC"],
            ["port", "3", "port-type-numeric", "6"],
            ["port", "3", "media", "FC(-)"],
            ["port", "3", "target-id", "217000c0ff43a3dd"],
            ["port", "3", "status", "Disconnected"],
            ["port", "3", "status-numeric", "6"],
            ["port", "3", "actual-speed"],
            ["port", "3", "actual-speed-numeric", "255"],
            ["port", "3", "configured-speed", "Auto"],
            ["port", "3", "configured-speed-numeric", "3"],
            ["port", "3", "fan-out", "1"],
            ["port", "3", "health", "N/A"],
            ["port", "3", "health-numeric", "4"],
            [
                "port",
                "3",
                "health-reason",
                "There",
                "is",
                "no",
                "active",
                "connection",
                "to",
                "this",
                "host",
                "port.",
            ],
            [
                "port",
                "3",
                "health-recommendation",
                "-",
                "If",
                "this",
                "host",
                "port",
                "is",
                "intentionally",
                "unused,",
                "no",
                "action",
                "is",
                "required.",
                "-",
                "Otherwise,",
                "use",
                "an",
                "appropriate",
                "interface",
                "cable",
                "to",
                "connect",
                "this",
                "host",
                "port",
                "to",
                "a",
                "switch",
                "or",
                "host.",
                "-",
                "If",
                "a",
                "cable",
                "is",
                "connected,",
                "check",
                "the",
                "cable",
                "and",
                "the",
                "switch",
                "or",
                "host",
                "for",
                "problems.",
            ],
            ["fc-port", "4", "configured-topology", "PTP"],
            ["fc-port", "4", "configured-topology-numeric", "1"],
            ["fc-port", "4", "primary-loop-id", "N/A"],
            ["fc-port", "4", "sfp-status", "OK"],
            ["fc-port", "4", "sfp-status-numeric", "3"],
            ["fc-port", "4", "sfp-present", "Present"],
            ["fc-port", "4", "sfp-present-numeric", "1"],
            ["fc-port", "4", "sfp-vendor", "DHS"],
            ["fc-port", "4", "sfp-part-number", "FTLF8529P4BCV-2H"],
            ["fc-port", "4", "sfp-revision", "A"],
            ["fc-port", "4", "sfp-supported-speeds", "4G,8G,16G"],
            ["fc-port", "4", "sfp-supported-speeds-numeric", "112"],
            ["port", "5", "durable-id", "hostport_A3"],
            ["port", "5", "controller", "A"],
            ["port", "5", "controller-numeric", "1"],
            ["port", "5", "port", "A3"],
            ["port", "5", "url", "/ports/A3"],
            ["port", "5", "port-type", "FC"],
            ["port", "5", "port-type-numeric", "6"],
            ["port", "5", "media", "FC(-)"],
            ["port", "5", "target-id", "227000c0ff43a3dd"],
            ["port", "5", "status", "Disconnected"],
            ["port", "5", "status-numeric", "6"],
            ["port", "5", "actual-speed"],
            ["port", "5", "actual-speed-numeric", "255"],
            ["port", "5", "configured-speed", "Auto"],
            ["port", "5", "configured-speed-numeric", "3"],
            ["port", "5", "fan-out", "1"],
            ["port", "5", "health", "N/A"],
            ["port", "5", "health-numeric", "4"],
            [
                "port",
                "5",
                "health-reason",
                "There",
                "is",
                "no",
                "active",
                "connection",
                "to",
                "this",
                "host",
                "port.",
            ],
            [
                "port",
                "5",
                "health-recommendation",
                "-",
                "If",
                "this",
                "host",
                "port",
                "is",
                "intentionally",
                "unused,",
                "no",
                "action",
                "is",
                "required.",
                "-",
                "Otherwise,",
                "use",
                "an",
                "appropriate",
                "interface",
                "cable",
                "to",
                "connect",
                "this",
                "host",
                "port",
                "to",
                "a",
                "switch",
                "or",
                "host.",
                "-",
                "If",
                "a",
                "cable",
                "is",
                "connected,",
                "check",
                "the",
                "cable",
                "and",
                "the",
                "switch",
                "or",
                "host",
                "for",
                "problems.",
            ],
            ["fc-port", "6", "configured-topology", "PTP"],
            ["fc-port", "6", "configured-topology-numeric", "1"],
            ["fc-port", "6", "primary-loop-id", "N/A"],
            ["fc-port", "6", "sfp-status", "OK"],
            ["fc-port", "6", "sfp-status-numeric", "3"],
            ["fc-port", "6", "sfp-present", "Present"],
            ["fc-port", "6", "sfp-present-numeric", "1"],
            ["fc-port", "6", "sfp-vendor", "DHS"],
            ["fc-port", "6", "sfp-part-number", "FTLF8529P4BCV-2H"],
            ["fc-port", "6", "sfp-revision", "A"],
            ["fc-port", "6", "sfp-supported-speeds", "4G,8G,16G"],
            ["fc-port", "6", "sfp-supported-speeds-numeric", "112"],
            ["port", "7", "durable-id", "hostport_A4"],
            ["port", "7", "controller", "A"],
            ["port", "7", "controller-numeric", "1"],
            ["port", "7", "port", "A4"],
            ["port", "7", "url", "/ports/A4"],
            ["port", "7", "port-type", "FC"],
            ["port", "7", "port-type-numeric", "6"],
            ["port", "7", "media", "FC(-)"],
            ["port", "7", "target-id", "237000c0ff43a3dd"],
            ["port", "7", "status", "Disconnected"],
            ["port", "7", "status-numeric", "6"],
            ["port", "7", "actual-speed"],
            ["port", "7", "actual-speed-numeric", "255"],
            ["port", "7", "configured-speed", "Auto"],
            ["port", "7", "configured-speed-numeric", "3"],
            ["port", "7", "fan-out", "1"],
            ["port", "7", "health", "N/A"],
            ["port", "7", "health-numeric", "4"],
            [
                "port",
                "7",
                "health-reason",
                "There",
                "is",
                "no",
                "active",
                "connection",
                "to",
                "this",
                "host",
                "port.",
            ],
            [
                "port",
                "7",
                "health-recommendation",
                "-",
                "If",
                "this",
                "host",
                "port",
                "is",
                "intentionally",
                "unused,",
                "no",
                "action",
                "is",
                "required.",
                "-",
                "Otherwise,",
                "use",
                "an",
                "appropriate",
                "interface",
                "cable",
                "to",
                "connect",
                "this",
                "host",
                "port",
                "to",
                "a",
                "switch",
                "or",
                "host.",
                "-",
                "If",
                "a",
                "cable",
                "is",
                "connected,",
                "check",
                "the",
                "cable",
                "and",
                "the",
                "switch",
                "or",
                "host",
                "for",
                "problems.",
            ],
            ["fc-port", "8", "configured-topology", "PTP"],
            ["fc-port", "8", "configured-topology-numeric", "1"],
            ["fc-port", "8", "primary-loop-id", "N/A"],
            ["fc-port", "8", "sfp-status", "Not", "present"],
            ["fc-port", "8", "sfp-status-numeric", "2"],
            ["fc-port", "8", "sfp-present", "Not", "Present"],
            ["fc-port", "8", "sfp-present-numeric", "0"],
            ["fc-port", "8", "sfp-vendor"],
            ["fc-port", "8", "sfp-part-number"],
            ["fc-port", "8", "sfp-revision"],
            ["fc-port", "8", "sfp-supported-speeds", "N/A"],
            ["fc-port", "8", "sfp-supported-speeds-numeric", "0"],
            ["port", "9", "durable-id", "hostport_B1"],
            ["port", "9", "controller", "B"],
            ["port", "9", "controller-numeric", "0"],
            ["port", "9", "port", "B1"],
            ["port", "9", "url", "/ports/B1"],
            ["port", "9", "port-type", "FC"],
            ["port", "9", "port-type-numeric", "6"],
            ["port", "9", "media", "FC(P)"],
            ["port", "9", "target-id", "247000c0ff43a3dd"],
            ["port", "9", "status", "Up"],
            ["port", "9", "status-numeric", "0"],
            ["port", "9", "actual-speed", "16Gb"],
            ["port", "9", "actual-speed-numeric", "12"],
            ["port", "9", "configured-speed", "Auto"],
            ["port", "9", "configured-speed-numeric", "3"],
            ["port", "9", "fan-out", "1"],
            ["port", "9", "health", "OK"],
            ["port", "9", "health-numeric", "0"],
            ["port", "9", "health-reason"],
            ["port", "9", "health-recommendation"],
            ["fc-port", "10", "configured-topology", "PTP"],
            ["fc-port", "10", "configured-topology-numeric", "1"],
            ["fc-port", "10", "primary-loop-id", "N/A"],
            ["fc-port", "10", "sfp-status", "OK"],
            ["fc-port", "10", "sfp-status-numeric", "3"],
            ["fc-port", "10", "sfp-present", "Present"],
            ["fc-port", "10", "sfp-present-numeric", "1"],
            ["fc-port", "10", "sfp-vendor", "DHS"],
            ["fc-port", "10", "sfp-part-number", "FTLF8529P4BCV-2H"],
            ["fc-port", "10", "sfp-revision", "A"],
            ["fc-port", "10", "sfp-supported-speeds", "4G,8G,16G"],
            ["fc-port", "10", "sfp-supported-speeds-numeric", "112"],
            ["port", "11", "durable-id", "hostport_B2"],
            ["port", "11", "controller", "B"],
            ["port", "11", "controller-numeric", "0"],
            ["port", "11", "port", "B2"],
            ["port", "11", "url", "/ports/B2"],
            ["port", "11", "port-type", "FC"],
            ["port", "11", "port-type-numeric", "6"],
            ["port", "11", "media", "FC(-)"],
            ["port", "11", "target-id", "257000c0ff43a3dd"],
            ["port", "11", "status", "Disconnected"],
            ["port", "11", "status-numeric", "6"],
            ["port", "11", "actual-speed"],
            ["port", "11", "actual-speed-numeric", "255"],
            ["port", "11", "configured-speed", "Auto"],
            ["port", "11", "configured-speed-numeric", "3"],
            ["port", "11", "fan-out", "1"],
            ["port", "11", "health", "N/A"],
            ["port", "11", "health-numeric", "4"],
            [
                "port",
                "11",
                "health-reason",
                "There",
                "is",
                "no",
                "active",
                "connection",
                "to",
                "this",
                "host",
                "port.",
            ],
            [
                "port",
                "11",
                "health-recommendation",
                "-",
                "If",
                "this",
                "host",
                "port",
                "is",
                "intentionally",
                "unused,",
                "no",
                "action",
                "is",
                "required.",
                "-",
                "Otherwise,",
                "use",
                "an",
                "appropriate",
                "interface",
                "cable",
                "to",
                "connect",
                "this",
                "host",
                "port",
                "to",
                "a",
                "switch",
                "or",
                "host.",
                "-",
                "If",
                "a",
                "cable",
                "is",
                "connected,",
                "check",
                "the",
                "cable",
                "and",
                "the",
                "switch",
                "or",
                "host",
                "for",
                "problems.",
            ],
            ["fc-port", "12", "configured-topology", "PTP"],
            ["fc-port", "12", "configured-topology-numeric", "1"],
            ["fc-port", "12", "primary-loop-id", "N/A"],
            ["fc-port", "12", "sfp-status", "OK"],
            ["fc-port", "12", "sfp-status-numeric", "3"],
            ["fc-port", "12", "sfp-present", "Present"],
            ["fc-port", "12", "sfp-present-numeric", "1"],
            ["fc-port", "12", "sfp-vendor", "DHS"],
            ["fc-port", "12", "sfp-part-number", "FTLF8529P4BCV-2H"],
            ["fc-port", "12", "sfp-revision", "A"],
            ["fc-port", "12", "sfp-supported-speeds", "4G,8G,16G"],
            ["fc-port", "12", "sfp-supported-speeds-numeric", "112"],
            ["port", "13", "durable-id", "hostport_B3"],
            ["port", "13", "controller", "B"],
            ["port", "13", "controller-numeric", "0"],
            ["port", "13", "port", "B3"],
            ["port", "13", "url", "/ports/B3"],
            ["port", "13", "port-type", "FC"],
            ["port", "13", "port-type-numeric", "6"],
            ["port", "13", "media", "FC(-)"],
            ["port", "13", "target-id", "267000c0ff43a3dd"],
            ["port", "13", "status", "Disconnected"],
            ["port", "13", "status-numeric", "6"],
            ["port", "13", "actual-speed"],
            ["port", "13", "actual-speed-numeric", "255"],
            ["port", "13", "configured-speed", "Auto"],
            ["port", "13", "configured-speed-numeric", "3"],
            ["port", "13", "fan-out", "1"],
            ["port", "13", "health", "N/A"],
            ["port", "13", "health-numeric", "4"],
            [
                "port",
                "13",
                "health-reason",
                "There",
                "is",
                "no",
                "active",
                "connection",
                "to",
                "this",
                "host",
                "port.",
            ],
            [
                "port",
                "13",
                "health-recommendation",
                "-",
                "If",
                "this",
                "host",
                "port",
                "is",
                "intentionally",
                "unused,",
                "no",
                "action",
                "is",
                "required.",
                "-",
                "Otherwise,",
                "use",
                "an",
                "appropriate",
                "interface",
                "cable",
                "to",
                "connect",
                "this",
                "host",
                "port",
                "to",
                "a",
                "switch",
                "or",
                "host.",
                "-",
                "If",
                "a",
                "cable",
                "is",
                "connected,",
                "check",
                "the",
                "cable",
                "and",
                "the",
                "switch",
                "or",
                "host",
                "for",
                "problems.",
            ],
            ["fc-port", "14", "configured-topology", "PTP"],
            ["fc-port", "14", "configured-topology-numeric", "1"],
            ["fc-port", "14", "primary-loop-id", "N/A"],
            ["fc-port", "14", "sfp-status", "OK"],
            ["fc-port", "14", "sfp-status-numeric", "3"],
            ["fc-port", "14", "sfp-present", "Present"],
            ["fc-port", "14", "sfp-present-numeric", "1"],
            ["fc-port", "14", "sfp-vendor", "DHS"],
            ["fc-port", "14", "sfp-part-number", "FTLF8529P4BCV-2H"],
            ["fc-port", "14", "sfp-revision", "A"],
            ["fc-port", "14", "sfp-supported-speeds", "4G,8G,16G"],
            ["fc-port", "14", "sfp-supported-speeds-numeric", "112"],
            ["port", "15", "durable-id", "hostport_B4"],
            ["port", "15", "controller", "B"],
            ["port", "15", "controller-numeric", "0"],
            ["port", "15", "port", "B4"],
            ["port", "15", "url", "/ports/B4"],
            ["port", "15", "port-type", "FC"],
            ["port", "15", "port-type-numeric", "6"],
            ["port", "15", "media", "FC(-)"],
            ["port", "15", "target-id", "277000c0ff43a3dd"],
            ["port", "15", "status", "Disconnected"],
            ["port", "15", "status-numeric", "6"],
            ["port", "15", "actual-speed"],
            ["port", "15", "actual-speed-numeric", "255"],
            ["port", "15", "configured-speed", "Auto"],
            ["port", "15", "configured-speed-numeric", "3"],
            ["port", "15", "fan-out", "1"],
            ["port", "15", "health", "N/A"],
            ["port", "15", "health-numeric", "4"],
            [
                "port",
                "15",
                "health-reason",
                "There",
                "is",
                "no",
                "active",
                "connection",
                "to",
                "this",
                "host",
                "port.",
            ],
            [
                "port",
                "15",
                "health-recommendation",
                "-",
                "If",
                "this",
                "host",
                "port",
                "is",
                "intentionally",
                "unused,",
                "no",
                "action",
                "is",
                "required.",
                "-",
                "Otherwise,",
                "use",
                "an",
                "appropriate",
                "interface",
                "cable",
                "to",
                "connect",
                "this",
                "host",
                "port",
                "to",
                "a",
                "switch",
                "or",
                "host.",
                "-",
                "If",
                "a",
                "cable",
                "is",
                "connected,",
                "check",
                "the",
                "cable",
                "and",
                "the",
                "switch",
                "or",
                "host",
                "for",
                "problems.",
            ],
            ["fc-port", "16", "configured-topology", "PTP"],
            ["fc-port", "16", "configured-topology-numeric", "1"],
            ["fc-port", "16", "primary-loop-id", "N/A"],
            ["fc-port", "16", "sfp-status", "Not", "present"],
            ["fc-port", "16", "sfp-status-numeric", "2"],
            ["fc-port", "16", "sfp-present", "Not", "Present"],
            ["fc-port", "16", "sfp-present-numeric", "0"],
            ["fc-port", "16", "sfp-vendor"],
            ["fc-port", "16", "sfp-part-number"],
            ["fc-port", "16", "sfp-revision"],
            ["fc-port", "16", "sfp-supported-speeds", "N/A"],
            ["fc-port", "16", "sfp-supported-speeds-numeric", "0"],
            ["host-port-statistics", "1", "durable-id", "hostport_A1"],
            ["host-port-statistics", "1", "bytes-per-second", "0B"],
            ["host-port-statistics", "1", "bytes-per-second-numeric", "0"],
            ["host-port-statistics", "1", "iops", "0"],
            ["host-port-statistics", "1", "number-of-reads", "1142166839"],
            ["host-port-statistics", "1", "number-of-writes", "1002753355"],
            ["host-port-statistics", "1", "data-read", "453.6TB"],
            ["host-port-statistics", "1", "data-read-numeric", "453669561808896"],
            ["host-port-statistics", "1", "data-written", "372.0TB"],
            ["host-port-statistics", "1", "data-written-numeric", "372010525295104"],
            ["host-port-statistics", "1", "queue-depth", "0"],
            ["host-port-statistics", "1", "avg-rsp-time", "0"],
            ["host-port-statistics", "1", "avg-read-rsp-time", "0"],
            ["host-port-statistics", "1", "avg-write-rsp-time", "0"],
            ["host-port-statistics", "1", "reset-time", "2019-03-12", "14:53:04"],
            ["host-port-statistics", "1", "reset-time-numeric", "1552402384"],
            [
                "host-port-statistics",
                "1",
                "start-sample-time",
                "2019-09-13",
                "12:31:10",
            ],
            ["host-port-statistics", "1", "start-sample-time-numeric", "1568377870"],
            ["host-port-statistics", "1", "stop-sample-time", "2019-09-13", "12:31:35"],
            ["host-port-statistics", "1", "stop-sample-time-numeric", "1568377895"],
            ["host-port-statistics", "2", "durable-id", "hostport_A2"],
            ["host-port-statistics", "2", "bytes-per-second", "0B"],
            ["host-port-statistics", "2", "bytes-per-second-numeric", "0"],
            ["host-port-statistics", "2", "iops", "0"],
            ["host-port-statistics", "2", "number-of-reads", "0"],
            ["host-port-statistics", "2", "number-of-writes", "0"],
            ["host-port-statistics", "2", "data-read", "0B"],
            ["host-port-statistics", "2", "data-read-numeric", "0"],
            ["host-port-statistics", "2", "data-written", "0B"],
            ["host-port-statistics", "2", "data-written-numeric", "0"],
            ["host-port-statistics", "2", "queue-depth", "0"],
            ["host-port-statistics", "2", "avg-rsp-time", "0"],
            ["host-port-statistics", "2", "avg-read-rsp-time", "0"],
            ["host-port-statistics", "2", "avg-write-rsp-time", "0"],
            ["host-port-statistics", "2", "reset-time", "2019-03-12", "14:53:04"],
            ["host-port-statistics", "2", "reset-time-numeric", "1552402384"],
            [
                "host-port-statistics",
                "2",
                "start-sample-time",
                "2019-09-13",
                "12:31:10",
            ],
            ["host-port-statistics", "2", "start-sample-time-numeric", "1568377870"],
            ["host-port-statistics", "2", "stop-sample-time", "2019-09-13", "12:31:35"],
            ["host-port-statistics", "2", "stop-sample-time-numeric", "1568377895"],
            ["host-port-statistics", "3", "durable-id", "hostport_A3"],
            ["host-port-statistics", "3", "bytes-per-second", "0B"],
            ["host-port-statistics", "3", "bytes-per-second-numeric", "0"],
            ["host-port-statistics", "3", "iops", "0"],
            ["host-port-statistics", "3", "number-of-reads", "0"],
            ["host-port-statistics", "3", "number-of-writes", "0"],
            ["host-port-statistics", "3", "data-read", "0B"],
            ["host-port-statistics", "3", "data-read-numeric", "0"],
            ["host-port-statistics", "3", "data-written", "0B"],
            ["host-port-statistics", "3", "data-written-numeric", "0"],
            ["host-port-statistics", "3", "queue-depth", "0"],
            ["host-port-statistics", "3", "avg-rsp-time", "0"],
            ["host-port-statistics", "3", "avg-read-rsp-time", "0"],
            ["host-port-statistics", "3", "avg-write-rsp-time", "0"],
            ["host-port-statistics", "3", "reset-time", "2019-03-12", "14:53:04"],
            ["host-port-statistics", "3", "reset-time-numeric", "1552402384"],
            [
                "host-port-statistics",
                "3",
                "start-sample-time",
                "2019-09-13",
                "12:31:10",
            ],
            ["host-port-statistics", "3", "start-sample-time-numeric", "1568377870"],
            ["host-port-statistics", "3", "stop-sample-time", "2019-09-13", "12:31:35"],
            ["host-port-statistics", "3", "stop-sample-time-numeric", "1568377895"],
            ["host-port-statistics", "4", "durable-id", "hostport_A4"],
            ["host-port-statistics", "4", "bytes-per-second", "0B"],
            ["host-port-statistics", "4", "bytes-per-second-numeric", "0"],
            ["host-port-statistics", "4", "iops", "0"],
            ["host-port-statistics", "4", "number-of-reads", "0"],
            ["host-port-statistics", "4", "number-of-writes", "0"],
            ["host-port-statistics", "4", "data-read", "0B"],
            ["host-port-statistics", "4", "data-read-numeric", "0"],
            ["host-port-statistics", "4", "data-written", "0B"],
            ["host-port-statistics", "4", "data-written-numeric", "0"],
            ["host-port-statistics", "4", "queue-depth", "0"],
            ["host-port-statistics", "4", "avg-rsp-time", "0"],
            ["host-port-statistics", "4", "avg-read-rsp-time", "0"],
            ["host-port-statistics", "4", "avg-write-rsp-time", "0"],
            ["host-port-statistics", "4", "reset-time", "2019-03-12", "14:53:04"],
            ["host-port-statistics", "4", "reset-time-numeric", "1552402384"],
            [
                "host-port-statistics",
                "4",
                "start-sample-time",
                "2019-09-13",
                "12:31:10",
            ],
            ["host-port-statistics", "4", "start-sample-time-numeric", "1568377870"],
            ["host-port-statistics", "4", "stop-sample-time", "2019-09-13", "12:31:35"],
            ["host-port-statistics", "4", "stop-sample-time-numeric", "1568377895"],
            ["host-port-statistics", "5", "durable-id", "hostport_B1"],
            ["host-port-statistics", "5", "bytes-per-second", "0B"],
            ["host-port-statistics", "5", "bytes-per-second-numeric", "0"],
            ["host-port-statistics", "5", "iops", "0"],
            ["host-port-statistics", "5", "number-of-reads", "524318103"],
            ["host-port-statistics", "5", "number-of-writes", "370831571"],
            ["host-port-statistics", "5", "data-read", "220.0TB"],
            ["host-port-statistics", "5", "data-read-numeric", "220087987815424"],
            ["host-port-statistics", "5", "data-written", "146.0TB"],
            ["host-port-statistics", "5", "data-written-numeric", "146011067318784"],
            ["host-port-statistics", "5", "queue-depth", "0"],
            ["host-port-statistics", "5", "avg-rsp-time", "0"],
            ["host-port-statistics", "5", "avg-read-rsp-time", "0"],
            ["host-port-statistics", "5", "avg-write-rsp-time", "0"],
            ["host-port-statistics", "5", "reset-time", "2019-03-12", "14:52:49"],
            ["host-port-statistics", "5", "reset-time-numeric", "1552402369"],
            [
                "host-port-statistics",
                "5",
                "start-sample-time",
                "2019-09-13",
                "12:31:10",
            ],
            ["host-port-statistics", "5", "start-sample-time-numeric", "1568377870"],
            ["host-port-statistics", "5", "stop-sample-time", "2019-09-13", "12:31:34"],
            ["host-port-statistics", "5", "stop-sample-time-numeric", "1568377894"],
            ["host-port-statistics", "6", "durable-id", "hostport_B2"],
            ["host-port-statistics", "6", "bytes-per-second", "0B"],
            ["host-port-statistics", "6", "bytes-per-second-numeric", "0"],
            ["host-port-statistics", "6", "iops", "0"],
            ["host-port-statistics", "6", "number-of-reads", "0"],
            ["host-port-statistics", "6", "number-of-writes", "0"],
            ["host-port-statistics", "6", "data-read", "0B"],
            ["host-port-statistics", "6", "data-read-numeric", "0"],
            ["host-port-statistics", "6", "data-written", "0B"],
            ["host-port-statistics", "6", "data-written-numeric", "0"],
            ["host-port-statistics", "6", "queue-depth", "0"],
            ["host-port-statistics", "6", "avg-rsp-time", "0"],
            ["host-port-statistics", "6", "avg-read-rsp-time", "0"],
            ["host-port-statistics", "6", "avg-write-rsp-time", "0"],
            ["host-port-statistics", "6", "reset-time", "2019-03-12", "14:52:49"],
            ["host-port-statistics", "6", "reset-time-numeric", "1552402369"],
            [
                "host-port-statistics",
                "6",
                "start-sample-time",
                "2019-09-13",
                "12:31:10",
            ],
            ["host-port-statistics", "6", "start-sample-time-numeric", "1568377870"],
            ["host-port-statistics", "6", "stop-sample-time", "2019-09-13", "12:31:34"],
            ["host-port-statistics", "6", "stop-sample-time-numeric", "1568377894"],
            ["host-port-statistics", "7", "durable-id", "hostport_B3"],
            ["host-port-statistics", "7", "bytes-per-second", "0B"],
            ["host-port-statistics", "7", "bytes-per-second-numeric", "0"],
            ["host-port-statistics", "7", "iops", "0"],
            ["host-port-statistics", "7", "number-of-reads", "0"],
            ["host-port-statistics", "7", "number-of-writes", "0"],
            ["host-port-statistics", "7", "data-read", "0B"],
            ["host-port-statistics", "7", "data-read-numeric", "0"],
            ["host-port-statistics", "7", "data-written", "0B"],
            ["host-port-statistics", "7", "data-written-numeric", "0"],
            ["host-port-statistics", "7", "queue-depth", "0"],
            ["host-port-statistics", "7", "avg-rsp-time", "0"],
            ["host-port-statistics", "7", "avg-read-rsp-time", "0"],
            ["host-port-statistics", "7", "avg-write-rsp-time", "0"],
            ["host-port-statistics", "7", "reset-time", "2019-03-12", "14:52:49"],
            ["host-port-statistics", "7", "reset-time-numeric", "1552402369"],
            [
                "host-port-statistics",
                "7",
                "start-sample-time",
                "2019-09-13",
                "12:31:10",
            ],
            ["host-port-statistics", "7", "start-sample-time-numeric", "1568377870"],
            ["host-port-statistics", "7", "stop-sample-time", "2019-09-13", "12:31:34"],
            ["host-port-statistics", "7", "stop-sample-time-numeric", "1568377894"],
            ["host-port-statistics", "8", "durable-id", "hostport_B4"],
            ["host-port-statistics", "8", "bytes-per-second", "0B"],
            ["host-port-statistics", "8", "bytes-per-second-numeric", "0"],
            ["host-port-statistics", "8", "iops", "0"],
            ["host-port-statistics", "8", "number-of-reads", "0"],
            ["host-port-statistics", "8", "number-of-writes", "0"],
            ["host-port-statistics", "8", "data-read", "0B"],
            ["host-port-statistics", "8", "data-read-numeric", "0"],
            ["host-port-statistics", "8", "data-written", "0B"],
            ["host-port-statistics", "8", "data-written-numeric", "0"],
            ["host-port-statistics", "8", "queue-depth", "0"],
            ["host-port-statistics", "8", "avg-rsp-time", "0"],
            ["host-port-statistics", "8", "avg-read-rsp-time", "0"],
            ["host-port-statistics", "8", "avg-write-rsp-time", "0"],
            ["host-port-statistics", "8", "reset-time", "2019-03-12", "14:52:49"],
            ["host-port-statistics", "8", "reset-time-numeric", "1552402369"],
            [
                "host-port-statistics",
                "8",
                "start-sample-time",
                "2019-09-13",
                "12:31:10",
            ],
            ["host-port-statistics", "8", "start-sample-time-numeric", "1568377870"],
            ["host-port-statistics", "8", "stop-sample-time", "2019-09-13", "12:31:34"],
            ["host-port-statistics", "8", "stop-sample-time-numeric", "1568377894"],
        ]
    ) == {
        "A1": {
            "actual-speed": "8Gb",
            "actual-speed-numeric": "7",
            "avg-read-rsp-time": "0",
            "avg-rsp-time": "0",
            "avg-write-rsp-time": "0",
            "bytes-per-second": "0B",
            "bytes-per-second-numeric": "0",
            "configured-speed": "Auto",
            "configured-speed-numeric": "3",
            "configured-topology": "PTP",
            "configured-topology-numeric": "1",
            "controller": "A",
            "controller-numeric": "1",
            "data-read": "453.6TB",
            "data-read-numeric": "453669561808896",
            "data-written": "372.0TB",
            "data-written-numeric": "372010525295104",
            "fan-out": "1",
            "health": "OK",
            "health-numeric": "0",
            "health-reason": "",
            "health-recommendation": "",
            "iops": "0",
            "item_type": "port",
            "media": "FC(P)",
            "number-of-reads": "1142166839",
            "number-of-writes": "1002753355",
            "port": "A1",
            "port-type": "FC",
            "port-type-numeric": "6",
            "primary-loop-id": "N/A",
            "queue-depth": "0",
            "reset-time": "2019-03-12 14:53:04",
            "reset-time-numeric": "1552402384",
            "sfp-part-number": "FTLF8529P4BCV-2H",
            "sfp-present": "Present",
            "sfp-present-numeric": "1",
            "sfp-revision": "A",
            "sfp-status": "OK",
            "sfp-status-numeric": "3",
            "sfp-supported-speeds": "4G,8G,16G",
            "sfp-supported-speeds-numeric": "112",
            "sfp-vendor": "DHS",
            "start-sample-time": "2019-09-13 12:31:10",
            "start-sample-time-numeric": "1568377870",
            "status": "Up",
            "status-numeric": "0",
            "stop-sample-time": "2019-09-13 12:31:35",
            "stop-sample-time-numeric": "1568377895",
            "target-id": "207000c0ff43a3dd",
            "url": "/ports/A1",
        },
        "A2": {
            "actual-speed": "",
            "actual-speed-numeric": "255",
            "avg-read-rsp-time": "0",
            "avg-rsp-time": "0",
            "avg-write-rsp-time": "0",
            "bytes-per-second": "0B",
            "bytes-per-second-numeric": "0",
            "configured-speed": "Auto",
            "configured-speed-numeric": "3",
            "configured-topology": "PTP",
            "configured-topology-numeric": "1",
            "controller": "A",
            "controller-numeric": "1",
            "data-read": "0B",
            "data-read-numeric": "0",
            "data-written": "0B",
            "data-written-numeric": "0",
            "fan-out": "1",
            "health": "N/A",
            "health-numeric": "4",
            "health-reason": "There is no active connection to this host port.",
            "health-recommendation": "- If this host port is intentionally unused, "
            "no action is required. - Otherwise, use an "
            "appropriate interface cable to connect this "
            "host port to a switch or host. - If a cable "
            "is connected, check the cable and the switch "
            "or host for problems.",
            "iops": "0",
            "item_type": "port",
            "media": "FC(-)",
            "number-of-reads": "0",
            "number-of-writes": "0",
            "port": "A2",
            "port-type": "FC",
            "port-type-numeric": "6",
            "primary-loop-id": "N/A",
            "queue-depth": "0",
            "reset-time": "2019-03-12 14:53:04",
            "reset-time-numeric": "1552402384",
            "sfp-part-number": "FTLF8529P4BCV-2H",
            "sfp-present": "Present",
            "sfp-present-numeric": "1",
            "sfp-revision": "A",
            "sfp-status": "OK",
            "sfp-status-numeric": "3",
            "sfp-supported-speeds": "4G,8G,16G",
            "sfp-supported-speeds-numeric": "112",
            "sfp-vendor": "DHS",
            "start-sample-time": "2019-09-13 12:31:10",
            "start-sample-time-numeric": "1568377870",
            "status": "Disconnected",
            "status-numeric": "6",
            "stop-sample-time": "2019-09-13 12:31:35",
            "stop-sample-time-numeric": "1568377895",
            "target-id": "217000c0ff43a3dd",
            "url": "/ports/A2",
        },
        "A3": {
            "actual-speed": "",
            "actual-speed-numeric": "255",
            "avg-read-rsp-time": "0",
            "avg-rsp-time": "0",
            "avg-write-rsp-time": "0",
            "bytes-per-second": "0B",
            "bytes-per-second-numeric": "0",
            "configured-speed": "Auto",
            "configured-speed-numeric": "3",
            "configured-topology": "PTP",
            "configured-topology-numeric": "1",
            "controller": "A",
            "controller-numeric": "1",
            "data-read": "0B",
            "data-read-numeric": "0",
            "data-written": "0B",
            "data-written-numeric": "0",
            "fan-out": "1",
            "health": "N/A",
            "health-numeric": "4",
            "health-reason": "There is no active connection to this host port.",
            "health-recommendation": "- If this host port is intentionally unused, "
            "no action is required. - Otherwise, use an "
            "appropriate interface cable to connect this "
            "host port to a switch or host. - If a cable "
            "is connected, check the cable and the switch "
            "or host for problems.",
            "iops": "0",
            "item_type": "port",
            "media": "FC(-)",
            "number-of-reads": "0",
            "number-of-writes": "0",
            "port": "A3",
            "port-type": "FC",
            "port-type-numeric": "6",
            "primary-loop-id": "N/A",
            "queue-depth": "0",
            "reset-time": "2019-03-12 14:53:04",
            "reset-time-numeric": "1552402384",
            "sfp-part-number": "FTLF8529P4BCV-2H",
            "sfp-present": "Present",
            "sfp-present-numeric": "1",
            "sfp-revision": "A",
            "sfp-status": "OK",
            "sfp-status-numeric": "3",
            "sfp-supported-speeds": "4G,8G,16G",
            "sfp-supported-speeds-numeric": "112",
            "sfp-vendor": "DHS",
            "start-sample-time": "2019-09-13 12:31:10",
            "start-sample-time-numeric": "1568377870",
            "status": "Disconnected",
            "status-numeric": "6",
            "stop-sample-time": "2019-09-13 12:31:35",
            "stop-sample-time-numeric": "1568377895",
            "target-id": "227000c0ff43a3dd",
            "url": "/ports/A3",
        },
        "A4": {
            "actual-speed": "",
            "actual-speed-numeric": "255",
            "avg-read-rsp-time": "0",
            "avg-rsp-time": "0",
            "avg-write-rsp-time": "0",
            "bytes-per-second": "0B",
            "bytes-per-second-numeric": "0",
            "configured-speed": "Auto",
            "configured-speed-numeric": "3",
            "configured-topology": "PTP",
            "configured-topology-numeric": "1",
            "controller": "A",
            "controller-numeric": "1",
            "data-read": "0B",
            "data-read-numeric": "0",
            "data-written": "0B",
            "data-written-numeric": "0",
            "fan-out": "1",
            "health": "N/A",
            "health-numeric": "4",
            "health-reason": "There is no active connection to this host port.",
            "health-recommendation": "- If this host port is intentionally unused, "
            "no action is required. - Otherwise, use an "
            "appropriate interface cable to connect this "
            "host port to a switch or host. - If a cable "
            "is connected, check the cable and the switch "
            "or host for problems.",
            "iops": "0",
            "item_type": "port",
            "media": "FC(-)",
            "number-of-reads": "0",
            "number-of-writes": "0",
            "port": "A4",
            "port-type": "FC",
            "port-type-numeric": "6",
            "primary-loop-id": "N/A",
            "queue-depth": "0",
            "reset-time": "2019-03-12 14:53:04",
            "reset-time-numeric": "1552402384",
            "sfp-part-number": "",
            "sfp-present": "Not Present",
            "sfp-present-numeric": "0",
            "sfp-revision": "",
            "sfp-status": "Not present",
            "sfp-status-numeric": "2",
            "sfp-supported-speeds": "N/A",
            "sfp-supported-speeds-numeric": "0",
            "sfp-vendor": "",
            "start-sample-time": "2019-09-13 12:31:10",
            "start-sample-time-numeric": "1568377870",
            "status": "Disconnected",
            "status-numeric": "6",
            "stop-sample-time": "2019-09-13 12:31:35",
            "stop-sample-time-numeric": "1568377895",
            "target-id": "237000c0ff43a3dd",
            "url": "/ports/A4",
        },
        "B1": {
            "actual-speed": "16Gb",
            "actual-speed-numeric": "12",
            "avg-read-rsp-time": "0",
            "avg-rsp-time": "0",
            "avg-write-rsp-time": "0",
            "bytes-per-second": "0B",
            "bytes-per-second-numeric": "0",
            "configured-speed": "Auto",
            "configured-speed-numeric": "3",
            "configured-topology": "PTP",
            "configured-topology-numeric": "1",
            "controller": "B",
            "controller-numeric": "0",
            "data-read": "220.0TB",
            "data-read-numeric": "220087987815424",
            "data-written": "146.0TB",
            "data-written-numeric": "146011067318784",
            "fan-out": "1",
            "health": "OK",
            "health-numeric": "0",
            "health-reason": "",
            "health-recommendation": "",
            "iops": "0",
            "item_type": "port",
            "media": "FC(P)",
            "number-of-reads": "524318103",
            "number-of-writes": "370831571",
            "port": "B1",
            "port-type": "FC",
            "port-type-numeric": "6",
            "primary-loop-id": "N/A",
            "queue-depth": "0",
            "reset-time": "2019-03-12 14:52:49",
            "reset-time-numeric": "1552402369",
            "sfp-part-number": "FTLF8529P4BCV-2H",
            "sfp-present": "Present",
            "sfp-present-numeric": "1",
            "sfp-revision": "A",
            "sfp-status": "OK",
            "sfp-status-numeric": "3",
            "sfp-supported-speeds": "4G,8G,16G",
            "sfp-supported-speeds-numeric": "112",
            "sfp-vendor": "DHS",
            "start-sample-time": "2019-09-13 12:31:10",
            "start-sample-time-numeric": "1568377870",
            "status": "Up",
            "status-numeric": "0",
            "stop-sample-time": "2019-09-13 12:31:34",
            "stop-sample-time-numeric": "1568377894",
            "target-id": "247000c0ff43a3dd",
            "url": "/ports/B1",
        },
        "B2": {
            "actual-speed": "",
            "actual-speed-numeric": "255",
            "avg-read-rsp-time": "0",
            "avg-rsp-time": "0",
            "avg-write-rsp-time": "0",
            "bytes-per-second": "0B",
            "bytes-per-second-numeric": "0",
            "configured-speed": "Auto",
            "configured-speed-numeric": "3",
            "configured-topology": "PTP",
            "configured-topology-numeric": "1",
            "controller": "B",
            "controller-numeric": "0",
            "data-read": "0B",
            "data-read-numeric": "0",
            "data-written": "0B",
            "data-written-numeric": "0",
            "fan-out": "1",
            "health": "N/A",
            "health-numeric": "4",
            "health-reason": "There is no active connection to this host port.",
            "health-recommendation": "- If this host port is intentionally unused, "
            "no action is required. - Otherwise, use an "
            "appropriate interface cable to connect this "
            "host port to a switch or host. - If a cable "
            "is connected, check the cable and the switch "
            "or host for problems.",
            "iops": "0",
            "item_type": "port",
            "media": "FC(-)",
            "number-of-reads": "0",
            "number-of-writes": "0",
            "port": "B2",
            "port-type": "FC",
            "port-type-numeric": "6",
            "primary-loop-id": "N/A",
            "queue-depth": "0",
            "reset-time": "2019-03-12 14:52:49",
            "reset-time-numeric": "1552402369",
            "sfp-part-number": "FTLF8529P4BCV-2H",
            "sfp-present": "Present",
            "sfp-present-numeric": "1",
            "sfp-revision": "A",
            "sfp-status": "OK",
            "sfp-status-numeric": "3",
            "sfp-supported-speeds": "4G,8G,16G",
            "sfp-supported-speeds-numeric": "112",
            "sfp-vendor": "DHS",
            "start-sample-time": "2019-09-13 12:31:10",
            "start-sample-time-numeric": "1568377870",
            "status": "Disconnected",
            "status-numeric": "6",
            "stop-sample-time": "2019-09-13 12:31:34",
            "stop-sample-time-numeric": "1568377894",
            "target-id": "257000c0ff43a3dd",
            "url": "/ports/B2",
        },
        "B3": {
            "actual-speed": "",
            "actual-speed-numeric": "255",
            "avg-read-rsp-time": "0",
            "avg-rsp-time": "0",
            "avg-write-rsp-time": "0",
            "bytes-per-second": "0B",
            "bytes-per-second-numeric": "0",
            "configured-speed": "Auto",
            "configured-speed-numeric": "3",
            "configured-topology": "PTP",
            "configured-topology-numeric": "1",
            "controller": "B",
            "controller-numeric": "0",
            "data-read": "0B",
            "data-read-numeric": "0",
            "data-written": "0B",
            "data-written-numeric": "0",
            "fan-out": "1",
            "health": "N/A",
            "health-numeric": "4",
            "health-reason": "There is no active connection to this host port.",
            "health-recommendation": "- If this host port is intentionally unused, "
            "no action is required. - Otherwise, use an "
            "appropriate interface cable to connect this "
            "host port to a switch or host. - If a cable "
            "is connected, check the cable and the switch "
            "or host for problems.",
            "iops": "0",
            "item_type": "port",
            "media": "FC(-)",
            "number-of-reads": "0",
            "number-of-writes": "0",
            "port": "B3",
            "port-type": "FC",
            "port-type-numeric": "6",
            "primary-loop-id": "N/A",
            "queue-depth": "0",
            "reset-time": "2019-03-12 14:52:49",
            "reset-time-numeric": "1552402369",
            "sfp-part-number": "FTLF8529P4BCV-2H",
            "sfp-present": "Present",
            "sfp-present-numeric": "1",
            "sfp-revision": "A",
            "sfp-status": "OK",
            "sfp-status-numeric": "3",
            "sfp-supported-speeds": "4G,8G,16G",
            "sfp-supported-speeds-numeric": "112",
            "sfp-vendor": "DHS",
            "start-sample-time": "2019-09-13 12:31:10",
            "start-sample-time-numeric": "1568377870",
            "status": "Disconnected",
            "status-numeric": "6",
            "stop-sample-time": "2019-09-13 12:31:34",
            "stop-sample-time-numeric": "1568377894",
            "target-id": "267000c0ff43a3dd",
            "url": "/ports/B3",
        },
        "B4": {
            "actual-speed": "",
            "actual-speed-numeric": "255",
            "avg-read-rsp-time": "0",
            "avg-rsp-time": "0",
            "avg-write-rsp-time": "0",
            "bytes-per-second": "0B",
            "bytes-per-second-numeric": "0",
            "configured-speed": "Auto",
            "configured-speed-numeric": "3",
            "configured-topology": "PTP",
            "configured-topology-numeric": "1",
            "controller": "B",
            "controller-numeric": "0",
            "data-read": "0B",
            "data-read-numeric": "0",
            "data-written": "0B",
            "data-written-numeric": "0",
            "fan-out": "1",
            "health": "N/A",
            "health-numeric": "4",
            "health-reason": "There is no active connection to this host port.",
            "health-recommendation": "- If this host port is intentionally unused, "
            "no action is required. - Otherwise, use an "
            "appropriate interface cable to connect this "
            "host port to a switch or host. - If a cable "
            "is connected, check the cable and the switch "
            "or host for problems.",
            "iops": "0",
            "item_type": "port",
            "media": "FC(-)",
            "number-of-reads": "0",
            "number-of-writes": "0",
            "port": "B4",
            "port-type": "FC",
            "port-type-numeric": "6",
            "primary-loop-id": "N/A",
            "queue-depth": "0",
            "reset-time": "2019-03-12 14:52:49",
            "reset-time-numeric": "1552402369",
            "sfp-part-number": "",
            "sfp-present": "Not Present",
            "sfp-present-numeric": "0",
            "sfp-revision": "",
            "sfp-status": "Not present",
            "sfp-status-numeric": "2",
            "sfp-supported-speeds": "N/A",
            "sfp-supported-speeds-numeric": "0",
            "sfp-vendor": "",
            "start-sample-time": "2019-09-13 12:31:10",
            "start-sample-time-numeric": "1568377870",
            "status": "Disconnected",
            "status-numeric": "6",
            "stop-sample-time": "2019-09-13 12:31:34",
            "stop-sample-time-numeric": "1568377894",
            "target-id": "277000c0ff43a3dd",
            "url": "/ports/B4",
        },
    }
