#!/usr/bin/env python3
# Copyright (C) 2019 Checkmk GmbH - License: GNU General Public License v2
# This file is part of Checkmk (https://checkmk.com). It is subject to the terms and
# conditions defined in the file COPYING, which is part of this source code package.

# fmt: off
# mypy: disable-error-code=var-annotated

checkname = "skype"

mock_item_state = {
    "": {
        "WEB - Failed search requests/sec_LS:WEB - Address Book Web Query": (0.0, 0),
        "WEB - Failed Get Locations Requests/Second_LS:WEB - Location Information Service": (0.0, 225),
        "WEB - Timed out Active Directory Requests/sec_LS:WEB - Distribution List Expansion": (0.0, 0),
        "UCWA - HTTP 5xx Responses/Second_LS:WEB - UCWA": (0.0, 1),
        "WEB - Failed File Requests/Second_LS:WEB - Address Book File Download": (0.0, 0),
    },
    "conferencing": {
        "CAA - Incomplete calls per sec_LS:CAA - Operations": (0.0, 2),
    },
    "sip_stack": {
       "SIP - Average Incoming Message Processing Time_LS:SIP - Protocol": (0, 2748689388),
       "SIP - Average Incoming Message Processing Time_LS:SIP - Protocol_Base": (0, 1761360),
       "SIP - Incoming Responses Dropped /Sec_LS:SIP - Protocol": (0, 271),
       "SIP - Incoming Requests Dropped /Sec_LS:SIP - Protocol": (0, 596),
       "USrv - Throttled requests/sec_LS:USrv - DBStore": (0, 0),
       "SIP - Local 503 Responses /Sec_LS:SIP - Responses": (0, 6),
       "SIP - Average Holding Time For Incoming Messages_LS:SIP - Load Management": (0.0, 3275709004),
       "SIP - Average Holding Time For Incoming Messages_LS:SIP - Load Management_Base": (0.0, 2063694),
       "SIP - Average Outgoing Queue Delay_LS:SIP - Peers": (0.0, 1198364279),
       "SIP - Average Outgoing Queue Delay_LS:SIP - Peers_Base": (0.0, 7423),
       "SIP - Sends Timed-Out /Sec_LS:SIP - Peers": (0.0, 0),
       "SIP - Authentication System Errors /Sec_LS:SIP - Authentication": (0.0, 0),
    },
    "edge_auth": {
        "- Bad Requests Received/sec_LS:A/V Auth - Requests": (0.0, 0),
    },
    "edge": {
        "A/V Edge - Authentication Failures/sec_LS:A/V Edge - UDP Counters": (0.0, 0),
        "A/V Edge - Authentication Failures/sec_LS:A/V Edge - TCP Counters": (0.0, 0),
        "A/V Edge - Allocate Requests Exceeding Port Limit/sec_LS:A/V Edge - UDP Counters": (0.0, 0),
        "A/V Edge - Allocate Requests Exceeding Port Limit/sec_LS:A/V Edge - TCP Counters": (0.0, 0),
        "A/V Edge - Packets Dropped/sec_LS:A/V Edge - UDP Counters": (0.0, 0),
        "A/V Edge - Packets Dropped/sec_LS:A/V Edge - TCP Counters": (0.0, 0),
    },
}

info = [
    ["sampletime", "42", "1"],
    ["[LS:USrv - Sync Replication Sprocs]"],
    [
        "instance",
        "USrv - SyncReplicationRepReplicaGetCurrentProgress: calls/Sec",
        "USrv - SyncReplicationRepReplicaGetCurrentProgress: Latency (msec)",
        " ",
        "USrv - SyncReplicationRepReplicaGetCurrentProgress: calls total",
        "USrv - SyncReplicationRepReplicaGetCurrentProgress: calls failed",
        "USrv - SyncReplicationRepUpdateEpoch: calls/Sec",
        "USrv - SyncReplicationRepUpdateEpoch: Latency (msec)",
        " ",
        "USrv - SyncReplicationRepUpdateEpoch: calls total",
        "USrv - SyncReplicationRepUpdateEpoch: calls failed",
        "USrv - SyncReplicationGetProgressVector: calls/Sec",
        "USrv - SyncReplicationGetProgressVector: Latency (msec)",
        " ",
        "USrv - SyncReplicationGetProgressVector: calls total",
        "USrv - SyncReplicationGetProgressVector: calls failed",
        "USrv - SyncReplicationRepReplicaUpdateProgressVector: calls/Sec",
        "USrv - SyncReplicationRepReplicaUpdateProgressVector: Latency (msec)",
        " ",
        "USrv - SyncReplicationRepReplicaUpdateProgressVector: calls total",
        "USrv - SyncReplicationRepReplicaUpdateProgressVector: calls failed",
        "USrv - SyncReplicationRepReplicaOnDataReceived: calls/Sec",
        "USrv - SyncReplicationRepReplicaOnDataReceived: Latency (msec)",
        " ",
        "USrv - SyncReplicationRepReplicaOnDataReceived: calls total",
        "USrv - SyncReplicationRepReplicaOnDataReceived: calls failed",
        "USrv - SyncReplicationRepMasterBulkRetrieveData: calls/Sec",
        "USrv - SyncReplicationRepMasterBulkRetrieveData: Latency (msec)",
        " ",
        "USrv - SyncReplicationRepMasterBulkRetrieveData: calls total",
        "USrv - SyncReplicationRepMasterBulkRetrieveData: calls failed",
        "USrv - SyncReplicationRepReplicaBulkApplyData: calls/Sec",
        "USrv - SyncReplicationRepReplicaBulkApplyData: Latency (msec)",
        " ",
        "USrv - SyncReplicationRepReplicaBulkApplyData: calls total",
        "USrv - SyncReplicationRepReplicaBulkApplyData: calls failed",
        "USrv - SyncReplicationRepMasterBulkRetrieveSignatures: calls/Sec",
        "USrv - SyncReplicationRepMasterBulkRetrieveSignatures: Latency (msec)",
        " ",
        "USrv - SyncReplicationRepMasterBulkRetrieveSignatures: calls total",
        "USrv - SyncReplicationRepMasterBulkRetrieveSignatures: calls failed",
        "USrv - SyncReplicationRepReplicaBulkApplySignatures: calls/Sec",
        "USrv - SyncReplicationRepReplicaBulkApplySignatures: Latency (msec)",
        " ",
        "USrv - SyncReplicationRepReplicaBulkApplySignatures: calls total",
        "USrv - SyncReplicationRepReplicaBulkApplySignatures: calls failed",
        "USrv - SyncReplicationRepMasterRetrieveConfsDocumentSignatures: calls/Sec",
        "USrv - SyncReplicationRepMasterRetrieveConfsDocumentSignatures: Latency (msec)",
        " ",
        "USrv - SyncReplicationRepMasterRetrieveConfsDocumentSignatures: calls total",
        "USrv - SyncReplicationRepMasterRetrieveConfsDocumentSignatures: calls failed",
        "USrv - SyncReplicationRepMasterResetState: calls/Sec",
        "USrv - SyncReplicationRepMasterResetState: Latency (msec)",
        " ",
        "USrv - SyncReplicationRepMasterResetState: calls total",
        "USrv - SyncReplicationRepMasterResetState: calls failed",
        "USrv - SyncReplicationRepReplicaBulkDeleteData: calls/Sec",
        "USrv - SyncReplicationRepReplicaBulkDeleteData: Latency (msec)",
        " ",
        "USrv - SyncReplicationRepReplicaBulkDeleteData: calls total",
        "USrv - SyncReplicationRepReplicaBulkDeleteData: calls failed",
        "USrv - SyncReplicationRepMasterOnSyncWithReplicasComplete: calls/Sec",
        "USrv - SyncReplicationRepMasterOnSyncWithReplicasComplete: Latency (msec)",
        " ",
        "USrv - SyncReplicationRepMasterOnSyncWithReplicasComplete: calls total",
        "USrv - SyncReplicationRepMasterOnSyncWithReplicasComplete: calls failed",
        "USrv - SyncReplicationMasterCompareProgressVector: calls/Sec",
        "USrv - SyncReplicationMasterCompareProgressVector: Latency (msec)",
        " ",
        "USrv - SyncReplicationMasterCompareProgressVector: calls total",
        "USrv - SyncReplicationMasterCompareProgressVector: calls failed",
        "USrv - XdsPurgeMetadata: calls/Sec",
        "USrv - XdsPurgeMetadata: Latency (msec)",
        " ",
        "USrv - XdsPurgeMetadata: calls total",
        "USrv - XdsPurgeMetadata: calls failed",
        "USrv - SyncReplicationGetEraForService: calls/Sec",
        "USrv - SyncReplicationGetEraForService: Latency (msec)",
        " ",
        "USrv - SyncReplicationGetEraForService: calls total",
        "USrv - SyncReplicationGetEraForService: calls failed",
        "USrv - SyncReplicationSetEraForService: calls/Sec",
        "USrv - SyncReplicationSetEraForService: Latency (msec)",
        " ",
        "USrv - SyncReplicationSetEraForService: calls total",
        "USrv - SyncReplicationSetEraForService: calls failed",
        "USrv - XdsGetEraForOwner: calls/Sec",
        "USrv - XdsGetEraForOwner: Latency (msec)",
        " ",
        "USrv - XdsGetEraForOwner: calls total",
        "USrv - XdsGetEraForOwner: calls failed",
        "USrv - XdsDeleteDirtyDocuments: calls/Sec",
        "USrv - XdsDeleteDirtyDocuments: Latency (msec)",
        " ",
        "USrv - XdsDeleteDirtyDocuments: calls total",
        "USrv - XdsDeleteDirtyDocuments: calls failed",
        "USrv - SyncReplicationPurgeDirtyDocumentQueue: calls/Sec",
        "USrv - SyncReplicationPurgeDirtyDocumentQueue: Latency (msec)",
        " ",
        "USrv - SyncReplicationPurgeDirtyDocumentQueue: calls total",
        "USrv - SyncReplicationPurgeDirtyDocumentQueue: calls failed",
        "USrv - SyncReplicationRepGetSyncReplicationBatch: calls/Sec",
        "USrv - SyncReplicationRepGetSyncReplicationBatch: Latency (msec)",
        " ",
        "USrv - SyncReplicationRepGetSyncReplicationBatch: calls total",
        "USrv - SyncReplicationRepGetSyncReplicationBatch: calls failed",
        "USrv - SyncReplicationRepOnBatchSyncComplete: calls/Sec",
        "USrv - SyncReplicationRepOnBatchSyncComplete: Latency (msec)",
        " ",
        "USrv - SyncReplicationRepOnBatchSyncComplete: calls total",
        "USrv - SyncReplicationRepOnBatchSyncComplete: calls failed",
        "USrv - Number of low churn data replication operations",
        "USrv - Number of low churn data replication operations per second",
        "USrv - Number of high churn data replication operations",
        "USrv - Number of high churn data replication operations per second",
        "USrv - Number of UserPin and Certificates replication operations",
        "USrv - Number of UserPin and Certificates replication operations per second",
        "USrv - Number of Conference replication operations",
        "USrv - Number of Conference replication operations per second",
        "USrv - Number of Endpoint replication operations",
        "USrv - Number of Endpoint replication operations per second",
    ],
    [
        '""',
        "10",
        "6",
        "10",
        "10",
        "0",
        "10",
        "107",
        "10",
        "10",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "10",
        "143",
        "10",
        "10",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2498",
        "2618",
        "2498",
        "2498",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "165",
        "27",
        "165",
        "165",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "266025",
        "15522",
        "266025",
        "266025",
        "0",
        "50",
        "40",
        "50",
        "50",
        "0",
        "1839",
        "1839",
        "53",
        "53",
        "50",
        "50",
        "0",
        "0",
        "368",
        "368",
    ],
    ["[LS:MCUF - CCCP Processing]"],
    [
        "instance",
        "MCUF - Total CCCP Messages Received",
        "MCUF - CCCP Messages Received/sec",
        "MCUF - Total CCCP Requests Received",
        "MCUF - CCCP Requests Received/sec",
        "MCUF - Total CCCP Responses Received",
        "MCUF - CCCP Responses Received/sec",
        "MCUF - Total CCCP Notifications Received",
        "MCUF - CCCP Notifications Received/sec",
        "MCUF - Total CCCP Messages Sent",
        "MCUF - CCCP Messages Sent/sec",
        "MCUF - Total CCCP Requests Sent",
        "MCUF - CCCP Requests Sent/sec",
        "MCUF - Total CCCP Responses Sent",
        "MCUF - CCCP Responses Sent/sec",
        "MCUF - Total CCCP Notifications Sent",
        "MCUF - CCCP Notifications Sent/sec",
        "MCUF - Total CCCP Messages Retried",
        "MCUF - CCCP Messages Retried/sec",
        "MCUF - Total CCCP Messages Failed",
        "MCUF - Current CCCP Message Queue Size",
        "MCUF - Number of Active Conference Notifiers",
        "MCUF - Number of Conference Notifications Sent",
        "MCUF - Number of Conference Notification Send Retries",
        "MCUF - Number of Conference Notification Send Aborts",
        "MCUF - Number of Invalid Conference Notifications Sent",
        "MCUF - Number of Conference Notification Sent to Non-Exisitent Conferences",
        "MCUF - Number of Unrecognized CCCP messages",
        "MCUF - Number of Exceptions During CCCP Serialization",
        "MCUF - Number of Exceptions During CCCP Message Processing",
        "MCUF - Number of add conference requests failed",
        "MCUF - Number of add user requests failed",
        "MCUF - Average processing time of incoming CCCP messages.",
        "MCUF - Number of outstanding receive operations.",
        "MCUF - Number of messages failed because queue is full.",
        "MCUF - Total AddConference Requests Processed",
        "MCUF - Total AddEndpointMedia Requests Processed",
        "MCUF - Total AddSidebar Requests Processed",
        "MCUF - Total AddUser Requests Processed",
        "MCUF - Total EndorseUser Requests Processed",
        "MCUF - Total DeleteConference Requests Processed",
        "MCUF - Total DeleteConferences Requests Processed",
        "MCUF - Total DeleteEndpointMedia Requests Processed",
        "MCUF - Total DeleteSidebar Requests Processed",
        "MCUF - Total DeleteUser Requests Processed",
        "MCUF - Total GetAvailableMcuTypes Requests Processed",
        "MCUF - Total GetConference Requests Processed",
        "MCUF - Total GetConferences Requests Processed",
        "MCUF - Total GetEncryptionKey Requests Processed",
        "MCUF - Total GetMcu Requests Processed",
        "MCUF - Total GetMeetingId Requests Processed",
        "MCUF - Total VerifyConferenceKey Requests Processed",
        "MCUF - Total ModifyConference Requests Processed",
        "MCUF - Total ModifyConferenceLock Requests Processed",
        "MCUF - Total ModifyConferenceAnnouncements Requests Processed",
        "MCUF - Total ModifyEndpoint Requests Processed",
        "MCUF - Total ModifyEndpointMedia Requests Processed",
        "MCUF - Total ModifyEndpointRole Requests Processed",
        "MCUF - Total ModifySidebar Requests Processed",
        "MCUF - Total ModifyUser Requests Processed",
        "MCUF - Total ModifyUsersMediaFilters Requests Processed",
        "MCUF - Total ModifyUserRoles Requests Processed",
        "MCUF - Total MoveUserToSidebar Requests Processed",
        "MCUF - Total Ping Requests Processed",
        "MCUF - Total PlayRecordedName Requests Processed",
        "MCUF - Total SetUserAccess Requests Processed",
        "MCUF - Total SetLobbyAccess Requests Processed",
        "MCUF - Total StartRecording Requests Processed",
        "MCUF - Total StopRecording Requests Processed",
        "MCUF - Total PauseRecording Requests Processed",
        "MCUF - Total ResumeRecording Requests Processed",
        "MCUF - Total GetConferencingCapabilities Requests Processed",
        "MCUF - Total ResolveConference Requests Processed",
        "MCUF - Total QueryMeetingId Requests Processed",
        "MCUF - Total DeleteMeetingId Requests Processed",
        "MCUF - Total AddConference Responses Processed",
        "MCUF - Total AddEndpointMedia Responses Processed",
        "MCUF - Total AddSidebar Responses Processed",
        "MCUF - Total AddUser Responses Processed",
        "MCUF - Total EndorseUser Responses Processed",
        "MCUF - Total DeleteConference Responses Processed",
        "MCUF - Total DeleteConferences Responses Processed",
        "MCUF - Total DeleteEndpointMedia Responses Processed",
        "MCUF - Total DeleteSidebar Responses Processed",
        "MCUF - Total DeleteUser Responses Processed",
        "MCUF - Total VerifyConferenceKey Responses Processed",
        "MCUF - Total GetAvailableMcuTypes Responses Processed",
        "MCUF - Total GetConference Responses Processed",
        "MCUF - Total GetConferences Responses Processed",
        "MCUF - Total GetEncryptionKey Responses Processed",
        "MCUF - Total GetMcu Responses Processed",
        "MCUF - Total GetMeetingId Responses Processed",
        "MCUF - Total ModifyConference Responses Processed",
        "MCUF - Total ModifyConferenceLock Responses Processed",
        "MCUF - Total ModifyConferenceAnnouncements Responses Processed",
        "MCUF - Total ModifyEndpoint Responses Processed",
        "MCUF - Total ModifyEndpointMedia Responses Processed",
        "MCUF - Total ModifyEndpointRole Responses Processed",
        "MCUF - Total ModifySidebar Responses Processed",
        "MCUF - Total ModifyUser Responses Processed",
        "MCUF - Total ModifyUsersMediaFilters Responses Processed",
        "MCUF - Total ModifyUserRoles Responses Processed",
        "MCUF - Total MoveUserToSidebar Responses Processed",
        "MCUF - Total Ping Responses Processed",
        "MCUF - Total PlayRecordedName Responses Processed",
        "MCUF - Total SetUserAccess Responses Processed",
        "MCUF - Total SetLobbyAccess Responses Processed",
        "MCUF - Total StartRecording Responses Processed",
        "MCUF - Total StopRecording Responses Processed",
        "MCUF - Total PauseRecording Responses Processed",
        "MCUF - Total ResumeRecording Responses Processed",
        "MCUF - Total GetConferencingCapabilities Responses Processed",
        "MCUF - Total ResolveConference Responses Processed",
        "MCUF - Total QueryMeetingId Responses Processed",
        "MCUF - Total DeleteMeetingId Responses Processed",
        "MCUF - Total ConferenceStateNotify Notifications Processed",
        "MCUF - Total McuAvailabilityNotify Notifications Processed",
    ],
    [
        '""',
        "457600",
        "457600",
        "209",
        "209",
        "53",
        "53",
        "457338",
        "457338",
        "262",
        "262",
        "53",
        "53",
        "209",
        "209",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "10",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "193",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "4",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "457338",
    ],
    ["[LS:USrv - GetPresence sproc]"],
    [
        "instance",
        "USrv - RtcGetPresence: calls/Sec",
        "USrv - RtcGetPresence: Latency (sec)",
        " ",
        "USrv - RtcGetPresence: calls total",
        "USrv - 503 responses sent",
        "USrv - Access denied responses sent",
        "USrv - Internal error responses sent",
        "USrv - Get Presence Queue Depth",
        " ",
        "USrv - Average GetPresence batch size",
        "",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:AVMCU - MCU Health And Performance]"],
    [
        "instance",
        "AVMCU - HTTP Stack load",
        "AVMCU - HTTP Stack state",
        "AVMCU - Thread Pool Load",
        "AVMCU - Thread Pool Health State",
        "AVMCU - Thread Pool Unhandled Exceptions",
        "AVMCU - MCU Health State",
        "AVMCU - MCU Draining State",
        "AVMCU - MCU Health State Changed Count",
        "AVMCU - MCU Health DNS resolution failure Count",
        "AVMCU - MCU Health DNS resolution succeeded Count",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0", "0", "1907"],
    ["[LS:JoinLauncher - Join Launcher Service Failures]"],
    [
        "instance",
        "JOINLAUNCHER - Join failures",
        "JOINLAUNCHER - Join failures due to Incorrect meeting URL format",
        "JOINLAUNCHER - Join failures due to failure to lookup Base URL",
        "JOINLAUNCHER - Join failures due to base URL mapping to multiple tenants",
        "JOINLAUNCHER - Join failures due to Lookup User failure",
        "JOINLAUNCHER - Join failures due to Verify Conference Key failure",
        "JOINLAUNCHER - Join failures due to no matching Regex found",
        "JOINLAUNCHER - Join failures due to join taking longer than expected time",
        "JOINLAUNCHER - Join failures to send Conference Error Reports.",
        "JOINLAUNCHER - Join failures due to failover or failback",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:MPPROXY - Informational]"],
    [
        "instance",
        "MPPROXY - Total CreateContext requests",
        "MPPROXY - Total CreateContext responses",
        "MPPROXY - Total calls to EndCreateContext",
        "MPPROXY - Total DeleteContext requests",
        "MPPROXY - Total DeleteContext responses",
        "MPPROXY - Total calls to EndDeleteContext",
        "MPPROXY - Total CreateEndpoint requests",
        "MPPROXY - Average CreateEndpoint request rate",
        "MPPROXY - Total CreateEndpoint responses",
        "MPPROXY - Total calls to EndCreateEndpoint",
        "MPPROXY - Total DeleteEndpoint requests",
        "MPPROXY - Total DeleteEndpoint responses",
        "MPPROXY - Total calls to EndDeleteEndpoint",
        "MPPROXY - Total SetRemoteAddressAndStreamParameters requests",
        "MPPROXY - Total SetRemoteAddressAndStreamParameters responses",
        "MPPROXY - Total calls to EndSetRemoteAddressAndStreamParameters",
        "MPPROXY - Total DisableAudioInputs requests",
        "MPPROXY - Total DisableAudioInputs responses",
        "MPPROXY - Total calls to EndDisableAudioInputs",
        "MPPROXY - Total GetEvents requests",
        "MPPROXY - Total GetEvents responses",
        "MPPROXY - Total calls to EndGetEvents",
        "MPPROXY - Count of active Media Processor connections",
    ],
    [
        '"pbwvw-skype03.16124_avmcusvc_appdom_1"',
        "18",
        "18",
        "18",
        "17",
        "17",
        "17",
        "64",
        "0",
        "64",
        "64",
        "60",
        "56",
        "60",
        "152",
        "152",
        "152",
        "0",
        "0",
        "0",
        "3398453",
        "3398449",
        "3398449",
        "1",
    ],
    [
        '"_Total"',
        "22",
        "22",
        "22",
        "21",
        "21",
        "21",
        "79",
        "0",
        "79",
        "79",
        "75",
        "71",
        "75",
        "161",
        "161",
        "161",
        "0",
        "0",
        "0",
        "6795084",
        "6795076",
        "6795076",
        "2",
    ],
    [
        '"pbwvw-skype03.21588_asmcusvc_appdom_1"',
        "4",
        "4",
        "4",
        "4",
        "4",
        "4",
        "15",
        "0",
        "15",
        "15",
        "15",
        "15",
        "15",
        "9",
        "9",
        "9",
        "0",
        "0",
        "0",
        "3396631",
        "3396627",
        "3396627",
        "1",
    ],
    ["[LS:JoinLauncher - Join Launcher Service incoming Requests]"],
    [
        "instance",
        "JOINLAUNCHER - Incoming join requests",
        "JOINLAUNCHER - Incoming mobile join requests",
        "JOINLAUNCHER - Incoming iPhone join requests",
        "JOINLAUNCHER - Incoming iPhone3G/3Gs join requests",
        "JOINLAUNCHER - Incoming iPad join requests",
        "JOINLAUNCHER - Incoming iPad 3G join requests",
        "JOINLAUNCHER - Incoming Windows Phone join requests",
        "JOINLAUNCHER - Incoming Windows Phone 6.5 join requests",
        "JOINLAUNCHER - Incoming Android join requests",
        "JOINLAUNCHER - Incoming Nokia join requests",
        "JOINLAUNCHER - Incoming desktop client in-app join requests",
        "JOINLAUNCHER - Incoming MLX in-app join requests",
        "JOINLAUNCHER - Incoming join requests from ARM devices",
        "JOINLAUNCHER - Incoming unknown device join requests",
        "JOINLAUNCHER - Incoming iPhone and iPad in-app join requests",
        "JOINLAUNCHER - Incoming Windows Phone in-app join requests",
        "JOINLAUNCHER - Incoming Android in-app join requests",
    ],
    ['""', "4", "0", "0", "0", "0", "0", "0", "0", "0", "0", "1", "0", "0", "0", "0", "0", "0"],
    ["[LS:SIP - Load Management]"],
    [
        "instance",
        "SIP - Average Holding Time For Incoming Messages",
        " ",
        "SIP - Incoming Messages Held",
        "SIP - Incoming Messages Held Above Low Watermark",
        "SIP - Incoming Messages Held Above High Watermark",
        "SIP - Incoming Messages Held Above Overload Watermark",
        "SIP - Incoming Messages Timed out",
        "SIP - Low Watermark",
        "SIP - High Watermark",
        "SIP - Address space usage",
        "SIP - Page file usage",
    ],
    ['""', "3275709004", "2063694", "1", "1", "1", "0", "0", "250", "500", "0", "40"],
    ["[LS:USrv - Conference Control Notification]"],
    [
        "instance",
        "USrv - Incoming Notifications",
        "USrv - Incoming Notifications / sec",
        "USrv - Outgoing Notifications",
        "USrv - Outgoing Notifications / sec",
        "USrv - Notifications in processing",
        "USrv - Incoming malformed C3P Notifications",
        "USrv - Incoming out-of-order notifications",
        "USrv - Incoming out-of-order notifications / sec",
        "USrv - Roster resynchronization requests",
        "USrv - Incoming Get Conference requests",
    ],
    ['""', "850", "850", "1240", "1240", "0", "0", "0", "0", "92", "0"],
    ["[LS:USrv - Conference Focus Factory]"],
    [
        "instance",
        "USrv - Add Conference requests",
        "USrv - Modify Conference requests",
        "USrv - Delete Conference requests",
        "USrv - Get Conference requests",
        "USrv - Get Conferences requests",
        "USrv - Get Available MCU Type requests",
        "USrv - Get Encryption Key requests",
        "USrv - Get Conferencing Capabilities requests",
        "USrv - Resolve Conference requests",
        "USrv - Resolve Conference remote requests",
        "USrv - Delete meeting id requests",
        "USrv - Query meeting id requests",
        "USrv - Add Conference requests succeeded",
        "USrv - Modify Conference requests succeeded",
        "USrv - Delete Conference requests succeeded",
        "USrv - Get Conference requests succeeded",
        "USrv - Get Conferences requests succeeded",
        "USrv - Get Available MCU Type requests succeeded",
        "USrv - Get Encryption Key requests succeeded",
        "USrv - Get Conferencing Capabilities requests succeeded",
        "USrv - Resolve Conference requests succeeded",
        "USrv - Resolve Conference remote requests succeeded",
        "USrv - Delete meeting id requests succeeded",
        "USrv - Query meeting id requests succeeded",
        "USrv - Requests routed to another FrontEnd.",
        "USrv - Requests rejected due to invalid encryption key",
        "USrv - Requests rejected due to invalid conference key",
        "USrv - Consistent Request Queue Depth",
        " ",
        "USrv - Consistent Request Queue Latency (sec)",
        " ",
        "USrv - Consistent Request Batch Latency (sec)",
        " ",
        "USrv - Consistent Request Queue Publish Latency (msec)",
        " ",
        "USrv - Consistent queue batches",
        "USrv - Consistent queue batches that failed due to backend",
        "USrv - Consistent queue batches that timed out",
        "USrv - Consistent queue requests",
        "USrv - Consistent queue requests failed",
        "USrv - Consistent queue requests expired",
        "USrv - Add conference request latency (msec)",
        " ",
        "USrv - Modify conference request latency (msec)",
        " ",
        "USrv - Delete conference request latency (msec)",
        " ",
        "USrv - Get conference request latency (msec)",
        " ",
        "USrv - Resolve conference request latency (msec)",
        "",
    ],
    [
        '""',
        "11",
        "1",
        "0",
        "166",
        "94",
        "1",
        "1",
        "4750",
        "12",
        "0",
        "0",
        "49",
        "11",
        "1",
        "0",
        "166",
        "94",
        "1",
        "1",
        "4750",
        "12",
        "0",
        "0",
        "49",
        "0",
        "0",
        "0",
        "0",
        "200",
        "0",
        "0",
        "3",
        "200",
        "1267",
        "35",
        "200",
        "0",
        "0",
        "201",
        "0",
        "0",
        "1203",
        "11",
        "109",
        "1",
        "0",
        "0",
        "592",
        "166",
        "16",
        "12",
    ],
    ["[LS:RMWebHandler - Room Management Web Handler]"],
    [
        "instance",
        "RMWebHandler - Incoming requests to Handler",
        "RMWebHandler - Requests for which Response Status is not Success",
        "RMWebHandler - Total number of cached Persistent Chat Endpoints",
    ],
    ['""', "0", "0", "0"],
    ["[LS:USrv - Conference Control]"],
    [
        "instance",
        "USrv - Incoming requests",
        "USrv - Incoming requests / sec",
        "USrv - Incoming requests failed",
        "USrv - Outgoing responses to clients",
        "USrv - Outgoing responses to clients / sec",
        "USrv - Incoming AddUser requests",
        "USrv - Incoming DeleteUser requests",
        "USrv - Incoming DeleteConference requests",
        "USrv - Incoming ModifyConfLock requests",
        "USrv - Incoming ModifyRole requests",
        "USrv - Incoming ModifyEndpoint requests",
        "USrv - Incoming VerifyConferencekey requests",
        "USrv - Incoming AddUser requests with trusted flag set",
        "USrv - Incoming media specific command requests",
        "USrv - Incoming SetLobbyAccess requests",
        "USrv - Incoming GetConference requests",
        "USrv - Incoming success responses proxied",
        "USrv - Incoming failure responses proxied",
        "USrv - Local C3P success responses",
        "USrv - Local C3P failure responses",
        "USrv - Local Requests rejected",
    ],
    [
        '""',
        "210",
        "210",
        "0",
        "261",
        "261",
        "71",
        "3",
        "0",
        "0",
        "2",
        "0",
        "12",
        "38",
        "70",
        "13",
        "39",
        "0",
        "0",
        "326665",
        "0",
        "0",
    ],
    ["[LS:LYSS - Storage Service QOS]"],
    [
        "instance",
        "LYSS - OAuth STS Request Time Bucket Counts",
        "LYSS - EWS Autodiscovery Time Bucket Counts",
        "LYSS - EWS Web Request Time Bucket Counts",
    ],
    ['"LYSS4"', "0", "0", "1"],
    ['"_Total"', "0", "220", "2462"],
    ['"UCWA3"', "0", "0", "0"],
    ['"UCWA2"', "0", "0", "2"],
    ['"UCWA1"', "0", "0", "15"],
    ['"UCWA0"', "0", "0", "1129"],
    ['"UCWA4"', "0", "0", "0"],
    ['"LYSS1"', "0", "2", "30"],
    ['"LYSS3"', "0", "0", "1"],
    ['"LYSS2"', "0", "3", "19"],
    ['"LYSS0"', "0", "215", "1265"],
    ["[LS:ClsAgent - Centralized Logging Service]"],
    [
        "instance",
        "ClsAgent - Total number of bytes consumed real time",
        "ClsAgent - Per second rate of bytes consumed and converted to cache",
        "ClsAgent - Total number of bytes copied to network share",
        "ClsAgent - Per second rate of bytes copied to network share",
        "ClsAgent - Total number of requests",
        "ClsAgent - Requests for which Response Status is not Success",
        "ClsAgent - Request latency (ms)",
        " ",
        "ClsAgent - Start Request latency (ms)",
        " ",
        "ClsAgent - Stop Request latency (ms)",
        " ",
        "ClsAgent - Update Request latency (ms)",
        " ",
        "ClsAgent - Flush Request latency (ms)",
        " ",
        "ClsAgent - MoveLogsToNetworkShare Request latency (ms)",
        " ",
        "ClsAgent - Query Request latency (ms)",
        " ",
        "ClsAgent - Search Request latency (ms)",
        " ",
        "ClsAgent - Total number of bytes returned for search requests",
        "ClsAgent - Per second rate of bytes returned for search requests",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:PDP - Core - Audio]"],
    [
        "instance",
        "PDP - BW Check Requests",
        "PDP - BW Check Requests/sec",
        "PDP - Failed BW Check Requests",
        "PDP - Failed BW Check Requests/sec",
        "PDP - BW Commit Requests",
        "PDP - BW Commit Requests/sec",
        "PDP - BW Update Requests",
        "PDP - BW Update Requests/sec",
        "PDP - Failed BW Update Requests",
        "PDP - Failed BW Update Requests/sec",
        "PDP - BW Return Requests",
        "PDP - BW Return Requests/sec",
        "PDP - Active BW Reservations",
        "PDP - Congested Links",
        "PDP - Timed-out BW Reservations",
        "PDP - Timed-out BW Reservations/sec",
        "PDP - Local BW Commit Requests Not Managed",
        "PDP - Local BW Commit Requests Not Managed/sec",
        "PDP - BW Commit Requests Not Managed [IP Address Not Found]",
        "PDP - BW Commit Requests Not Managed/sec [IP Address Not Found]",
        "PDP - BW Commit Requests Not Managed [Modality Not Supported]",
        "PDP - BW Commit Requests Not Managed/sec [Modality Not Supported]",
        "PDP - BW Commit Requests with Reservation ID",
        "PDP - BW Commit Requests with Reservation ID/sec",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:DATAMCU - CCCP Processing]"],
    [
        "instance",
        "DATAMCU - Total CCCP Messages Received",
        "DATAMCU - CCCP Messages Received/sec",
        "DATAMCU - Total CCCP Requests Received",
        "DATAMCU - CCCP Requests Received/sec",
        "DATAMCU - Total CCCP Responses Received",
        "DATAMCU - CCCP Responses Received/sec",
        "DATAMCU - Total CCCP Notifications Received",
        "DATAMCU - CCCP Notifications Received/sec",
        "DATAMCU - Total CCCP Messages Sent",
        "DATAMCU - CCCP Messages Sent/sec",
        "DATAMCU - Total CCCP Requests Sent",
        "DATAMCU - CCCP Requests Sent/sec",
        "DATAMCU - Total CCCP Responses Sent",
        "DATAMCU - CCCP Responses Sent/sec",
        "DATAMCU - Total CCCP Notifications Sent",
        "DATAMCU - CCCP Notifications Sent/sec",
        "DATAMCU - Total CCCP Messages Retried",
        "DATAMCU - CCCP Messages Retried/sec",
        "DATAMCU - Total CCCP Messages Failed",
        "DATAMCU - Current CCCP Message Queue Size",
        "DATAMCU - Number of Active Conference Notifiers",
        "DATAMCU - Number of Conference Notifications Sent",
        "DATAMCU - Number of Conference Notification Send Retries",
        "DATAMCU - Number of Conference Notification Send Aborts",
        "DATAMCU - Number of Invalid Conference Notifications Sent",
        "DATAMCU - Number of Conference Notification Sent to Non-Exisitent Conferences",
        "DATAMCU - Number of Unrecognized CCCP messages",
        "DATAMCU - Number of Exceptions During CCCP Serialization",
        "DATAMCU - Number of Exceptions During CCCP Message Processing",
        "DATAMCU - Number of add conference requests failed",
        "DATAMCU - Number of add user requests failed",
        "DATAMCU - Average processing time of incoming CCCP messages.",
        "DATAMCU - Number of outstanding receive operations.",
        "DATAMCU - Number of messages failed because queue is full.",
        "DATAMCU - Total AddConference Requests Processed",
        "DATAMCU - Total AddEndpointMedia Requests Processed",
        "DATAMCU - Total AddSidebar Requests Processed",
        "DATAMCU - Total AddUser Requests Processed",
        "DATAMCU - Total EndorseUser Requests Processed",
        "DATAMCU - Total DeleteConference Requests Processed",
        "DATAMCU - Total DeleteConferences Requests Processed",
        "DATAMCU - Total DeleteEndpointMedia Requests Processed",
        "DATAMCU - Total DeleteSidebar Requests Processed",
        "DATAMCU - Total DeleteUser Requests Processed",
        "DATAMCU - Total GetAvailableMcuTypes Requests Processed",
        "DATAMCU - Total GetConference Requests Processed",
        "DATAMCU - Total GetConferences Requests Processed",
        "DATAMCU - Total GetEncryptionKey Requests Processed",
        "DATAMCU - Total GetMcu Requests Processed",
        "DATAMCU - Total GetMeetingId Requests Processed",
        "DATAMCU - Total VerifyConferenceKey Requests Processed",
        "DATAMCU - Total ModifyConference Requests Processed",
        "DATAMCU - Total ModifyConferenceLock Requests Processed",
        "DATAMCU - Total ModifyConferenceAnnouncements Requests Processed",
        "DATAMCU - Total ModifyEndpoint Requests Processed",
        "DATAMCU - Total ModifyEndpointMedia Requests Processed",
        "DATAMCU - Total ModifyEndpointRole Requests Processed",
        "DATAMCU - Total ModifySidebar Requests Processed",
        "DATAMCU - Total ModifyUser Requests Processed",
        "DATAMCU - Total ModifyUsersMediaFilters Requests Processed",
        "DATAMCU - Total ModifyUserRoles Requests Processed",
        "DATAMCU - Total MoveUserToSidebar Requests Processed",
        "DATAMCU - Total Ping Requests Processed",
        "DATAMCU - Total PlayRecordedName Requests Processed",
        "DATAMCU - Total SetUserAccess Requests Processed",
        "DATAMCU - Total SetLobbyAccess Requests Processed",
        "DATAMCU - Total StartRecording Requests Processed",
        "DATAMCU - Total StopRecording Requests Processed",
        "DATAMCU - Total PauseRecording Requests Processed",
        "DATAMCU - Total ResumeRecording Requests Processed",
        "DATAMCU - Total GetConferencingCapabilities Requests Processed",
        "DATAMCU - Total ResolveConference Requests Processed",
        "DATAMCU - Total QueryMeetingId Requests Processed",
        "DATAMCU - Total DeleteMeetingId Requests Processed",
        "DATAMCU - Total AddConference Responses Processed",
        "DATAMCU - Total AddEndpointMedia Responses Processed",
        "DATAMCU - Total AddSidebar Responses Processed",
        "DATAMCU - Total AddUser Responses Processed",
        "DATAMCU - Total EndorseUser Responses Processed",
        "DATAMCU - Total DeleteConference Responses Processed",
        "DATAMCU - Total DeleteConferences Responses Processed",
        "DATAMCU - Total DeleteEndpointMedia Responses Processed",
        "DATAMCU - Total DeleteSidebar Responses Processed",
        "DATAMCU - Total DeleteUser Responses Processed",
        "DATAMCU - Total VerifyConferenceKey Responses Processed",
        "DATAMCU - Total GetAvailableMcuTypes Responses Processed",
        "DATAMCU - Total GetConference Responses Processed",
        "DATAMCU - Total GetConferences Responses Processed",
        "DATAMCU - Total GetEncryptionKey Responses Processed",
        "DATAMCU - Total GetMcu Responses Processed",
        "DATAMCU - Total GetMeetingId Responses Processed",
        "DATAMCU - Total ModifyConference Responses Processed",
        "DATAMCU - Total ModifyConferenceLock Responses Processed",
        "DATAMCU - Total ModifyConferenceAnnouncements Responses Processed",
        "DATAMCU - Total ModifyEndpoint Responses Processed",
        "DATAMCU - Total ModifyEndpointMedia Responses Processed",
        "DATAMCU - Total ModifyEndpointRole Responses Processed",
        "DATAMCU - Total ModifySidebar Responses Processed",
        "DATAMCU - Total ModifyUser Responses Processed",
        "DATAMCU - Total ModifyUsersMediaFilters Responses Processed",
        "DATAMCU - Total ModifyUserRoles Responses Processed",
        "DATAMCU - Total MoveUserToSidebar Responses Processed",
        "DATAMCU - Total Ping Responses Processed",
        "DATAMCU - Total PlayRecordedName Responses Processed",
        "DATAMCU - Total SetUserAccess Responses Processed",
        "DATAMCU - Total SetLobbyAccess Responses Processed",
        "DATAMCU - Total StartRecording Responses Processed",
        "DATAMCU - Total StopRecording Responses Processed",
        "DATAMCU - Total PauseRecording Responses Processed",
        "DATAMCU - Total ResumeRecording Responses Processed",
        "DATAMCU - Total GetConferencingCapabilities Responses Processed",
        "DATAMCU - Total ResolveConference Responses Processed",
        "DATAMCU - Total QueryMeetingId Responses Processed",
        "DATAMCU - Total DeleteMeetingId Responses Processed",
        "DATAMCU - Total ConferenceStateNotify Notifications Processed",
        "DATAMCU - Total McuAvailabilityNotify Notifications Processed",
    ],
    [
        '""',
        "81754",
        "81754",
        "147",
        "147",
        "81607",
        "81607",
        "0",
        "0",
        "196230",
        "196230",
        "81607",
        "81607",
        "147",
        "147",
        "114476",
        "114476",
        "0",
        "0",
        "0",
        "0",
        "1",
        "143",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "10",
        "0",
        "60",
        "0",
        "0",
        "0",
        "0",
        "21",
        "1",
        "0",
        "0",
        "2",
        "0",
        "61",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "81607",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:CHAT - Persistent Chat Message processing.]"],
    [
        "instance",
        "CHAT - Number of AD Updates processed",
        "CHAT - AD Update processing time",
        "CHAT - Total number of AD Updates",
        "CHAT - Number of principals to be synchronized",
        "CHAT - Number of Auto provisions",
        "CHAT - Auto provision processing time",
        "CHAT - Number of invites for new endpoint",
        "CHAT - Number of invites for last new endpoint",
        "CHAT - New endpoint processing time",
        "CHAT - Number of Joins",
        "CHAT - Join processing time",
        "CHAT - Number of remote joins",
        "CHAT - Remote join processing time",
        "CHAT - Number of Parts",
        "CHAT - Part processing time",
        "CHAT - Number of remote parts",
        "CHAT - Remote part processing time",
        "CHAT - Number of Quits",
        "CHAT - Quit processing time",
        "CHAT - Number of Batch Joins",
        "CHAT - Batch join processing time",
        "CHAT - Batch join size",
        "CHAT - Number of remote batch joins",
        "CHAT - Remote batch join processing time",
        "CHAT - Number of Backchat requests",
        "CHAT - Backchat request processing time",
        "CHAT - Backchat request size",
        "CHAT - Chat request processing time",
        "CHAT - Remote chat request processing time",
        "CHAT - Number of preference fetches",
        "CHAT - Preference fetch processing time",
        "CHAT - Number of preference save requests",
        "CHAT - Preference save processing time",
        "CHAT - Preference size",
        "CHAT - Total request processing time",
        "CHAT - Requests processed under 500 ms",
        "CHAT - Requests processed over 500 ms",
        "CHAT - Requests processed over 1000 ms",
        "CHAT - Requests processed over 2000 ms",
        "CHAT - Requests processed over 5000 ms",
        "CHAT - Requests processed over 10000 ms",
        "CHAT - Outbound message wait time",
        "CHAT - Last message fanout size",
        "CHAT - Last message client fanout size",
        "CHAT - Last message server fanout size",
        "CHAT - Total outbound messages for clients",
        "CHAT - Total outbound messages for servers",
        "CHAT - Outbound messages that waited under 500 ms",
        "CHAT - Outbound messages that waited over 500 ms",
        "CHAT - Outbound messages that waited over 1000 ms",
        "CHAT - Outbound messages that waited over 2000 ms",
        "CHAT - Outbound messages that waited over 5000 ms",
        "CHAT - Outbound messages that waited over 10000 ms",
        "CHAT - Number of fetch principal from db calls",
        "CHAT - Fetch principal from db processing time",
        "CHAT - Number of save principal to db calls",
        "CHAT - Save principal to db processing time",
        "CHAT - Number of compliance messages sent",
        "CHAT - Compliance message send time",
        "CHAT - Time spent in db operations",
        "CHAT - Time spent caching chat",
        "CHAT - Time spent fetching chat from cache",
        "CHAT - Time spent sending server messages",
        "CHAT - Time spent queuing outbound client messages",
        "CHAT - Total number of messages waiting in the multiplexer queue",
        "CHAT - Total number of messages waiting to be sent to peers",
        "CHAT - Total number of process results waiting to be processed",
        "CHAT - Total number of messages embedded in pending process results",
    ],
    [
        '""',
        "3867",
        "1970924",
        "2311",
        "0",
        "71",
        "26271",
        "0",
        "0",
        "7799",
        "725",
        "57",
        "0",
        "0",
        "1",
        "1",
        "0",
        "0",
        "4088",
        "31",
        "412",
        "138",
        "2",
        "0",
        "0",
        "755",
        "4",
        "1",
        "137",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2107359",
        "34125",
        "166",
        "139",
        "82",
        "43",
        "38",
        "1",
        "0",
        "1",
        "0",
        "16328",
        "1",
        "15792",
        "139",
        "58",
        "24",
        "3",
        "1",
        "5980",
        "26869",
        "3930",
        "33653",
        "0",
        "0",
        "546844",
        "117",
        "2",
        "2",
        "23",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:SIP - External Edge Protocol]"],
    [
        "instance",
        "SIP - External Messages Received With Internally Supported Domain",
        "SIP - External Messages With Internally Supported Domain /Sec",
        "SIP - External Messages Received With Allowed Partner Server Domain",
        "SIP - External Messages Received With Allowed Partner Server Domain /Sec",
        "SIP - External Messages Received With Hosting Provider Domain",
        "SIP - External Messages Received With Hosting Provider Domain /Sec",
        "SIP - External Messages Received With Public Provider Domain",
        "SIP - External Messages Received With Public Provider Domain /Sec",
        "SIP - External Messages Received With a Configured Allowed Domain",
        "SIP - External Messages Received With a Configured Allowed Domain /Sec",
        "SIP - External Messages Received With a Discovered Domain",
        "SIP - External Messages Received With a Discovered Domain /Sec",
        "SIP - External Messages Sent With Internally Supported Domain",
        "SIP - External Messages Sent With Internally Supported Domain /Sec",
        "SIP - External Messages Sent With Allowed Partner Server Domain",
        "SIP - External Messages Sent With Allowed Partner Server Domain /Sec",
        "SIP - External Messages Sent With Hosting Provider Domain",
        "SIP - External Messages Sent With Hosting Provider Domain /Sec",
        "SIP - External Messages Sent With Public Provider Domain",
        "SIP - External Messages Sent With Public Provider Domain /Sec",
        "SIP - External Messages Sent With a Configured Allowed Domain",
        "SIP - External Messages With a Configured Allowed Domain /Sec",
        "SIP - External Messages Sent With a Discovered Domain",
        "SIP - External Messages Sent With a Discovered Domain /Sec",
        "SIP - Messages Dropped Due To Certificate Mismatch",
        "SIP - Messages Dropped Due To Unknown Domain",
        "SIP - Messages Dropped Due To Unknown Domain /Sec",
        "SIP - External Messages Rejected Due To Internally Supported Domain",
        "SIP - External Messages Rejected Due To Internally Supported Domain /Sec",
        "SIP - External Messages Rejected Due To Federation Disabled",
        "SIP - External Messages Rejected Due To Federation Disabled /Sec",
        "SIP - External Messages Rejected Due To Shared Address Space Disabled",
        "SIP - External Messages Rejected Due To Shared Address Space Disabled /Sec",
        "SIP - External Messages Rejected Due To Shared Address Space Routing Loop",
        "SIP - External Messages Dropped Due To Shared Address Space Routing Loop /Sec",
        "SIP - External Messages Rejected Due To Blocked Domain",
        "SIP - External Messages Rejected Due To Blocked Domain /Sec",
        "SIP - External Messages Rejected Due To Invalid Domains",
        "SIP - External Messages Rejected Due To Invalid Domains /Sec",
        "SIP - External Messages Rejected Due To Domain Not Hosted Here (Service Deployment Only)",
        "SIP - External Messages Rejected Due To Domain Not Hosted Here (Service Deployment Only) /Sec",
        "SIP - External Messages rejected Due To Unresolved Domain",
        "SIP - External Messages rejected Due To Unresolved Domain /Sec",
        "SIP - Messages Rejected Due To Blocked Hosting Provider",
        "SIP - External Messages Rejected Due To Mismatched DNS SRV Result For Allowed Domain",
        "SIP - External Messages Rejected Due To Mismatched DNS SRV Result For Allowed Domain /Sec",
        "SIP - External Messages Rejected Due To Mismatched DNS SRV Result For Discovered Domain",
        "SIP - External Messages Rejected Due To Mismatched DNS SRV Result For Discovered Domain /Sec",
        "SIP - External Messages Rejected Due To Hosting Provider Domain Not Configured",
        "SIP - External Messages Rejected Due To Hosting Provider Domain Not Configured /Sec",
        "SIP - External Messages Rejected Due To Incompatible DNS SRV Result for Allowed Domain",
        "SIP - External Messages Rejected Due To Incompatible DNS SRV Result for Allowed Domain /Sec",
        "SIP - External Messages Rejected Due To Multiple Incompatible DNS SRV Results",
        "SIP - External Messages Rejected Due To Multiple Incompatible DNS SRV Results /Sec",
        "SIP - External Messages Rejected Due To Incompatible Message Domain",
        "SIP - External Messages Rejected Due To Incompatible Message Domain /Sec",
        "SIP - Messages Rejected Due To Incompatible Asserted Identity",
        "SIP - Messages Rejected Due To Incompatible Asserted Identity /Sec",
        "SIP - Messages Rejected Due To Incompatible Boss Domain",
        "SIP - Messages Rejected Due To Incompatible Boss Domain /Sec",
        "SIP - Messages Rejected Due To Incompatible Diversion Domain",
        "SIP - Messages Rejected Due To Incompatible Diversion Domain /Sec",
        "SIP - External Rejected REGISTERs",
        "SIP - External Rejected REGISTERs /Sec",
        "SIP - External Rejected SERVICEs",
        "SIP - External Rejected SERVICEs /Sec",
        "SIP - External Rejected SUBSCRIBEs For Get Rich Presence",
        "SIP - External Rejected SUBSCRIBEs For Get Rich Presence /Sec",
        "SIP - Client Login Attempts Delayed Due To Overloaded Home Server",
        "SIP - Client Login Attempts Delayed Due To Overloaded Home Server /Sec",
        "SIP - Client Login Attempts Delayed Due To Overloaded Home Server Ratio",
        "SIP - Client Messages Rejected Due To Unsupported Internal Domain",
        "SIP - Client Messages Rejected Due To Unsupported Internal Domain /Sec",
        "SIP - Remote User Client Messages Rejected Due To Access Disabled",
        "SIP - Remote User Client Messages Rejected Due To Access Disabled /Sec",
        "SIP - Anonymous User Client Messages Rejected Due To Access Disabled",
        "SIP - Anonymous User Client Messages Rejected Due To Access Disabled /Sec",
        "SIP - Messages From Users Not Enabled For Federation",
        "SIP - Messages From Users Not Enabled For Federation /Sec",
        "SIP - Messages From Users Not Enabled For Public Hosting Providers",
        "SIP - Messages From Users Not Enabled For Public Hosting Providers /Sec",
        "SIP - Messages To Federated Partners Throttled Due to Frequent Connectivity Failures",
        "SIP - Messages To Federated Partners Throttled Due to Frequent Connectivity Failures /Sec",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:AVMCU - Planning]"],
    [
        "instance",
        "AVMCU - Total Conferences Created",
        "AVMCU - Total Conferences Deleted",
        "AVMCU - Total Users Added",
        "AVMCU - Total Users Removed",
        "AVMCU - Total RtpConferences Created",
        "AVMCU - Total Trusted Users Added",
        "AVMCU - Total Trusted Users Removed",
    ],
    ['""', "37", "36", "54", "52", "0", "12", "10"],
    ["[LS:Monitored TCP Connections Statistics]"],
    [
        "instance",
        "01-Process ID",
        "02-Smoothed RTT (ms)",
        "03-Current retransmit timeout (ms)",
        "04-Current retransmit count",
        "05-Retransmitted Bytes Per Second",
        "06-Unacknowledged bytes",
        "07-Send window",
        "08-Send window max",
        "09-Congestion window",
        "10-MSS",
        "11-Collection Error",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:FEDSVC - Outgoing Federation Processing]"],
    [
        "instance",
        "FEDSVC - Messages Dropped Due To Blocked Domain",
        "FEDSVC - Messages/sec Dropped Due To Blocked Domain",
        "FEDSVC - Messages Dropped Due To Domain not present in explicitly configured Allowed list.",
        "FEDSVC - Messages/sec Dropped Due To Domain not present in explicitly configured Allowed list.",
    ],
    ['""', "0", "0", "0", "0"],
    ["[LS:USrv - UpdateEndpoint sproc]"],
    [
        "instance",
        "USrv - RtcUpdateEndpoint: calls/Sec",
        "USrv - RtcUpdateEndpoint: Latency (msec)",
        " ",
        "USrv - RtcUpdateEndpoint: calls total",
        "USrv - RtcUpdateRegistrarEndpoint: calls/Sec",
        "USrv - RtcUpdateRegistrarEndpoint: Latency (msec)",
        " ",
        "USrv - RtcUpdateRegistrarEndpoint: calls total",
    ],
    ['""', "0", "0", "0", "0", "10578", "75738", "10578", "10578"],
    ["[LS:DATACOLLECTION - Data Collection Agent]"],
    [
        "instance",
        "UDC - Number of QoE reports received",
        "UDC - Number of QoE reports received per second",
        "UDC - Number of QoE reports accepted",
        "UDC - Number of QoE reports accepted per second",
        "UDC - Number of QoE reports rejected",
        "UDC - Number of QoE reports rejected per second",
        "UDC - Number of CQF reports received",
        "UDC - Number of CQF reports received per second",
        "UDC - Number of CQF reports accepted",
        "UDC - Number of CQF reports accepted per second",
        "UDC - Number of CQF reports rejected",
        "UDC - Number of CQF reports rejected per second",
        "UDC - Number of items enqueued into Storage Service",
        "UDC - Number of items enqueued into Storage Service per second",
        "UDC - Number of items redirected by Storage Service",
        "UDC - Number of items redirected by Storage Service per second",
        "UDC - Number of items that failed to enqueue into Storage Service",
        "UDC - Number of items that failed to enqueue into Storage Service per second",
        "UDC - Number of IM Messages Blocked",
        "UDC - Number of IM Messages Blocked per second",
        "UDC - Number of LookupUser API Calls",
        "UDC - Number of LookupUser API Calls per second",
        "UDC - Number of LookupUser API Calls Result in Timeout",
        "UDC - Number of LookupUser API Calls Failed",
    ],
    [
        '""',
        "882",
        "882",
        "882",
        "882",
        "0",
        "0",
        "27",
        "27",
        "27",
        "27",
        "0",
        "0",
        "15933",
        "15933",
        "0",
        "0",
        "1707",
        "1707",
        "0",
        "0",
        "58652",
        "58652",
        "0",
        "819",
    ],
    ["[LS:USrv - Conference Mcu Allocator]"],
    [
        "instance",
        "USrv - Mcu allocation requests",
        "USrv - Mcu allocation requests / sec",
        "USrv - Mcu reallocation requests",
        "USrv - Mcu reallocation requests / sec",
        "USrv - Mcu allocation requests satisfied through database",
        "USrv - Mcu allocation requests outstanding",
        "USrv - Factory Calls",
        "USrv - Factory Calls / sec",
        "USrv - Factory Calls Unsuccessful",
        "USrv - Factory Unreachable Failures",
        "USrv - Factory Calls Timed-Out",
        "USrv - Factory Call Latency (msec)",
        " ",
        "USrv - Create Conference Requests",
        "USrv - Create Conference Requests / sec",
        "USrv - Create Conference requests Rejected",
        "USrv - Create Conference Mcu Unreachable Failures",
        "USrv - Create Conference Requests Timed-Out",
        "USrv - Create Conference requests Outstanding",
        "USrv - Create Conference Latency (msec)",
        " ",
        "USrv - Allocation Latency (msec)",
        " ",
        "USrv - Incoming Ping Requests from Mcu",
        "USrv - Outgoing Ping Conference Requests",
        "USrv - Outgoing Ping Conference Requests Succeeded",
        "USrv - Mcu reallocation requests in wait queue",
        "USrv - Mcu reallocation requests failed",
    ],
    [
        '""',
        "378",
        "378",
        "101",
        "101",
        "286",
        "0",
        "193",
        "193",
        "0",
        "0",
        "0",
        "2806",
        "193",
        "193",
        "193",
        "0",
        "0",
        "0",
        "0",
        "3517",
        "193",
        "8097",
        "193",
        "326430",
        "116",
        "15",
        "0",
        "0",
    ],
    ["[LS:WEB - Address Book File Download]"],
    [
        "instance",
        "WEB - Succeeded File Requests",
        "WEB - Succeeded File Requests/Second",
        "WEB - Average processing time for a succeeded file request in milliseconds",
        " ",
        "WEB - Failed File Requests",
        "WEB - Failed File Requests/Second",
    ],
    ['""', "202", "202", "426", "202", "0", "0"],
    ["[LS:UPINSVC - UserPinDBAccess]"],
    [
        "instance",
        "UPINSVC - Queue Depth",
        " ",
        "UPINSVC - Queue Latency (msec)",
        " ",
        "UPINSVC - Sproc Latency (msec)",
        "",
    ],
    ['""', "10994", "21956", "98", "10978", "3819", "10978"],
    ["[LS:WebScheduler - Web Scheduler Handler]"],
    [
        "instance",
        "WEBSCHEDULER - Incoming requests to Handler",
        "WEBSCHEDULER - Requests for which Response Status is not Success",
        "WEBSCHEDULER - Total number of Abwq lookups",
        "WEBSCHEDULER - Number of failed Address Book lookups that failed",
    ],
    ['""', "0", "0", "0", "0"],
    ["[LS:AVMCU - CCCP Processing]"],
    [
        "instance",
        "AVMCU - Total CCCP Messages Received",
        "AVMCU - CCCP Messages Received/sec",
        "AVMCU - Total CCCP Requests Received",
        "AVMCU - CCCP Requests Received/sec",
        "AVMCU - Total CCCP Responses Received",
        "AVMCU - CCCP Responses Received/sec",
        "AVMCU - Total CCCP Notifications Received",
        "AVMCU - CCCP Notifications Received/sec",
        "AVMCU - Total CCCP Messages Sent",
        "AVMCU - CCCP Messages Sent/sec",
        "AVMCU - Total CCCP Requests Sent",
        "AVMCU - CCCP Requests Sent/sec",
        "AVMCU - Total CCCP Responses Sent",
        "AVMCU - CCCP Responses Sent/sec",
        "AVMCU - Total CCCP Notifications Sent",
        "AVMCU - CCCP Notifications Sent/sec",
        "AVMCU - Total CCCP Messages Retried",
        "AVMCU - CCCP Messages Retried/sec",
        "AVMCU - Total CCCP Messages Failed",
        "AVMCU - Current CCCP Message Queue Size",
        "AVMCU - Number of Active Conference Notifiers",
        "AVMCU - Number of Conference Notifications Sent",
        "AVMCU - Number of Conference Notification Send Retries",
        "AVMCU - Number of Conference Notification Send Aborts",
        "AVMCU - Number of Invalid Conference Notifications Sent",
        "AVMCU - Number of Conference Notification Sent to Non-Exisitent Conferences",
        "AVMCU - Number of Unrecognized CCCP messages",
        "AVMCU - Number of Exceptions During CCCP Serialization",
        "AVMCU - Number of Exceptions During CCCP Message Processing",
        "AVMCU - Number of add conference requests failed",
        "AVMCU - Number of add user requests failed",
        "AVMCU - Average processing time of incoming CCCP messages.",
        "AVMCU - Number of outstanding receive operations.",
        "AVMCU - Number of messages failed because queue is full.",
        "AVMCU - Total AddConference Requests Processed",
        "AVMCU - Total AddEndpointMedia Requests Processed",
        "AVMCU - Total AddSidebar Requests Processed",
        "AVMCU - Total AddUser Requests Processed",
        "AVMCU - Total EndorseUser Requests Processed",
        "AVMCU - Total DeleteConference Requests Processed",
        "AVMCU - Total DeleteConferences Requests Processed",
        "AVMCU - Total DeleteEndpointMedia Requests Processed",
        "AVMCU - Total DeleteSidebar Requests Processed",
        "AVMCU - Total DeleteUser Requests Processed",
        "AVMCU - Total GetAvailableMcuTypes Requests Processed",
        "AVMCU - Total GetConference Requests Processed",
        "AVMCU - Total GetConferences Requests Processed",
        "AVMCU - Total GetEncryptionKey Requests Processed",
        "AVMCU - Total GetMcu Requests Processed",
        "AVMCU - Total GetMeetingId Requests Processed",
        "AVMCU - Total VerifyConferenceKey Requests Processed",
        "AVMCU - Total ModifyConference Requests Processed",
        "AVMCU - Total ModifyConferenceLock Requests Processed",
        "AVMCU - Total ModifyConferenceAnnouncements Requests Processed",
        "AVMCU - Total ModifyEndpoint Requests Processed",
        "AVMCU - Total ModifyEndpointMedia Requests Processed",
        "AVMCU - Total ModifyEndpointRole Requests Processed",
        "AVMCU - Total ModifySidebar Requests Processed",
        "AVMCU - Total ModifyUser Requests Processed",
        "AVMCU - Total ModifyUsersMediaFilters Requests Processed",
        "AVMCU - Total ModifyUserRoles Requests Processed",
        "AVMCU - Total MoveUserToSidebar Requests Processed",
        "AVMCU - Total Ping Requests Processed",
        "AVMCU - Total PlayRecordedName Requests Processed",
        "AVMCU - Total SetUserAccess Requests Processed",
        "AVMCU - Total SetLobbyAccess Requests Processed",
        "AVMCU - Total StartRecording Requests Processed",
        "AVMCU - Total StopRecording Requests Processed",
        "AVMCU - Total PauseRecording Requests Processed",
        "AVMCU - Total ResumeRecording Requests Processed",
        "AVMCU - Total GetConferencingCapabilities Requests Processed",
        "AVMCU - Total ResolveConference Requests Processed",
        "AVMCU - Total QueryMeetingId Requests Processed",
        "AVMCU - Total DeleteMeetingId Requests Processed",
        "AVMCU - Total AddConference Responses Processed",
        "AVMCU - Total AddEndpointMedia Responses Processed",
        "AVMCU - Total AddSidebar Responses Processed",
        "AVMCU - Total AddUser Responses Processed",
        "AVMCU - Total EndorseUser Responses Processed",
        "AVMCU - Total DeleteConference Responses Processed",
        "AVMCU - Total DeleteConferences Responses Processed",
        "AVMCU - Total DeleteEndpointMedia Responses Processed",
        "AVMCU - Total DeleteSidebar Responses Processed",
        "AVMCU - Total DeleteUser Responses Processed",
        "AVMCU - Total VerifyConferenceKey Responses Processed",
        "AVMCU - Total GetAvailableMcuTypes Responses Processed",
        "AVMCU - Total GetConference Responses Processed",
        "AVMCU - Total GetConferences Responses Processed",
        "AVMCU - Total GetEncryptionKey Responses Processed",
        "AVMCU - Total GetMcu Responses Processed",
        "AVMCU - Total GetMeetingId Responses Processed",
        "AVMCU - Total ModifyConference Responses Processed",
        "AVMCU - Total ModifyConferenceLock Responses Processed",
        "AVMCU - Total ModifyConferenceAnnouncements Responses Processed",
        "AVMCU - Total ModifyEndpoint Responses Processed",
        "AVMCU - Total ModifyEndpointMedia Responses Processed",
        "AVMCU - Total ModifyEndpointRole Responses Processed",
        "AVMCU - Total ModifySidebar Responses Processed",
        "AVMCU - Total ModifyUser Responses Processed",
        "AVMCU - Total ModifyUsersMediaFilters Responses Processed",
        "AVMCU - Total ModifyUserRoles Responses Processed",
        "AVMCU - Total MoveUserToSidebar Responses Processed",
        "AVMCU - Total Ping Responses Processed",
        "AVMCU - Total PlayRecordedName Responses Processed",
        "AVMCU - Total SetUserAccess Responses Processed",
        "AVMCU - Total SetLobbyAccess Responses Processed",
        "AVMCU - Total StartRecording Responses Processed",
        "AVMCU - Total StopRecording Responses Processed",
        "AVMCU - Total PauseRecording Responses Processed",
        "AVMCU - Total ResumeRecording Responses Processed",
        "AVMCU - Total GetConferencingCapabilities Responses Processed",
        "AVMCU - Total ResolveConference Responses Processed",
        "AVMCU - Total QueryMeetingId Responses Processed",
        "AVMCU - Total DeleteMeetingId Responses Processed",
        "AVMCU - Total ConferenceStateNotify Notifications Processed",
        "AVMCU - Total McuAvailabilityNotify Notifications Processed",
    ],
    [
        '""',
        "81852",
        "81852",
        "245",
        "245",
        "81607",
        "81607",
        "0",
        "0",
        "196619",
        "196619",
        "81607",
        "81607",
        "311",
        "311",
        "114701",
        "114701",
        "0",
        "0",
        "0",
        "0",
        "1",
        "368",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "10",
        "0",
        "37",
        "0",
        "0",
        "66",
        "0",
        "22",
        "1",
        "0",
        "0",
        "3",
        "0",
        "44",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "70",
        "0",
        "0",
        "0",
        "0",
        "2",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "81607",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:AVMP - Informational]"],
    [
        "instance",
        "AVMP - Total CreateContext requests",
        "AVMP - Total CreateContext responses",
        "AVMP - Total calls to EndCreateContext",
        "AVMP - Total DeleteContext requests",
        "AVMP - Total DeleteContext responses",
        "AVMP - Total calls to EndDeleteContext",
        "AVMP - Total CreateEndpoint requests",
        "AVMP - Average CreateEndpoint request rate",
        "AVMP - Total CreateEndpoint responses",
        "AVMP - Total calls to EndCreateEndpoint",
        "AVMP - Total DeleteEndpoint requests",
        "AVMP - Total DeleteEndpoint responses",
        "AVMP - Total calls to EndDeleteEndpoint",
        "AVMP - Total SetRemoteAddressAndStreamParameters requests",
        "AVMP - Total SetRemoteAddressAndStreamParameters responses",
        "AVMP - Total calls to EndSetRemoteAddressAndStreamParameters",
        "AVMP - Total DisableAudioInputs requests",
        "AVMP - Total DisableAudioInputs responses",
        "AVMP - Total calls to EndDisableAudioInputs",
        "AVMP - Total GetEvents requests",
        "AVMP - Total GetEvents responses",
        "AVMP - Total calls to EndGetEvents",
        "AVMP - Total RDP Bandwidth Reallocations",
        "AVMP - Total Send Channel Bandwidth Changes",
        "AVMP - Total Receive Channel Bandwidth Changes",
        "AVMP - Total Rdp Attendee objects connected",
        "AVMP - Total Rdp Attendee objects disconnected",
        "AVMP - Total Rdp Attendee objects cleaned up",
    ],
    [
        '"pbwvw-skype03.16124_avmcusvc_appdom_1"',
        "18",
        "18",
        "18",
        "17",
        "17",
        "17",
        "64",
        "0",
        "64",
        "64",
        "60",
        "60",
        "60",
        "152",
        "152",
        "152",
        "0",
        "0",
        "0",
        "3398453",
        "3398449",
        "3398449",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"_Total"',
        "22",
        "22",
        "22",
        "21",
        "21",
        "21",
        "79",
        "0",
        "79",
        "79",
        "75",
        "75",
        "75",
        "161",
        "161",
        "161",
        "0",
        "0",
        "0",
        "6795084",
        "6795076",
        "6795076",
        "5",
        "5",
        "11",
        "9",
        "9",
        "9",
    ],
    [
        '"pbwvw-skype03.21588_asmcusvc_appdom_1"',
        "4",
        "4",
        "4",
        "4",
        "4",
        "4",
        "15",
        "0",
        "15",
        "15",
        "15",
        "15",
        "15",
        "9",
        "9",
        "9",
        "0",
        "0",
        "0",
        "3396631",
        "3396627",
        "3396627",
        "5",
        "5",
        "11",
        "9",
        "9",
        "9",
    ],
    ["[LS:USrv - Base]"],
    [
        "instance",
        "USrv - Events Received",
        "USrv - Events Received/Sec",
        "USrv - Incoming Requests",
        "USrv - Incoming Requests/Sec",
        "USrv - Messages to be Authenticated",
        "USrv - Messages to be Authenticated/Sec",
        "USrv - Requests to be Authenticated",
        "USrv - Requests to be Authenticated/Sec",
        "USrv - Responses to be Authenticated",
        "USrv - Responses to be Authenticated/Sec",
        "USrv - Phone Numbers to be Authorized",
        "USrv - Phone Numbers to be Authorized/Sec",
        "USrv - Requests with Pool lookups",
        "USrv - Requests with Pool lookups/Sec",
        "USrv - Requests forwarded",
        "USrv - Requests forwarded via Proxy",
        "USrv - Requests forwarded via Redirect response",
        "USrv - Requests processed locally",
        "USrv - OPTIONS requests",
        "USrv - OPTIONS responses",
        "USrv - Incoming Responses",
        "USrv - Incoming Responses/Sec",
        "USrv - Incoming timeouts",
        "USrv - Incoming timeouts/Sec",
        "USrv - Incoming disconnect endpoint events from Proxy",
        "USrv - Throttled Requests",
        "USrv - Throttled Requests/Sec",
        "USrv - Number of failures to delete an endpoint in the User Services Cluster",
    ],
    [
        '""',
        "2156948",
        "2156910",
        "1155849",
        "1156171",
        "4129",
        "4129",
        "4129",
        "4129",
        "0",
        "0",
        "158",
        "158",
        "255724",
        "255726",
        "3139",
        "0",
        "0",
        "250445",
        "55991",
        "55991",
        "703378",
        "703403",
        "42",
        "42",
        "1665",
        "0",
        "0",
        "0",
    ],
    ["[LS:CHAT - Persistent Chat Rooms.]"],
    [
        "instance",
        "CHAT - Chat rooms with users",
        "CHAT - Chat rooms with local users",
        "CHAT - Number of users in a chat room",
        "CHAT - Number of local users in a chat room",
        "CHAT - Inbound Chat Messages",
        "CHAT - Inbound Chat Messages/Sec",
        "CHAT - Outbound Chat Messages",
        "CHAT - Outbound Chat Messages/Sec",
        "CHAT - Permission Check Time",
        "CHAT - Number of Permission Checks",
    ],
    ['""', "5", "5", "1", "1", "42", "42", "330", "330", "21", "2447"],
    ["[LS:LDM - Transports]"],
    [
        "instance",
        "LDM - Active TCP Connections",
        "LDM - Active Multiplexed Connections",
        "LDM - Active Connections to DataProxies",
    ],
    ['""', "0", "0", "0"],
    ["[LS:SIP - Peers]"],
    [
        "instance",
        "SIP - Connections Active",
        "SIP - Inactive Connections Dropped",
        "SIP - Revoked Connections Dropped",
        "SIP - Above Limit Connections Dropped (Access Edge Server only)",
        "SIP - Outgoing Connects Failed",
        "SIP - Outgoing TLS Negotiations Failed",
        "SIP - Sends Outstanding",
        "SIP - Sends Timed-Out",
        "SIP - Sends Timed-Out /Sec",
        "SIP - Average Outgoing Queue Delay",
        " ",
        "SIP - Average Number Of Messages In Processing",
        "SIP - Flow-controlled Connections",
        "SIP - Flow-controlled Connections Dropped",
        "SIP - Average Flow-Control Delay",
        " ",
        "SIP - Incoming Requests",
        "SIP - Incoming Requests /Sec",
        "SIP - Incoming Responses",
        "SIP - Incoming Responses /Sec",
        "SIP - Outgoing Requests",
        "SIP - Outgoing Requests /Sec",
        "SIP - Outgoing Responses",
        "SIP - Outgoing Responses /Sec",
        "SIP - Requests Rejected Due To User Limits Exceeded (Access Edge Server only)",
        "SIP - Messages To Federated Partners Throttled Due to Frequent Connectivity Failures",
        "SIP - Messages To Federated Partners Throttled Due to Frequent Connectivity Failures /Sec",
    ],
    [
        '"_Total"',
        "148",
        "21196",
        "0",
        "0",
        "209",
        "0",
        "0",
        "0",
        "0",
        "1198364279",
        "7423",
        "65841537",
        "0",
        "0",
        "0",
        "0",
        "1030197",
        "1029493",
        "716944",
        "716944",
        "936151",
        "936156",
        "1035146",
        "1035155",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-stapp01"',
        "6",
        "1593",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "19548464",
        "322",
        "1275499",
        "0",
        "0",
        "0",
        "0",
        "16113",
        "16095",
        "758",
        "758",
        "2542",
        "2542",
        "16270",
        "16271",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwbw-exchg01"',
        "3",
        "2732",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "574802",
        "6",
        "20774",
        "0",
        "0",
        "0",
        "0",
        "3588",
        "3588",
        "44",
        "44",
        "41",
        "41",
        "7165",
        "7165",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype01"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwaw-exchg02"',
        "2",
        "2612",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "371775",
        "3",
        "30667",
        "0",
        "0",
        "0",
        "0",
        "3592",
        "3592",
        "12",
        "12",
        "12",
        "12",
        "7176",
        "7176",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03"',
        "39",
        "1553",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "54089135",
        "1231",
        "13906428",
        "0",
        "0",
        "0",
        "0",
        "233327",
        "232642",
        "74731",
        "74731",
        "76868",
        "76868",
        "233699",
        "233707",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype02"',
        "0",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "3",
        "2381",
        "0",
        "0",
        "0",
        "0",
        "69",
        "69",
        "0",
        "0",
        "0",
        "0",
        "71",
        "71",
        "0",
        "0",
        "0",
    ],
    [
        '"edge"',
        "16",
        "1095",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "128776551",
        "2144",
        "2921982",
        "0",
        "0",
        "0",
        "0",
        "45149",
        "45149",
        "261983",
        "261983",
        "262102",
        "262102",
        "45499",
        "45499",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype04"',
        "10",
        "756",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "42962289",
        "815",
        "249212",
        "0",
        "0",
        "0",
        "0",
        "177884",
        "177884",
        "67671",
        "67671",
        "67659",
        "67659",
        "177838",
        "177838",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-stapp02"',
        "4",
        "8",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "31334564",
        "381",
        "1783970",
        "0",
        "0",
        "0",
        "0",
        "17094",
        "17094",
        "1028",
        "1028",
        "12074",
        "12074",
        "17094",
        "17094",
        "0",
        "0",
        "0",
    ],
    [
        '"outlook"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "46784",
        "0",
        "0",
        "0",
        "0",
        "720",
        "720",
        "0",
        "0",
        "0",
        "0",
        "720",
        "720",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwbw-exchg02"',
        "3",
        "2655",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "247850",
        "2",
        "41597",
        "0",
        "0",
        "0",
        "0",
        "3596",
        "3596",
        "10",
        "10",
        "10",
        "10",
        "7184",
        "7184",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwaw-exchg01"',
        "3",
        "2800",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "284765",
        "3",
        "13671",
        "0",
        "0",
        "0",
        "0",
        "3592",
        "3592",
        "12",
        "12",
        "12",
        "12",
        "7176",
        "7176",
        "0",
        "0",
        "0",
    ],
    [
        '"Clients"',
        "58",
        "40",
        "0",
        "0",
        "209",
        "0",
        "0",
        "0",
        "0",
        "918449677",
        "2497",
        "45346126",
        "0",
        "0",
        "0",
        "0",
        "518136",
        "518135",
        "310581",
        "310581",
        "514724",
        "514729",
        "500596",
        "500596",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-exchg01"',
        "2",
        "2665",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "166112",
        "2",
        "64321",
        "0",
        "0",
        "0",
        "0",
        "3629",
        "3629",
        "12",
        "12",
        "12",
        "12",
        "7250",
        "7250",
        "0",
        "0",
        "0",
    ],
    [
        '"0.0.0.0"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-exchg02"',
        "2",
        "2686",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1558295",
        "14",
        "138125",
        "0",
        "0",
        "0",
        "0",
        "3708",
        "3708",
        "102",
        "102",
        "95",
        "95",
        "7408",
        "7408",
        "0",
        "0",
        "0",
    ],
    ["[LS:RoutingApps - Emergency Call Routing]"],
    [
        "instance",
        "RoutingApps - Number of requests received",
        "RoutingApps - Number of requests failed locally",
        "RoutingApps - Number of incoming failure responses",
        "RoutingApps - Number of incoming success responses",
    ],
    ['""', "0", "0", "0", "0"],
    ["[LS:DATACOLLECTION - Exchange Archiving Adaptor]"],
    [
        "instance",
        "UDC - Number of Sessions Processed",
        "UDC - Number of Sessions Processed per second",
        "UDC - Number of Retry Sessions",
        "UDC - Number of Retry Sessions per second",
        "UDC - Number of Exchange Archiving Item Created",
        "UDC - Number of Exchange Archiving Item Created per second",
        "UDC - Number of Exchange Archiving Files Uploaded",
        "UDC - Number of Exchange Archiving Files Uploaded per second",
        "UDC - Number of Exchange Archiving Failures",
        "UDC - Number of Exchange Archiving Failures per second",
        "UDC - Number of Undeliverable Items",
        "UDC - Number of Undeliverable Items per second",
        "UDC - Number of Dropped Sessions",
        "UDC - Number of Dropped Sessions per second",
        "UDC - No Task Finish in Expected Time",
        "UDC - Number of Exchange Archiving Sessions without data to process",
        "UDC - Number of Exchange Archiving Sessions without data to process per second",
        "UDC - Number of Exchange Archiving Sessions without users to process",
        "UDC - Number of Exchange Archiving Sessions without users to process per second",
        "UDC - Number of Exchange Archiving Sessions that failed to generate a transcript",
        "UDC - Number of Exchange Archiving Sessions that failed to generate a transcript per second",
        "UDC - Number of Exchange Archiving Items that need to be created",
        "UDC - Number of Exchange Archiving Items that need to be Created per second",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:USrv - Rich presence service SQL calls]"],
    [
        "instance",
        "USrv - RtcPublishMultipleCategories: calls/Sec",
        "USrv - RtcPublishMultipleCategories: Latency (msec)",
        " ",
        "USrv - RtcPublishMultipleCategories: calls total",
        "USrv - Total number of publications",
        "USrv - Publications/Sec",
        "USrv - Total number of deleted publications",
        "USrv - Deleted publications/Sec",
        "USrv - Total number of publications failed due to version conflict.",
        "USrv - Total number of publications failed due to the compute lock.",
        "USrv - Number of failed publications/sec due to the compute lock.",
        "USrv - RtcSetContainerMembers: calls/Sec",
        "USrv - RtcSetContainerMembers: Latency (msec)",
        " ",
        "USrv - RtcSetContainerMembers: calls total",
        "USrv - Total number of container operations failed due to version conflict.",
        "USrv - RtcAckPromptedSubscriber: calls/Sec",
        "USrv - RtcAckPromptedSubscriber: Latency (msec)",
        " ",
        "USrv - RtcAckPromptedSubscriber: calls total",
        "USrv - RtcSetOrDeleteDelegate: calls/Sec",
        "USrv - RtcSetOrDeleteDelegate: Latency (msec)",
        " ",
        "USrv - RtcSetOrDeleteDelegate: calls total",
        "USrv - SetDelegate failures due to version conflict.",
        "USrv - RtcGetNextNotifyBatch: calls/Sec",
        "USrv - RtcGetNextNotifyBatch: Latency (msec)",
        " ",
        "USrv - RtcGetNextNotifyBatch: calls total",
        "USrv - Rtc(Read)Persist(ed)Setting: calls/Sec",
        "USrv - Rtc(Read)Persist(ed)Setting: Latency (msec)",
        " ",
        "USrv - Rtc(Read)Persist(ed)Setting: calls total",
        "USrv - RtcGetNextNotifyBatchStatistics sproc calls/Sec",
        "USrv - RtcGetNextNotifyBatchStatistics sproc Latency",
        " ",
        "USrv - Number of calls for RtcGetNextNotifyBatchStatistics",
        "USrv - RtcGetNextNotifyBatch requests throttled by database store throttle.",
    ],
    [
        '""',
        "81032",
        "488920",
        "81032",
        "81032",
        "100656",
        "100656",
        "12974",
        "12974",
        "739",
        "0",
        "0",
        "131",
        "4317",
        "131",
        "131",
        "30",
        "55",
        "450",
        "55",
        "55",
        "1",
        "63",
        "1",
        "1",
        "0",
        "1710181",
        "6573069",
        "1710181",
        "1710181",
        "9",
        "0",
        "9",
        "9",
        "171914",
        "6281",
        "171914",
        "171914",
        "0",
    ],
    ["[LS:DATAMCU - DataMCU Content]"],
    [
        "instance",
        "DATAMCU - Number of Data MCU Content objects under Content Manager",
        "DATAMCU - Number of Data MCU Set Location calls to Power Point",
        "DATAMCU - Number of Data MCU Set Location calls to Power Point per second",
        "DATAMCU - Number of Data MCU Whiteboard Content objects created",
        "DATAMCU - Number of Data MCU Power Point Content objects created",
        "DATAMCU - Number of Data MCU native file only Content objects created",
        "DATAMCU - Number of Data MCU Poll Content objects created",
        "DATAMCU - Number of Data MCU Shared Notes Content objects created",
        "DATAMCU - Currently presented data conferencing content that uses Office Web Apps Server.",
        "DATAMCU - Total number of legacy W14 - Office Web Apps Server interop sessions started.",
        "DATAMCU - Total milliseconds needed for starting W14 - Office Web Apps Server interop sessions.",
        "DATAMCU - Total number of W14 - Office Web Apps Server interop sessions start retries.",
        "DATAMCU - Total number of bytes sent by WOPI endpoint as the file content.",
        "DATAMCU - Total number of milliseconds in WOPI when sending the file content .",
        "DATAMCU - Total number of bytes uploaded as Office Web Apps Server content.",
        "DATAMCU - Total number of milliseconds taken for uploading and publishing Office Web Apps Server content.",
        "DATAMCU - Number of active meetings that have Question and Answer content.",
        "DATAMCU - Total number of Question and Answer objects created.",
        "DATAMCU - Total number of Question and Answer question object created.",
        "DATAMCU - Total number of Question and Answer answer object created.",
        "DATAMCU - Average time to process a question or answer across the meetings.",
        " ",
        "DATAMCU - Number of failed Question and Answer requests.",
        "DATAMCU - Average length of a question.",
        " ",
        "DATAMCU - Average length of an answer.",
        " ",
        "DATAMCU - Indicator for the amount of content at risk.",
        "DATAMCU - Indicator for the number of DFS issues in the last five minutes.",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:SipEps - SipEps Transactions]"],
    [
        "instance",
        "SipEps - Outgoing Transactions Processed",
        "SipEps - Outgoing Transactions Processed/sec",
        "SipEps - Incoming Transactions Processed",
        "SipEps - Incoming Transactions Processed/sec",
        "SipEps - Active Transactions",
        "SipEps - Transactions Processed",
        "SipEps - Transactions Processed/sec",
        "SipEps - Transactions Timed Out",
        "SipEps - Transactions Timed Out/sec",
    ],
    [
        '"pbwvw-skype03.16124_avmcusvc_appdom_1"',
        "562",
        "562",
        "376",
        "376",
        "0",
        "938",
        "938",
        "0",
        "0",
    ],
    ['"_Total"', "159652", "159652", "109896", "109896", "0", "269548", "269548", "1", "1"],
    [
        '"pbwvw-skype03.22372_ocsappserverhost_appdom_2"',
        "6039",
        "6039",
        "59",
        "59",
        "0",
        "6098",
        "6098",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.17128_ocsappserverhost_appdom_2"',
        "9873",
        "9873",
        "0",
        "0",
        "0",
        "9873",
        "9873",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.9112_mediationserversvc_appdom_1"',
        "85465",
        "85465",
        "57911",
        "57911",
        "0",
        "143376",
        "143376",
        "1",
        "1",
    ],
    [
        '"pbwvw-skype03.11528_immcusvc_appdom_1"',
        "101",
        "101",
        "131",
        "131",
        "0",
        "232",
        "232",
        "0",
        "0",
    ],
    ['"pbwvw-skype03.276_rtchost_appdom_9"', "55", "55", "0", "0", "0", "55", "55", "0", "0"],
    [
        '"pbwvw-skype03.13864_ocsappserverhost_appdom_2"',
        "52977",
        "52977",
        "51012",
        "51012",
        "0",
        "103989",
        "103989",
        "0",
        "0",
    ],
    ['"pbwvw-skype03.21588_asmcusvc_appdom_1"', "35", "35", "55", "55", "0", "90", "90", "0", "0"],
    [
        '"pbwvw-skype03.24308_ocsappserverhost_appdom_2"',
        "2023",
        "2023",
        "27",
        "27",
        "0",
        "2050",
        "2050",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.24040_ocsappserverhost_appdom_2"',
        "2522",
        "2522",
        "325",
        "325",
        "0",
        "2847",
        "2847",
        "0",
        "0",
    ],
    ["[LS:WEB - UPRP Processing]"],
    [
        "instance",
        "WEB - Total UPRP Messages Received over http",
        "WEB - UPRP Messages Received/sec over http",
        "WEB - Number of local LookupUser requests received",
        "WEB - Number of local LookupDomain requests received",
        "WEB - Number of local EnumerateDomains requests received",
    ],
    ['""', "0", "0", "0", "0", "0"],
    ["[LS:CAS - Informational]"],
    [
        "instance",
        "CAS - Number of active personal announcers",
        "CAS - Number of conferences joined",
        "CAS - Total number of conference INVITES received",
        "CAS - Total number of conferences joined",
        "CAS - Total number of conferences left",
        "CAS - Total number of personal announcers created",
        "CAS - Total number of DTMF commands used",
        "CAS - Total number of roll call commands used",
        "CAS - Total number of roll call command failures",
        "CAS - Total number entry and exit announcements are turned on and off",
        "CAS - Total number of admit all successes",
        "CAS - Total number of admit all failed",
        "CAS - Total number of the pay load command successes",
        "CAS - Total number of the load command failures",
        "CAS - Total number of the text to speech attempts",
        "CAS - Total number of the text to speech failures",
        "CAS - Total number of the modify endpoint attempts",
        "CAS - Total number of the modify endpoint failures",
        "CAS - Total number of times the service was kicked out",
        "CAS - Total time spent between user joined or left a conference and the announcement started",
        "CAS - Total time spent between on entry and exit announcements",
        "CAS - Total time spent to take out participant from conference default and GVA mixes",
        "CAS - Total time spent to put back participant to conference default and GVA mixes",
        "CAS - Total number of times taking participant outside conference default mix failed",
        "CAS - Total number of times puting back participant to conference default mix failed",
        "CAS - Total time required to initialize before making first announcements",
        "CAS - Total time spent for joining given conference after invitation received",
        "CAS - Total time spent for initialization given language for a conference",
        "CAS - Total time spent to initialize Personal Virtual Assistant",
        "CAS - Total time spent since PVA started executing Mute or Unmute command for participant until announcement is being played to participant",
    ],
    [
        '""',
        "2",
        "1",
        "18",
        "18",
        "17",
        "12",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2",
        "0",
        "0",
        "0",
        "0",
        "385",
        "10",
        "0",
        "0",
        "0",
        "44",
        "0",
        "534",
        "0",
    ],
    ["[LS:SipEps - SipEps Forwarded messages]"],
    [
        "instance",
        "SipEps - Incoming Forwarding Transactions Processed",
        "SipEps - Incoming Forwarding Transactions Processed/sec",
        "SipEps - Active Forwarding Transactions",
        "SipEps - Incoming Forwarding Transactions Accepted",
        "SipEps - Incoming Forwarding Transactions Accepted/sec",
        "SipEps - Incoming Forwarding Transactions Declined",
        "SipEps - Incoming Forwarding Transactions Declined/sec",
        "SipEps - Incoming Forwarding Transactions Forwarded",
        "SipEps - Incoming Forwarding Transactions Forwarded/sec",
        "SipEps - Incoming Forwarding Transactions Failed",
        "SipEps - Incoming Forwarding Transactions Failed/sec",
    ],
    [
        '"pbwvw-skype03.16124_avmcusvc_appdom_1"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ['"_Total"', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    [
        '"pbwvw-skype03.22372_ocsappserverhost_appdom_2"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.17128_ocsappserverhost_appdom_2"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.9112_mediationserversvc_appdom_1"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.11528_immcusvc_appdom_1"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ['"pbwvw-skype03.276_rtchost_appdom_9"', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    [
        '"pbwvw-skype03.13864_ocsappserverhost_appdom_2"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.21588_asmcusvc_appdom_1"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.24308_ocsappserverhost_appdom_2"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.24040_ocsappserverhost_appdom_2"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:UPINSVC - User Pin Service related Calls]"],
    [
        "instance",
        "UPINSVC - Total ResolveUser Requests Failed",
        "UPINSVC - Total number of empty ResolveUser Responses",
        "UPINSVC - Total GetUserPinInfo Requests Failed",
        "UPINSVC - Total UnlockUserPin Requests Failed",
        "UPINSVC - Total UpdateUserPin Requests Failed",
        "UPINSVC - Total VerifyUserPin Requests Failed",
        "UPINSVC - Total ResolveUserWithPin Requests Failed",
        "UPINSVC - Total PublishCert Requests Failed",
        "UPINSVC - Total GetPublishedCert Requests Failed",
        "UPINSVC - Total LookupUser Requests Failed",
        "UPINSVC - Total LookupDomain Requests Failed",
        "UPINSVC - Total EnumerateDomains Requests Failed",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:SipEps - SipEps Connections]"],
    [
        "instance",
        "SipEps - Bytes Received",
        "SipEps - Bytes Received/sec",
        "SipEps - Bytes Sent",
        "SipEps - Bytes Sent/sec",
        "SipEps - Disconnections",
        "SipEps - Disconnections/sec",
        "SipEps - Incoming Connections",
        "SipEps - Incoming Connections/sec",
        "SipEps - Outgoing Connections",
        "SipEps - Outgoing Connections/sec",
        "SipEps - NumberOfDNSResolutionFailures",
        "SipEps - NumberOfDNSResolutionFailuresPerSecond",
    ],
    [
        '"pbwvw-skype03.16124_avmcusvc_appdom_1"',
        "2376855",
        "2376855",
        "2835869",
        "2835869",
        "180",
        "180",
        "35",
        "35",
        "149",
        "149",
        "0",
        "0",
    ],
    [
        '"_Total"',
        "593725448",
        "593725448",
        "493433310",
        "493433310",
        "162698",
        "162698",
        "57357",
        "57357",
        "105385",
        "105385",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.22372_ocsappserverhost_appdom_2"',
        "18518076",
        "18518076",
        "13403582",
        "13403582",
        "5967",
        "5967",
        "16",
        "16",
        "5954",
        "5954",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.17128_ocsappserverhost_appdom_2"',
        "30182414",
        "30182414",
        "21900660",
        "21900660",
        "9885",
        "9885",
        "114",
        "114",
        "9773",
        "9773",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.9112_mediationserversvc_appdom_1"',
        "434009960",
        "434009960",
        "353510543",
        "353510543",
        "141622",
        "141622",
        "57140",
        "57140",
        "84497",
        "84497",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.11528_immcusvc_appdom_1"',
        "395185",
        "395185",
        "350998",
        "350998",
        "13",
        "13",
        "11",
        "11",
        "3",
        "3",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.276_rtchost_appdom_9"',
        "122107",
        "122107",
        "143861",
        "143861",
        "30",
        "30",
        "0",
        "0",
        "30",
        "30",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.13864_ocsappserverhost_appdom_2"',
        "93746103",
        "93746103",
        "92271273",
        "92271273",
        "1965",
        "1965",
        "6",
        "6",
        "1971",
        "1971",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.21588_asmcusvc_appdom_1"',
        "286661",
        "286661",
        "299926",
        "299926",
        "47",
        "47",
        "12",
        "12",
        "35",
        "35",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.24308_ocsappserverhost_appdom_2"',
        "4543720",
        "4543720",
        "3533622",
        "3533622",
        "958",
        "958",
        "6",
        "6",
        "954",
        "954",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.24040_ocsappserverhost_appdom_2"',
        "9544367",
        "9544367",
        "5182976",
        "5182976",
        "2031",
        "2031",
        "17",
        "17",
        "2019",
        "2019",
        "0",
        "0",
    ],
    ["[LS:USrv - Subscribe]"],
    [
        "instance",
        "USrv - SUBSCRIBEs received",
        "USrv - SUBSCRIBEs received/Sec",
        "USrv - UNSUBSCRIBEs received",
        "USrv - UNSUBSCRIBEs received/Sec",
        "USrv - Polling SUBSCRIBEs received",
        "USrv - Polling SUBSCRIBEs received/Sec",
        "USrv - Polling SUBSCRIBEs received from directly connected users",
        "USrv - Polling SUBSCRIBEs received/Sec from directly connected users",
        "USrv - Presence SUBSCRIBEs received",
        "USrv - Presence WPending SUBSCRIBEs received",
        "USrv - Roaming Contact SUBSCRIBEs received",
        "USrv - Roaming ACL SUBSCRIBEs received",
        "USrv - Provisioning SUBSCRIBEs received",
        "USrv - Subscriptions added",
        "USrv - Subscriptions modified",
        "USrv - Subscriptions deleted",
        "USrv - Subscribes with no action taken",
        "USrv - Subscribe verifications failed",
        "USrv - Roaming Contact Subscriptions redirected to Exchange",
        "USrv - Contact Subscriptions made to Exchange folder.",
        "USrv - Contact Unsubscriptions from Exchange folder.",
        "USrv - Subscribes denied",
        "USrv - Subscriptions per user limit reached",
        "USrv - Route information not returned from Subscription sprocs",
        "USrv - Subscriptions expired",
        "USrv - Piggybacked Notify Sent",
        "USrv - Rich Presence CSeq hits",
        "USrv - Rich Presence CSeq hits/Sec",
        "USrv - Rich Presence CSeq misses",
        "USrv - Rich Presence CSeq misses/Sec",
        "USrv - Rich Presence CSeq failures",
        "USrv - Rich Presence subscription table size",
        "USrv - Rich Presence polling subscribe failures",
        "USrv - Rich Presence polling subscribe successes",
        "USrv - Rich Presence polling subscribe failures per second",
        "USrv - Rich Presence persistent subscribe failures",
        "USrv - Rich Presence persistent subscribe successes",
        "USrv - Rich Presence persistent subscribe failures per second",
        "USrv - Rich Presence publish failures",
        "USrv - Rich Presence publish failures per second",
        "USrv - Rich Presence publish successes",
        "USrv - Rich Presence persistent subscribe successes per second",
        "USrv - Rich Presence persistent subscribe failures - forbidden response",
        "USrv - Rich Presence persistent subscribe failures per second - forbidden response",
        "USrv - Rich Presence persistent subscribe failures - entity too large response",
        "USrv - Rich Presence persistent subscribe failures per second - entity too large response",
        "USrv - Rich Presence persistent subscribe failures - not found response",
        "USrv - Rich Presence persistent subscribe failures per second - not found response",
        "USrv - Rich Presence persistent subscribe failures - bad request response",
        "USrv - Rich Presence persistent subscribe failures per second - bad request response",
        "USrv - Rich Presence persistent subscribe failures - temp unavailable response",
        "USrv - Rich Presence persistent subscribe failures per second - temp unavailable response",
        "USrv - Rich Presence persistent subscribe failures - call leg unavailable response",
        "USrv - Rich Presence persistent subscribe failures per second - call leg unavailable response",
        "USrv - Rich Presence persistent subscribe failures - internal server error response",
        "USrv - Rich Presence persistent subscribe failures per second - internal server error response",
        "USrv - Rich Presence polling subscribe failures - forbidden response",
        "USrv - Rich Presence polling subscribe failures per second - forbidden response",
        "USrv - Rich Presence polling subscribe failures - entity too large response",
        "USrv - Rich Presence polling subscribe failures per second - entity too large response",
        "USrv - Rich Presence polling subscribe failures - not found response",
        "USrv - Rich Presence polling subscribe failures per second - not found response",
        "USrv - Rich Presence polling subscribe failures - bad request response",
        "USrv - Rich Presence polling subscribe failures per second - bad request response",
        "USrv - Rich Presence polling subscribe failures - temp unavailable response",
        "USrv - Rich Presence polling subscribe failures per second - temp unavailable response",
        "USrv - Rich Presence polling subscribe failures - call leg unavailable response",
        "USrv - Rich Presence polling subscribe failures per second - call leg unavailable response",
        "USrv - Rich Presence polling subscribe failures - internal server error response",
        "USrv - Rich Presence polling subscribe failures per second - internal server error response",
        "USrv - Number of header errors in SUBSCRIBEs received.",
        "USrv - Per second number of header errors in SUBSCRIBEs received.",
        "USrv - Number of invalid SUBSCRIBEs received.",
        "USrv - Per second number of invalid SUBSCRIBEs received.",
        "USrv - Number of internal errors that occurred for SUBSCRIBEs received.",
        "USrv - Per second number of internal errors that occurred for SUBSCRIBEs received.",
        "USrv - Persistent SUBSCRIBEs received",
        "USrv - Persistent SUBSCRIBEs received/Sec",
        "USrv - Rich Presence polling subscribe successes per second",
    ],
    [
        '""',
        "109974",
        "109973",
        "3853",
        "3853",
        "70315",
        "70315",
        "70312",
        "70312",
        "3113",
        "0",
        "16016",
        "0",
        "0",
        "866",
        "1820",
        "564",
        "3",
        "0",
        "15527",
        "286",
        "63",
        "0",
        "0",
        "0",
        "400",
        "0",
        "228882",
        "228881",
        "0",
        "0",
        "0",
        "146",
        "0",
        "70815",
        "0",
        "845",
        "18940",
        "845",
        "0",
        "0",
        "0",
        "18940",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "845",
        "845",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "35810",
        "35810",
        "70815",
    ],
    ["[LS:WEB - EventChannel]"],
    [
        "instance",
        "EventChannel - Pending Get",
        " Timed Out Request Count",
        "EventChannel - Pending Get",
        " Active Request Count",
        "EventChannel - Push Events",
        " Channel Clients Active",
        "EventChannel - Push Events",
        " Channel Clients Disposed",
        "EventChannel - Push Events",
        " Notification Requests Sent",
        "EventChannel - Push Events",
        " Heartbeat Requests Sent",
        "EventChannel - Push Events",
        " Requests Succeeded",
        "EventChannel - Push Events",
        " Requests Failed",
    ],
    ['"_Total"', "259", "1", "0", "0", "0", "0", "0", "0"],
    ['"DefaultInstance"', "259", "1", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.11008_w3wp_appdom"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:CPS - Call Park Service Planning]"],
    [
        "instance",
        "CPS - Total number of SIP requests received.",
        "CPS - Total incoming SIP requests without media type",
        "CPS - Total un-park requests from PBX or PSTN callers",
        "CPS - Total un-park requests from UC clients",
        "CPS - Total park requests",
        "CPS - Total park requests drained",
        "CPS - Total un-park requests",
        "CPS - Total success retrieves.",
        "CPS - Total success ringbacks.",
        "CPS - Total success fallbacks.",
        "CPS - Total parked calls disconnected.",
        "CPS - Current parked calls.",
        "CPS - Total park requests that failed.",
        "CPS - Total park requests failed because unavailable orbit.",
        "CPS - Total park requests failed because backend error.",
        "CPS - Total park requests failed because client error.",
        "CPS - Total park requests failed because bandwidth management.",
        "CPS - Total failed fallback attempts.",
        "CPS - Total un-park requests failed.",
        "CPS - Total un-park requests failed because the source is not in enterprise.",
        "CPS - Total un-park requests failed because invalid XML.",
        "CPS - Total un-park requests failed because the orbit was not found.",
        "CPS - Total un-park requests failed because of a backend error.",
        "CPS - Total un-park requests failed because of an internal error.",
        "CPS - Total failed safe-retrieve requests.",
        "CPS - Total failed redirect un-park requests.",
        "CPS - Total redirect un-park requests.",
        "CPS - Total notifications sent.",
        "CPS - Total failed notifications.",
        "CPS - SQL query duration to reserve an orbit.",
        "CPS - SQL query duration to get a call from orbit.",
        "CPS - SQL query duration to update a call.",
        "CPS - SQL query duration to remove an orbit.",
        "CPS - SQL query duration to retrieve an orbit.",
        "CPS - Total failed SQL attempts to reset orbits.",
        "CPS - Total number of SQL queries that failed in first attempt.",
        "CPS - Total number of internal conversations being terminated.",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:MEDIA - Planning]"],
    [
        "instance",
        "MEDIA - Number of conferences started",
        "MEDIA - Number of audio channels started",
        "MEDIA - Number of video channels started",
        "MEDIA - Number of data channels started",
        "MEDIA - Number of conferences with NORMAL health",
        "MEDIA - Number of conferences with OVERLOADED health",
        "MEDIA - Number of packets dropped in flow control",
        "MEDIA - Number of failed end to end connectivity checks",
        "MEDIA - Number of packet loss events raised on data channels",
        "MEDIA - Number of occasions conference processing is delayed significantly",
    ],
    ['"Call_Park_Service_1.0"', "12", "12", "0", "0", "12", "0", "0", "0", "0", "364"],
    ['"_Total"', "18", "24", "0", "0", "18", "0", "0", "14", "0", "374"],
    ['"MediationServer"', "3", "6", "0", "0", "3", "0", "0", "0", "0", "2"],
    ['"Conferencing_Announcement_Service_1.0"', "2", "2", "0", "0", "2", "0", "0", "0", "0", "2"],
    ['"AVMCUSvc.exe"', "1", "4", "0", "0", "1", "0", "0", "8", "0", "3"],
    ['"ATS_1.0.100"', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"Conferencing_Attendant_1.0"', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"ASMCUSvc.exe"', "0", "0", "0", "0", "0", "0", "0", "6", "0", "3"],
    [
        '"Reach_Server"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ['"Response_Group_Service"', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:MediationServer - Inbound Calls]"],
    [
        "instance",
        "- Current",
        "- Total established",
        "- Total attempts",
        "- Total rejected due to load",
        "- Total INVITEs sent to proxy",
        "- Active priority calls",
        "- Active media bypass calls",
        "- Total inbound media bypass calls",
    ],
    ['"_Total"', "2", "23", "29", "0", "29", "0", "0", "0"],
    [
        '"pbwva-vgate01.intern.rossmann.de;trunk=pbwva-vgate01.intern.rossmann.de"',
        "2",
        "23",
        "0",
        "0",
        "29",
        "0",
        "0",
        "0",
    ],
    ['"pbwva-vgate01.intern.rossmann.de"', "0", "0", "29", "0", "0", "0", "0", "0"],
    ["[LS:MEDIA - Transcoding]"],
    [
        "instance",
        "MEDIA - Transcoding Mode",
        "MEDIA - Number of instances - Total",
        "MEDIA - Number of instances - Capable",
        "MEDIA - Maximum number of capable instances",
        "MEDIA - Number of forced passthroughs",
        "MEDIA - Number of forced transcodings - Resolution",
        "MEDIA - Number of forced transcodings - Bitstream",
        "MEDIA - Current utilization of the system",
        "MEDIA - Current required utilization of the system",
        "MEDIA - Threshold violation count for required utilization",
        "MEDIA - Dynamic load of VIS on the system",
        "MEDIA - Number of very low resolution streams in requests",
        "MEDIA - Number of low resolution streams in requests",
        "MEDIA - Number of medium resolution streams in requests",
        "MEDIA - Number of high resolution streams in requests",
        "MEDIA - Number of very high resolution streams in requests",
        "MEDIA - Number of very low resolution streams being serviced",
        "MEDIA - Number of low resolution streams being serviced",
        "MEDIA - Number of medium resolution streams being serviced",
        "MEDIA - Number of high resolution streams being serviced",
        "MEDIA - Number of very high resolution streams being serviced",
        "MEDIA - Number of very low resolution streams being passed through",
        "MEDIA - Number of low resolution streams being passed through",
        "MEDIA - Number of medium resolution streams being passed through",
        "MEDIA - Number of high resolution streams being passed through",
        "MEDIA - Number of very high resolution streams being passed through",
        "MEDIA - Number of encoders - Very overloaded",
        "MEDIA - Number of encoders - Overloaded",
        "MEDIA - Number of encoders - Underloaded",
        "MEDIA - Number of decoders - Very overloaded",
        "MEDIA - Number of decoders - Overloaded",
        "MEDIA - Number of decoders - Underloaded",
    ],
    [
        '"_Total"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:WEB - Address Book Web Query]"],
    [
        "instance",
        "WEB - Search requests",
        "WEB - Search requests/sec",
        "WEB - Successful search requests",
        "WEB - Successful search requests/sec",
        "WEB - Failed search requests",
        "WEB - Failed search requests/sec",
        "WEB - Average processing time for a search request in milliseconds",
        " ",
        "WEB - Database queries/sec",
        "WEB - Average processing time per address book database query in milliseconds",
        " ",
        "WEB - Change Search requests",
        "WEB - Change Search requests/sec",
        "WEB - Failed change search requests",
        "WEB - Failed change search requests/sec",
        "WEB - Average processing time per change search in milliseconds",
        " ",
        "WEB - Change Search of DTMF requests",
        "WEB - Change Search of DTMF requests/sec",
        "WEB - Organizational search requests",
        "WEB - Organizational search requests/sec",
        "WEB - Failed organizational search requests",
        "WEB - Failed organizational search requests/sec",
        "WEB - Average processing time for organizational search request in milliseconds",
        " ",
        "WEB - Basic and Org Search Request Exception Count",
        "WEB - Basic and Org Search Request Exception/sec",
        "WEB - Basic Search requests",
        "WEB - Basic Search requests/sec",
        "WEB - Failed basic search requests",
        "WEB - Failed Basic search requests/sec",
        "WEB - Average processing time for basic search request in milliseconds",
        " ",
        "WEB - Prefix dial string search requests",
        "WEB - Prefix dial string search requests/sec",
        "WEB - One character prefix search requests",
        "WEB - One character prefix search requests/sec",
        "WEB - Average processing time for one character search requests in milliseconds",
        " ",
        "WEB - Two character prefix search requests",
        "WEB - Two character prefix search requests/sec",
        "WEB - Average processing time for two character search requests in milliseconds",
        " ",
        "WEB - Three or more character prefix search requests",
        "WEB - Three or more character prefix search requests/sec",
        "WEB - Average processing time for three or more character search requests in milliseconds",
        " ",
        "WEB - Photo requests",
        "WEB - Photo requests/sec",
        "WEB - Photo failed requests",
        "WEB - Photo failed requests/sec",
        "WEB - Photo requests throttled",
        "WEB - Photo hash cache entry update count",
        "WEB - Average processing time for photo cached locally in milliseconds",
        " ",
        "WEB - Average processing time for photo not cached in milliseconds",
        " ",
        "WEB - % Photo Local Cache Hit",
        " ",
        "WEB - Skype Public Directory Search Requests",
        "WEB - Skype Public Directory Search Requests/sec",
        "WEB - Failed Skype Public Directory Search Requests",
        "WEB - Failed Skype Public Directory Search Requests/sec",
        "WEB - Skype Public Search Average Processing Time",
        " ",
        "WEB - Skype Public Directory Search Feedback Requests",
        "WEB - Skype Public Directory Search Feedback Requests/sec",
        "WEB - Failed Skype Public Directory Search Feedback Requests",
        "WEB - Failed Skype Public Directory Search Feedback Requests/sec",
        "WEB - Skype Public Search Feedback Average Processing Time",
        " ",
        "WEB - Failed Skype Search Requests With 4xx Response Codes",
        "WEB - Failed Skype Search Requests Per Second With 4xx Response Codes",
        "WEB - Total Skype Search Requests Throttled",
        "WEB - Skype Search Requests Throttled Per Second",
        "WEB - Failed Skype Search Requests With 5xx Response Codes",
        "WEB - Failed Skype Search Requests Per Second With 5xx Response Codes",
        "WEB - Failed Skype Search Feedback Requests With 4xx Response Codes",
        "WEB - Failed Skype Search Feedback Requests Per Second With 4xx Response Codes",
        "WEB - Total Skype Search Feedback Requests Throttled",
        "WEB - Skype Search Feedback Requests Throttled Per Second",
        "WEB - Failed Skype Search Feedback Requests With 5xx Response Codes",
        "WEB - Failed Skype Search Feedback Requests Per Second With 5xx Response Codes",
        "WEB - Total Skype Search Requests Next Hop Connection Failures",
        "WEB - Skype Search Requests Next Hop Connection Failures Per Second",
        "WEB - Skype Search Or Feedback Requests In Processing",
        "WEB - Total Skype Search Or Feedback Requests Throttled By Local Server",
    ],
    [
        '""',
        "8515",
        "8515",
        "8515",
        "8515",
        "0",
        "0",
        "17665",
        "8515",
        "8515",
        "17523",
        "8515",
        "3129",
        "3129",
        "0",
        "0",
        "3167",
        "3129",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1326",
        "1326",
        "0",
        "0",
        "0",
        "243",
        "236",
        "1083",
        "6645",
        "243",
        "1083",
        "1326",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:USrv - UserServices RPC Server]"],
    [
        "instance",
        "USrv - Calls in progress",
        "USrv - Inbound RPC Calls",
        "USrv - Inbound RPC Calls/Sec",
        "USrv - SIP Notifications",
        "USrv - SIP Notifications/Sec",
        "USrv - Delete Rich Presence Subscription ID Notifications",
        "USrv - Security Callbacks",
        "USrv - Security Callbacks/Sec",
        "USrv - Inbound RPC Call Latency (ms)",
        " ",
        "USrv - Access Denied Errors",
        "USrv - Inbound RPC Failures",
        "USrv - Inbound Non-RPC Failures",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:LYSS - Storage Service Adaptors]"],
    [
        "instance",
        "LYSS - Get item queue entries result count with status of new",
        "LYSS - Get item queue entries result count with status of new per second",
        "LYSS - Get item queue entries result count with status of error",
        "LYSS - Get item queue entries result count with status of error per second",
        "LYSS - Enqueue or update queue item to new status",
        "LYSS - Enqueue or update queue item to new status per second",
        "LYSS - Update queue item to in process status",
        "LYSS - Update queue item to in process status per second",
        "LYSS - Update queue item to complete status",
        "LYSS - Update queue item to complete status per second",
        "LYSS - Update queue item to error status",
        "LYSS - Update queue item to error status per second",
        "LYSS - Update queue item to archive status",
        "LYSS - Update queue item to archive status per second",
        "LYSS - Update queue item with session identifier",
        "LYSS - Update queue item with session identifier per second",
        "LYSS - Total number of storage adaptor asynchronous task timeouts",
        "LYSS - Total number of storage adaptor asynchronous task cancel timeouts",
        "LYSS - Total number of storage adaptor asynchronous task stop operation failures",
        "LYSS - Total number of storage adaptor asynchronous task unhandled exceptions",
        "LYSS - Queue items processed",
        "LYSS - Queue items processed per second",
        "LYSS - Latency for adaptor stored procedure (ms)",
        "",
    ],
    [
        '"_Total"',
        "17447",
        "17447",
        "1",
        "1",
        "17447",
        "17447",
        "0",
        "0",
        "13692",
        "13692",
        "1",
        "1",
        "0",
        "0",
        "7210",
        "7210",
        "0",
        "0",
        "0",
        "0",
        "20894",
        "20894",
        "2931248",
        "1373598",
    ],
    [
        '"LegalIntercept Adaptor"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "358118",
        "171066",
    ],
    [
        '"UC Session Aapdater"',
        "7210",
        "7210",
        "0",
        "0",
        "7210",
        "7210",
        "0",
        "0",
        "13",
        "13",
        "0",
        "0",
        "0",
        "0",
        "7210",
        "7210",
        "0",
        "0",
        "0",
        "0",
        "7210",
        "7210",
        "380682",
        "174294",
    ],
    [
        '"QoE Adaptor"',
        "0",
        "0",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "905",
        "905",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "910",
        "910",
        "360272",
        "171068",
    ],
    [
        '"Conversation History Adaptor"',
        "1414",
        "1414",
        "0",
        "0",
        "1414",
        "1414",
        "0",
        "0",
        "1414",
        "1414",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1414",
        "1414",
        "364777",
        "171060",
    ],
    [
        '"Exchange Archiving Adaptor"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "359418",
        "171067",
    ],
    [
        '"Fabric"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"SQL Archiving Adaptor"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "361057",
        "171069",
    ],
    [
        '"Exchange Storage"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"Data MCU Archiving Content Purger"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"UCS Adaptor"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"CDR Adaptor"',
        "8823",
        "8823",
        "0",
        "0",
        "8823",
        "8823",
        "0",
        "0",
        "11360",
        "11360",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "11360",
        "11360",
        "388074",
        "172908",
    ],
    [
        '"Meeting Report Adaptor"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "358850",
        "171066",
    ],
    ["[LS:WEB - UCWA]"],
    [
        "instance",
        "UCWA - Average Lifetime for Session (ms)",
        " ",
        "UCWA - Average Application Startup Time (ms)",
        " ",
        "UCWA - Active Application Count",
        "UCWA - Active User Instance Count",
        "UCWA - Active User Instances without application",
        "UCWA - Active Session Count",
        "UCWA - Active Session Count With Active Presence Subscriptions",
        "UCWA - HTTP 4xx Responses/Second",
        "UCWA - HTTP 5xx Responses/Second",
        "UCWA - Requests Received/Second",
        "UCWA - Requests Succeeded/Second",
        "UCWA - Application Creation Requests Received/Second",
        "UCWA - Succeeded Create Application Requests/Second",
        "UCWA - Total Requests Received on the Command Channel",
        "UCWA - Total HTTP 4xx Responses",
        "UCWA - Total HTTP 5xx Responses",
        "UCWA - Total Requests Succeeded",
        "UCWA - Total Application Creation Requests Received",
        "UCWA - Total Sessions Initiated",
        "UCWA - Total Sessions Terminated Because of Idle Timeout",
        "UCWA - Active Messaging Modality Count",
        "UCWA - Active Audio Modality Count",
        "UCWA - Active Video Modality Count",
        "UCWA - Active Panoramic Video Modality Count",
        "UCWA - Active Application Sharing Modality Count",
        "UCWA - Active Data Collaboration Modality Count",
        "UCWA - Exchange HD Photo Get Latency (ms)",
        " ",
        "UCWA - Number of HD Photo Get Failures",
        "UCWA - Exchange Contact Search Latency (ms)",
        " ",
        "UCWA - Currently Active Presence Subscription Count",
        "UCWA - Over The Maximum Subscriptions Per Application",
        "UCWA - Over The Maximum Subscriptions Per Batch",
        "UCWA - Retrieving Inband Data Failures",
        "UCWA - Presence Subscription Failures",
        "UCWA - Registering Endpoint Failures",
        "UCWA - Total Throttled Applications",
        "UCWA - IM MCU Join Failures",
        "UCWA - AV MCU Join Failures",
        "UCWA - AS MCU Join Failures",
        "UCWA - Data MCU Join Failures",
        "UCWA - Active Directory Photo Get Latency (ms)",
        " ",
        "UCWA - Number of Active Directory Photo Get Failures",
        "UCWA - Number of Deserialization Failures",
        "UCWA - Exchange Photo Get Requests/Second",
        "UCWA - Exchange Photo Get Success/Second",
        "UCWA - Exchange Photo Get Latency (ms)",
        " ",
        "UCWA - Number of Photo Get Failures",
        "UCWA - AD Photo Get Requests/Second",
        "UCWA - AD Photo Get Success/Second",
        "UCWA - Number of Serialization Failures",
        "UCWA - Number of Presence Publications",
        "UCWA - Presence Publications/Second",
        "UCWA - Number of Presence Deletions",
        "UCWA - Presence Deletions/Second",
        "UCWA - Number of Presence Polling",
        "UCWA - Presence Polling/Second",
        "UCWA - Number of External Presence Subscriptions",
        "UCWA - Current Number of External Presence Subscriptions",
        "UCWA - External Presence Subscriptions/Second",
        "UCWA - Address Book Search Requests/Second",
        "UCWA - Number of Address Book Search Request Failures",
        "UCWA - Exchange Search Requests/Second",
        "UCWA - Number of Exchange Search Request Failures",
        "UCWA - Number of UCS Subcription failures",
        "UCWA - Current Number of AV Calls",
        "UCWA - Outbound AV Calls/Second",
        "UCWA - Number of Outbound AV Call Failures",
        "UCWA - Inbound AV Calls/Second",
        "UCWA - Number of Inbound AV Call Failures",
        "UCWA - Number of Inbound AV Calls Declined",
        "UCWA - Push Notifications/Second",
        "UCWA - Number of Push Notification Failures",
        "UCWA - Number of PNCH returned Push Notification Failures",
        "UCWA - Number of Push Notifications Throttled",
        "UCWA - DL Expansion Latency (ms)",
        " ",
        "UCWA - Number of DL Expansion Failures",
        "UCWA - DL Expansion Requests/Second",
        "UCWA - Inbound IM Calls/Second",
        "UCWA - Number of Inbound IM Call Failures",
        "UCWA - Number of Inbound IM Calls Declined",
        "UCWA - Outbound IM Calls/Second",
        "UCWA - Number of Outbound IM Call Failures",
        "UCWA - IM Messages Sent/Second",
        "UCWA - IM Messages Received/Second",
        "UCWA - Number of Outgoing IM Message Failures",
        "UCWA - Number of Incoming IM Message Failures",
        "UCWA - UCWA Application Instance Lifetime Bucket 0",
        "UCWA - UCWA Application Instance Lifetime Bucket 1",
        "UCWA - UCWA Application Instance Lifetime Bucket 2",
        "UCWA - Total Missed Conversations Pulled from Exchange",
        "UCWA - Total Archived Conversations Pulled from Exchange",
        "UCWA - Total Conversations History Requests to Exchange Failed",
        "UCWA - Total Conversations History Requests to Exchange Succeeded",
        "UCWA - Exchange Conversation History Request Latency (ms)",
        " ",
        "UCWA - Number of Conversation History Message Format Transcription Failed",
        "UCWA - Conversation History Message Converted to Plain Text",
        "UCWA - Total Conversation History Messages Converted to HTML",
        "UCWA - Total Number of Start Modality Requested",
        "UCWA - Total Number of Continue Modality Requested",
        "UCWA - Conversation History Fallbacks To Mail Addresses",
        "UCWA - Total number of get conversation log requests",
        "UCWA - Total number of get conversation log batched requests",
        "UCWA - Total number of get conversation log effective batched requests",
        "UCWA - Total number of auto accepted incoming messaging invite requests",
        "UCWA - Total number of auto accepted incoming conference invite requests",
        "UCWA - Number of Address Book Search Request Succeeded",
        "UCWA - Number of Exchange Search Request Succeeded",
    ],
    [
        '"_Total"',
        "174290071",
        "267",
        "6022396",
        "396",
        "2",
        "1",
        "0",
        "2",
        "0",
        "2454",
        "1",
        "13438",
        "10983",
        "23",
        "396",
        "13438",
        "2454",
        "1",
        "10983",
        "23",
        "269",
        "10",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "4186",
        "371",
        "0",
        "0",
        "1146",
        "472",
        "115164",
        "1146",
        "674",
        "371",
        "371",
        "0",
        "673",
        "673",
        "124",
        "124",
        "155",
        "155",
        "94",
        "0",
        "94",
        "56",
        "0",
        "0",
        "0",
        "0",
        "0",
        "16",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "26",
        "0",
        "0",
        "18",
        "3",
        "24",
        "5",
        "0",
        "0",
        "2",
        "0",
        "0",
        "156",
        "3198",
        "9",
        "253",
        "69787",
        "203",
        "0",
        "431",
        "0",
        "10",
        "4",
        "4",
        "262",
        "76",
        "23",
        "26",
        "0",
        "56",
        "0",
    ],
    [
        '"iPadLync"',
        "5290124",
        "8",
        "340",
        "11",
        "1",
        "0",
        "0",
        "1",
        "0",
        "76",
        "0",
        "772",
        "696",
        "2",
        "11",
        "772",
        "76",
        "0",
        "696",
        "2",
        "9",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "4",
        "0",
        "4",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2",
        "0",
        "0",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "0",
        "0",
        "4",
        "121",
        "0",
        "9",
        "1897",
        "7",
        "0",
        "0",
        "0",
        "0",
        "1",
        "4",
        "25",
        "4",
        "2",
        "2",
        "0",
        "0",
        "0",
    ],
    [
        '"LWA"',
        "11636861",
        "14",
        "222",
        "14",
        "0",
        "0",
        "0",
        "0",
        "0",
        "55",
        "0",
        "415",
        "360",
        "14",
        "14",
        "415",
        "55",
        "0",
        "360",
        "14",
        "14",
        "4",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "9",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "7",
        "0",
        "11",
        "5",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"Undefined"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "0",
        "0",
        "0",
        "1344",
        "1",
        "3534",
        "2189",
        "0",
        "0",
        "3534",
        "1344",
        "1",
        "2189",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "4186",
        "371",
        "0",
        "0",
        "1146",
        "472",
        "115164",
        "1146",
        "674",
        "371",
        "371",
        "0",
        "673",
        "673",
        "124",
        "124",
        "155",
        "155",
        "0",
        "0",
        "0",
        "56",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "431",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "56",
        "0",
    ],
    [
        '"iPhoneLync"',
        "100712749",
        "160",
        "6018188",
        "268",
        "1",
        "0",
        "0",
        "1",
        "0",
        "893",
        "0",
        "7392",
        "6499",
        "4",
        "268",
        "7392",
        "893",
        "0",
        "6499",
        "4",
        "161",
        "4",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "59",
        "0",
        "59",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "5",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "13",
        "0",
        "0",
        "10",
        "3",
        "13",
        "0",
        "0",
        "0",
        "1",
        "0",
        "0",
        "41",
        "1921",
        "0",
        "144",
        "43596",
        "136",
        "0",
        "0",
        "0",
        "10",
        "3",
        "0",
        "140",
        "53",
        "15",
        "13",
        "0",
        "0",
        "0",
    ],
    [
        '"AndroidLync"',
        "56650337",
        "85",
        "3646",
        "103",
        "0",
        "0",
        "0",
        "0",
        "0",
        "86",
        "0",
        "1325",
        "1239",
        "3",
        "103",
        "1325",
        "86",
        "0",
        "1239",
        "3",
        "85",
        "2",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "31",
        "0",
        "31",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "11",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "111",
        "1156",
        "9",
        "100",
        "24294",
        "60",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "97",
        "19",
        "6",
        "11",
        "0",
        "0",
        "0",
    ],
    ["[LS:DATACOLLECTION - Meeting Report Adaptor]"],
    [
        "instance",
        "UDC - Number of meeting reports uploaded",
        "UDC - Number of meeting reports uploaded per second",
        "UDC - Number of meeting reports uploading failures",
        "UDC - Number of meeting reports uploading failures per second",
    ],
    ['""', "0", "0", "0", "0"],
    ["[LS:USrv - SetPresence sproc]"],
    [
        "instance",
        "USrv - RtcSetPresence: calls/Sec",
        "USrv - RtcSetPresence: Latency (msec)",
        " ",
        "USrv - RtcSetPresence: calls total",
    ],
    ['""', "0", "0", "0", "0"],
    ["[LS:SipEps - SipEps Outgoing Messages]"],
    [
        "instance",
        "SipEps - Outgoing Messages",
        "SipEps - Outgoing Messages/sec",
        "SipEps - Failed Outgoing Messages",
        "SipEps - Failed Outgoing Messages/sec",
        "SipEps - Outgoing ACK messages",
        "SipEps - Outgoing ACK messages/sec",
        "SipEps - Outgoing BYE messages",
        "SipEps - Outgoing BYE messages/sec",
        "SipEps - Outgoing CANCEL messages",
        "SipEps - Outgoing CANCEL messages/sec",
        "SipEps - Outgoing INFO messages",
        "SipEps - Outgoing INFO messages/sec",
        "SipEps - Outgoing INVITE messages",
        "SipEps - Outgoing INVITE messages/sec",
        "SipEps - Outgoing MESSAGE messages",
        "SipEps - Outgoing MESSAGE messages/sec",
        "SipEps - Outgoing NEGOTIATE messages",
        "SipEps - Outgoing NEGOTIATE messages/sec",
        "SipEps - Outgoing NOTIFY messages",
        "SipEps - Outgoing NOTIFY messages/sec",
        "SipEps - Outgoing OPTIONS messages",
        "SipEps - Outgoing OPTIONS messages/sec",
        "SipEps - Outgoing REFER messages",
        "SipEps - Outgoing REFER messages/sec",
        "SipEps - Outgoing REGISTER messages",
        "SipEps - Outgoing REGISTER messages/sec",
        "SipEps - Outgoing SERVICE messages",
        "SipEps - Outgoing SERVICE messages/sec",
        "SipEps - Outgoing SUBSCRIBE messages",
        "SipEps - Outgoing SUBSCRIBE messages/sec",
        "SipEps - Outgoing Generic Messages",
        "SipEps - Outgoing Generic Messages/sec",
        "SipEps - Outgoing 3xx Responses",
        "SipEps - Outgoing 3xx Responses/sec",
        "SipEps - Outgoing 4xx Responses",
        "SipEps - Outgoing 4xx Responses/sec",
        "SipEps - Outgoing 5xx Responses",
        "SipEps - Outgoing 5xx Responses/sec",
        "SipEps - Outgoing 6xx Responses",
        "SipEps - Outgoing 6xx Responses/sec",
        "SipEps - Outgoing 180(Ringing) Responses",
        "SipEps - Outgoing 180(Ringing) Responses/sec",
        "SipEps - Outgoing 200 Responses",
        "SipEps - Outgoing 200 Responses/sec",
        "SipEps - Outgoing 301(Moved Permanently) Responses",
        "SipEps - Outgoing 301(Moved Permanently) Responses/sec",
        "SipEps - Outgoing 302(Moved Temporarily) Responses",
        "SipEps - Outgoing 302(Moved Temporarily) Responses/sec",
        "SipEps - Outgoing 400(Bad Request) Responses",
        "SipEps - Outgoing 400(Bad Request) Responses/sec",
        "SipEps - Outgoing 401(Unauthorized) Responses",
        "SipEps - Outgoing 401(Unauthorized) Responses/sec",
        "SipEps - Outgoing 403(Forbidden) Responses",
        "SipEps - Outgoing 403(Forbidden) Responses/sec",
        "SipEps - Outgoing 404(Not Found) Responses",
        "SipEps - Outgoing 404(Not Found) Responses/sec",
        "SipEps - Outgoing 407(Proxy Authentication Required) Responses",
        "SipEps - Outgoing 407(Proxy Authentication Required) Responses/sec",
        "SipEps - Outgoing 409 Responses",
        "SipEps - Outgoing 409 Responses/sec",
        "SipEps - Outgoing 413(Request Entity Too Large) Responses",
        "SipEps - Outgoing 413(Request Entity Too Large) Responses/sec",
        "SipEps - Outgoing 421(Extension Required) Responses",
        "SipEps - Outgoing 421(Extension Required) Responses/sec",
        "SipEps - Outgoing 480(Temporarily Unavailable) Responses",
        "SipEps - Outgoing 480(Temporarily Unavailable) Responses/sec",
        "SipEps - Outgoing 481(Call/Transaction Does Not Exist) Responses",
        "SipEps - Outgoing 481(Call/Transaction Does Not Exist) Responses/sec",
        "SipEps - Outgoing 486(Busy Here) Responses",
        "SipEps - Outgoing 486(Busy Here) Responses/sec",
        "SipEps - Outgoing 487(Request Terminated) Responses",
        "SipEps - Outgoing 487(Request Terminated) Responses/sec",
        "SipEps - Outgoing 488(Not Acceptable Here) Responses",
        "SipEps - Outgoing 488(Not Acceptable Here) Responses/sec",
        "SipEps - Outgoing 499 Responses",
        "SipEps - Outgoing 499 Responses/sec",
        "SipEps - Outgoing 500(Internal Server Error) Responses",
        "SipEps - Outgoing 500(Internal Server Error) Responses/sec",
        "SipEps - Outgoing 501(Not Implemented) Responses",
        "SipEps - Outgoing 501(Not Implemented) Responses/sec",
        "SipEps - Outgoing 503(Service Unavailable) Responses",
        "SipEps - Outgoing 503(Service Unavailable) Responses/sec",
        "SipEps - Outgoing 504(Server Time-out) Responses",
        "SipEps - Outgoing 504(Server Time-out) Responses/sec",
        "SipEps - Outgoing 599 Responses",
        "SipEps - Outgoing 599 Responses/sec",
        "SipEps - Outgoing 600(Busy Everywhere) Responses",
        "SipEps - Outgoing 600(Busy Everywhere) Responses/sec",
        "SipEps - Outgoing 603(Decline) Responses",
        "SipEps - Outgoing 603(Decline) Responses/sec",
        "SipEps - Outgoing 699 Responses",
        "SipEps - Outgoing 699 Responses/sec",
    ],
    [
        '"pbwvw-skype03.16124_avmcusvc_appdom_1"',
        "1169",
        "1169",
        "0",
        "0",
        "99",
        "99",
        "20",
        "20",
        "0",
        "0",
        "0",
        "0",
        "99",
        "99",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "180",
        "180",
        "0",
        "0",
        "263",
        "263",
        "0",
        "0",
        "37",
        "37",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "374",
        "374",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2",
        "2",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"_Total"',
        "271654",
        "271654",
        "1",
        "1",
        "489",
        "489",
        "270",
        "270",
        "71",
        "71",
        "130",
        "130",
        "489",
        "489",
        "19",
        "19",
        "0",
        "0",
        "5",
        "5",
        "83979",
        "83979",
        "1",
        "1",
        "41",
        "41",
        "11913",
        "11913",
        "10576",
        "10576",
        "52176",
        "52176",
        "0",
        "0",
        "429",
        "429",
        "3",
        "3",
        "0",
        "0",
        "68",
        "68",
        "109756",
        "109756",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "3",
        "3",
        "3",
        "3",
        "13",
        "13",
        "65",
        "65",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "3",
        "3",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.22372_ocsappserverhost_appdom_2"',
        "6152",
        "6152",
        "0",
        "0",
        "18",
        "18",
        "18",
        "18",
        "0",
        "0",
        "10",
        "10",
        "18",
        "18",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "3099",
        "3099",
        "2886",
        "2886",
        "8",
        "8",
        "0",
        "0",
        "16",
        "16",
        "0",
        "0",
        "0",
        "0",
        "12",
        "12",
        "59",
        "59",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.17128_ocsappserverhost_appdom_2"',
        "9873",
        "9873",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "5074",
        "5074",
        "4799",
        "4799",
        "0",
        "0",
        "0",
        "0",
        "114",
        "114",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.9112_mediationserversvc_appdom_1"',
        "144942",
        "144942",
        "1",
        "1",
        "294",
        "294",
        "177",
        "177",
        "71",
        "71",
        "0",
        "0",
        "294",
        "294",
        "0",
        "0",
        "0",
        "0",
        "5",
        "5",
        "83979",
        "83979",
        "1",
        "1",
        "0",
        "0",
        "435",
        "435",
        "0",
        "0",
        "503",
        "503",
        "0",
        "0",
        "210",
        "210",
        "3",
        "3",
        "0",
        "0",
        "40",
        "40",
        "57819",
        "57819",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "3",
        "3",
        "1",
        "1",
        "13",
        "13",
        "65",
        "65",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "3",
        "3",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.11528_immcusvc_appdom_1"',
        "319",
        "319",
        "0",
        "0",
        "0",
        "0",
        "1",
        "1",
        "0",
        "0",
        "81",
        "81",
        "0",
        "0",
        "19",
        "19",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "18",
        "18",
        "0",
        "0",
        "11",
        "11",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "85",
        "85",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.276_rtchost_appdom_9"',
        "67",
        "67",
        "0",
        "0",
        "12",
        "12",
        "12",
        "12",
        "0",
        "0",
        "13",
        "13",
        "12",
        "12",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "18",
        "18",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.13864_ocsappserverhost_appdom_2"',
        "104019",
        "104019",
        "0",
        "0",
        "12",
        "12",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "12",
        "12",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1016",
        "1016",
        "949",
        "949",
        "51000",
        "51000",
        "0",
        "0",
        "6",
        "6",
        "0",
        "0",
        "0",
        "0",
        "6",
        "6",
        "51012",
        "51012",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.21588_asmcusvc_appdom_1"',
        "114",
        "114",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "35",
        "35",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "12",
        "12",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "55",
        "55",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.24308_ocsappserverhost_appdom_2"',
        "2080",
        "2080",
        "0",
        "0",
        "0",
        "0",
        "3",
        "3",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "41",
        "41",
        "1029",
        "1029",
        "950",
        "950",
        "0",
        "0",
        "0",
        "0",
        "6",
        "6",
        "0",
        "0",
        "0",
        "0",
        "10",
        "10",
        "27",
        "27",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.24040_ocsappserverhost_appdom_2"',
        "2919",
        "2919",
        "0",
        "0",
        "54",
        "54",
        "39",
        "39",
        "0",
        "0",
        "26",
        "26",
        "54",
        "54",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1027",
        "1027",
        "992",
        "992",
        "384",
        "384",
        "0",
        "0",
        "17",
        "17",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "325",
        "325",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:Arch Agent - MSMQ]"],
    [
        "instance",
        "Arch Agent - Archiving Messages",
        "Arch Agent - Archiving Messages/sec",
        "Arch Agent - Archiving Message bytes",
        "Arch Agent - Archiving Message bytes/sec",
        "Arch Agent - Call Details Recording Messages",
        "Arch Agent - Call Details Recording Messages/sec",
        "Arch Agent - Call Details Recording Message bytes",
        "Arch Agent - Call Details Recording Message bytes/sec",
        "Arch Agent - Heartbeat Messages for Archiving and Call Details Recording",
        "Arch Agent - Heartbeat Messages/sec for Archiving and Call Details Recording",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:MPPROXY - Debugging]"],
    [
        "instance",
        "MPPROXY - Total Channel Recovery Attempts",
        "MPPROXY - Total Channel Recovery Attempts Completed",
        "MPPROXY - Total Channel Recovery Exceptions",
    ],
    ['"pbwvw-skype03.16124_avmcusvc_appdom_1"', "0", "0", "0"],
    ['"_Total"', "0", "0", "0"],
    ['"pbwvw-skype03.21588_asmcusvc_appdom_1"', "0", "0", "0"],
    ["[LS:RoutingApps - UC Routing Applications]"],
    [
        "instance",
        "RoutingApps - Translated Numbers",
        "RoutingApps - Total Hybrid voice Location profile requests",
        "RoutingApps - Translated Numbers per second",
        "RoutingApps - Calls to voice mail",
        "RoutingApps - Calls to voice mail per second",
        "RoutingApps - Calls to SA/AA",
        "RoutingApps - Errors from UM server",
        "RoutingApps - Exchange UM requests",
        "RoutingApps - Failed Exchange UM calls",
        "RoutingApps - Failed Outbound PSTN calls",
        "RoutingApps - Outbound PSTN calls",
        "RoutingApps - CPS Unpark Calls",
        "RoutingApps - Vacant Number calls",
        "RoutingApps - Outbound PSTN calls per second",
        "RoutingApps - Inbound calls",
        "RoutingApps - Inbound calls per second",
        "RoutingApps - Inbound Contact Object calls",
        "RoutingApps - Successful Inbound calls",
        "RoutingApps - Successful Inbound Contact Object calls",
        "RoutingApps - Forwarded calls",
        "RoutingApps - Simul-ring calls",
        "RoutingApps - Delegate calls",
        "RoutingApps - Team calls",
        "RoutingApps - Private Line calls",
        "RoutingApps - Instances of receiving invalid dial plan",
        "RoutingApps - Instances where no match in normalization rules of dial plan",
        "RoutingApps - Instances where the matching rule caused a failed translation",
        "RoutingApps - Calls made to VOIP gateways which were successful",
        "RoutingApps - Received 5XX from VOIP gateway",
        "RoutingApps - Gateway detected to be up",
        "RoutingApps - Total Hybrid voice Oubound calls",
        "RoutingApps - Gateway detected to be down",
        "RoutingApps - Calls failed due to gateway unavailability",
        "RoutingApps - Calls failed due to no matching route",
        "RoutingApps - Voicemail redirected over pstn link",
        "RoutingApps - Invite requests on hosted Access Proxy",
        "RoutingApps - Service requests on hosted Access Proxy",
        "RoutingApps - Average number of requests on Access Proxy per second",
        "RoutingApps - Average number of 303 per request",
    ],
    [
        '""',
        "331",
        "0",
        "331",
        "3",
        "3",
        "11",
        "7",
        "14",
        "1",
        "32",
        "246",
        "0",
        "0",
        "246",
        "995",
        "995",
        "20",
        "745",
        "18",
        "1",
        "30",
        "0",
        "0",
        "0",
        "0",
        "5",
        "0",
        "151",
        "3",
        "235",
        "0",
        "0",
        "3",
        "10",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:CHAT - Persistent Chat Networking.]"],
    [
        "instance",
        "CHAT - Inbound Messages Dropped",
        "CHAT - Connection Attempts",
        "CHAT - Connection Attempts/sec",
        "CHAT - Active Endpoints",
        "CHAT - New Endpoints/sec",
        "CHAT - Connections Refused",
        "CHAT - Connections Refused/sec",
        "CHAT - Connections Failed",
        "CHAT - Connections Failed/sec",
        "CHAT - Connections Disconnected",
        "CHAT - Connections Dropped/sec",
        "CHAT - Active Users",
    ],
    ['""', "0", "2124", "2124", "60", "2110", "0", "0", "14", "14", "2050", "2050", "60"],
    ["[LS:PDP - Diagnostics]"],
    [
        "instance",
        "PDP - Segments received/sec",
        "PDP - Segments sent/sec",
        "PDP - Messages dropped/sec",
        "PDP - Average task processing time (milliseconds)",
        "PDP - Average queue depth",
        " ",
        "PDP - Maximum queue depth",
        "PDP - Log messages dropped",
        "PDP - Average subnet lookup time (microseconds)",
    ],
    ['""', "0", "0", "0", "19", "2", "2", "1", "0", "0"],
    ["[LS:WEB - Device Update]"],
    [
        "instance",
        "WEB - Total Requests Received",
        "WEB - Total Update Requests",
        "WEB - Total Updates Needed",
        "WEB - Total Log Upload Attempts",
        "WEB - Total Failed Device Update Attempts",
        "WEB - Total Failed Log Upload Attempts",
        "WEB - Device Update requests/sec",
        "WEB - Device Update log uploads/sec",
    ],
    ['""', "1", "1", "0", "0", "0", "0", "1", "0"],
    ["[LS:SIP - Networking]"],
    [
        "instance",
        "SIP - Sockets",
        "SIP - Sockets/Sec",
        "SIP - Connections Established",
        "SIP - Connections Established /Sec",
        "SIP - Connections Failed To Establish",
        "SIP - Connections /Sec Failed To Establish",
        "SIP - Connections Refused Due To Server Overload",
        "SIP - Connections /Sec Refused Due To Server Overload",
        "SIP - Connections Being Established",
        "SIP - TLS Negotiation Completed",
        "SIP - TLS Negotiations Completed /Sec",
        "SIP - TLS Negotiations Failed",
        "SIP - TLS Negotiations Failed /Sec",
        "SIP - TLS Connections Being Negotiated",
        "SIP - Outstanding Accept Operations",
        "SIP - Outstanding Receive Operations",
        "SIP - DNS queries queued for DNS resolution",
        "SIP - DNS queries being resolved by the operating system",
        "SIP - Successful host name queries",
        "SIP - Failed host name queries",
        "SIP - Timed out host name queries",
        "SIP - Successful accesses to the internal DNS cache",
        "SIP - Successful accesses to the internal DNS cache (per second)",
        "SIP - Successful DNS query results in the internal DNS cache",
        "SIP - Failed DNS query results in the internal DNS cache",
        "SIP - Average DNS Query Time",
        "",
    ],
    [
        '""',
        "158",
        "801310",
        "113101",
        "113103",
        "17",
        "17",
        "0",
        "0",
        "0",
        "114541",
        "114542",
        "686766",
        "686766",
        "0",
        "5",
        "151",
        "0",
        "0",
        "3139",
        "0",
        "0",
        "790388",
        "790358",
        "9",
        "0",
        "8113064",
        "3139",
    ],
    ["[LS:XmppFederation - Internal objects]"],
    [
        "instance",
        "XmppFederation - XMPP users",
        "XmppFederation - IM Conversations",
        "XmppFederation - Inbound subscriptions",
        "XmppFederation - Outbound subscriptions",
        "XmppFederation - UserEndpoints",
        "XmppFederation - Command queue count",
        "XmppFederation - Command queue token count",
        "XmppFederation - Commands in process.",
        "XmppFederation - Command processing time (ms)",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:WEB - Mobile Communication Service]"],
    [
        "instance",
        "WEB - Total Session Initiated Count",
        "WEB - Currently Active Session Count",
        "WEB - Currently Active Session Count With Active Presence Subscriptions",
        "WEB - Succeeded Initiate Session Requests/Second",
        "WEB - Total number of sessions terminated by user",
        "WEB - Total Sessions Terminated Because of User Idle Timeout",
        "WEB - Average life time for a session in milliseconds",
        " ",
        "WEB - Total Requests received on the Command Channel",
        "WEB - Requests received/Second",
        "WEB - Total Requests Rejected",
        "WEB - Requests Rejected/Second",
        "WEB - Total Requests Succeeded",
        "WEB - Requests Succeeded/Second",
        "WEB - Total Requests Failed",
        "WEB - Requests Failed/Second",
        "WEB - Currently Active Poll Count",
        "WEB - Currently Active Network Timeout Poll Count",
        "WEB - Total Succesful Outbound Voice Calls",
        "WEB - Total Succesful Inbound Voice Calls",
        "WEB - Total Failed Outbound Voice Calls",
        "WEB - Total Failed Inbound Voice Calls",
        "WEB - Total Declined Inbound Voice Calls",
        "WEB - Current Push Notification Subscriptions",
        "WEB - Total Push Notification Requests",
        "WEB - Push Notification Requests/Second",
        "WEB - Total Push Notification Requests Succeeded",
        "WEB - Push Notification Requests Succeeded/Second",
        "WEB - Total Push Notification Requests Throttled",
        "WEB - Push Notification Requests Throttled/Second",
        "WEB - Total Push Notification Requests Failed",
        "WEB - Push Notification Requests Failed/Second",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:WEB - Auth Provider related calls]"],
    [
        "instance",
        "WEB - Total validate pin calls to the pin auth provider",
        "WEB - Validate pin calls to the pin auth provider per second",
        "WEB - Failed validate pin calls to the pin auth provider",
        "WEB - Failed validate pin calls to the pin auth provider per second",
        "WEB - Total validate cert calls to the cert auth provider",
        "WEB - Validate cert calls to the cert auth provider per second",
        "WEB - Failed validate cert calls to the cert auth provider",
        "WEB - Failed validate cert calls to the cert auth provider per second",
    ],
    ['""', "0", "0", "0", "0", "183", "183", "0", "0"],
    ["[LS:SIP - Access Edge Server - Key Manager]"],
    [
        "instance",
        "SIP - Messages Verified Using Shared Session Key",
        "SIP - Messages Verified Using Shared Session Key /Sec",
        "SIP - Active Keys In Shared Session Key Table",
        "SIP - Total Shared Session Keys Imported So Far",
        "SIP - Invalid Shared Session Keys Received So Far",
    ],
    ['""', "0", "0", "0", "0", "0"],
    ["[LS:JoinLauncher - Join Launcher Success]"],
    [
        "instance",
        "JOINLAUNCHER - Join successes",
        "JOINLAUNCHER - Number of successful User Lookups",
        "JOINLAUNCHER - Lookup User Sproc Latency in Milliseconds",
    ],
    ['""', "4", "0", "0"],
    ["[LS:RGS - Response Group Service Hosting]"],
    [
        "instance",
        "RGS - Total number of incoming calls that were declined because of a Match Making failure",
        "RGS - Total number of different workflows loaded in memory",
        "RGS - Total number of different application endpoints",
        "RGS - Total number of failures when binding to the Collaboration Platform",
        "RGS - Total number of failures when binding Match Making to WCF",
        "RGS - Total number of application endpoint binding failures",
        "RGS - Total number of certificate validation failures",
        "RGS - Total number of successful certificate validations",
        "RGS - Total number of application endpoint terminations",
        "RGS - Duration of the call in milliseconds",
    ],
    ['""', "0", "5", "5", "0", "0", "0", "0", "113", "0", "0"],
    ["[LS:USrv - Expiration sprocs]"],
    [
        "instance",
        "USrv - ExpireEndpoint: calls/Sec",
        "USrv - ExpireEndpoint: Latency (msec)",
        " ",
        "USrv - ExpireEndpoint: calls total",
        "USrv - ExpireSubscription: calls/Sec",
        "USrv - ExpireSubscription: Latency (msec)",
        " ",
        "USrv - ExpireSubscription: calls total",
        "USrv - ExpireConference: calls/Sec",
        "USrv - ExpireConference: Latency (msec)",
        " ",
        "USrv - ExpireConference: calls total",
        "USrv - ExpireConferenceParticipant: calls/Sec",
        "USrv - ExpireConferenceParticipants: Latency (msec)",
        " ",
        "USrv - ExpireConferenceParticipants: calls total",
        "USrv - ExpireIdleMcu: calls/Sec",
        "USrv - ExpireIdleMcu: Latency (msec)",
        " ",
        "USrv - ExpireIdleMcu: calls total",
        "USrv - ExpireTimeBoundPublication: calls/Sec",
        "USrv - ExpireTimeBoundPublication: Latency (msec)",
        " ",
        "USrv - ExpireTimeBoundPublication: calls total",
        "USrv - DeactivateConferences: calls/Sec",
        "USrv - DeactivateConferences: Latency (msec)",
        " ",
        "USrv - DeactivateConferences: calls total",
        "USrv - ExpireConference sproc call batch size",
        "",
    ],
    [
        '""',
        "167424",
        "70621",
        "167424",
        "167424",
        "23926",
        "6973",
        "23926",
        "23926",
        "4826",
        "312",
        "4826",
        "4826",
        "23938",
        "1048",
        "23938",
        "23938",
        "47552",
        "4967",
        "47552",
        "47552",
        "4819",
        "7387",
        "4819",
        "4819",
        "23961",
        "7321",
        "23961",
        "23961",
        "4",
        "4826",
    ],
    ["[LS:WEB - User Pin Service related Calls]"],
    [
        "instance",
        "WEB - Number of failed local LookupUser Requests",
        "WEB - Total LookupDomain Requests Failed",
        "WEB - Total EnumerateDomains Requests Failed",
    ],
    ['""', "0", "0", "0"],
    ["[LS:SIP - Protocol]"],
    [
        "instance",
        "SIP - Incoming Messages",
        "SIP - Incoming Messages /Sec",
        "SIP - Incoming Dialog Creating Requests",
        "SIP - Incoming Dialog Creating Requests /Sec",
        "SIP - Incoming Requests Dropped",
        "SIP - Incoming Requests Dropped /Sec",
        "SIP - Incoming Responses Dropped",
        "SIP - Incoming Responses Dropped /Sec",
        "SIP - REGISTER Requests that Failed or Timed Out",
        "SIP - REGISTER Requests that Failed or Timed Out /Sec",
        "SIP - Messages In Server",
        "SIP - Compressed Server Connections",
        "SIP - Compressed Client Connections",
        "SIP - Incoming Requests In Server",
        "SIP - Incoming Responses In Server",
        "SIP - Local Requests In Server",
        "SIP - Local Responses In Server",
        "SIP - Outgoing Messages",
        "SIP - Outgoing Messages /Sec",
        "SIP - Average Incoming Message Processing Time",
        " ",
        "SIP - Average Local Message Processing Time",
        " ",
        "SIP - Events In Processing",
        "SIP - Events Processed /Sec",
        "SIP - Events Queued In State Machine",
        "SIP - Average Event Processing Time",
        " ",
        "SIP - Average Number Of Active Worker Threads",
        "SIP - UAS Transactions Outstanding",
        "SIP - UAS Transactions Timed Out",
        "SIP - UAS Transactions Timed Out /Sec",
        "SIP - UAC Transactions Outstanding",
        "SIP - UAC Transactions Timed Out",
        "SIP - UAC Transactions Timed Out /Sec",
        "SIP - Proxy Transactions Outstanding",
        "SIP - Proxy Transactions Timed Out",
        "SIP - Proxy Transactions Timed Out /Sec",
    ],
    [
        '""',
        "1747147",
        "1747176",
        "1030170",
        "1030188",
        "596",
        "596",
        "271",
        "271",
        "1416",
        "1416",
        "9",
        "20",
        "93",
        "0",
        "1",
        "7",
        "1",
        "1972105",
        "1972111",
        "2748689388",
        "1761360",
        "698675861",
        "925446",
        "0",
        "5422489",
        "0",
        "1082927416",
        "5419565",
        "1183229",
        "5",
        "49",
        "49",
        "0",
        "53",
        "53",
        "1",
        "579",
        "579",
    ],
    ["[LS:REPAPPSVC - RepMasterGetModifiedItems sproc]"],
    ["instance", "REPAPP - Sproc Latency (msec)", "REPAPP - Number of calls"],
    ['""', "0", "0"],
    ["[LS:RGS - Response Group Service Workflow]"],
    [
        "instance",
        "RGS - Total received calls",
        "RGS - Calls terminated with a workflow failure",
        "RGS - Calls completed with a workflow success",
        "RGS - The total number of active workflows",
        "RGS - Calls placed during the business hours",
        "RGS - Calls placed outside the business hours",
        "RGS - Calls that have timed out while on hold",
        "RGS - Calls put on hold by caller",
        "RGS - Calls put on hold that have been retrieved",
        "RGS - Calls that failed due to incorrect answers",
        "RGS - Calls that failed because no answer was given",
        "RGS - Calls that failed due to critical server errors",
        "RGS - Calls that failed due to call connection errors",
        "RGS - Transfer attempts that failed due to agent URIs that were not valid",
        "RGS - Time spent in Match Making service",
        "RGS - Time it took to place a call to the Match Making service",
        "RGS - Time spent in Make Transfer service",
        "RGS - Attempts to open a connection to Match Making",
        "RGS - Pending Match Making work items",
        "RGS - Waiting time for pending Match Making work items",
        "RGS - Pending Make Transfer work items",
        "RGS - Waiting time for pending Make Transfer work items",
        "RGS - Timed out calls to Match Making",
        "RGS - Calls to Match Making that failed because the connection is not opened",
        "RGS - Calls to Match Making that failed because of a communication exception",
        "RGS - Calls to Match Making failed because of a general exception",
        "RGS - Number of registered calls to Match Making",
        "RGS - Number of unregistered calls to Match Making",
        "RGS - Number of completed call transfers to Match Making",
        "RGS - Number of failed register calls to Match Making",
        "RGS - Number of failed unregister calls to Match Making",
        "RGS - Failed transfer completed calls to Match Making",
        "RGS - Calls transferred",
        "RGS - Calls failed because of bandwidth",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:REPAPPSVC - GetModifiedItems Request]"],
    ["instance", "REPAPP - Request Latency (msec)", "REPAPP - Number of calls"],
    ['""', "0", "0"],
    ["[LS:USrv - Conference Focus Base]"],
    [
        "instance",
        "USrv - INVITEs received",
        "USrv - INVITEs received / sec",
        "USrv - Join INVITEs received",
        "USrv - Join INVITEs succeeded",
        "USrv - Media INVITEs received",
        "USrv - Media INVITEs succeeded",
        "USrv - INFOs received",
        "USrv - INFOs received / sec",
        "USrv - SUBSCRIBEs received",
        "USrv - SUBSCRIBEs received / sec",
        "USrv - Number of successful SUBSCRIBEs",
        "USrv - BYEs received",
        "USrv - BYEs received / sec",
        "USrv - ACKs received",
        "USrv - ACKs received / sec",
        "USrv - CANCELs received",
        "USrv - CANCELs received / sec",
        "USrv - UPDATEs received",
        "USrv - UPDATEs received / sec",
        "USrv - Other requests received",
        "USrv - Other requests received / sec",
        "USrv - Crashed endpoints disconnected",
        "USrv - Crashed endpoints disconnect/Sec",
        "USrv - Conferences automatically deactivated",
        "USrv - Conferences automatically deactivated/Sec",
        "USrv - Conferences that could not be automatically deactivated",
        "USrv - Conferences that could not be automatically deactivated/Sec",
        "USrv - Conference activations attempted",
        "USrv - Conference activations succeeded",
        "USrv - Nudge UCAP to start recording requests",
        "USrv - Nudge UCAP to start recording requests succeeded",
        "USrv - Nudge UCAP to start recording latency (msec)",
        " ",
        "USrv - Join INVITE latency (msec)",
        " ",
        "USrv - Media INVITE latency (msec)",
        " ",
        "USrv - SUBSCRIBE request latency (msec)",
        "",
    ],
    [
        '""',
        "97",
        "97",
        "97",
        "97",
        "82",
        "82",
        "198",
        "198",
        "173",
        "173",
        "173",
        "93",
        "93",
        "97",
        "97",
        "0",
        "0",
        "355",
        "355",
        "0",
        "0",
        "0",
        "0",
        "22",
        "22",
        "0",
        "0",
        "23",
        "23",
        "0",
        "0",
        "0",
        "0",
        "2124",
        "97",
        "3078",
        "82",
        "5302",
        "173",
    ],
    ["[LS:USrv - Pool Conference Statistics]"],
    [
        "instance",
        "USrv - Conference Count",
        "USrv - Active Conference Count",
        "USrv - Active Participant Count",
        "USrv - Active Focus Endpoint Count",
        "USrv - Active Mcu Session Count",
        "USrv - Conference Count in expiry extension",
        "USrv - Organizer Count with 0-10 percent quota usage",
        "USrv - Organizer Count with 10-20 percent quota usage",
        "USrv - Organizer Count with 20-30 percent quota usage",
        "USrv - Organizer Count with 30-40 percent quota usage",
        "USrv - Organizer Count with 40-50 percent quota usage",
        "USrv - Organizer Count with 50-60 percent quota usage",
        "USrv - Organizer Count with 60-70 percent quota usage",
        "USrv - Organizer Count with 70-80 percent quota usage",
        "USrv - Organizer Count with 80-90 percent quota usage",
        "USrv - Organizer Count with 90-100 percent quota usage",
    ],
    ['""', "70", "1", "6", "2", "5", "1", "58", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:ClientVersionFilter - Client Version Filter]"],
    [
        "instance",
        "ClientVersionFilter - Messages processed",
        "ClientVersionFilter - Sessions blocked with error message response",
        "ClientVersionFilter - Sessions blocked with URL response",
        "ClientVersionFilter - Sessions blocked with dynamic URL response",
        "ClientVersionFilter - Sessions allowed with url response",
        "ClientVersionFilter - Sessions allowed with dynamic URL response",
        "ClientVersionFilter - Active messages",
        "ClientVersionFilter - Throttling mode active",
        "ClientVersionFilter - Locally generated 503 responses",
        "ClientVersionFilter - Locally generated 400 responses",
    ],
    ['""', "17548", "0", "0", "0", "0", "0", "2", "0", "0", "0"],
    ["[LS:USrv - Cluster Manager Store]"],
    [
        "instance",
        "USrv - ClusterMgmtGetRoutingGroups: calls/Sec",
        "USrv - ClusterMgmtGetRoutingGroups: Latency (msec)",
        " ",
        "USrv - ClusterMgmtGetRoutingGroups: calls total",
        "USrv - ClusterMgmtGetRoutingGroups: calls failed",
        "USrv - ClusterMgmtPrepareRoutingGroups: calls/Sec",
        "USrv - ClusterMgmtPrepareRoutingGroups: Latency (msec)",
        " ",
        "USrv - ClusterMgmtPrepareRoutingGroups: calls total",
        "USrv - ClusterMgmtPrepareRoutingGroups: calls failed",
        "USrv - ClusterMgmtUpdateGroupAssignment: calls/Sec",
        "USrv - ClusterMgmtUpdateGroupAssignment: Latency (msec)",
        " ",
        "USrv - ClusterMgmtUpdateGroupAssignment: calls total",
        "USrv - ClusterMgmtUpdateGroupAssignment: calls failed",
        "USrv - ClusterMgmtUpdateGroup: calls/Sec",
        "USrv - ClusterMgmtUpdateGroup: Latency (msec)",
        " ",
        "USrv - ClusterMgmtUpdateGroup: calls total",
        "USrv - ClusterMgmtUpdateGroup: calls failed",
        "USrv - RtcSetPoolState: calls/Sec",
        "USrv - RtcSetPoolState: Latency (msec)",
        " ",
        "USrv - RtcSetPoolState: calls total",
        "USrv - RtcSetPoolState: calls failed",
        "USrv - XdsBackupDbSetPoolState: calls/Sec",
        "USrv - XdsBackupDbSetPoolState: Latency (msec)",
        " ",
        "USrv - XdsBackupDbSetPoolState: calls total",
        "USrv - XdsBackupDbSetPoolState: calls failed",
        "USrv - RtcGetPoolState: calls/Sec",
        "USrv - RtcGetPoolState: Latency (msec)",
        " ",
        "USrv - RtcGetPoolState: calls total",
        "USrv - RtcGetPoolState: calls failed",
        "USrv - ClusterMgmtEnsureRoutingGroupExists: calls/Sec",
        "USrv - ClusterMgmtEnsureRoutingGroupExists: Latency (msec)",
        " ",
        "USrv - ClusterMgmtEnsureRoutingGroupExists: calls total",
        "USrv - ClusterMgmtEnsureRoutingGroupExists: calls failed",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "47",
        "1",
        "1",
        "0",
        "2",
        "18",
        "2",
        "2",
        "0",
        "10",
        "408",
        "10",
        "10",
        "0",
        "3",
        "19",
        "3",
        "3",
        "0",
        "2",
        "1",
        "2",
        "2",
        "0",
        "1",
        "1",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:AsTA - ApplicationSharing Server Transport Adaptor]"],
    [
        "instance",
        "ASMCU - Total Bytes sent",
        "ASMCU - Total Packets sent",
        "ASMCU - Bytes sent per second",
        "ASMCU - Packets sent per second",
        "ASMCU - Total Bytes received",
        "ASMCU - Total Packets received",
        "ASMCU - Bytes received per second",
        "ASMCU - Packets received per second",
        "ASMCU - Total Number of Sharer Streams",
        "ASMCU - Total Number of Viewer Streams",
        "ASMCU - Bytes sent per second to sharers",
        "ASMCU - Bytes received per second from sharers",
        "ASMCU - Bytes sent per second to viewers",
        "ASMCU - Bytes received per second from viewers",
    ],
    [
        '""',
        "95552922",
        "13691",
        "95552922",
        "13691",
        "142844928",
        "28369",
        "142844928",
        "28369",
        "0",
        "0",
        "19096",
        "142835410",
        "95533826",
        "9518",
    ],
    ["[LS:LYSS - Storage Service API]"],
    [
        "instance",
        "LYSS - Total number of messages enqueued",
        "LYSS - Total number of queue message requests",
        "LYSS - Enqueue messages requests/sec",
        "LYSS - Total number of queue messages failures",
        "LYSS - Total number of execute command requests",
        "LYSS - Execute command requests/sec",
        "LYSS - Total number of execute command failure",
        "LYSS - Total number of notification requests",
        "LYSS - Notification requests/sec",
        "LYSS - Total number of notification failure",
        "LYSS - Total number PUT blob operations succeeded",
        "LYSS - Put blob requests/sec",
        "LYSS - Total number of PUT blob operations failed.",
        "LYSS - Total number GET blob operations succeeded",
        "LYSS - Get blob requests/sec",
        "LYSS - Total number of GET blob operations failed.",
        "LYSS - Total number DELETE blob operations succeeded",
        "LYSS - Delete blob requests/sec",
        "LYSS - Total number of DELETE blob operations failed.",
        "LYSS - Total number of create Exchange item requests",
        "LYSS - Total number of create Exchange item requests failure",
        "LYSS - Total number of get item from Exchange response type requests",
        "LYSS - Total number of get item from Exchange response type requests failure",
        "LYSS - Total number of find item in Exchange requests",
        "LYSS - Total number of find item requests failure",
        "LYSS - Total number of update item in Exchange requests",
        "LYSS - Total number of update item requests failure",
        "LYSS - Total number of delete item in Exchange requests",
        "LYSS - Total number of delete item requests failure",
        "LYSS - Current number of EWS Subscriptions in idle state",
        "LYSS - Current number of EWS Subscriptions in subscribing state",
        "LYSS - Current number of EWS Subscriptions in subscribed state",
        "LYSS - Total number of EWS Subscriptions failed",
        "LYSS - Number of EWS Subscriptions failed/sec",
        "LYSS - Total number of EWS Subscriptions disposed",
        "LYSS - EWS requests/sec",
        "LYSS - Total number of storage adaptors reported in unhealthy state",
        "LYSS - Total number of storage adaptor asynchronous task timeouts",
        "LYSS - Total number of storage adaptor asynchronous task cancel timeouts",
        "LYSS - Total number of storage adaptor asynchronous task stop operation failures",
        "LYSS - Total number of storage adaptor asynchronous task unhandled exceptions",
        "LYSS - Total number of unexpected exceptions",
        "LYSS - Total Number of Reconnections to Fabric Pool Manager",
        "LYSS - Total Group Services for which we are the Master Replica",
        "LYSS - Total Group Services for which we are the Secondary Replica",
        "LYSS - Total Group Services for which we are an Idle Secondary Replica",
        "LYSS - Total Number of Health Notifications sent to other Replicas",
        "LYSS - Total Number of Health Notifications received from Master",
        "LYSS - Total number of fabric begin replication request attempts from the queue on the primary",
        "LYSS - Total number of fabric begin replication request failures from the queue on the primary",
        "LYSS - Total number of fabric received replication request attempts by the queue on the secondary",
        "LYSS - Total number of fabric received replication request failures by the queue on the secondary",
        "LYSS - Total number of Storage Service Fabric Service unhandled exceptions.",
        "LYSS - Total number of LYSS database operation failures",
        "LYSS - Total number of Storage Service OAuth STS requests.",
        "LYSS - Total number of Storage Service OAuth STS request failures.",
        "LYSS - Total number of Storage Service OAuth authentication failures.",
        "LYSS - Total number of Storage Service EWS Autodiscovery operations.",
        "LYSS - Total number of Storage Service EWS Autodiscovery errors.",
        "LYSS - Current number of Storage Service API calls Executing",
        "LYSS - Current percentage of space used by Storage Service DB.",
        "LYSS - Total number of fabric received replication full copy request attempts for the queue on the primary",
        "LYSS - Total number of fabric received replication full copy request failures for the queue on the primary",
        "LYSS - Current number of outgoing active fabric delta replication requests",
        "LYSS - Current number of incoming active fabric delta replication requests",
        "LYSS - Total number of fabric clean DB attempts (for full copy) for the queue on the secondary",
        "LYSS - Total number of fabric clean DB failures (for full copy) for the queue on the secondary",
        "LYSS - Current number of Storage Service DAL calls Executing",
        "LYSS - Current number of total (primary and secondary) Storage Service queue items with new status",
        "LYSS - Current number of total (primary and secondary) Storage Service queue items with in process status",
        "LYSS - Current number of total (primary and secondary) Storage Service queue items with error status",
        "LYSS - Current number of total (primary and secondary) Storage Service queue items with archived status",
        "LYSS - Current number of owned (primary) Storage Service queue items with new status",
        "LYSS - Current number of owned (primary) Storage Service queue items with in process status",
        "LYSS - Current number of owned (primary) Storage Service queue items with error status",
        "LYSS - Current number of owned (primary) Storage Service queue items with archived status",
        "LYSS - Current number of unowned (secondary) Storage Service queue items with new status",
        "LYSS - Current number of unowned (secondary) Storage Service queue items with in process status",
        "LYSS - Current number of unowned (secondary) Storage Service queue items with error status",
        "LYSS - Current number of unowned (secondary) Storage Service queue items with archived status",
        "LYSS - Current number of Storage Service stale queue items",
        "LYSS - Total number of failed stored procedure time outs",
        "LYSS - Number of failed stored procedure time outs per second",
        "LYSS - Total number of failed flushes triggered by the DB usage timer function",
        "LYSS - Total number of GetImItemList calls while processing ucs contact notifications",
        "LYSS - Total number of failed GetImItemList calls while processing ucs contact notifications",
        "LYSS - Total number of files containing items with an Archived status",
    ],
    [
        '""',
        "16166",
        "11611",
        "11611",
        "0",
        "1751",
        "1751",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "5",
        "0",
        "0",
        "628",
        "1316",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "10",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "220",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2",
        "0",
        "0",
        "0",
        "2",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "352",
        "0",
        "0",
    ],
    ["[LS:USrv - Directory Search]"],
    [
        "instance",
        "USrv - Number of outstanding searches",
        "USrv - Total number of searches",
        "USrv - Number of searches / sec",
        "USrv - Total number of LDAP errors",
        "USrv - Number of LDAP errors / sec",
        "USrv - Search Latency (ms)",
        "",
    ],
    ['"_Total"', "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:AsMcu - MCU Health And Performance]"],
    [
        "instance",
        "ASMCU - HTTP Stack load",
        "ASMCU - HTTP Stack state",
        "ASMCU - Thread Pool Load",
        "ASMCU - Thread Pool Health State",
        "ASMCU - Thread Pool Unhandled Exceptions",
        "ASMCU - MCU Health State",
        "ASMCU - MCU Draining State",
        "ASMCU - MCU Health State Changed Count",
        "ASMCU - MCU Health DNS resolution failure Count",
        "ASMCU - MCU Health DNS resolution succeeded Count",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0", "0", "1907"],
    ["[LS:CAS - Planning]"],
    [
        "instance",
        "CAS - Total number of mute/unmute announcements",
        "CAS - Total number of entry/exit announcements",
    ],
    ['""', "0", "0"],
    ["[LS:HA - Health Agent Probes]"],
    [
        "instance",
        "HA - All Probes healthy time ellapsed",
        "HA - Probes in failure state",
        "HA - Probes in error state",
    ],
    ['""', "1715109", "0", "0"],
    ["[LS:IIMFILTER - Intelligent IM Filter]"],
    [
        "instance",
        "IIMFILTER - Messages Processed",
        "IIMFILTER - File Transfer Messages Rejected",
        "IIMFILTER - Clickable URL Messages Rejected",
        "IIMFILTER - Clickable URL Messages Modified",
        "IIMFILTER - Active Message Objects",
        "IIMFILTER - Throttling Mode Active",
        "IIMFILTER - Locally Generated 503 Responses",
        "IIMFILTER - Clickable URL or File Transfer Messages Regex Failures",
    ],
    ['""', "9631", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:ImMcu - CCCP Processing]"],
    [
        "instance",
        "IMMCU - Total CCCP Messages Received",
        "IMMCU - CCCP Messages Received/sec",
        "IMMCU - Total CCCP Requests Received",
        "IMMCU - CCCP Requests Received/sec",
        "IMMCU - Total CCCP Responses Received",
        "IMMCU - CCCP Responses Received/sec",
        "IMMCU - Total CCCP Notifications Received",
        "IMMCU - CCCP Notifications Received/sec",
        "IMMCU - Total CCCP Messages Sent",
        "IMMCU - CCCP Messages Sent/sec",
        "IMMCU - Total CCCP Requests Sent",
        "IMMCU - CCCP Requests Sent/sec",
        "IMMCU - Total CCCP Responses Sent",
        "IMMCU - CCCP Responses Sent/sec",
        "IMMCU - Total CCCP Notifications Sent",
        "IMMCU - CCCP Notifications Sent/sec",
        "IMMCU - Total CCCP Messages Retried",
        "IMMCU - CCCP Messages Retried/sec",
        "IMMCU - Total CCCP Messages Failed",
        "IMMCU - Current CCCP Message Queue Size",
        "IMMCU - Number of Active Conference Notifiers",
        "IMMCU - Number of Conference Notifications Sent",
        "IMMCU - Number of Conference Notification Send Retries",
        "IMMCU - Number of Conference Notification Send Aborts",
        "IMMCU - Number of Invalid Conference Notifications Sent",
        "IMMCU - Number of Conference Notification Sent to Non-Exisitent Conferences",
        "IMMCU - Number of Unrecognized CCCP messages",
        "IMMCU - Number of Exceptions During CCCP Serialization",
        "IMMCU - Number of Exceptions During CCCP Message Processing",
        "IMMCU - Number of add conference requests failed",
        "IMMCU - Number of add user requests failed",
        "IMMCU - Average processing time of incoming CCCP messages.",
        "IMMCU - Number of outstanding receive operations.",
        "IMMCU - Number of messages failed because queue is full.",
        "IMMCU - Total AddConference Requests Processed",
        "IMMCU - Total AddEndpointMedia Requests Processed",
        "IMMCU - Total AddSidebar Requests Processed",
        "IMMCU - Total AddUser Requests Processed",
        "IMMCU - Total EndorseUser Requests Processed",
        "IMMCU - Total DeleteConference Requests Processed",
        "IMMCU - Total DeleteConferences Requests Processed",
        "IMMCU - Total DeleteEndpointMedia Requests Processed",
        "IMMCU - Total DeleteSidebar Requests Processed",
        "IMMCU - Total DeleteUser Requests Processed",
        "IMMCU - Total GetAvailableMcuTypes Requests Processed",
        "IMMCU - Total GetConference Requests Processed",
        "IMMCU - Total GetConferences Requests Processed",
        "IMMCU - Total GetEncryptionKey Requests Processed",
        "IMMCU - Total GetMcu Requests Processed",
        "IMMCU - Total GetMeetingId Requests Processed",
        "IMMCU - Total VerifyConferenceKey Requests Processed",
        "IMMCU - Total ModifyConference Requests Processed",
        "IMMCU - Total ModifyConferenceLock Requests Processed",
        "IMMCU - Total ModifyConferenceAnnouncements Requests Processed",
        "IMMCU - Total ModifyEndpoint Requests Processed",
        "IMMCU - Total ModifyEndpointMedia Requests Processed",
        "IMMCU - Total ModifyEndpointRole Requests Processed",
        "IMMCU - Total ModifySidebar Requests Processed",
        "IMMCU - Total ModifyUser Requests Processed",
        "IMMCU - Total ModifyUsersMediaFilters Requests Processed",
        "IMMCU - Total ModifyUserRoles Requests Processed",
        "IMMCU - Total MoveUserToSidebar Requests Processed",
        "IMMCU - Total Ping Requests Processed",
        "IMMCU - Total PlayRecordedName Requests Processed",
        "IMMCU - Total SetUserAccess Requests Processed",
        "IMMCU - Total SetLobbyAccess Requests Processed",
        "IMMCU - Total StartRecording Requests Processed",
        "IMMCU - Total StopRecording Requests Processed",
        "IMMCU - Total PauseRecording Requests Processed",
        "IMMCU - Total ResumeRecording Requests Processed",
        "IMMCU - Total GetConferencingCapabilities Requests Processed",
        "IMMCU - Total ResolveConference Requests Processed",
        "IMMCU - Total QueryMeetingId Requests Processed",
        "IMMCU - Total DeleteMeetingId Requests Processed",
        "IMMCU - Total AddConference Responses Processed",
        "IMMCU - Total AddEndpointMedia Responses Processed",
        "IMMCU - Total AddSidebar Responses Processed",
        "IMMCU - Total AddUser Responses Processed",
        "IMMCU - Total EndorseUser Responses Processed",
        "IMMCU - Total DeleteConference Responses Processed",
        "IMMCU - Total DeleteConferences Responses Processed",
        "IMMCU - Total DeleteEndpointMedia Responses Processed",
        "IMMCU - Total DeleteSidebar Responses Processed",
        "IMMCU - Total DeleteUser Responses Processed",
        "IMMCU - Total VerifyConferenceKey Responses Processed",
        "IMMCU - Total GetAvailableMcuTypes Responses Processed",
        "IMMCU - Total GetConference Responses Processed",
        "IMMCU - Total GetConferences Responses Processed",
        "IMMCU - Total GetEncryptionKey Responses Processed",
        "IMMCU - Total GetMcu Responses Processed",
        "IMMCU - Total GetMeetingId Responses Processed",
        "IMMCU - Total ModifyConference Responses Processed",
        "IMMCU - Total ModifyConferenceLock Responses Processed",
        "IMMCU - Total ModifyConferenceAnnouncements Responses Processed",
        "IMMCU - Total ModifyEndpoint Responses Processed",
        "IMMCU - Total ModifyEndpointMedia Responses Processed",
        "IMMCU - Total ModifyEndpointRole Responses Processed",
        "IMMCU - Total ModifySidebar Responses Processed",
        "IMMCU - Total ModifyUser Responses Processed",
        "IMMCU - Total ModifyUsersMediaFilters Responses Processed",
        "IMMCU - Total ModifyUserRoles Responses Processed",
        "IMMCU - Total MoveUserToSidebar Responses Processed",
        "IMMCU - Total Ping Responses Processed",
        "IMMCU - Total PlayRecordedName Responses Processed",
        "IMMCU - Total SetUserAccess Responses Processed",
        "IMMCU - Total SetLobbyAccess Responses Processed",
        "IMMCU - Total StartRecording Responses Processed",
        "IMMCU - Total StopRecording Responses Processed",
        "IMMCU - Total PauseRecording Responses Processed",
        "IMMCU - Total ResumeRecording Responses Processed",
        "IMMCU - Total GetConferencingCapabilities Responses Processed",
        "IMMCU - Total ResolveConference Responses Processed",
        "IMMCU - Total QueryMeetingId Responses Processed",
        "IMMCU - Total DeleteMeetingId Responses Processed",
        "IMMCU - Total ConferenceStateNotify Notifications Processed",
        "IMMCU - Total McuAvailabilityNotify Notifications Processed",
    ],
    [
        '""',
        "81742",
        "81742",
        "132",
        "132",
        "81610",
        "81610",
        "0",
        "0",
        "196228",
        "196228",
        "81610",
        "81610",
        "132",
        "132",
        "114486",
        "114486",
        "0",
        "0",
        "0",
        "0",
        "1",
        "146",
        "0",
        "0",
        "0",
        "0",
        "2",
        "0",
        "0",
        "0",
        "0",
        "0",
        "10",
        "0",
        "45",
        "0",
        "0",
        "16",
        "0",
        "18",
        "1",
        "0",
        "0",
        "2",
        "0",
        "48",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "81610",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:UPINSVC - UPRP Processing]"],
    [
        "instance",
        "UPINSVC - Total UPRP Messages Received",
        "UPINSVC - UPRP Messages Received/sec",
        "UPINSVC - Total UPRP Requests Received",
        "UPINSVC - UPRP Requests Received/sec",
        "UPINSVC - Total UPRP Responses Received",
        "UPINSVC - UPRP Responses Received/sec",
        "UPINSVC - Number of Exceptions During UPRP Serialization",
        "UPINSVC - Number of Exceptions During UPRP Message Processing",
        "UPINSVC - Number of ResolveUser requests received",
        "UPINSVC - Number of GetEncryptionKey requests received",
        "UPINSVC - Number of Unlock Pin requests received",
        "UPINSVC - Number of Get Pin Info requests received",
        "UPINSVC - Number of Verify Pin requests received",
        "UPINSVC - Number of Update Pin requests received",
        "UPINSVC - Total UPRP Messages Received over http",
        "UPINSVC - UPRP Messages Received/sec over http",
        "UPINSVC - Total UPRP Requests Received",
        "UPINSVC - UPRP Requests Received/sec",
        "UPINSVC - Number of GetPublishedCert requests received",
        "UPINSVC - Number of PublishCert requests received",
        "UPINSVC - Number of ResolveUserWithPin requests received",
        "UPINSVC - Number of LookupUser requests received",
        "UPINSVC - Number of local LookupDomain requests received",
        "UPINSVC - Number of local EnumerateDomains requests received",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "6430",
        "6430",
        "6430",
        "6430",
        "3994",
        "49",
        "0",
        "6430",
        "0",
        "0",
    ],
    ["[LS:AsMcu - CCCP Processing]"],
    [
        "instance",
        "ASMCU - Total CCCP Messages Received",
        "ASMCU - CCCP Messages Received/sec",
        "ASMCU - Total CCCP Requests Received",
        "ASMCU - CCCP Requests Received/sec",
        "ASMCU - Total CCCP Responses Received",
        "ASMCU - CCCP Responses Received/sec",
        "ASMCU - Total CCCP Notifications Received",
        "ASMCU - CCCP Notifications Received/sec",
        "ASMCU - Total CCCP Messages Sent",
        "ASMCU - CCCP Messages Sent/sec",
        "ASMCU - Total CCCP Requests Sent",
        "ASMCU - CCCP Requests Sent/sec",
        "ASMCU - Total CCCP Responses Sent",
        "ASMCU - CCCP Responses Sent/sec",
        "ASMCU - Total CCCP Notifications Sent",
        "ASMCU - CCCP Notifications Sent/sec",
        "ASMCU - Total CCCP Messages Retried",
        "ASMCU - CCCP Messages Retried/sec",
        "ASMCU - Total CCCP Messages Failed",
        "ASMCU - Current CCCP Message Queue Size",
        "ASMCU - Number of Active Conference Notifiers",
        "ASMCU - Number of Conference Notifications Sent",
        "ASMCU - Number of Conference Notification Send Retries",
        "ASMCU - Number of Conference Notification Send Aborts",
        "ASMCU - Number of Invalid Conference Notifications Sent",
        "ASMCU - Number of Conference Notification Sent to Non-Exisitent Conferences",
        "ASMCU - Number of Unrecognized CCCP messages",
        "ASMCU - Number of Exceptions During CCCP Serialization",
        "ASMCU - Number of Exceptions During CCCP Message Processing",
        "ASMCU - Number of add conference requests failed",
        "ASMCU - Number of add user requests failed",
        "ASMCU - Average processing time of incoming CCCP messages.",
        "ASMCU - Number of outstanding receive operations.",
        "ASMCU - Number of messages failed because queue is full.",
        "ASMCU - Total AddConference Requests Processed",
        "ASMCU - Total AddEndpointMedia Requests Processed",
        "ASMCU - Total AddSidebar Requests Processed",
        "ASMCU - Total AddUser Requests Processed",
        "ASMCU - Total EndorseUser Requests Processed",
        "ASMCU - Total DeleteConference Requests Processed",
        "ASMCU - Total DeleteConferences Requests Processed",
        "ASMCU - Total DeleteEndpointMedia Requests Processed",
        "ASMCU - Total DeleteSidebar Requests Processed",
        "ASMCU - Total DeleteUser Requests Processed",
        "ASMCU - Total GetAvailableMcuTypes Requests Processed",
        "ASMCU - Total GetConference Requests Processed",
        "ASMCU - Total GetConferences Requests Processed",
        "ASMCU - Total GetEncryptionKey Requests Processed",
        "ASMCU - Total GetMcu Requests Processed",
        "ASMCU - Total GetMeetingId Requests Processed",
        "ASMCU - Total VerifyConferenceKey Requests Processed",
        "ASMCU - Total ModifyConference Requests Processed",
        "ASMCU - Total ModifyConferenceLock Requests Processed",
        "ASMCU - Total ModifyConferenceAnnouncements Requests Processed",
        "ASMCU - Total ModifyEndpoint Requests Processed",
        "ASMCU - Total ModifyEndpointMedia Requests Processed",
        "ASMCU - Total ModifyEndpointRole Requests Processed",
        "ASMCU - Total ModifySidebar Requests Processed",
        "ASMCU - Total ModifyUser Requests Processed",
        "ASMCU - Total ModifyUsersMediaFilters Requests Processed",
        "ASMCU - Total ModifyUserRoles Requests Processed",
        "ASMCU - Total MoveUserToSidebar Requests Processed",
        "ASMCU - Total Ping Requests Processed",
        "ASMCU - Total PlayRecordedName Requests Processed",
        "ASMCU - Total SetUserAccess Requests Processed",
        "ASMCU - Total SetLobbyAccess Requests Processed",
        "ASMCU - Total StartRecording Requests Processed",
        "ASMCU - Total StopRecording Requests Processed",
        "ASMCU - Total PauseRecording Requests Processed",
        "ASMCU - Total ResumeRecording Requests Processed",
        "ASMCU - Total GetConferencingCapabilities Requests Processed",
        "ASMCU - Total ResolveConference Requests Processed",
        "ASMCU - Total QueryMeetingId Requests Processed",
        "ASMCU - Total DeleteMeetingId Requests Processed",
        "ASMCU - Total AddConference Responses Processed",
        "ASMCU - Total AddEndpointMedia Responses Processed",
        "ASMCU - Total AddSidebar Responses Processed",
        "ASMCU - Total AddUser Responses Processed",
        "ASMCU - Total EndorseUser Responses Processed",
        "ASMCU - Total DeleteConference Responses Processed",
        "ASMCU - Total DeleteConferences Responses Processed",
        "ASMCU - Total DeleteEndpointMedia Responses Processed",
        "ASMCU - Total DeleteSidebar Responses Processed",
        "ASMCU - Total DeleteUser Responses Processed",
        "ASMCU - Total VerifyConferenceKey Responses Processed",
        "ASMCU - Total GetAvailableMcuTypes Responses Processed",
        "ASMCU - Total GetConference Responses Processed",
        "ASMCU - Total GetConferences Responses Processed",
        "ASMCU - Total GetEncryptionKey Responses Processed",
        "ASMCU - Total GetMcu Responses Processed",
        "ASMCU - Total GetMeetingId Responses Processed",
        "ASMCU - Total ModifyConference Responses Processed",
        "ASMCU - Total ModifyConferenceLock Responses Processed",
        "ASMCU - Total ModifyConferenceAnnouncements Responses Processed",
        "ASMCU - Total ModifyEndpoint Responses Processed",
        "ASMCU - Total ModifyEndpointMedia Responses Processed",
        "ASMCU - Total ModifyEndpointRole Responses Processed",
        "ASMCU - Total ModifySidebar Responses Processed",
        "ASMCU - Total ModifyUser Responses Processed",
        "ASMCU - Total ModifyUsersMediaFilters Responses Processed",
        "ASMCU - Total ModifyUserRoles Responses Processed",
        "ASMCU - Total MoveUserToSidebar Responses Processed",
        "ASMCU - Total Ping Responses Processed",
        "ASMCU - Total PlayRecordedName Responses Processed",
        "ASMCU - Total SetUserAccess Responses Processed",
        "ASMCU - Total SetLobbyAccess Responses Processed",
        "ASMCU - Total StartRecording Responses Processed",
        "ASMCU - Total StopRecording Responses Processed",
        "ASMCU - Total PauseRecording Responses Processed",
        "ASMCU - Total ResumeRecording Responses Processed",
        "ASMCU - Total GetConferencingCapabilities Responses Processed",
        "ASMCU - Total ResolveConference Responses Processed",
        "ASMCU - Total QueryMeetingId Responses Processed",
        "ASMCU - Total DeleteMeetingId Responses Processed",
        "ASMCU - Total ConferenceStateNotify Notifications Processed",
        "ASMCU - Total McuAvailabilityNotify Notifications Processed",
    ],
    [
        '""',
        "81755",
        "81755",
        "149",
        "149",
        "81606",
        "81606",
        "0",
        "0",
        "196297",
        "196297",
        "81606",
        "81606",
        "166",
        "166",
        "114525",
        "114525",
        "0",
        "0",
        "0",
        "0",
        "1",
        "193",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "10",
        "0",
        "102",
        "0",
        "0",
        "34",
        "0",
        "21",
        "1",
        "0",
        "0",
        "2",
        "0",
        "55",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "51",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "81606",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:ClsAgent - Centralized Logging Component]"],
    [
        "instance",
        "ClsAgent - Total number of trace records",
        "ClsAgent - Per second rate of trace records",
        "ClsAgent - Total number of trace records of levels TL_ERROR or TL_FATAL",
        "ClsAgent - Per second rate of trace records of levels TL_ERROR or TL_FATAL",
        "ClsAgent - Total number of trace bytes",
        "ClsAgent - Per second rate of trace bytes",
    ],
    ['"pbwvw-skype03.5372_clsagent_appdom_1"', "0", "0", "0", "0", "0", "0"],
    ['"_Total"', "0", "0", "0", "0", "0", "0"],
    ["[LS:SIP - Responses]"],
    [
        "instance",
        "SIP - Incoming 1xx (non-100) Responses",
        "SIP - Incoming 1xx (non-100) Responses /Sec",
        "SIP - Incoming 2xx Responses",
        "SIP - Incoming 2xx Responses /Sec",
        "SIP - Incoming 3xx Responses",
        "SIP - Incoming 3xx Responses /Sec",
        "SIP - Incoming 400 Responses",
        "SIP - Incoming 400 Responses /Sec",
        "SIP - Incoming 401 Responses",
        "SIP - Incoming 401 Responses /Sec",
        "SIP - Incoming 403 Responses",
        "SIP - Incoming 403 Responses /Sec",
        "SIP - Incoming 404 Responses",
        "SIP - Incoming 404 Responses /Sec",
        "SIP - Incoming 407 Responses",
        "SIP - Incoming 407 Responses /Sec",
        "SIP - Incoming 408 Responses",
        "SIP - Incoming 408 Responses /Sec",
        "SIP - Incoming 482 Responses",
        "SIP - Incoming 482 Responses /Sec",
        "SIP - Incoming 483 Responses",
        "SIP - Incoming 483 Responses /Sec",
        "SIP - Incoming Other 4xx Responses",
        "SIP - Incoming Other 4xx Responses /Sec",
        "SIP - Incoming 503 Responses",
        "SIP - Incoming 503 Responses /Sec",
        "SIP - Incoming 504 Responses",
        "SIP - Incoming 504 Responses /Sec",
        "SIP - Incoming Other 5xx Responses",
        "SIP - Incoming Other 5xx Responses /Sec",
        "SIP - Incoming 6xx Responses",
        "SIP - Incoming 6xx Responses /Sec",
        "SIP - Local 1xx Responses",
        "SIP - Local 1xx Responses /Sec",
        "SIP - Local 2xx Responses",
        "SIP - Local 2xx Responses /Sec",
        "SIP - Local 3xx Responses",
        "SIP - Local 3xx Responses /Sec",
        "SIP - Local 400 Responses",
        "SIP - Local 400 Responses /Sec",
        "SIP - Local 400 Responses Ratio",
        "SIP - Local 403 Responses",
        "SIP - Local 403 Responses /Sec",
        "SIP - Local 403 Responses Ratio",
        "SIP - Local 404 Responses",
        "SIP - Local 404 Responses /Sec",
        "SIP - Local 404 Responses Ratio",
        "SIP - Local 408 Responses",
        "SIP - Local 408 Responses /Sec",
        "SIP - Local 408 Responses Ratio",
        "SIP - Local 482 Responses",
        "SIP - Local 482 Responses /Sec",
        "SIP - Local 482 Responses Ratio",
        "SIP - Local 483 Responses",
        "SIP - Local 483 Responses /Sec",
        "SIP - Local 483 Responses Ratio",
        "SIP - Local Other 4xx Responses",
        "SIP - Local 4xx Responses /Sec",
        "SIP - Local Other 4xx Responses Ratio",
        "SIP - Local 500 Responses",
        "SIP - Local 500 Responses /Sec",
        "SIP - Local 500 Responses Ratio",
        "SIP - Local 503 Responses",
        "SIP - Local 503 Responses /Sec",
        "SIP - Local 503 Responses Ratio",
        "SIP - Local 504 Responses",
        "SIP - Local 504 Responses /Sec",
        "SIP - Local 504 Responses Ratio",
        "SIP - Local Other 5xx Responses",
        "SIP - Local 5xx Responses /Sec",
        "SIP - Local Other 5xx Responses Ratio",
        "SIP - Local 6xx Responses",
        "SIP - Local 6xx Responses /Sec",
        "SIP - Local 6xx Responses Ratio",
    ],
    [
        '""',
        "1686",
        "1686",
        "482810",
        "482810",
        "36",
        "36",
        "3225",
        "3225",
        "0",
        "0",
        "22743",
        "22743",
        "190115",
        "190115",
        "0",
        "0",
        "10",
        "10",
        "0",
        "0",
        "0",
        "0",
        "4165",
        "4165",
        "0",
        "0",
        "5565",
        "5565",
        "21",
        "21",
        "6",
        "6",
        "10476",
        "10476",
        "306134",
        "306139",
        "0",
        "0",
        "80",
        "80",
        "0",
        "119",
        "119",
        "0",
        "1373",
        "1373",
        "0",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "31757",
        "31757",
        "0",
        "0",
        "0",
        "0",
        "6",
        "6",
        "0",
        "292",
        "292",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:SIP - Authentication]"],
    [
        "instance",
        "SIP - Security Records Stored",
        "SIP - Security Records Created /Sec",
        "SIP - Security Association (SAs) Stored",
        "SIP - Security Associations (SAs) Created /Sec",
        "SIP - Incomplete Security Association (SAs) Stored",
        "SIP - Kerberos Security Association (SAs) Stored",
        "SIP - Kerberos Security Associations (SAs) Created /Sec",
        "SIP - NTLM Security Association (SAs) Stored",
        "SIP - NTLM Security Associations (SAs) Created /Sec",
        "SIP - Client Certificate Security Association (SAs) Stored",
        "SIP - Client Certificate Security Associations (SAs) Created /Sec",
        "SIP - Anonymous Conference Participant Security Association (SAs) Stored",
        "SIP - Anonymous Conference Participant Security Associations (SAs) Created /Sec",
        "SIP - Incoming Messages To Be Authenticated",
        "SIP - Incoming Messages To Be Authenticated /Sec",
        "SIP - Incoming Messages Queued in Authentication Engine",
        "SIP - Incoming Messages Not Authenticated",
        "SIP - Incoming Messages Not Authenticated /Sec",
        "SIP - Incoming Messages Not Authorized",
        "SIP - Incoming Messages Not Authorized /Sec",
        "SIP - Incoming Messages With Invalid Signatures",
        "SIP - Incoming Messages With Invalid Signatures /Sec",
        "SIP - Incoming Messages Signed With Stale SA",
        "SIP - Incoming Messages Signed With Stale SA /Sec",
        "SIP - Incoming Messages With Invalid Authentication Headers",
        "SIP - Incoming Messages With Invalid Authentication Header /Sec",
        "SIP - Incoming Messages Replayed",
        "SIP - Incoming Messages Replayed /Sec",
        "SIP - Outgoing Messages To Be Signed",
        "SIP - Outgoing Messages To Be Signed /Sec",
        "SIP - Authentication System Errors",
        "SIP - Authentication System Errors /Sec",
        "SIP - Authentication System Errors Ratio",
    ],
    [
        '""',
        "61",
        "2436",
        "61",
        "4146",
        "0",
        "0",
        "1394",
        "0",
        "5",
        "61",
        "2737",
        "0",
        "10",
        "844234",
        "844223",
        "0",
        "4162",
        "4162",
        "0",
        "0",
        "530",
        "530",
        "41",
        "41",
        "0",
        "0",
        "6",
        "6",
        "1303558",
        "1303540",
        "0",
        "0",
        "0",
    ],
    ["[LS:RGS - Response Group Service Match Making]"],
    [
        "instance",
        "RGS - Total number of calls",
        "RGS - Current number of calls",
        "RGS - Calls transferred",
        "RGS - Calls stopped",
        "RGS - Calls to active Match Making failed due to communication exception",
        "RGS - Calls to Match Making failed due to security exception",
        "RGS - Total number of presence notifications received",
        "RGS - Active Match Making",
        "RGS - Total number of terminated presence subscriptions",
        "RGS - Number of calls registered in Match Making",
        "RGS - Number of calls unregistered from Match Making",
        "RGS - Number of requests placed to the active Match Making",
        "RGS - Total number of attempts to start listening.",
        "RGS - Total number of failures to start listening.",
        "RGS - Total number of attempts to get active MM.",
        "RGS - Total number of failures to get active MM.",
        "RGS - Total number of available agents for MM.",
        "RGS - Total number of agents for MM.",
        "RGS - MM event queue length.",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "714",
        "1",
        "0",
        "0",
        "0",
        "0",
        "2",
        "0",
        "244859",
        "8",
        "0",
        "2",
        "0",
    ],
    ["[LS:XmppFederation - XMPP Presence]"],
    [
        "instance",
        "XmppFederation - Inbound Presence Type=Error",
        "XmppFederation - Inbound Presence Type=Error/sec",
        "XmppFederation - Inbound Presence Type=None",
        "XmppFederation - Inbound Presence Type=None/sec",
        "XmppFederation - Inbound Presence Type=Unavailable",
        "XmppFederation - Inbound Presence Type=Unavailable/sec",
        "XmppFederation - Inbound Presence Type=Probe",
        "XmppFederation - Inbound Presence Type=Probe/sec",
        "XmppFederation - Inbound Presence Type=Subscribe",
        "XmppFederation - Inbound Presence Type=Subscribe/sec",
        "XmppFederation - Inbound Presence Type=Subscribed",
        "XmppFederation - Inbound Presence Type=Subscribed/sec",
        "XmppFederation - Inbound Presence Type=Unsubscribe",
        "XmppFederation - Inbound Presence Type=Unsubscribe/sec",
        "XmppFederation - Inbound Presence Type=Unsubscribed",
        "XmppFederation - Inbound Presence Type=Unsubscribed/sec",
        "XmppFederation - Outbound Presence Type=Error",
        "XmppFederation - Outbound Presence Type=Error/sec",
        "XmppFederation - Outbound Presence Type=None",
        "XmppFederation - Outbound Presence Type=None/sec",
        "XmppFederation - Outbound Presence Type=Unavailable",
        "XmppFederation - Outbound Presence Type=Unavailable/sec",
        "XmppFederation - Outbound Presence Type=Probe",
        "XmppFederation - Outbound Presence Type=Probe/sec",
        "XmppFederation - Outbound Presence Type=Subscribe",
        "XmppFederation - Outbound Presence Type=Subscribe/sec",
        "XmppFederation - Outbound Presence Type=Subscribed",
        "XmppFederation - Outbound Presence Type=Subscribed/sec",
        "XmppFederation - Outbound Presence Type=Unsubscribe",
        "XmppFederation - Outbound Presence Type=Unsubscribe/sec",
        "XmppFederation - Outbound Presence Type=Unsubscribed",
        "XmppFederation - Outbound Presence Type=Unsubscribed/sec",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:FEDSVC - Incoming Federation Processing]"],
    [
        "instance",
        "FEDSVC - Messages Dropped Due To Blocked Domain",
        "FEDSVC - Messages/sec Dropped Due To Blocked Domain",
        "FEDSVC - Messages Dropped Due To Domain not present in explicitly configured Allowed list.",
        "FEDSVC - Messages/sec Dropped Due To Domain not present in explicitly configured Allowed list.",
    ],
    ['""', "0", "0", "0", "0"],
    ["[LS:AVMP - Debugging]"],
    [
        "instance",
        "AVMP - Total RTP EndpointConnectivityStatus events",
        "AVMP - Total RTP ConnectivityStateChanged events",
        "AVMP - Total RTP Local Address Allocations started",
        "AVMP - Total RTP Local Address Allocations completed",
        "AVMP - Total RTP Local Address Allocation failures",
        "AVMP - Total RTP Local Address Allocation failures due to BW",
        "AVMP - Total RTP Local Address Allocation failovers due to BW",
        "AVMP - Total RTP Connectivity Checks started",
        "AVMP - Total RTP Connectivity Checks completed",
        "AVMP - Total RTP Connectivity Check failures",
        "AVMP - Total Transcoder Errors",
        "AVMP - Total Create Transcoder Errors",
        "AVMP - Total Close Transcoder Errors",
        "AVMP - Packet Loss Failure",
        "AVMP - Rdp Connection Timeout Failures",
    ],
    [
        '"pbwvw-skype03.16124_avmcusvc_appdom_1"',
        "303",
        "0",
        "81",
        "81",
        "0",
        "0",
        "0",
        "80",
        "71",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ['"_Total"', "355", "0", "96", "96", "0", "0", "0", "95", "80", "0", "0", "0", "0", "0", "0"],
    [
        '"pbwvw-skype03.21588_asmcusvc_appdom_1"',
        "52",
        "0",
        "15",
        "15",
        "0",
        "0",
        "0",
        "15",
        "9",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:AsMcu - AsMcu Conferences]"],
    [
        "instance",
        "ASMCU - Active Conferences",
        "ASMCU - Active Transcoders",
        "ASMCU - Active Data Channels",
        "ASMCU - Connected Users",
        "ASMCU - Conferences Created Total",
        "ASMCU - Active Trusted Server Connections",
        "ASMCU - Active Ajax Viewers",
        "ASMCU - Active Anonymous Connections",
        "ASMCU - Active Federated Connections",
        "ASMCU - Active External Connections",
        "ASMCU - Total Transcoder Errors",
        "ASMCU - Total Create Transcoder Errors",
        "ASMCU - Total Close Transcoder Errors",
        "ASMCU - Total allocated bandwidth",
        "ASMCU - Bandwidth allocated per client",
        "ASMCU - Media Timeout Failures",
        "ASMCU - Packet Loss Failure",
        "ASMCU - Sip Dialog Failures",
        "ASMCU - Rdp Connection Timeout Failures",
        "ASMCU - Total Bandwidth Reallocations",
        "ASMCU - Total Send Channel Bandwidth Changes",
        "ASMCU - Total Receive Channel Bandwidth Changes",
        "ASMCU - Active Ajax Transcoders",
        "ASMCU - Active RLE Transcoders",
        "ASMCU - Total MRAS Request",
        "ASMCU - Total MRAS Responses Received",
        "ASMCU - Total MRAS Requests Failure",
        "ASMCU - Total MRAS Timeout",
        "ASMCU - Total SIP BYE Sent",
        "ASMCU - Total SIP INVITE Sent",
        "ASMCU - Total SIP INVITE Received",
        "ASMCU - Total SIP REINVITE Sent",
        "ASMCU - Total SIP REINVITE Received",
        "ASMCU - Total SIP INVITE Accepted",
        "ASMCU - Total SIP INVITE Rejected",
        "ASMCU - Total SIP REINVITE Accepted",
        "ASMCU - Total SIP REINVITE Rejected",
        "ASMCU - Total SIP Invites rejected due to Bandwidth restrictions",
        "ASMCU - Total Conferences Deleted",
        "ASMCU - Total Users Added",
        "ASMCU - Total Users Removed",
        "ASMCU - Total Trusted Users Added",
        "ASMCU - Total Trusted Users Removed",
        "ASMCU - Total QOE Reports Sent",
        "ASMCU - Total QoE Requests Sent",
        "ASMCU - Total QoE Responses Received",
        "ASMCU - Total QOE Reports Rejected",
        "ASMCU - Total QoE Request Errors",
        "ASMCU - Total QoE Timeout Exceptions",
        "ASMCU - Total QoE Failure Response Exceptions",
        "ASMCU - Total QoE Real Time Exceptions",
        "ASMCU - Total QoE Generic Exceptions",
    ],
    [
        '""',
        "1",
        "0",
        "0",
        "0",
        "51",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "17",
        "17",
        "0",
        "0",
        "0",
        "0",
        "15",
        "0",
        "9",
        "15",
        "0",
        "9",
        "0",
        "0",
        "50",
        "17",
        "17",
        "0",
        "0",
        "9",
        "9",
        "9",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:REPAPPSVC - Replication Application Processing]"],
    [
        "instance",
        "REPAPP - Total Replication Requests Received",
        "REPAPP - Number of failed Replication requests",
        "REPAPP - Number of Items synced",
        "REPAPP - Compressed replication message size (in kilobytes)",
        "REPAPP - Decompressed replication message size (in kilobytes)",
    ],
    ['""', "47", "0", "0", "0", "0"],
    ["[LS:XmppFederation - HTTP listener]"],
    [
        "instance",
        "XmppFederation - Requests recevied",
        "XmppFederation - Requests received/sec",
        "XmppFederation - Request processsing time (ms)",
    ],
    ['""', "0", "0", "0"],
    ["[LS:DATAMCU - DataMCU Annotations]"],
    [
        "instance",
        "DATAMCU - Number of Data MCU annotations under Annotation Container",
        "DATAMCU - Number of Data MCU annotations under Annotation Container per sec",
        "DATAMCU - Number of Data MCU image annotations under Annotation Container",
        "DATAMCU - Number of Data MCU image annotations under Annotation Container per sec",
    ],
    ['""', "0", "0", "0", "0"],
    ["[LS:MEDIA - Informational]"],
    [
        "instance",
        "MEDIA - Number of send-only audio channels started",
        "MEDIA - Number of receive-only audio channels started",
        "MEDIA - Number of send-receive audio channels started",
        "MEDIA - Number of send-only video channels started",
        "MEDIA - Number of receive-only video channels started",
        "MEDIA - Number of send-receive video channels started",
        "MEDIA - Average time spent in processing audio packets",
        " ",
        "MEDIA - Timer ticks/sec",
        "MEDIA - Conference process rate",
        "MEDIA - Average ICE Address Binding Time",
        " ",
        "MEDIA - Average ICE Connectivity Check Time",
        " ",
        "MEDIA - Audio packets received from transport provider/sec",
        "MEDIA - Audio packets received from RTP layer/sec",
        "MEDIA - Audio packets received from audio engine/sec",
        "MEDIA - Audio packets sent into audio engine/sec",
        "MEDIA - Audio router input buffers/sec",
        "MEDIA - Audio router output buffers/sec",
        "MEDIA - Audio packets sent to RTP/sec",
        "MEDIA - Audio packets sent to transport provider/sec",
        "MEDIA - Audio FEC packets sent/sec",
        "MEDIA - Video packets received from transport provider/sec",
        "MEDIA - Video packets received from RTP/sec",
        "MEDIA - Video frame received from users/sec",
        "MEDIA - Video packets sent to video engine/sec",
        "MEDIA - Video packets sent to RTP/sec",
        "MEDIA - Video packets sent to transport provider/sec",
        "MEDIA - Video switcher input frames/sec",
        "MEDIA - Video switcher output frames/sec",
        "MEDIA - Data packets received from transport provider/sec",
        "MEDIA - Data packets sent to transport provider/sec",
        "MEDIA - The number of times data channel is stalled",
        "MEDIA - The number of times data channel transport is stalled",
        "MEDIA - Packets produced by the TCP packetizer/sec",
        "MEDIA - Number of successful receive IO/sec",
        "MEDIA - Number of successful send IO/sec",
        "MEDIA - Number of failed receive IO/sec",
        "MEDIA - Number of failed send IO/sec",
        "MEDIA - RTCP packets received/sec",
        "MEDIA - RTCP packets sent/sec",
        "MEDIA - Heap allocation",
        "MEDIA - Heap free",
        "MEDIA - Total number of network buffers",
        "MEDIA - Total number of streaming buffers",
        "MEDIA - Total number of port collisions",
        "MEDIA - Total number of media timeouts",
        "MEDIA - Video switcher rate matched frames/sec",
        "MEDIA - Number of incoming QVGA video streams",
        "MEDIA - Number of incoming VGA video streams",
        "MEDIA - Number of incoming HD video streams",
        "MEDIA - Number of incoming PANO video streams",
        "MEDIA - Number of outgoing QVGA video streams",
        "MEDIA - Number of outgoing VGA video streams",
        "MEDIA - Number of outgoing HD video streams",
        "MEDIA - Number of outgoing PANO video streams",
        "MEDIA - Number of incoming VC1 video streams",
        "MEDIA - Number of outgoing VC1 video streams",
        "MEDIA - Total bandwidth of incoming audio streams in bytes per second",
        "MEDIA - Total bandwidth of outgoing audio streams in bytes per second",
        "MEDIA - Total bandwidth of incoming video streams in bytes per second",
        "MEDIA - Total bandwidth of outgoing video streams in bytes per second",
        "MEDIA - Total bandwidth of incoming data streams in bytes per second",
        "MEDIA - Total bandwidth of outgoing data streams in bytes per second",
        "MEDIA - Siren audio encode/sec",
        "MEDIA - Siren audio decode/sec",
        "MEDIA - SILK audio encode/sec",
        "MEDIA - SILK audio decode/sec",
        "MEDIA - RTVoice audio encode/sec",
        "MEDIA - RTVoice audio decode/sec",
        "MEDIA - Other audio encode/sec",
        "MEDIA - Other audio decode/sec",
        "MEDIA - G722 audio encode/sec",
        "MEDIA - G722 audio decode/sec",
    ],
    [
        '"Call_Park_Service_1.0"',
        "0",
        "0",
        "12",
        "0",
        "0",
        "0",
        "1629633658",
        "1024581601",
        "343687347",
        "196",
        "622206",
        "12",
        "1770752",
        "12",
        "514424840",
        "507591879",
        "1022800683",
        "513721314",
        "1025572955",
        "514697325",
        "513621805",
        "512046856",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "36",
        "537322921",
        "537393760",
        "138",
        "0",
        "22122765",
        "22119244",
        "152580",
        "133191",
        "176",
        "422",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "93586926480",
        "110387019374",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "514159093",
        "1015346505",
    ],
    [
        '"_Total"',
        "0",
        "0",
        "24",
        "0",
        "0",
        "0",
        "2052514287",
        "1031897856",
        "369468081",
        "781",
        "71631636",
        "680",
        "366254961",
        "319",
        "523417369",
        "516799566",
        "1035436692",
        "524573324",
        "1034775746",
        "525936623",
        "523147919",
        "521571833",
        "140656",
        "399572",
        "399573",
        "0",
        "400037",
        "400145",
        "400145",
        "60956",
        "61160",
        "3974882",
        "81373",
        "0",
        "1141",
        "658644",
        "547186530",
        "547774004",
        "24055",
        "4",
        "22446532",
        "22457299",
        "557680",
        "480373",
        "346",
        "778",
        "42",
        "7",
        "9386",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "95220571195",
        "112380924052",
        "367302400",
        "373168239",
        "2489603564",
        "98118884",
        "2932",
        "275142",
        "0",
        "0",
        "177449",
        "140849",
        "7403360",
        "15346276",
        "516004507",
        "1017102749",
    ],
    [
        '"MediationServer"',
        "0",
        "0",
        "6",
        "0",
        "0",
        "0",
        "198296248",
        "3798239",
        "13007470",
        "196",
        "57282932",
        "539",
        "65232387",
        "184",
        "6388885",
        "6389031",
        "7583746",
        "6372854",
        "6471529",
        "6469368",
        "6370000",
        "6368859",
        "81773",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "16044",
        "6549597",
        "6483088",
        "19397",
        "2",
        "150650",
        "92558",
        "283376",
        "268884",
        "85",
        "180",
        "33",
        "6",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1162749775",
        "1178391698",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "177449",
        "140849",
        "6190856",
        "12462839",
        "0",
        "0",
    ],
    [
        '"Conferencing_Announcement_Service_1.0"',
        "0",
        "0",
        "2",
        "0",
        "0",
        "0",
        "1064242",
        "1370843",
        "4279108",
        "196",
        "1179547",
        "11",
        "2101294",
        "12",
        "16",
        "0",
        "0",
        "162",
        "162",
        "162",
        "162",
        "162",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "72",
        "44432",
        "33195",
        "416",
        "0",
        "42804",
        "31388",
        "23960",
        "15764",
        "28",
        "30",
        "4",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "852",
        "22687391",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "161",
        "0",
    ],
    [
        '"AVMCUSvc.exe"',
        "0",
        "0",
        "4",
        "0",
        "0",
        "0",
        "223118161",
        "1592752",
        "6312845",
        "193",
        "8590035",
        "81",
        "207787957",
        "79",
        "2530098",
        "2737174",
        "4970219",
        "4407082",
        "2585259",
        "4694940",
        "3084043",
        "3084043",
        "58883",
        "399572",
        "399573",
        "0",
        "400037",
        "400145",
        "400145",
        "60956",
        "61160",
        "0",
        "0",
        "0",
        "0",
        "485877",
        "3051331",
        "3691854",
        "2977",
        "0",
        "119286",
        "200369",
        "40996",
        "27687",
        "57",
        "146",
        "5",
        "1",
        "9386",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "456400645",
        "776627336",
        "367302400",
        "373168239",
        "0",
        "0",
        "2932",
        "275142",
        "0",
        "0",
        "0",
        "0",
        "1149837",
        "2742898",
        "1836107",
        "1755256",
    ],
    [
        '"ATS_1.0.100"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "6129",
        "11104",
        "45821",
        "0",
        "1080510",
        "10",
        "11524151",
        "10",
        "1415",
        "1411",
        "11105",
        "9178",
        "12178",
        "10710",
        "9178",
        "9178",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "66",
        "2967",
        "11064",
        "369",
        "0",
        "1357",
        "1459",
        "21008",
        "14733",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "165572",
        "2434464",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "9146",
        "988",
    ],
    [
        '"Conferencing_Attendant_1.0"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "35972",
        "70943",
        "242847",
        "0",
        "1272885",
        "12",
        "1964431",
        "12",
        "72115",
        "80071",
        "70939",
        "62734",
        "133663",
        "64118",
        "62731",
        "62735",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "72",
        "73359",
        "66327",
        "444",
        "0",
        "1064",
        "3362",
        "20256",
        "12579",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "14327871",
        "13763789",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "62667",
        "140539",
        "0",
        "0",
    ],
    [
        '"ASMCUSvc.exe"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "359877",
        "472374",
        "1892643",
        "0",
        "1603521",
        "15",
        "75873989",
        "10",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "3974882",
        "81373",
        "0",
        "1141",
        "156477",
        "141923",
        "94716",
        "314",
        "2",
        "8606",
        "8919",
        "13200",
        "7535",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2489603564",
        "98118884",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"Reach_Server"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "768",
        "768",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"Response_Group_Service"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "768",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:USrv - Register]"],
    [
        "instance",
        "USrv - REGISTERs received",
        "USrv - REGISTERs received/Sec",
        "USrv - UNREGISTERs received",
        "USrv - UNREGISTERs received/Sec",
        "USrv - REGISTERs rejected",
        "USrv - Legacy REGISTERs rejected (421 Response)",
        "USrv - Registration Notifications Sent",
        "USrv - Endpoints expired",
        "USrv - Registrar Endpoints expired",
        "USrv - Users presence affected by expiration",
        "USrv - Endpoints requiring aggregation and batch expired",
        "USrv - Endpoints Disconnected",
        "USrv - Indirectly Connected Endpoints Disconnected",
        "USrv - Number of times User Services was detected as down",
        "USrv - Current status of User Services",
    ],
    [
        '""',
        "12111",
        "12111",
        "1533",
        "1533",
        "136",
        "0",
        "0",
        "673",
        "0",
        "673",
        "667",
        "0",
        "0",
        "0",
        "1",
    ],
    ["[LS:USrv - Unmanaged Certificate Auth Provider]"],
    [
        "instance",
        "USrv - CertStoreGetPublishedCert: calls/Sec",
        "USrv - CertStoreGetPublishedCert: Latency (msec)",
        " ",
        "USrv - CertStoreGetPublishedCert: calls total",
        "USrv - CertStorePublishCert: calls/Sec",
        "USrv - CertStorePublishCert: Latency (msec)",
        " ",
        "USrv - CertStorePublishCert: calls total",
        "USrv - Number of authorization attempt using certificate",
        "USrv - Number of authorization attempt using certificate per second",
        "USrv - Number of successful certificate lookups",
        "USrv - Number of successful certificate lookups per second",
        "USrv - Number of certificate lookups in registrar database",
        "USrv - Number of certificate lookups in registrar database which returned valid certificate",
        "USrv - Number of certificate lookups in presence database",
        "USrv - Number of certificate lookups in presence database which returned valid certificate",
        "USrv - Number of certificate lookups in User Services Cluster",
        "USrv - Number of certificate lookups in User Services Cluster which returned valid certificate",
        "USrv - Number of certificate lookups in remote registrar (primary or backup)",
        "USrv - Number of certificate lookups in remote registrar (primary or backup) which returned valid certificate",
    ],
    [
        '""',
        "2888",
        "415",
        "2888",
        "2888",
        "0",
        "0",
        "0",
        "0",
        "2888",
        "2888",
        "2844",
        "2844",
        "2888",
        "2844",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:XmppFederation - XMPP Instant Messaging]"],
    [
        "instance",
        "XmppFederation - Message stanzas received",
        "XmppFederation - Message stanzas received/sec",
        "XmppFederation - Message error stanzas received",
        "XmppFederation - Message error stanzas received/sec",
        "XmppFederation - Message stanzas sent",
        "XmppFederation - Message stanzas sent/sec",
        "XmppFederation - Message error stanzas sent",
        "XmppFederation - Message error stanzas sent/sec",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:WEB - Throttling and Authentication]"],
    [
        "instance",
        "WEB - Unauthenticated Requests In Processing",
        "WEB - User Authenticated Requests In Processing",
        "WEB - Conference Authenticated Requests In Processing",
        "WEB - Total Requests In Processing",
        "WEB - Entity Body Reads Outstanding",
        "WEB - Requests Exceeded Per-App Limit",
        "WEB - Requests Exceeded Per-User Limit",
        "WEB - Requests Exceeded Per-Conference Limit",
        "WEB - Requests Exceeded Entity Body Read Time",
        "WEB - Windows Authentication Requests",
        "WEB - Windows Authentication Requests/sec",
        "WEB - Failed Windows Authentication Requests",
        "WEB - Failed Windows Authentication Requests/sec",
        "WEB - Certificate Authentication Requests",
        "WEB - Certificate Authentication Requests/sec",
        "WEB - Failed Certificate Authentication Requests",
        "WEB - Failed Certificate Authentication Requests/sec",
        "WEB - Phone and PIN Authentication Requests",
        "WEB - Phone and PIN Authentication Requests/sec",
        "WEB - Failed Phone and PIN Authentication Requests",
        "WEB - Failed Phone and PIN Authentication Requests/sec",
        "WEB - Conference ID/PIN Authentication Requests",
        "WEB - Conference ID/PIN Authentication Requests/sec",
        "WEB - Failed Conference ID/PIN Authentication Requests",
        "WEB - Failed Conference ID/PIN Authentication Requests/sec",
        "WEB - Machine Certificate Authentication Requests",
        "WEB - Machine Certificate Authentication Requests/sec",
        "WEB - Failed Machine Certificate Authentication Requests",
        "WEB - Failed Machine Certificate Authentication Requests/sec",
        "WEB - WS Federated Authentication Requests",
        "WEB - WS Federated Authentication Requests/sec",
        "WEB - Failed WS Federated Authentication Requests",
        "WEB - Failed WS Federated Authentication Requests/sec",
        "WEB - Web Ticket Authentication Requests",
        "WEB - Web Ticket Authentication Requests/sec",
        "WEB - Failed Web Ticket Authentication Requests",
        "WEB - Failed Web Ticket Authentication Requests/sec",
        "WEB - Conference Ticket Authentication Requests",
        "WEB - Conference Ticket Authentication Requests/sec",
        "WEB - Failed Conference Ticket Authentication Requests",
        "WEB - Failed Conference Ticket Authentication Requests/sec",
        "WEB - Expired Web Tickets Rejected",
        "WEB - Expired Web Tickets Rejected/sec",
        "WEB - Other Server Proof Tickets Rejected",
        "WEB - Other Server Proof Tickets Rejected/sec",
        "WEB - Time Skewed Proof Tickets Rejected",
        "WEB - Time Skewed Proof Tickets Rejected/sec",
        "WEB - Missing Credential Requests Challenged",
        "WEB - Missing Credential Requests Challenged/sec",
        "WEB - Total Requests",
        "WEB - Total Requests/sec",
        "WEB - WS-Federation Passive Authentication Requests",
        "WEB - WS-Federation Passive Authentication Requests/sec",
        "WEB - Failed WS-Federation Passive Authentication Requests",
        "WEB - Failed WS-Federation Passive Authentication Requests/sec",
        "WEB - OAuth Token Authentication Requests",
        "WEB - OAuth Token Authentication Requests/sec",
        "WEB - Failed OAuth Token Authentication Requests",
        "WEB - Failed OAuth Token Authentication Requests/sec",
        "WEB - Internal Mutual TLS Authentication Requests",
        "WEB - Internal Mutual TLS Authentication Requests/sec",
        "WEB - Failed Internal Mutual TLS Authentication Requests",
        "WEB - Failed Internal Mutual TLS Authentication Requests/sec",
        "WEB - Session Web Ticket Authentication Requests",
        "WEB - Session Web Ticket Authentication Requests/sec",
        "WEB - Failed Session Web Ticket Authentication Requests",
        "WEB - Failed Session Web Ticket Authentication Requests/sec",
        "WEB - HTTP Proxy Requests",
        "WEB - HTTP Proxy Requests/sec",
        "WEB - Failed HTTP Proxy Requests",
        "WEB - Failed HTTP Proxy Requests/sec",
        "WEB - Number of proxy requests awaiting completion.",
        "WEB - Deep lookup user Latency (ms)",
        " ",
        "WEB - Failed Deep Lookup Requests",
        "WEB - HTTP Proxy Server Request Latency (ms)",
        "",
    ],
    [
        '"_Total"',
        "0",
        "1",
        "0",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "1",
        "0",
        "0",
        "183",
        "183",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "4896",
        "4896",
        "25",
        "25",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "9338",
        "9338",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "3544",
        "3544",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "7",
        "7",
        "0",
        "0",
        "0",
        "0",
        "6733",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34577_ROOT_meet"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "19",
        "19",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34577_ROOT_WebTicket"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "115",
        "115",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "241",
        "241",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "13",
        "13",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34578_ROOT_meet"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "24",
        "24",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "7",
        "7",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34577_ROOT_GroupExpansion"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1032",
        "1032",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1090",
        "1090",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34577_ROOT_RequestHandler"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34578_ROOT_CertProv"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34578_ROOT_Reach"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34577_ROOT_LocationInformation"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "225",
        "225",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "335",
        "335",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34578_ROOT_Ucwa"',
        "0",
        "1",
        "0",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "3186",
        "3186",
        "25",
        "25",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "6567",
        "6567",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "3368",
        "3368",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "6529",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34577_ROOT_Reach"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34578_ROOT_RgsClients"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "8",
        "8",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "11",
        "11",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "5",
        "5",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "10",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34577_ROOT_RgsClients"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "130",
        "130",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "242",
        "242",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34578_ROOT_Autodiscover"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "40",
        "40",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "151",
        "151",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "33",
        "33",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "73",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34578_ROOT_GroupExpansion"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "63",
        "63",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "69",
        "69",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "30",
        "30",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "60",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34577_ROOT_Abs_Handler"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "190",
        "190",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "362",
        "362",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34578_ROOT_WebTicket"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "1",
        "0",
        "0",
        "68",
        "68",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "155",
        "155",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "86",
        "86",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "41",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34578_ROOT_Abs_Handler"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "10",
        "10",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "18",
        "18",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2",
        "2",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2",
        "0",
        "0",
        "0",
    ],
    [
        '"LM_W3SVC_34577_ROOT_Autodiscover"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "11",
        "11",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "50",
        "50",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "7",
        "7",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "18",
        "0",
        "0",
        "0",
    ],
    ["[LS:Ats - Planning]"],
    [
        "instance",
        "Ats - Total number of incoming calls",
        "Ats - Number of current active calls",
        "Ats - Total number of failed calls",
    ],
    ['""', "10", "0", "0"],
    ["[LS:A/V Auth - Requests]"],
    [
        "instance",
        "- Credentials Issued",
        "- Credentials Issued/sec",
        "- Bad Requests Received",
        "- Bad Requests Received/sec",
        "- Current requests serviced",
    ],
    ['""', "0", "0", "0", "0", "0"],
    ["[LS:AVMCU - Informational]"],
    [
        "instance",
        "AVMCU - Total SIP BYE Sent",
        "AVMCU - Total SIP INVITE Sent",
        "AVMCU - Total SIP INVITE Received",
        "AVMCU - Total SIP REINVITE Sent",
        "AVMCU - Total SIP REINVITE Received",
        "AVMCU - Total SIP INVITE Accepted",
        "AVMCU - Total SIP INVITE Rejected",
        "AVMCU - Total SIP REINVITE Accepted",
        "AVMCU - Total SIP REINVITE Rejected",
        "AVMCU - Total Picture Freeze/Fast Update Request Sent",
        "AVMCU - Total SIP Invites rejected due to Bandwidth restrictions",
        "AVMCU - Total MRAS Request",
        "AVMCU - Total MRAS Request error",
        "AVMCU - Total MRAS Responses Received",
        "AVMCU - Total MRAS Requests Rejected",
        "AVMCU - Total MRAS Timeout Exceptions",
        "AVMCU - Total MRAS Failure Response Exceptions",
        "AVMCU - Total MRAS Real Time Exceptions",
        "AVMCU - Total MRAS Generic Exceptions",
        "AVMCU - Total QOE Reports Sent",
        "AVMCU - Total QoE Requests Sent",
        "AVMCU - Total QoE Responses Received",
        "AVMCU - Total QOE Reports Rejected",
        "AVMCU - Total QoE Request Errors",
        "AVMCU - Total QoE Timeout Exceptions",
        "AVMCU - Total QoE Failure Response Exceptions",
        "AVMCU - Total QoE Real Time Exceptions",
        "AVMCU - Total QoE Generic Exceptions",
        "AVMCU - Total CCCP AddUser Request",
        "AVMCU - Total CCCP AddUser Response",
        "AVMCU - Total CCCP AddConference Request",
        "AVMCU - Total CCCP AddConference Response",
        "AVMCU - Total Mediation Server Media Bypass Calls",
    ],
    [
        '""',
        "20",
        "13",
        "51",
        "68",
        "81",
        "51",
        "0",
        "81",
        "0",
        "0",
        "0",
        "66",
        "0",
        "66",
        "0",
        "0",
        "0",
        "0",
        "0",
        "55",
        "55",
        "55",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "66",
        "0",
        "37",
        "37",
        "0",
    ],
    ["[LS:BACKUP - Presence / Focus related Module]"],
    [
        "instance",
        "BACKUP - Steady sync state",
        "BACKUP - Time of last acknowledged steady sync",
        "BACKUP - Number of batches exported",
        "BACKUP - Number of batches pre-fetched",
        "BACKUP - Number of export operation failures",
        "BACKUP - Latency in milliseconds of exporting data",
        " ",
        "BACKUP - Latency in milliseconds of whole export task",
        " ",
        "BACKUP - Number of batches imported",
        "BACKUP - Number of batches partially imported",
        "BACKUP - Number of import operation failures",
        "BACKUP - Latency in milliseconds of importing data",
        " ",
        "BACKUP - Latency in milliseconds of whole import task",
        " ",
        "BACKUP - Number of data zip files created",
        "BACKUP - Amount of zipped data in KiB in last batch",
        "BACKUP - Total amount of zipped data in KiB",
        "BACKUP - Latency in milliseconds of zipping data",
        " ",
        "BACKUP - Latency in milliseconds of sending zipped data",
        " ",
        "BACKUP - Number of batches received in backup pool",
        "BACKUP - Latency in milliseconds of unzipping data",
        " ",
        "BACKUP - Latency in milliseconds of zipping cookie",
        " ",
        "BACKUP - Latency in milliseconds of sending zipped cookie",
        " ",
        "BACKUP - Latency in milliseconds of unzipping cookie",
        " ",
        "BACKUP - Number of handled exceptions encountered in export operation",
        "BACKUP - Number of unhandled exceptions encountered in export operation",
        "BACKUP - Number of handled exceptions encountered in import operation",
        "BACKUP - Number of unhandled exceptions encountered in import operation",
        "BACKUP - Number of full sync export operations",
        "BACKUP - Number of documents successfully exported",
        "BACKUP - Number of documents successfully exported in last batch",
        "BACKUP - Number of documents successfully imported",
        "BACKUP - Number of documents successfully imported in last batch",
        "BACKUP - Number of changes successfully exported",
        "BACKUP - Number of changes successfully exported in last sync",
        "BACKUP - Number of changes successfully imported",
        "BACKUP - Number of changes successfully imported in last sync",
        "BACKUP - Number of changes failed to import",
        "BACKUP - Number of changes failed to import in last sync",
        "BACKUP - Number of retriable database import operaton failures",
        "BACKUP - Number of retriable database import operaton failures in last sync",
        "BACKUP - Number of changes available for export in last sync",
        "BACKUP - Number of changes available for export in last second sync",
        "BACKUP - Number of changes available for export in last sync for high priority queue",
        "BACKUP - Number of changes successfully exported for high priority queue",
        "BACKUP - Number of changes successfully exported in last sync for high priority queue",
        "BACKUP - Number of documents successfully exported for high priority queue",
        "BACKUP - Number of documents successfully exported in last sync for high priority queue",
        "BACKUP - Steady sync state for high priority queue",
        "BACKUP - Time of last acknowledged steady sync for high priority queue",
        "BACKUP - Time of earliest change available for export in last sync",
        "BACKUP - Time of earliest change available for export in last sync for high priority queue",
    ],
    [
        '""',
        "1",
        "1460464931",
        "1195",
        "0",
        "0",
        "14893",
        "1195",
        "47780",
        "1195",
        "0",
        "0",
        "0",
        "0",
        "0",
        "288400",
        "14297",
        "1195",
        "6",
        "10143",
        "2982",
        "1195",
        "9808",
        "1195",
        "0",
        "0",
        "0",
        "26173",
        "14297",
        "125224",
        "14297",
        "85176",
        "29780",
        "0",
        "1",
        "0",
        "0",
        "0",
        "1468",
        "0",
        "0",
        "0",
        "1402",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "47",
        "0",
        "47",
        "0",
        "1",
        "1460464931",
        "1460464931",
        "1460464931",
    ],
    ["[LS:USrv - Cluster Manager]"],
    [
        "instance",
        "USrv - Number of times any primary cluster was detected as down",
        "USrv - Whether server is connected to fabric pool manager",
        "USrv - Number of Reconnections to Fabric Pool Manager",
        "USrv - Number of routing groups for which the current machine is primary replica",
        "USrv - Number of routing groups for which the current machine is active secondary replica",
        "USrv - Number of routing groups for which the current machine is idle secondary replica",
        "USrv - Number of replication operations sent to other Replicas",
        "USrv - Number of replication operations sent to other Replicas per second",
        "USrv - Total bytes transferred as replication operations",
        "USrv - Number of replication operations sent to other Replicas which failed",
        "USrv - Number of failures of replication operations sent to other Replicas per second",
        "USrv - Number of copy operations sent to other Replicas",
        "USrv - Total bytes transferred as copy operations",
        "USrv - Number of replication operations received from Master",
        "USrv - Number of replication operations received from Master per second",
        "USrv - Total bytes received as replication operations",
        "USrv - Number of received replication operations which could not be applied successfully",
        "USrv - Number of failed replication operations per second",
        "USrv - Number of copy operations received from Master",
        "USrv - Total bytes received as copy operations",
        "USrv - Number of copy operations received from Master which could not be successfully applied",
        "USrv - Number of active sync from backup store calls",
        "USrv - Number of sync from backup store calls",
        "USrv - Number of failed sync from backup store calls",
        "USrv - Number of sync from backup store calls which were throttled",
        "USrv - Number of data loss events with state change",
        "USrv - Number of data loss events without state change",
        "USrv - Replication operations which have not yet completed",
        "USrv - Replication operations which are currently queued on secondary",
        "USrv - Copy operations which are currently queued on secondary",
        "USrv - Replication operations which are currently queued on primary",
        "USrv - Replicas Pending Role Transition",
        "USrv - Number Of Pending Create Service Calls",
        "USrv - Current Connected Fabric Process Id",
        "USrv - Number of full replica rebuilds that have been performed",
        "USrv - Number of incremental replica rebuilds that have been performed",
        "USrv - Number of write requests that were denied due to lack of write quorum",
        "USrv - Number of write requests that were denied due to pending reconfiguration",
        "USrv - Number of write requests that were denied due to other errors",
        "USrv - Number of requests that were denied due to replication queue throttling",
        "USrv - Idle Secondary replicas which have been throttled",
        "USrv - Update Epoch calls which are waiting for the operation queue to become empty",
        "USrv - Total number of routing group hydration calls",
        "USrv - Total number of routing group hydration calls which failed",
        "USrv - Number of routing group hydration calls which are currently active",
        "USrv - Number of routing group hydration calls which were cancelled",
        "USrv - Number of routing group hydration calls which timed out",
    ],
    [
        '""',
        "0",
        "1",
        "1",
        "10",
        "0",
        "0",
        "2498",
        "2498",
        "33132091",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "10",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "22820",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:USrv - Https Transport]"],
    [
        "instance",
        "USrv - Active HTTPS connections",
        "USrv - Connections Opened / Sec",
        "USrv - Number of failed connection attempts",
        "USrv - Number of failed connection attempts / Sec",
        "USrv - Outstanding receive operations",
        "USrv - Number of incoming HTTPS requests",
        "USrv - Number of incoming HTTPS requests / Sec",
        "USrv - Number of failed incoming HTTPS requests",
        "USrv - Number of incoming 400 HTTP responses",
        "USrv - Number of incoming 500 HTTP responses",
        "USrv - Number of outgoing HTTPS requests",
        "USrv - Number of outgoing HTTPS requests / Sec",
        "USrv - Outstanding HTTPS requests",
        "USrv - Average Outgoing Queue Delay (ms)",
        " ",
        "USrv - Number of outgoing requests that timed out",
        "USrv - Number of outgoing requests that timed out / Sec",
        "USrv - Number of failed outgoing HTTPS requests",
        "USrv - Number of outgoing 400 HTTP responses",
        "USrv - Number of outgoing 500 HTTP responses",
        "USrv - Number of cached certificates",
        "USrv - Number of certificate cache misses",
        "USrv - Number of certificate cache hits",
        "USrv - Outstanding Active transactions",
        "USrv - Transactions Timed-Out",
        "USrv - Transactions Timed-Out / sec",
        "USrv - Number of Request Resends",
    ],
    [
        '""',
        "2",
        "3",
        "0",
        "0",
        "20",
        "376843",
        "376862",
        "0",
        "0",
        "286",
        "375667",
        "375667",
        "0",
        "436198",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "2",
        "1623",
        "750920",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:SIP - Routing]"],
    [
        "instance",
        "SIP - Requests Routed By Static Routing Rule",
        "SIP - Requests Routed By Static Routing Rule / sec",
        "SIP - Requests Routed By Default Federation Routing Rule (Internal Servers only)",
        "SIP - Requests Routed By Default Federation Routing Rule / sec (Internal Servers only)",
        "SIP - Requests Routed By Access Edge Server Routing Rule (Access Edge Server only)",
        "SIP - Requests Routed By Access Edge Server Routing Rule / sec (Access Edge Server only)",
        "SIP - Requests Routed To Another Forest (Access Edge Server only)",
        "SIP - Requests Routed To Another Forest / sec (Access Edge Server only)",
        "SIP - Requests Routed By User Services Module",
        "SIP - Requests Routed By User Services Module / sec",
        "SIP - Requests Routed By Applications",
        "SIP - Requests Routed By Applications / sec",
        "SIP - Requests Routed By Route Headers From Authorized Server",
        "SIP - Requests Routed By Route Headers From Authorized Server / sec",
        "SIP - Requests Routed By Resolving Server GRUU",
        "SIP - Requests Routed By Resolving Server GRUU / sec",
        "SIP - Requests Routed By Signed Route Headers",
        "SIP - Requests Routed By Signed Route Headers / sec",
        "SIP - Incoming Requests Dropped Due To Bad Route Signature",
        "SIP - Incoming Responses Dropped Due To Bad Via",
        "SIP - Incoming Responses Dropped Due To Bad Record-Route Signature",
        "SIP - Incoming Requests Dropped Due To Unauthorized Referred-By User",
        "SIP - Incoming Requests Dropped Due To Bad Referred-By Identity",
        "SIP - Messages Dropped Due To Other Routing Failure",
        "SIP - Messages Dropped Due To Internal Error",
        "SIP - Routing Failures Due To User Not Homed In Local Forest (Access Edge Server in Service Deployment Only)",
        "SIP - Routing Failures Due To User Not Homed In Local Forest (Access Edge Server in Service Deployment Only) /Sec",
        "SIP - User Database Queries (Access Edge Server in Service Deployment Only)",
        "SIP - User Database Failures (Access Edge Server in Service Deployment Only)",
        "SIP - User Database Failures (Access Edge Server in Service Deployment Only) /Sec",
        "SIP - User Database Failure Ratio (Access Edge Server in Service Deployment Only)",
        "SIP - Average User Database Query Time (Access Edge Server in Service Deployment Only)",
        "",
    ],
    [
        '""',
        "0",
        "0",
        "220499",
        "220499",
        "0",
        "0",
        "0",
        "0",
        "787",
        "787",
        "13869",
        "13869",
        "301672",
        "301315",
        "7215",
        "7215",
        "146308",
        "146304",
        "10",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:USrv - Endpoint Cache]"],
    [
        "instance",
        "USrv - RegUser Objects in Cache",
        "USrv - Active Registered Users",
        "USrv - Active Registered Users In Resiliency",
        "USrv - Active Registered Endpoints",
        "USrv - Delegator objects in cache",
        "USrv - BSUB CSeq misses",
        "USrv - BSUB CSeq misses/Sec",
        "USrv - BSUB CSeq failures",
        "USrv - Cache objects invalidated by AD attribute changes",
        "USrv - Cache objects invalidated by routing",
        "USrv - USC Down CSeq hits",
        "USrv - USC Down CSeq misses",
    ],
    ['""', "82", "66", "0", "77", "2", "0", "0", "0", "16", "0", "0", "0"],
    ["[LS:USrv - Remote subscribe SQL calls]"],
    [
        "instance",
        "USrv - RtcBatchSubscribeCategoryList: calls/Sec (for remote subscribes)",
        "USrv - RtcBatchSubscribeCategoryList: Latency (msec) (for remote subscribes)",
        " ",
        "USrv - RtcBatchSubscribeCategoryList: calls (for remote subscribes)",
        "USrv - Average number of publishers per remote subscribe request",
        " ",
        "USrv - RtcBatchDemuxRemoteNotifications: calls/Sec",
        "USrv - RtcBatchDemuxRemoteNotifications: Latency (msec)",
        " ",
        "USrv - RtcBatchDemuxRemoteNotifications: calls total",
        "USrv - Average number of subscribers per remote notify request",
        " ",
        "USrv - Wait time for a remote notification request in the queue.",
        " ",
        "USrv - Number of remote notification requests waiting to be completed.",
        " ",
        "USrv - Number of requests in the call to RtcBatchDemuxRemoteNotifications.",
        " ",
        "USrv - Remote notification requests throttled by database store throttle.",
        "USrv - Remote notification requests throttled by database store throttle/Sec.",
        "USrv - Remote notification requests throttled by queue throttle.",
        "USrv - Remote notification requests throttled by queue throttle/Sec.",
        "USrv - RtcHealRemoteSubscriptions: calls/Sec",
        "USrv - RtcHealRemoteSubscriptions: Latency (msec)",
        " ",
        "USrv - RtcHealRemoteSubscriptions: calls total",
        "USrv - RtcExecuteSyncTask: calls/Sec",
        "USrv - RtcExecuteSyncTask: Latency (msec)",
        " ",
        "USrv - RtcExecuteSyncTask: calls total",
        "USrv - RtcOnSyncResponse: calls/Sec",
        "USrv - RtcOnSyncResponse: Latency (msec)",
        " ",
        "USrv - RtcOnSyncResponse: calls total",
        "USrv - RtcOnSyncRequest: calls/Sec",
        "USrv - RtcOnSyncRequest: Latency (msec)",
        " ",
        "USrv - RtcOnSyncRequest: calls total",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "23919",
        "27036",
        "23919",
        "23919",
        "2405",
        "70",
        "2405",
        "2405",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:USrv - NotifyPipe]"],
    [
        "instance",
        "USrv - Virtual subscriber count",
        "USrv - Virtual publisher count",
        "USrv - Incoming notify pipe count",
        "USrv - Outgoing notify pipe count",
        "USrv - Incoming pool targeted notify pipe count",
        "USrv - Outgoing pool targeted notify pipe count",
        "USrv - Active memory arena count.",
        "USrv - Total batch messages (outgoing)",
        "USrv - Total batch messages (outgoing) /Sec",
        "USrv - Active outgoing batch messages.",
        "USrv - Throttled batch messages (outgoing)",
        "USrv - Throttled batch messages (outgoing) /Sec",
        "USrv - Timed-out batch messages (outgoing)",
        "USrv - Timed-out batch messages (outgoing) /Sec",
        "USrv - Failed batch messages (outgoing)",
        "USrv - Failed batch messages (outgoing) /Sec",
        "USrv - Total batch messages (incoming)",
        "USrv - Total batch messages (incoming) /Sec",
        "USrv - Throttled batch messages (incoming)",
        "USrv - Throttled batch messages (incoming) /Sec",
        "USrv - Rejected batch messages (incoming)",
        "USrv - Rejected batch messages (incoming) /Sec",
        "USrv - Remote subscribe batch messages sent",
        "USrv - Remote subscribe messages batch sent /Sec",
        "USrv - Average number of messages per remote subscribe batch sent.",
        " ",
        "USrv - Active outgoing remote subscribe messages.",
        "USrv - Lifetime of an outgoing remote subscribe message (msec).",
        " ",
        "USrv - Remote subscribe messages batch received",
        "USrv - Remote subscribe messages batch received /Sec",
        "USrv - Average number of messages per remote subscribe batch received.",
        " ",
        "USrv - Active incoming remote subscribe messages.",
        "USrv - Lifetime of an incoming remote subscribe message (msec).",
        " ",
        "USrv - Remote notify batch messages sent",
        "USrv - Remote notify messages batch sent /Sec",
        "USrv - Average number of messages per remote notify batch sent.",
        " ",
        "USrv - Active outgoing remote notify messages.",
        "USrv - Lifetime of an outgoing remote notify message (msec).",
        " ",
        "USrv - Remote notify messages batch received",
        "USrv - Remote notify messages batch received /Sec",
        "USrv - Average number of messages per remote notify batch received.",
        " ",
        "USrv - Active incoming remote notify messages.",
        "USrv - Lifetime of an incoming remote notify message (msec).",
        " ",
        "USrv - Notify pipe sync request messages sent",
        "USrv - Notify pipe sync request messages sent /Sec",
        "USrv - Notify pipe sync request messages received",
        "USrv - Notify pipe sync request messages received /Sec",
        "USrv - Notify pipe sync response messages sent",
        "USrv - Notify pipe sync response messages sent /Sec",
        "USrv - Notify pipe sync response messages received",
        "USrv - Notify pipe sync response messages received /Sec",
        "USrv - Remote notify batch splits",
        "USrv - Remote notify batch splits / Sec",
        "USrv - Outgoing remote notify batch message size (bytes).",
        " ",
        "USrv - Outgoing remote notify message size (bytes).",
        "",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2964",
        "1472",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:PDP - Core - Total]"],
    [
        "instance",
        "PDP - BW Check Requests",
        "PDP - BW Check Requests/sec",
        "PDP - BW Check Requests with Unsupported Modality",
        "PDP - BW Check Requests  with Unsupported Modality/sec",
        "PDP - Failed BW Check Requests",
        "PDP - Failed BW Check Requests/sec",
        "PDP - BW Commit Request",
        "PDP - BW Commit Request/sec",
        "PDP - BW Commit Requests with Unsupported Modality",
        "PDP - BW Commit Requests  with Unsupported Modality/sec",
        "PDP - BW Update Requests",
        "PDP - BW Update Requests/sec",
        "PDP - Failed BW Update Requests",
        "PDP - Failed BW Update Requests/sec",
        "PDP - BW Return Requests",
        "PDP - BW Return Requests/sec",
        "PDP - Active BW Reservations",
        "PDP - Congested Links",
        "PDP - Timed-out BW Reservations",
        "PDP - Timed-out BW Reservations/sec",
        "PDP - Local BW Commit Requests Not Managed",
        "PDP - Local BW Commit Requests Not Managed/sec",
        "PDP - BW Commit Requests Not Managed [IP Address Not Found]",
        "PDP - BW Commit Requests Not Managed/sec [IP Address Not Found]",
        "PDP - BW Commit Requests Not Managed [Modality Not Supported]",
        "PDP - BW Commit Requests Not Managed/sec [Modality Not Supported]",
        "PDP - BW Commit Requests with Reservation ID",
        "PDP - BW Commit Requests with Reservation ID/sec",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:XmppFederation - Subscription Limiting]"],
    [
        "instance",
        "XmppFederation - Max limit",
        "XmppFederation - Current total",
        "XmppFederation - Outbound rejected by server limit",
        "XmppFederation - Inbound rejected by server limit",
        "XmppFederation - Max limit per XMPP user",
        "XmppFederation - Inbound rejected by XMPP user limit",
    ],
    ['""', "0", "0", "0", "0", "0", "0"],
    ["[LS:USrv - SHAREDDBStore]"],
    [
        "instance",
        "USrv - Queue Depth",
        " ",
        "USrv - Queue Latency (msec)",
        " ",
        "USrv - Sproc Latency (msec)",
        " ",
        "USrv - % Database Time",
        " ",
        "USrv - Threads Waiting for New Database Requests",
        "USrv - Threads Executing Database Operations",
        "USrv - Threads Calling Back with Database Results",
        "USrv - Blocked Client Threads",
        " ",
        "USrv - Total Deadlocks",
        "USrv - Total Dropped Requests",
        "USrv - Total Deadlock Failures",
        "USrv - Total Transaction Count Mismatch Failures",
        "USrv - Total ODBC Timeout Failures",
        "USrv - Total severe SQL errors",
        "USrv - Total fatal SQL errors",
        "USrv - Throttled requests/sec",
        "USrv - Total throttled requests",
        "USrv - Database connection status",
        "USrv - Sproc Calls/sec",
        "USrv - Total sproc calls",
    ],
    [
        '""',
        "7",
        "335413",
        "5648",
        "335415",
        "226516",
        "335415",
        "957016",
        "9730",
        "5",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "311486",
        "311486",
    ],
    ["[LS:BACKUP - Central Management Module]"],
    [
        "instance",
        "BACKUP - Steady sync state",
        "BACKUP - Time of last acknowledged steady sync",
        "BACKUP - Number of batches exported",
        "BACKUP - Number of batches pre-fetched",
        "BACKUP - Number of export operation failures",
        "BACKUP - Latency in milliseconds of exporting data",
        " ",
        "BACKUP - Latency in milliseconds of whole export task",
        " ",
        "BACKUP - Number of batches imported",
        "BACKUP - Number of batches partially imported",
        "BACKUP - Number of import operation failures",
        "BACKUP - Latency in milliseconds of importing data",
        " ",
        "BACKUP - Latency in milliseconds of whole import task",
        " ",
        "BACKUP - Number of data zip files created",
        "BACKUP - Amount of zipped data in KiB in last batch",
        "BACKUP - Total amount of zipped data in KiB",
        "BACKUP - Latency in milliseconds of zipping data",
        " ",
        "BACKUP - Latency in milliseconds of sending zipped data",
        " ",
        "BACKUP - Number of batches received in backup pool",
        "BACKUP - Latency in milliseconds of unzipping data",
        " ",
        "BACKUP - Latency in milliseconds of zipping cookie",
        " ",
        "BACKUP - Latency in milliseconds of sending zipped cookie",
        " ",
        "BACKUP - Latency in milliseconds of unzipping cookie",
        " ",
        "BACKUP - Number of handled exceptions encountered in export operation",
        "BACKUP - Number of unhandled exceptions encountered in export operation",
        "BACKUP - Number of handled exceptions encountered in import operation",
        "BACKUP - Number of unhandled exceptions encountered in import operation",
        "BACKUP - Number of full sync export operations",
        "BACKUP - Number of documents successfully exported",
        "BACKUP - Number of documents successfully exported in last batch",
        "BACKUP - Number of documents successfully imported",
        "BACKUP - Number of documents successfully imported in last batch",
        "BACKUP - Number of changes successfully exported",
        "BACKUP - Number of changes successfully exported in last sync",
        "BACKUP - Number of changes successfully imported",
        "BACKUP - Number of changes successfully imported in last sync",
        "BACKUP - Number of changes available for export in last sync",
        "BACKUP - Number of changes available for export in last second sync",
    ],
    [
        '""',
        "1",
        "1460464931",
        "5729",
        "0",
        "0",
        "34595",
        "5729",
        "203297",
        "5729",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "5729",
        "1",
        "5785",
        "7287",
        "5729",
        "46038",
        "5729",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "90765",
        "34307",
        "1",
        "1",
        "0",
        "0",
        "1",
        "5762",
        "1",
        "0",
        "0",
        "5731",
        "1",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:REPAPPSVC - Sync Agent Processing]"],
    [
        "instance",
        "REPAPP - Batch Pull Sync",
        " local RTC DB XdsUpdateReplicaData: Latency (msec)",
        " ",
        "REPAPP - Batch Pull Sync",
        " local RTC DB XdsUpdateReplicaData: calls failed",
        "REPAPP - Batch Pull Sync",
        " local RTC DB XdsQueryReplicaStatus: Latency (msec)",
        " ",
        "REPAPP - Batch Pull Sync",
        " local RTC DB XdsQueryReplicaStatus: calls failed",
        "REPAPP - Push Sync",
        " Blob DB XdsPublishItems: calls total",
        "REPAPP - Batch Pull Sync",
        " Blob DB XdsQueryChanges: calls total",
        "REPAPP - Push Sync",
        " Blob DB low churn presence documents published total",
        "REPAPP - Push Sync",
        " Blob DB low churn presence documents deleted total",
        "REPAPP - Push Sync",
        " Blob DB high churn presence documents published total",
        "REPAPP - Push Sync",
        " Blob DB high churn presence documents deleted total",
        "REPAPP - Push Sync",
        " Blob DB user pin and certificate documents published total",
        "REPAPP - Push Sync",
        " Blob DB user pin and certificate documents deleted total",
        "REPAPP - Push Sync",
        " Blob DB static conferences published total",
        "REPAPP - Push Sync",
        " Blob DB static conferences deleted total",
        "REPAPP - Batch Pull Sync",
        " Blob DB enqueue sproc calls failed",
        "REPAPP - Batch Pull Sync",
        " local RTC DB enqueue sproc calls failed",
        "REPAPP - Doc Pull Sync",
        " local RTC DB XdspQueryReplicaCriticalDocuments: calls total",
        "REPAPP - Doc Pull Sync",
        " local RTC DB XdspQueryReplicaCriticalDocuments: Latency (msec)",
        "REPAPP - Doc Pull Sync",
        " local RTC DB XdspQueryReplicaCriticalDocuments: calls failed",
        "REPAPP - Doc Pull Sync",
        " Blob DB XdsQueryDocumentChanges: calls total",
        "REPAPP - Doc Pull Sync",
        " Blob DB XdsQueryDocumentChanges returned document count",
        "REPAPP - Doc Pull Sync",
        " Blob DB XdsQueryDocumentChanges: Latency (msec)",
        "REPAPP - Doc Pull Sync",
        " Blob DB XdsQueryDocumentChanges: calls failed",
        "REPAPP - Doc Pull Sync",
        " local RTC DB XdsUpdateDocumentData: calls total",
        "REPAPP - Doc Pull Sync",
        " local RTC DB XdsUpdateDocumentData: Latency (msec)",
        "REPAPP - Doc Pull Sync",
        " local RTC DB XdsUpdateDocumentData: calls failed",
        "REPAPP - Push Sync",
        " active cycle count",
        "REPAPP - Batch Pull Sync",
        " active cycle count",
        "REPAPP - Doc Pull Sync",
        " active cycle count",
    ],
    [
        '""',
        "706",
        "9",
        "0",
        "394351",
        "114401",
        "0",
        "1363",
        "114401",
        "1366",
        "3",
        "58",
        "3",
        "51",
        "3",
        "40",
        "3",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:XmppFederation - LookupUser calls]"],
    [
        "instance",
        "XmppFederation - Calls",
        "XmppFederation - Calls/sec",
        "XmppFederation - Call latency (ms)",
        "XmppFederation - User-known responses",
        "XmppFederation - User-known repsonses/sec",
        "XmppFederation - User-unknown responses",
        "XmppFederation - User-unknown repsonses/sec",
        "XmppFederation - Call failures",
        "XmppFederation - Call failures/sec",
        "XmppFederation - Calls outstanding",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:StoreWeb - Store Web Handler]"],
    [
        "instance",
        "STOREWEB - Incoming requests to Handler",
        "STOREWEB - Incoming requests per second to Handler",
        "STOREWEB - Requests for which Response Status is not Success",
        "STOREWEB - Failed calls to the Storage Service",
        "STOREWEB - Failed calls to the Storage Service per second",
        "STOREWEB - Total number of notifications routed",
        "STOREWEB - Notifications routed per second",
        "STOREWEB - Requests without a destination server",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:WEB - Location Information Service]"],
    [
        "instance",
        "WEB - Succeeded Get Locations Requests",
        "WEB - Succeeded Get Locations Requests/Second",
        "WEB - Average processing time for a successful Get Locations request in milliseconds",
        " ",
        "WEB - Failed Get Locations Requests",
        "WEB - Failed Get Locations Requests/Second",
        "WEB - Location matches by WAP",
        "WEB - Location matches by WAP/Second",
        "WEB - Location matches by Subnet",
        "WEB - Location matches by Subnet/Second",
        "WEB - Location matches by Switch",
        "WEB - Location matches by Switch/Second",
        "WEB - Location matches by Port",
        "WEB - LocationMatchesByPort/Second",
        "WEB - Location matches by MAC",
        "WEB - Location matches by MAC/Second",
        "WEB - Succeeded Get Locations In City Requests",
        "WEB - Succeeded Get Locations In City Requests/Second",
        "WEB - Average processing time for a successful Get Locations In City request in milliseconds",
        " ",
        "WEB - Failed Get Locations In City Requests",
        "WEB - Failed Get Locations In City Requests/Second",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "225",
        "225",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:USrv - URDBStore]"],
    [
        "instance",
        "USrv - Queue Depth",
        " ",
        "USrv - Queue Latency (msec)",
        " ",
        "USrv - Sproc Latency (msec)",
        " ",
        "USrv - % Database Time",
        " ",
        "USrv - Threads Waiting for New Database Requests",
        "USrv - Threads Executing Database Operations",
        "USrv - Threads Calling Back with Database Results",
        "USrv - Blocked Client Threads",
        " ",
        "USrv - Total Deadlocks",
        "USrv - Total Dropped Requests",
        "USrv - Total Deadlock Failures",
        "USrv - Total Transaction Count Mismatch Failures",
        "USrv - Total ODBC Timeout Failures",
        "USrv - Total severe SQL errors",
        "USrv - Total fatal SQL errors",
        "USrv - Throttled requests/sec",
        "USrv - Total throttled requests",
        "USrv - Database connection status",
        "USrv - Sproc Calls/sec",
        "USrv - Total sproc calls",
    ],
    [
        '""',
        "0",
        "143858",
        "2644",
        "143858",
        "161392",
        "143858",
        "444639",
        "4494",
        "10",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "143858",
        "143858",
    ],
    ["[LS:USrv - Unified Contact Store]"],
    [
        "instance",
        "USrv - Number of users selected for contact migration to Exchange",
        "USrv - SetUcsMode: calls/Sec",
        "USrv - SetUcsMode: Latency (msec)",
        " ",
        "USrv - SetUcsMode: calls total",
        "USrv - RollbackUcs: calls/Sec",
        "USrv - RollbackUcs: Latency (msec)",
        " ",
        "USrv - RollbackUcs: calls total",
        "USrv - OnUcsNotification: calls/Sec",
        "USrv - OnUcsNotification: Latency (msec)",
        " ",
        "USrv - OnUcsNotification: calls total",
        "USrv - RtcTerminateContactSubscription: calls/Sec",
        "USrv - RtcTerminateContactSubscription: Latency (msec)",
        " ",
        "USrv - RtcTerminateContactSubscription: calls total",
        "USrv - RtcTerminateContactSubscription: calls failed",
        "USrv - RtcMigrateContacts: calls/Sec",
        "USrv - RtcMigrateContacts: Latency (msec)",
        " ",
        "USrv - RtcMigrateContacts: calls total",
        "USrv - Number of successful user migrations to Unified Contact Store",
        "USrv - Number of failed user migrations to Unified Contact Store",
        "USrv - Number of user migrations to Unified Contact Store not accounted for",
        "USrv - Number of failed user migrations to Unified Contact Store",
        "USrv - Number of failed user migrations to Unified Contact Store due to http request failures",
        "USrv - Number of failed user migrations to Unified Contact Store due to http request time outs",
        "USrv - Number of failed user migrations to Unified Contact Store due to unknown reason",
        "USrv - Number of failed user migrations to Unified Contact Store due to oauth errors",
        "USrv - Number of failed user migrations to Unified Contact Store due to store configuration errors",
        "USrv - Number of failed user migrations to Unified Contact Store due to unsupported store errors",
        "USrv - Number of failed user migrations to Unified Contact Store due to autodiscover errors",
        "USrv - Number of failed user migrations to Unified Contact Store due to malformed requests",
        "USrv - Number of failed user migrations to Unified Contact Store due to malformed responses from Exchange",
        "USrv - Number of failed user migrations to Unified Contact Store due to malformed AddNewImContactToGroupResponses from Exchange",
        "USrv - Number of failed user migrations to Unified Contact Store due to invalid user info error",
        "USrv - Number of failed user migrations to Unified Contact Store due to access denied error",
        "USrv - Number of failed user migrations to Unified Contact Store due to mailbox version error",
        "USrv - Number of failed user migrations to Unified Contact Store with disabled user account error",
        "USrv - Number of failed user migrations to Unified Contact Store due to connection failures",
        "USrv - Number of failed user migrations to Unified Contact Store with invalid mailbox error",
        "USrv - Number of failed user migrations to Unified Contact Store with invalid smtp address error",
        "USrv - Number of failed user migrations to Unified Contact Store with quota exceeded error",
        "USrv - Number of failed user migrations to Unified Contact Store with max groups exceeded error",
        "USrv - Number of failed user migrations to Unified Contact Store due to failed ucs mode transition",
        "USrv - Number of failed user migrations to Unified Contact Store due to failure to set the ucs mode",
        "USrv - Number of successful contact subscriptions to Exchange",
        "USrv - Number of successful contact unsubscriptions to Exchange",
        "USrv - Number of failed contact subscriptions to Exchange due to http request failures",
        "USrv - Number of failed contact subscriptions to Exchange due to http request time outs",
        "USrv - Number of failed contact unsubscriptions to Exchange due to http request failures",
        "USrv - Number of failed contact unsubscriptions to Exchange due to http request time outs",
        "USrv - Number of failed contact subscriptions to Exchange due to unknown reason",
        "USrv - Number of failed contact subscriptions to Exchange due to oauth errors",
        "USrv - Number of failed contact subscriptions to Exchange due to store configuration errors",
        "USrv - Number of failed contact subscriptions to Exchange due to unsupported store errors",
        "USrv - Number of failed contact subscriptions to Exchange due to autodiscover errors",
        "USrv - Number of failed contact subscriptions to Exchange with invalid user info reason",
        "USrv - Number of failed contact subscriptions to Exchange with malformed request error",
        "USrv - Number of failed contact subscriptions to Exchange because of malformed subscription responses from Exchange",
        "USrv - Number of failed contact subscriptions to Exchange with account disabled reason",
        "USrv - Number of failed contact subscriptions to Exchange with access denied reason",
        "USrv - Number of failed contact subscriptions to Exchange with invalid mailbox version reason",
        "USrv - Number of failed contact subscriptions to Exchange due to connection failures",
        "USrv - Number of failed contact subscriptions to Exchange with invalid smtp address error",
        "USrv - Number of failed contact subscriptions to Exchange with invalid mailbox error",
        "USrv - Number of failed contact subscriptions to Exchange as the mailbox failovers were in progress",
        "USrv - Number of failed contact subscriptions to Exchange as the mailbox moves were in progress",
        "USrv - Number of failed contact subscriptions to Exchange due to max contact limit exceeded error",
        "USrv - Number of failed contact subscriptions to Exchange due to max group limit exceeded error",
        "USrv - Number of failed contact subscriptions to Exchange while establishing subscriptions due to service request error",
        "USrv - Number of failed contact subscriptions to Exchange while establishing subscriptions due to unknown error",
        "USrv - Number of failed contact subscriptions to Exchange due to unknown error while reading subscription response",
        "USrv - Number of failed contact subscription teardowns on Exchange due to service request error",
        "USrv - Number of failed contact subscription teardowns on Exchange due to unknown error",
        "USrv - Number of failed contact subscriptions to Exchange",
        "USrv - Number of failed contact notifications from Exchange due to unknown reason",
        "USrv - Number of failed contact notifications from Exchange due to oauth errors",
        "USrv - Number of failed contact notifications from Exchange due to store configuration errors",
        "USrv - Number of failed contact notifications from Exchange due to unsupported store errors",
        "USrv - Number of failed contact notifications from Exchange due to autodiscover errors",
        "USrv - Number of failed contact notifications from Exchange because of malformed responses from Exchange",
        "USrv - Number of failed contact notifications from Exchange with account disabled reason",
        "USrv - Number of failed contact notifications from Exchange with invalid mailbox version reason",
        "USrv - Number of failed contact notifications from Exchange due to connection failures",
        "USrv - Number of failed contact notifications from Exchange with invalid smtp address error",
        "USrv - Number of failed contact notifications from Exchange with invalid mailbox error",
        "USrv - Number of failed contact notifications from Exchange as the mailbox failovers were in progress",
        "USrv - Number of failed contact notifications from Exchange as the mailbox moves were in progress",
        "USrv - Number of contact notifications indicating exchange subscription or heartbeat timeout",
        "USrv - Number of contact notifications from Exchange where the contact list generation failed",
        "USrv - Number of failed contact notifications from Exchange",
        "USrv - Number of successful contact notifications from Exchange delivered to clients",
        "USrv - Number of failed contact unsubscriptions to Exchange",
        "USrv - Number of Unified Contact Store roll back calls received",
        "USrv - Number of successful Unified Contact Store roll backs",
        "USrv - Number of successful Unified Contact Store roll backs when the user was in migrated mode",
        "USrv - Number of successful Unified Contact Store roll backs when the user was not in migrated mode",
        "USrv - Number of successful Unified Contact Store roll backs using force when the user was in migrated mode",
        "USrv - Number of failed Unified Contact Store roll backs",
        "USrv - Number of failed Unified Contact Store roll backs as the user was currently being migrated",
        "USrv - Number of failed Unified Contact Store roll backs as the contact list was missing",
        "USrv - Number of failed Unified Contact Store roll backs due to user not found or available error",
        "USrv - Number of failed Unified Contact Store roll backs due to roll back sproc failure",
        "USrv - Number of failed user roll backs from Unified Contact Store due to failed replication",
    ],
    [
        '""',
        "11",
        "11",
        "142",
        "11",
        "11",
        "0",
        "0",
        "0",
        "0",
        "286",
        "617",
        "286",
        "286",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2404",
        "543",
        "2404",
        "2404",
        "11",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "286",
        "63",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "322",
        "0",
        "322",
        "286",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:REPAPPSVC - RepReplicaUpdateBatches sproc]"],
    ["instance", "REPAPP - Sproc Latency (msec)", "REPAPP - Number of calls"],
    ['""', "0", "0"],
    ["[LS:USrv - Service]"],
    [
        "instance",
        "USrv - SERVICE requests received",
        "USrv - SERVICE requests received/Sec",
        "USrv - Parser Objects Total",
        "USrv - Parser Objects In Use",
        "USrv - Add Group Objects Total",
        "USrv - Add Group Objects In Use",
        "USrv - Delete ACE Objects Total",
        "USrv - Delete ACE Objects In Use",
        "USrv - Delete Contact Objects Total",
        "USrv - Delete Contact Objects In Use",
        "USrv - Delete Group Objects Total",
        "USrv - Delete Group Objects In Use",
        "USrv - Directory Search Objects Total",
        "USrv - Directory Search Objects In Use",
        "USrv - Modify Group Objects Total",
        "USrv - Modify Group Objects In Use",
        "USrv - Set ACE Objects Total",
        "USrv - Set ACE Objects In Use",
        "USrv - Set Contact Objects Total",
        "USrv - Set Contact Objects In Use",
        "USrv - Set Presence Objects Total",
        "USrv - Set Presence Objects In Use",
        "USrv - Get Presence Objects Total",
        "USrv - Get Presence Objects In Use",
        "USrv - MWI NOTIFY error responses sent",
        "USrv - MWI NOTIFY error responses sent/Sec",
        "USrv - MWI NOTIFYs received",
        "USrv - MWI NOTIFYs received/Sec",
        "USrv - Total number of 3PP publications failed due to version conflict.",
        "USrv - 3PP PUBLISH requests received",
        "USrv - 3PP PUBLISH requests received/Sec",
        "USrv - 3PP PUBLISH error responses sent",
        "USrv - 3PP PUBLISH error responses sent/Sec",
        "USrv - Rich Presence publish failures",
        "USrv - Rich Presence publish failures per second",
        "USrv - Rich Presence publish successes",
        "USrv - Rich Presence publish successes per second",
        "USrv - Rich Presence publish internal failures",
        "USrv - Rich Presence publish internal failures per second",
        "USrv - Rich Presence publish failures - forbidden response",
        "USrv - Rich Presence publish failures per second - forbidden response",
        "USrv - Rich Presence publish failures - entity too large response",
        "USrv - Rich Presence publish failures per second - entity too large response",
        "USrv - Rich Presence publish failures - service unavailable response",
        "USrv - Rich Presence publish failures per second - service unavailable response",
        "USrv - Rich Presence publish failures - conflict response",
        "USrv - Rich Presence publish failures per second - conflict response",
        "USrv - Rich Presence publish failures - bad request response",
        "USrv - Rich Presence publish failures per second - bad request response",
        "USrv - Rich Presence publish failures - not acceptable here response",
        "USrv - Rich Presence publish failures per second - not acceptable here response",
        "USrv - Rich Presence publish failures - not found response",
        "USrv - Rich Presence publish failures per second - not found response",
        "USrv - Rich Presence publish failures - temp unavailable response",
        "USrv - Rich Presence publish failures per second - temp unavailable response",
        "USrv - Notification batch size",
        " ",
        "USrv - Notification batch interval",
        "",
    ],
    [
        '""',
        "42972",
        "42972",
        "1",
        "0",
        "1",
        "0",
        "0",
        "0",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "286",
        "286",
        "0",
        "0",
        "0",
        "0",
        "0",
        "739",
        "739",
        "40212",
        "40212",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "739",
        "739",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "4788000",
        "3192",
        "6294784",
        "3192",
    ],
    ["[LS:MediationServer - Global Per Gateway Counters]"],
    ["instance", "- Total failed calls caused by unexpected interaction from a gateway"],
    ['"_Total"', "0"],
    ['"pbwva-vgate01.intern.rossmann.de;trunk=pbwva-vgate01.intern.rossmann.de"', "0"],
    ['"pbwva-vgate01.intern.rossmann.de"', "0"],
    ["[LS:WEB - OAuth Token Manager API]"],
    [
        "instance",
        "WEB - Total number of OAuth Token Manager OAuth STS requests.",
        "WEB - Total number of OAuth Token Manager OAuth STS request failures.",
        "WEB - Total number of OAuth Token Manager OAuth authentication failures.",
        "WEB - Time acquiring ACS tokens in milliseconds",
        " ",
        "WEB - Time processing OAuth Token Manager OAuth STS requests.",
        " ",
        "WEB - Valid cached ACS tokens retrieved",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:LDM - LDM Memory]"],
    [
        "instance",
        "LDM - Allocated buffers/sec",
        "LDM - Freed buffers/sec",
        "LDM - Contention or spin waits/sec",
        "LDM - Buffer views allocated total",
        "LDM - Buffer views free in cache",
        "LDM - Small buffers allocated total",
        "LDM - Small buffers free in cache",
        "LDM - Medium buffers allocated total",
        "LDM - Medium buffers free in cache",
        "LDM - Large buffers allocated total",
        "LDM - Large buffers free in cache",
        "LDM - Composite buffers allocated total",
        "LDM - Composite buffers free in cache",
        "LDM - Non cacheable buffers allocations",
        "LDM - Non cacheable buffers releases",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:DATACOLLECTION - Legal Intercept Adaptor]"],
    [
        "instance",
        "UDC - Sessions Processed",
        "UDC - Processing Failed Sessions",
        "UDC - Emails Sent",
        "UDC - Email Sending Failures",
        "UDC - Max Retried Sessions",
        "UDC - Send Email latency (ms)",
        "",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:SIP - Requests]"],
    [
        "instance",
        "SIP - Incoming ACK Requests",
        "SIP - Incoming ACK Requests /Sec",
        "SIP - Incoming BYE Requests",
        "SIP - Incoming BYE Requests /Sec",
        "SIP - Incoming CANCEL Requests",
        "SIP - Incoming CANCEL Requests /Sec",
        "SIP - Incoming INFO Requests",
        "SIP - Incoming INFO Requests /Sec",
        "SIP - Incoming INVITE Requests",
        "SIP - Incoming INVITE Requests /Sec",
        "SIP - Incoming MESSAGE Requests",
        "SIP - Incoming MESSAGE Requests /Sec",
        "SIP - Incoming NEGOTIATE Requests",
        "SIP - Incoming NEGOTIATE Requests /Sec",
        "SIP - Incoming NOTIFY Requests",
        "SIP - Incoming NOTIFY Requests /Sec",
        "SIP - Incoming OPTION Requests",
        "SIP - Incoming OPTION Requests /Sec",
        "SIP - Incoming REFER Requests",
        "SIP - Incoming REFER Requests /Sec",
        "SIP - Incoming REGISTER Requests",
        "SIP - Incoming REGISTER Requests /Sec",
        "SIP - Incoming SERVICE Requests",
        "SIP - Incoming SERVICE Requests /Sec",
        "SIP - Incoming SUBSCRIBE Requests",
        "SIP - Incoming SUBSCRIBE Requests /Sec",
        "SIP - Incoming BENOTIFY Requests",
        "SIP - Incoming BENOTIFY Requests /Sec",
        "SIP - Incoming PUBLISH Requests",
        "SIP - Incoming PUBLISH Requests /Sec",
        "SIP - Incoming OTHER Requests",
        "SIP - Incoming OTHER Requests /Sec",
        "SIP - Local NOTIFY Requests",
        "SIP - Local NOTIFY Requests /Sec",
        "SIP - Local BENOTIFY Requests",
        "SIP - Local BENOTIFY Requests /Sec",
        "SIP - Local INFO Requests",
        "SIP - Local INFO Requests /Sec",
        "SIP - Local BYE Requests",
        "SIP - Local BYE Requests /Sec",
        "SIP - Local CANCEL Requests",
        "SIP - Local CANCEL Requests /Sec",
        "SIP - Incoming ACK Requests proxied",
        "SIP - Incoming ACK Requests Proxied /Sec",
        "SIP - Incoming BYE Requests proxied",
        "SIP - Incoming BYE Requests Proxied /Sec",
        "SIP - Incoming CANCEL Requests proxied",
        "SIP - Incoming CANCEL Requests Proxied /Sec",
        "SIP - Incoming INFO Requests proxied",
        "SIP - Incoming INFO Requests Proxied /Sec",
        "SIP - Incoming INVITE Requests proxied",
        "SIP - Incoming INVITE Requests Proxied /Sec",
        "SIP - Incoming MESSAGE Requests proxied",
        "SIP - Incoming MESSAGE Requests Proxied /Sec",
        "SIP - Incoming NOTIFY Requests proxied",
        "SIP - Incoming NOTIFY Requests Proxied /Sec",
        "SIP - Incoming OPTION Requests proxied",
        "SIP - Incoming OPTION Requests Proxied /Sec",
        "SIP - Incoming REFER Requests proxied",
        "SIP - Incoming REFER Requests Proxied /Sec",
        "SIP - Incoming SERVICE Requests proxied",
        "SIP - Incoming SERVICE Requests Proxied /Sec",
        "SIP - Incoming REGISTER Requests proxied",
        "SIP - Incoming REGISTER Requests Proxied /Sec",
        "SIP - Incoming SUBSCRIBE Requests proxied",
        "SIP - Incoming SUBSCRIBE Requests Proxied /Sec",
        "SIP - Incoming BENOTIFY Requests proxied",
        "SIP - Incoming BENOTIFY Requests Proxied /Sec",
        "SIP - Incoming PUBLISH Requests proxied",
        "SIP - Incoming PUBLISH Requests Proxied /Sec",
        "SIP - Incoming OTHER Requests proxied",
        "SIP - Incoming OTHER Requests Proxied /Sec",
    ],
    [
        '""',
        "6324",
        "6324",
        "5157",
        "5157",
        "109",
        "109",
        "161564",
        "161564",
        "6355",
        "6355",
        "3391",
        "3391",
        "53063",
        "53071",
        "10926",
        "10926",
        "55991",
        "55991",
        "1",
        "1",
        "22606",
        "22608",
        "73399",
        "73398",
        "355834",
        "355832",
        "18",
        "18",
        "0",
        "0",
        "274227",
        "274215",
        "16873",
        "16873",
        "220488",
        "220489",
        "261",
        "261",
        "3",
        "3",
        "338",
        "338",
        "6580",
        "6580",
        "3940",
        "3940",
        "1",
        "1",
        "161139",
        "161152",
        "6634",
        "6634",
        "3390",
        "3390",
        "9478",
        "9478",
        "0",
        "0",
        "1",
        "1",
        "4907",
        "4907",
        "0",
        "0",
        "223113",
        "223113",
        "18",
        "18",
        "0",
        "0",
        "271709",
        "271725",
    ],
    ["[LS:API - API Application Instance Counters]"],
    [
        "instance",
        "API - Transaction Events Processed/Sec",
        "API - Messages Processed/Sec",
        "API - Active Transactions Contexts",
        "API - Request Transactions Processed",
        "API - Response Transactions Processed",
        "API - ACK Transactions Processed",
        "API - BENOTIFY Transactions Processed",
        "API - Timeout Transactions Processed",
        "API - Cancel Transactions Processed",
        "API - Requests simple proxied from SPL",
        "API - Requests simple proxied from SPL/Sec",
        "API - Responses simple proxied from SPL",
        "API - Responses simple proxied from SPL/Sec",
        "API - Requests simple proxied from ServerAgent",
        "API - Requests simple proxied from ServerAgent/Sec",
        "API - Responses simple proxied from ServerAgent",
        "API - Responses simple proxied from ServerAgent/Sec",
        "API - Requests forwarded using forking proxy",
        "API - Requests forwarded using forking proxy/Sec",
        "API - Responses forwarded using forking proxy",
        "API - Responses forwarded using forking proxy/Sec",
        "API - Locally generated responses",
        "API - Application Script Errors",
        "API - System Errors Ignored",
        "API - Dispatch Notification Calls",
        "API - Dispatch Notification Calls/Sec",
        "API - Transactions Pending Dispatch Completion",
        "API - Dispatch calls timed out",
        "API - Dispatch Calls Timed out/Sec",
        "API - SA Write Queue Maximum Length",
        "API - SA Write Queue Length",
        "API - Queued SA Batches/Sec",
        "API - AS Read Queue Length",
        "API - Dequeued AS Batches/Sec",
        "API - SA Read Queue Length",
        "API - AS Write Queue Length",
        "API - SA Queue Free Bytes (KB)",
        "API - AS Queue Free Bytes (KB)",
        "API - Application Dispatch failures",
    ],
    [
        '"_Total"',
        "1989944",
        "1986035",
        "11",
        "1132779",
        "853715",
        "56",
        "1542",
        "290",
        "326",
        "824731",
        "824746",
        "771588",
        "771586",
        "275563",
        "275563",
        "48562",
        "48562",
        "13754",
        "13754",
        "21841",
        "21841",
        "25495",
        "0",
        "0",
        "4447",
        "4447",
        "18446744073709540870",
        "0",
        "0",
        "22000",
        "0",
        "661196",
        "0",
        "604759",
        "0",
        "11",
        "5577",
        "5621",
        "0",
    ],
    [
        '"UserPinService"',
        "4835",
        "4832",
        "0",
        "4836",
        "0",
        "0",
        "0",
        "0",
        "0",
        "4838",
        "4838",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2000",
        "0",
        "26395",
        "0",
        "26394",
        "0",
        "1",
        "511",
        "511",
        "0",
    ],
    [
        '"ExumRouting"',
        "7327",
        "7324",
        "0",
        "2352",
        "4821",
        "0",
        "0",
        "0",
        "3",
        "2338",
        "2338",
        "4867",
        "4867",
        "0",
        "0",
        "0",
        "0",
        "51",
        "51",
        "20",
        "20",
        "53",
        "0",
        "0",
        "0",
        "0",
        "18446744073709551511",
        "0",
        "0",
        "2000",
        "0",
        "26589",
        "0",
        "26608",
        "0",
        "1",
        "511",
        "511",
        "0",
    ],
    [
        '"InterClusterRouting"',
        "494012",
        "493902",
        "2",
        "242380",
        "250638",
        "28",
        "762",
        "63",
        "36",
        "239855",
        "239856",
        "244562",
        "244559",
        "0",
        "0",
        "0",
        "0",
        "3317",
        "3317",
        "4059",
        "4059",
        "2121",
        "0",
        "0",
        "0",
        "0",
        "18446744073709545436",
        "0",
        "0",
        "2000",
        "0",
        "44177",
        "0",
        "36385",
        "0",
        "1",
        "510",
        "511",
        "0",
    ],
    [
        '"DefaultRouting"',
        "30779",
        "30422",
        "2",
        "13553",
        "16844",
        "28",
        "0",
        "36",
        "41",
        "9281",
        "9281",
        "9234",
        "9234",
        "0",
        "0",
        "0",
        "0",
        "3533",
        "3533",
        "3814",
        "3814",
        "2611",
        "0",
        "0",
        "0",
        "0",
        "18446744073709548283",
        "0",
        "0",
        "2000",
        "0",
        "33245",
        "0",
        "32363",
        "0",
        "1",
        "511",
        "511",
        "0",
    ],
    [
        '"IIMFilter"',
        "9747",
        "9631",
        "2",
        "9631",
        "0",
        "0",
        "0",
        "8",
        "0",
        "0",
        "0",
        "0",
        "0",
        "9631",
        "9631",
        "108",
        "108",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2000",
        "0",
        "33952",
        "0",
        "33951",
        "0",
        "1",
        "504",
        "511",
        "0",
    ],
    [
        '"TranslationService"',
        "81140",
        "79010",
        "1",
        "79072",
        "1886",
        "0",
        "0",
        "1",
        "81",
        "59271",
        "59273",
        "26",
        "26",
        "3",
        "3",
        "0",
        "0",
        "328",
        "328",
        "1558",
        "1558",
        "19551",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2000",
        "0",
        "61850",
        "0",
        "41508",
        "0",
        "1",
        "511",
        "511",
        "0",
    ],
    [
        '"ClientVersionFilter"',
        "46996",
        "46284",
        "2",
        "17877",
        "29012",
        "0",
        "0",
        "1",
        "0",
        "368",
        "368",
        "753",
        "753",
        "17548",
        "17548",
        "28366",
        "28366",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2000",
        "0",
        "57023",
        "0",
        "56720",
        "0",
        "1",
        "508",
        "511",
        "0",
    ],
    [
        '"OutboundRouting"',
        "18757",
        "18637",
        "0",
        "7536",
        "10943",
        "0",
        "0",
        "0",
        "62",
        "7288",
        "7288",
        "9973",
        "9973",
        "0",
        "0",
        "0",
        "0",
        "235",
        "235",
        "893",
        "893",
        "249",
        "0",
        "0",
        "0",
        "0",
        "18446744073709550488",
        "0",
        "0",
        "2000",
        "0",
        "28284",
        "0",
        "27870",
        "0",
        "1",
        "511",
        "511",
        "0",
    ],
    [
        '"UdcAgent"',
        "495096",
        "494879",
        "2",
        "242029",
        "252700",
        "0",
        "18",
        "111",
        "103",
        "215124",
        "215126",
        "215267",
        "215268",
        "19836",
        "19836",
        "19933",
        "19933",
        "6290",
        "6290",
        "11497",
        "11497",
        "910",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2000",
        "0",
        "89707",
        "0",
        "67432",
        "0",
        "1",
        "511",
        "511",
        "0",
    ],
    [
        '"XmppRouting"',
        "228770",
        "228541",
        "0",
        "227783",
        "0",
        "0",
        "762",
        "70",
        "0",
        "0",
        "0",
        "0",
        "0",
        "228545",
        "228545",
        "155",
        "155",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2000",
        "0",
        "229132",
        "0",
        "229134",
        "0",
        "1",
        "509",
        "511",
        "0",
    ],
    [
        '"XmppListener"',
        "572485",
        "572573",
        "0",
        "285730",
        "286871",
        "0",
        "0",
        "0",
        "0",
        "286368",
        "286378",
        "286906",
        "286906",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "4447",
        "4447",
        "0",
        "0",
        "0",
        "2000",
        "0",
        "30842",
        "0",
        "26394",
        "0",
        "1",
        "480",
        "511",
        "0",
    ],
    ["[LS:DATACOLLECTION - SQL Archiving Adaptor]"],
    [
        "instance",
        "UDC - Number of peer-to-peer sessions logged",
        "UDC - Number of peer-to-peer sessions logged per second",
        "UDC - Number of peer-to-peer sessions dropped",
        "UDC - Number of peer-to-peer sessions dropped per second",
        "UDC - Number of peer-to-peer sessions rejected",
        "UDC - Number of peer-to-peer sessions rejected per second",
        "UDC - Number of peer-to-peer messages logged",
        "UDC - Number of peer-to-peer messages dropped",
        "UDC - Number of conference sessions logged",
        "UDC - Number of conference sessions logged per second",
        "UDC - Number of conference sessions dropped",
        "UDC - Number of conference sessions dropped per second",
        "UDC - Number of conference sessions rejected",
        "UDC - Number of conference sessions rejected per second",
        "UDC - Number of conference activities logged",
        "UDC - Number of conference activities dropped",
        "UDC - Number of web conference activities logged",
        "UDC - Number of web conference activities dropped",
        "UDC - Number of conference messages logged",
        "UDC - Number of conference messages dropped",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:CPS - Call Park Service Hosting]"],
    [
        "instance",
        "CPS - Number of times the SQL server was called",
        "CPS - Number of the SQL server failures",
        "CPS - Number of times a new orbit was requested",
        "CPS - Number of the Orbit request failures",
    ],
    ['""', "57187", "0", "28592", "0"],
    ["[LS:PDP Auth - Requests]"],
    [
        "instance",
        "- Credentials Issued",
        "- Credentials Issued/sec",
        "- Bad Requests Received",
        "- Bad Requests Received/sec",
        "- Current requests serviced",
    ],
    ['""', "0", "0", "0", "0", "0"],
    ["[LS:Autodiscover - Autodiscover Service]"],
    [
        "instance",
        "AUTODISCOVER - RootResourceResponses",
        "AUTODISCOVER - DomainResourceResponses",
        "AUTODISCOVER - UserResourceResponses",
        "AUTODISCOVER - OAuthResourceResponses",
        "AUTODISCOVER - FederationDocumentResponses",
        "AUTODISCOVER - SplitDomainRedirects",
        "AUTODISCOVER - CrossForestRedirects",
        "AUTODISCOVER - FailedSplitDomainRedirects",
        "AUTODISCOVER - FailedCrossForestRedirects",
    ],
    ['""', "52", "0", "91", "0", "8", "0", "0", "0", "0"],
    ["[LS:DATAMCU - MCU Health And Performance]"],
    [
        "instance",
        "DATAMCU - HTTP Stack load",
        "DATAMCU - HTTP Stack state",
        "DATAMCU - Thread Pool Load",
        "DATAMCU - Thread Pool Health State",
        "DATAMCU - Thread Pool Unhandled Exceptions",
        "DATAMCU - MCU Health State",
        "DATAMCU - MCU Draining State",
        "DATAMCU - MCU Health State Changed Count",
        "DATAMCU - MCU Health DNS resolution failure Count",
        "DATAMCU - MCU Health DNS resolution succeeded Count",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0", "0", "1907"],
    ["[LS:USrv - Authorize delegate sproc]"],
    [
        "instance",
        "USrv - RtcAuthorizeDelegate: calls/Sec",
        "USrv - RtcAuthorizeDelegate: Latency (msec)",
        " ",
        "USrv - RtcAuthorizeDelegate: calls total",
    ],
    ['""', "565", "74", "565", "565"],
    ["[LS:USrv - Notify]"],
    [
        "instance",
        "USrv - NOTIFYs sent",
        "USrv - NOTIFYs sent/Sec",
        "USrv - BENOTIFYs sent",
        "USrv - BENOTIFYs sent/Sec",
        "USrv - Presence NOTIFYs sent",
        "USrv - Presence NOTIFYs sent/Sec",
        "USrv - Presence WPending NOTIFYs sent",
        "USrv - Presence WPending NOTIFYs sent/Sec",
        "USrv - Roaming Self NOTIFYs sent",
        "USrv - Roaming Self NOTIFYs sent/Sec",
        "USrv - Roaming Contact NOTIFYs sent",
        "USrv - Roaming Contact NOTIFYs sent/Sec",
        "USrv - Roaming ACL NOTIFYs sent",
        "USrv - Roaming ACL NOTIFYs sent/Sec",
        "USrv - Provisioning NOTIFYs sent",
        "USrv - Provisioning NOTIFYs sent/Sec",
        "USrv - Conferencing NOTIFYs sent",
        "USrv - Conferencing NOTIFYs sent/Sec",
        "USrv - Unsubscribed NOTIFYs sent",
        "USrv - Unsubscribed NOTIFYs sent/Sec",
        "USrv - Throttled NOTIFYs sent",
        "USrv - Throttled NOTIFYs sent/Sec",
        "USrv - NOTIFYs sent to subscriber in the same home server",
        "USrv - NOTIFYs sent to subscriber in the same home server/Sec",
        "USrv - NOTIFYs sent to subscriber in different home server",
        "USrv - NOTIFYs sent to subscriber in different home server/Sec",
        "USrv - NOTIFYs sent without request uri being set",
        "USrv - NOTIFYs sent without request uri being set/Sec",
        "USrv - NOTIFYs sent as a result of presence change",
        "USrv - NOTIFYs sent as a result of presence change/Sec",
        "USrv - NOTIFYs sent as a result of category publish",
        "USrv - NOTIFYs sent as a result of category publish/Sec",
        "USrv - NOTIFYs sent as a result of container change",
        "USrv - NOTIFYs sent as a result of container change/Sec",
        "USrv - NOTIFYs sent as a result of subscriber change",
        "USrv - NOTIFYs sent as a result of subscriber change/Sec",
        "USrv - NOTIFYs sent as a result of contact or group change",
        "USrv - NOTIFYs sent as a result of contact or group change/Sec",
        "USrv - NOTIFYs sent as a result of permission change",
        "USrv - NOTIFYs sent as a result of permission change/Sec",
        "USrv - NOTIFYs sent as a result of incoming subscribes",
        "USrv - NOTIFYs sent as a result of incoming subscribes/Sec",
        "USrv - NOTIFYs sent as a result of registration expiration",
        "USrv - NOTIFYs sent as a result of registration expiration/Sec",
        "USrv - NOTIFYs sent as a result of other reasons",
        "USrv - NOTIFYs sent as a result of other reasons/Sec",
        "USrv - NOTIFY responses",
        "USrv - NOTIFY responses/Sec",
        "USrv - NOTIFY failures received",
        "USrv - NOTIFY failures received/Sec",
        "USrv - Category NOTIFY failed due to unknown user or endpoint",
        "USrv - Category NOTIFY timeout received",
        "USrv - Category NOTIFY 48x responses received",
        "USrv - Category NOTIFY 504 responses received",
        "USrv - Category NOTIFY 500 responses received",
        "USrv - Category NOTIFY failure responses received",
        "USrv - Self NOTIFY failed due to unknown user or endpoint",
        "USrv - Self NOTIFY timeout received",
        "USrv - Self NOTIFY 48x responses received",
        "USrv - Self NOTIFY 504 responses received",
        "USrv - Self NOTIFY 500 responses received",
        "USrv - Self NOTIFY failure responses received",
        "USrv - Legacy presence NOTIFY failed due to unknown user or endpoint",
        "USrv - Legacy presence NOTIFY timeout received",
        "USrv - Legacy presence NOTIFY 48x responses received",
        "USrv - Legacy presence NOTIFY 504 responses received",
        "USrv - Legacy presence NOTIFY 500 responses received",
        "USrv - Legacy presence NOTIFY failure responses received",
        "USrv - Conferencing NOTIFY failed due to unknown user or endpoint",
        "USrv - Conferencing NOTIFY timeout received",
        "USrv - Conferencing NOTIFY 48x responses received",
        "USrv - Conferencing NOTIFY 504 responses received",
        "USrv - Conferencing NOTIFY 500 responses received",
        "USrv - Conferencing NOTIFY failure responses received",
        "USrv - Other NOTIFY failed due to unknown user or endpoint",
        "USrv - Other NOTIFY timeout received",
        "USrv - Other NOTIFY 48x responses received",
        "USrv - Other NOTIFY 504 responses received",
        "USrv - Other NOTIFY 500 responses received",
        "USrv - Other NOTIFY failure responses received",
        "USrv - Failed to send NOTIFY",
        "USrv - Failed to send NOTIFY/Sec",
        "USrv - NOTIFY timeouts",
        "USrv - NOTIFY timeouts/Sec",
        "USrv - NOTIFY batches skipped because another batch was running",
        "USrv - Notification Queue Highest Batch Latency",
        "USrv - Notification Queue Highest Queue Latency",
        "USrv - Notification Queue Average Queue Latency",
        "USrv - Notification Queue Size",
        "USrv - Local Notification Queue Highest Batch Latency",
        "USrv - Local Notification Queue Highest Queue Latency",
        "USrv - Local Notification Queue Average Queue Latency",
        "USrv - Local Notification Queue Size",
        "USrv - Remote Notification Queue Highest Batch Latency",
        "USrv - Remote Notification Queue Highest Queue Latency",
        "USrv - Remote Notification Queue Average Queue Latency",
        "USrv - Remote Notification Queue Size",
        "USrv - Calculated Congestion Level",
        "USrv - Average number of notifications per batch",
        "USrv - Average number of notification messages per batch",
        "USrv - The total number of notifications discarded due to an invalid document.",
    ],
    [
        '""',
        "238237",
        "238237",
        "221447",
        "221447",
        "187760",
        "187760",
        "0",
        "0",
        "48385",
        "48385",
        "346",
        "346",
        "0",
        "0",
        "0",
        "0",
        "1746",
        "1746",
        "2478",
        "2478",
        "0",
        "0",
        "238162",
        "238162",
        "74",
        "74",
        "0",
        "0",
        "0",
        "0",
        "50715",
        "50715",
        "153",
        "153",
        "56",
        "56",
        "38",
        "38",
        "0",
        "0",
        "5045",
        "5045",
        "0",
        "0",
        "182230",
        "182230",
        "15617",
        "15617",
        "1031",
        "1031",
        "16",
        "36",
        "26",
        "13",
        "0",
        "573",
        "142",
        "2",
        "8",
        "0",
        "0",
        "0",
        "0",
        "4",
        "410",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "134",
        "134",
        "42",
        "42",
        "2276",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2",
        "3",
        "3",
        "0",
    ],
    ["[LS:DATACOLLECTION - CDR Adaptor]"],
    [
        "instance",
        "UDC - Number of peer-to-peer sessions logged",
        "UDC - Number of peer-to-peer sessions logged per second",
        "UDC - Number of peer-to-peer sessions dropped",
        "UDC - Number of peer-to-peer sessions dropped per second",
        "UDC - Number of peer-to-peer sessions rejected",
        "UDC - Number of peer-to-peer sessions rejected per second",
        "UDC - Number of conference sessions logged",
        "UDC - Number of conference sessions logged per second",
        "UDC - Number of conference sessions dropped",
        "UDC - Number of conference sessions dropped per second",
        "UDC - Number of conference sessions rejected",
        "UDC - Number of conference sessions rejected per second",
        "UDC - Number of conference activities logged",
        "UDC - Number of conference activities dropped",
        "UDC - Number of conference sub-sessions logged",
        "UDC - Number of conference sub-sessions dropped",
        "UDC - Number of error reports logged",
        "UDC - Number of error reports logged per second",
        "UDC - Number of error reports dropped",
        "UDC - Number of error reports dropped per second",
        "UDC - Number of client registrations logged",
        "UDC - Number of client registrations logged per second",
        "UDC - Number of client registrations dropped",
        "UDC - Number of client registrations dropped per second",
        "UDC - Number of error reports throttled",
    ],
    [
        '""',
        "1382",
        "1382",
        "0",
        "0",
        "3",
        "3",
        "51",
        "51",
        "0",
        "0",
        "0",
        "0",
        "551",
        "0",
        "303",
        "0",
        "4359",
        "4359",
        "31",
        "31",
        "2026",
        "2026",
        "0",
        "0",
        "31",
    ],
    ["[LS:RoutingApps - Inter Cluster Routing]"],
    [
        "instance",
        "RoutingApps - Number of requests processed",
        "RoutingApps - Number of active requests processed",
        "RoutingApps - Number of primary registrar timeouts",
        "RoutingApps - Number of backup registrar timeouts",
        "RoutingApps - Number of requests rerouted to PSTN",
        "RoutingApps - Number of requests successfully rerouted to PSTN",
    ],
    ['""', "3317", "1", "0", "0", "0", "0"],
    ["[LS:MediationServer - Health Indices]"],
    ["instance", "- Load Call Failure Index"],
    ['""', "0"],
    ["[LS:SIP - External Edge Networking]"],
    [
        "instance",
        "SIP - Accepted External Client Connections",
        "SIP - Accepted External Client Connections /Sec",
        "SIP - Accepted Federated Partner Connections",
        "SIP - Accepted Federated Partner Connections /Sec",
        "SIP - External Connections Failed To Establish",
        "SIP - External Connections Failed To Establish /Sec",
        "SIP - External Connections Refused Due To Server Overload",
        "SIP - External Connections Refused Due To Server Overload /Sec",
        "SIP - Rejected Federated Partner Connections Due To Federation Disabled",
        "SIP - Rejected External Client Connections",
        "SIP - Rejected Remote User Client Connections /Sec",
        "SIP - Rejected Hosting Provider Connections.",
        "SIP - Successful DNS SRV queries",
        "SIP - Failed DNS SRV queries",
        "SIP - Timed out DNS SRV queries",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:SipEps - Sip Dialogs]"],
    [
        "instance",
        "SipEps - Active Dialogs",
        "SipEps - Dialogs Created",
        "SipEps - Dialogs Created /sec",
        "SipEps - CoreManagerQueueLength",
        "SipEps - CoreManagerMaximumQueueExecutionTime",
        "SipEps - CoreManagerTotalWorkitemsExecuted",
        "SipEps - NumberOfBrokenDialogs",
        "SipEps - NumberOfBrokenDialogsPerSecond",
        "SipEps - NumberOfHealedDialogs",
        "SipEps - NumberOfHealedDialogsPerSecond",
        "SipEps - NumberOfAttemptsToHealDialog",
        "SipEps - NumberOfAttemptsToHealDialogPerSecond",
        "SipEps - NumberOfFailedAttemptsToHealDialog",
        "SipEps - NumberOfFailedAttemptsToHealDialogPerSecond",
    ],
    [
        '"pbwvw-skype03.16124_avmcusvc_appdom_1"',
        "5",
        "82",
        "82",
        "0",
        "70",
        "469",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ['"_Total"', "30", "851", "851", "0", "1125", "327365", "0", "0", "0", "0", "0", "0", "0", "0"],
    [
        '"pbwvw-skype03.22372_ocsappserverhost_appdom_2"',
        "0",
        "48",
        "48",
        "0",
        "91",
        "11995",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.17128_ocsappserverhost_appdom_2"',
        "1",
        "1",
        "1",
        "0",
        "117",
        "19696",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.9112_mediationserversvc_appdom_1"',
        "6",
        "577",
        "577",
        "0",
        "102",
        "283929",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.11528_immcusvc_appdom_1"',
        "1",
        "16",
        "16",
        "0",
        "192",
        "31",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.276_rtchost_appdom_9"',
        "0",
        "12",
        "12",
        "0",
        "76",
        "72",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.13864_ocsappserverhost_appdom_2"',
        "12",
        "12",
        "12",
        "0",
        "77",
        "3954",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.21588_asmcusvc_appdom_1"',
        "0",
        "15",
        "15",
        "0",
        "83",
        "97",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.24308_ocsappserverhost_appdom_2"',
        "0",
        "10",
        "10",
        "0",
        "184",
        "2993",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.24040_ocsappserverhost_appdom_2"',
        "5",
        "78",
        "78",
        "0",
        "133",
        "4129",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:DATACOLLECTION - Session Adaptor]"],
    [
        "instance",
        "UDC - Number of Messages Processed",
        "UDC - Number of Message Processed per second",
        "UDC - Number of Finalized Normal Sessions",
        "UDC - Number of Timeout Sessions",
        "UDC - Number of Queued Sessions",
        "UDC - Number of Queued Sessions per second",
        "UDC - Number of Discarded Sessions per second",
        "UDC - Queued Sessions for CDR per second",
        "UDC - Queued Sessions for SQL Archiving per second",
        "UDC - Queued Sessions for Exchanged Archiving per second",
        "UDC - Queued Sessions for Server Side Conversation History per second",
        "UDC - Number of LookupUser API Calls",
        "UDC - Number of LookupUser API Calls per second",
        "UDC - Number of LookupUser API Calls Result in Timeout",
        "UDC - Number of LookupUser API Calls Failed",
    ],
    [
        '""',
        "7210",
        "7210",
        "1027",
        "439",
        "2867",
        "2867",
        "13",
        "1453",
        "0",
        "0",
        "1414",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:XmppFederation - Proxy Network]"],
    [
        "instance",
        "XmppFederation - Number of messages sent",
        "XmppFederation - Number of component messages sent",
        "XmppFederation - Number of keep alive messages sent",
        "XmppFederation - Number of messages received",
        "XmppFederation - Number of component messages received",
        "XmppFederation - Number of keep alive messages received",
        "XmppFederation - Outbound Proxy Connections",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:MEDIA - Operations]"],
    [
        "instance",
        "MEDIA - Global health",
        "MEDIA - TCP disconnects because remote out of sync",
        "MEDIA - Relay allocation failures",
        "MEDIA - Number of packets dropped by Secure RTP/sec",
    ],
    ['"Call_Park_Service_1.0"', "1", "0", "0", "0"],
    ['"_Total"', "8", "0", "0", "67"],
    ['"MediationServer"', "1", "0", "0", "67"],
    ['"Conferencing_Announcement_Service_1.0"', "1", "0", "0", "0"],
    ['"AVMCUSvc.exe"', "1", "0", "0", "0"],
    ['"ATS_1.0.100"', "1", "0", "0", "0"],
    ['"Conferencing_Attendant_1.0"', "1", "0", "0", "0"],
    ['"ASMCUSvc.exe"', "1", "0", "0", "0"],
    ['"Reach_Server"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"Response_Group_Service"', "1", "0", "0", "0"],
    ["[LS:MediationServer - Media Relay]"],
    ["instance", "- Candidates Missing", "- Media Connectivity Check Failure"],
    ['""', "0", "0"],
    ["[LS:DATAMCU - DataMCU Conferences]"],
    [
        "instance",
        "DATAMCU - Blocked files",
        "DATAMCU - Blocked files/sec",
        "DATAMCU - Number of Session Controllers",
        "DATAMCU - Active Conferences",
        "DATAMCU - Number of Stopping Sessions",
        "DATAMCU - Number of Unhandled Application Exception",
        "DATAMCU - Number of Content Expiration Exception",
        "DATAMCU - Conference workitems load",
        "DATAMCU - Session queues state",
        "DATAMCU - Number of Failures Because of Invalid Internal Download URL",
        "DATAMCU - Number of Failures Because of Invalid External Download URL",
        "DATAMCU - Number of Failures Because of Empty List of Proxies",
        "DATAMCU - Maximum average time on conference queue for LDM messages",
        "DATAMCU - Minimum average time on conference queue for LDM messages",
        "DATAMCU - Average time queued in data Mcu for LDM messages",
        "DATAMCU - Maximum length of conference queues",
        "DATAMCU - Miniumum length of conference queues",
        "DATAMCU - Average length of conference queues",
        "DATAMCU - MSMQ messages written per second",
        "DATAMCU - Data Archiving events recorded per second",
        "DATAMCU - Total data archiving events recorded.",
        "DATAMCU - MSMQ failures per second",
        "DATAMCU - Total number of MSMQ failures.",
        "DATAMCU - Bytes per second written to the Data Conf archiving file store",
        "DATAMCU - Number of Data MCU meetings created",
        "DATAMCU - Number of data conferencing meetings that used Office Web Apps Server content",
        "DATAMCU - Number of active Data MCU meetings",
        "DATAMCU - Number of Data MCU users in any role",
        "DATAMCU - Number of Data MCU presenters",
        "DATAMCU - Number of pending WOPI requests",
        "DATAMCU - WOPI requests received",
        "DATAMCU - Incoming WOPI requests rate",
        "DATAMCU - WOPI requests failed",
    ],
    [
        '""',
        "0",
        "0",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "60",
        "0",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:BACKUP - Data Content Module]"],
    [
        "instance",
        "BACKUP - Steady sync state",
        "BACKUP - Time of last acknowledged steady sync",
        "BACKUP - Number of batches exported",
        "BACKUP - Number of batches pre-fetched",
        "BACKUP - Number of export operation failures",
        "BACKUP - Latency in milliseconds of exporting data",
        " ",
        "BACKUP - Latency in milliseconds of whole export task",
        " ",
        "BACKUP - Number of batches imported",
        "BACKUP - Number of batches partially imported",
        "BACKUP - Number of import operation failures",
        "BACKUP - Latency in milliseconds of importing data",
        " ",
        "BACKUP - Latency in milliseconds of whole import task",
        " ",
        "BACKUP - Number of data zip files created",
        "BACKUP - Amount of zipped data in KiB in last batch",
        "BACKUP - Total amount of zipped data in KiB",
        "BACKUP - Latency in milliseconds of zipping data",
        " ",
        "BACKUP - Latency in milliseconds of sending zipped data",
        " ",
        "BACKUP - Number of batches received in backup pool",
        "BACKUP - Latency in milliseconds of unzipping data",
        " ",
        "BACKUP - Latency in milliseconds of zipping cookie",
        " ",
        "BACKUP - Latency in milliseconds of sending zipped cookie",
        " ",
        "BACKUP - Latency in milliseconds of unzipping cookie",
        " ",
        "BACKUP - Number of handled exceptions encountered in export operation",
        "BACKUP - Number of unhandled exceptions encountered in export operation",
        "BACKUP - Number of handled exceptions encountered in import operation",
        "BACKUP - Number of unhandled exceptions encountered in import operation",
        "BACKUP - Total number of change entries exported",
        "BACKUP - Number of change entries exported in last batch",
        "BACKUP - Total number of change entries skipped during export",
        "BACKUP - Number of change entries skipped during last export",
        "BACKUP - Total number of change entries imported",
        "BACKUP - Number of change entries imported in last batch",
        "BACKUP - Total number of change entries skipped during import",
        "BACKUP - Number of change entries skipped during last import",
        "BACKUP - Total amount of data in KiB exported",
        "BACKUP - Amount of data in KiB exported in last batch",
        "BACKUP - Number of journals available for export in last sync",
        "BACKUP - Number of journals available for export in last second sync",
    ],
    [
        '""',
        "1",
        "1460464931",
        "80",
        "0",
        "0",
        "662",
        "80",
        "2400",
        "80",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "80",
        "3",
        "172",
        "318",
        "80",
        "662",
        "80",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "39340",
        "12941",
        "0",
        "0",
        "0",
        "0",
        "420",
        "7",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "118",
        "2",
        "0",
        "0",
    ],
    ["[LS:LDM - Messaging]"],
    [
        "instance",
        "LDM - Total Messages Received",
        "LDM - Total Messages Sent",
        "LDM - Received Messages/sec",
        "LDM - Sent Messages/sec",
        "LDM - Total TCPF messages sent",
        "LDM - Total TCPF messages received",
    ],
    ['""', "0", "0", "0", "0", "0", "0"],
    ["[LS:USrv - RPC Client]"],
    [
        "instance",
        "USrv - Outstanding Outbound RPC Calls",
        "USrv - Outbound RPC Calls",
        "USrv - Outbound RPC Calls/Sec",
        "USrv - SIP Notifications Batched",
        "USrv - SIP Notifications Batched/Sec",
        "USrv - Outbound RPC Call Latency (ms)",
        " ",
        "USrv - Outbound RPC Non-Runtime Failures",
        "USrv - Access Denied Errors",
        "USrv - Server Unavailable Errors",
        "USrv - Endpoint Not Registered Errors",
        "USrv - Call Failed Errors",
        "USrv - Call Cancelled Errors",
        "USrv - Invalid Async Handle Errors",
        "USrv - Other RPC Runtime Failures",
        "USrv - RPC Binding Resets",
        "USrv - Calls Failed On Binding Reset",
        "USrv - Endpoint Resolutions Attempted",
        "USrv - Endpoint Resolutions Succeeded",
        "USrv - Endpoint Resolutions Failed",
        "USrv - Endpoint Resolution Success Latency (ms)",
        "USrv - Endpoint Resolution Failure Latency (ms)",
    ],
    [
        '"_Total"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:USrv - User Replicator]"],
    [
        "instance",
        "USrv - Number of DirSync requests",
        "USrv - Number of DirSync requests that succeeded",
        "USrv - Number of DirSync requests that failed",
        "USrv - Number of DirSync responses successfully processed",
        "USrv - Number of DirSync responses unsuccessfully processed",
        "USrv - Number of user updates",
        "USrv - Number of user updates / sec",
        "USrv - Number of address book update failures / sec",
        "USrv - Number of address book update failures",
    ],
    ['"_Total"', "0", "191380", "0", "191380", "0", "923", "923", "0", "0"],
    ['"Registrar"', "0", "95692", "0", "95692", "0", "402", "402", "0", "0"],
    ['"AddressBook"', "0", "95688", "0", "95688", "0", "521", "521", "0", "0"],
    ["[LS:DATACOLLECTION - Conversation History Adaptor]"],
    [
        "instance",
        "UDC - Number of Retry Sessions",
        "UDC - Number of Retry Sessions per second",
        "UDC - No Task Finish in Expected Time",
        "UDC - Number of Sessions Processed",
        "UDC - Number of Sessions Processed per second",
        "UDC - Number of Sessions Skipped",
        "UDC - Number of Sessions Skipped per second",
        "UDC - Number of Undeliverable Items",
        "UDC - Number of Undeliverable Items per second",
        "UDC - Number of Conversation History folders created",
        "UDC - Number of Conversation History folders created per second",
        "UDC - Number of Conversation History Lookup queries",
        "UDC - Number of Conversation History Lookup queries per second",
        "UDC - Number of items in the Conversation History lookup cache",
        "UDC - Number of Conversation History Lookup cache hits",
        "UDC - Number of Conversation History Lookup cache hits per second",
        "UDC - Number of Conversation History cache clean-up operations",
        "UDC - Number of Conversation History cache clean-up operations per second",
        "UDC - Number of failed User Lookup queries",
        "UDC - Number of failed Conversation History Lookup queries per second",
        "UDC - Number of Conversation History Conversation Index Parent lookups",
        "UDC - Number of Conversation History Conversation Index Parent lookups per second",
        "UDC - Number of failed Conversation History Conversation Index Parent lookups",
        "UDC - Number of failed Conversation History Conversation Index Parent lookups per second",
        "UDC - Number of successful Conversation History Conversation Index Parent lookups",
        "UDC - Number of successful Conversation History Conversation Index Parent lookups per second",
        "UDC - Number of Conversation History Conversation Index Parent find attempts",
        "UDC - Number of Conversation History Conversation Index Parent find attempts per second",
        "UDC - Number of failed Conversation History Conversation Index Parent finds",
        "UDC - Number of failed Conversation History Conversation Index Parent finds per second",
        "UDC - Number of successful Conversation History Conversation Index Parent finds that found a parent conversation",
        "UDC - Number of successful Conversation History Conversation Index Parent finds that found a parent conversation per second",
        "UDC - Number of successful attempts to find a Conversation History Conversation Index Parent that did not find a parent",
        "UDC - Number of successful attempts to find a Conversation History Conversation Index Parent that did not find a parent per second",
        "UDC - Number of successful attempts to find a Conversation History Conversation Index Parent",
        "UDC - Number of successful attempts to find a Conversation History Conversation Index Parent per second",
        "UDC - Number conversation history sip headers that did not include a time zone offset",
        "UDC - Number conversation history sip headers that did not include a time zone offset per second",
        "UDC - Number conversation history sip headers were malformed",
        "UDC - Number conversation history sip headers were malformed per second",
        "UDC - Time spent in queue (ms)",
        " ",
        "UDC - Number of Conversation History Parent Conversation XML get attempts",
        "UDC - Number of Conversation History Conversation Parent Conversation XML get attempts per second",
        "UDC - Number of failed Conversation History Parent Conversation XML get",
        "UDC - Number of failed Conversation History Parent Conversation XML gets per second",
        "UDC - Number of successful attempts to get a Conversation History Parent Conversation XML",
        "UDC - Number of successful attempts to get a Conversation History Parent Conversation XML per second",
        "UDC - Number of Conversation History continuation conversation xml merges",
        "UDC - Number of Conversation History continuation conversation xml merges per second",
        "UDC - Number of retry attempts to find previous conversation id from Exchange",
        "UDC - Number of retry attempts to find previous conversation id per second",
        "UDC - Number of skips of previous conversation when retry limit is reached on lookup of previous conversation id",
        "UDC - Number of skips of previous conversation when retry limit is reached on lookup of previous conversation id per second",
        "UDC - Number of retry attempts to get previous conversation from Exchange",
        "UDC - Number of retry attempts to get previous conversation from Exchange per second",
        "UDC - Number of skips of previous conversation when retry limit is reached on retrieval from Exchange",
        "UDC - Number of skips of previous conversation when retry limit is reached on retrieval from Exchange per second",
        "UDC - Number of Conversation History Items Created",
        "UDC - Number of Conversation History Items Created per second",
        "UDC - Number of Conversation History Failures",
        "UDC - Number of Conversation History Failures per second",
        "UDC - Number of Conversation History Sessions without data to process",
        "UDC - Number of Conversation History Sessions without data to process per second",
        "UDC - Number of Conversation History Sessions without users to process",
        "UDC - Number of Conversation History Sessions without users to process per second",
        "UDC - Number of Conversation History Sessions that failed to generate a transcript",
        "UDC - Number of Conversation History Sessions that failed to generate a transcript per second",
        "UDC - Number of Conversation History Items that need to be created",
        "UDC - Number of Conversation History Items that need to be Created per second",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "1414",
        "1414",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "43",
        "43",
        "0",
        "0",
        "14",
        "14",
        "12",
        "12",
        "0",
        "0",
        "12",
        "12",
        "0",
        "0",
        "12",
        "12",
        "115",
        "115",
        "0",
        "0",
        "8414213",
        "1414",
        "17",
        "17",
        "0",
        "0",
        "17",
        "17",
        "17",
        "17",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "43",
        "43",
        "0",
        "0",
        "253",
        "253",
        "1119",
        "1119",
        "0",
        "0",
        "43",
        "43",
    ],
    ["[LS:WEB - Certificate Provisioning Service related Calls]"],
    [
        "instance",
        "WEB - Total ResolveUser calls to web service",
        "WEB - ResolveUser calls  per second to web service",
        "WEB - Number of failed ResolveUser calls",
        "WEB - Total GetAndPublishCert calls to web service",
        "WEB - GetAndPublishCert calls  per second to web service",
        "WEB - Number of failed GetAndPublish calls",
        "WEB - Total GetRootCertChains calls to web service",
        "WEB - GetRootCertChains calls per second to web service",
        "WEB - Number of failed GetRootCertChains calls",
    ],
    ['""', "0", "0", "0", "1", "1", "0", "0", "0", "0"],
    ["[LS:CAA - Operations]"],
    [
        "instance",
        "CAA - Incomplete calls per sec",
        "CAA - Total number of calls that were placed in the lobby per sec",
        "CAA - Total transfer requests per sec",
        "CAA - Total conference URI lookup requests per sec",
        "CAA - Total operator assistance transfers per sec",
    ],
    ['""', "2", "0", "10", "12", "0"],
    ["[LS:DATACOLLECTION - QoE Adaptor]"],
    [
        "instance",
        "UDC - Number of QoE reports validated against QoE Schema",
        "UDC - Number of QoE reports validated against QoE Schema per second",
        "UDC - Number of QoE reports rejected due to validation failure against QoE schema",
        "UDC - Number of QoE reports rejected per second due to validation failure against QoE schema",
        "UDC - Number of QoE reports inserted successfully into the database",
        "UDC - Number of QoE reports inserted successfully into the database per second",
        "UDC - Number of QoE reports dropped due to database insertion failure",
        "UDC - Number of QoE reports dropped per second due to database insertion failure",
        "UDC - Number of QoE reports failed due to unexpected server processing errors",
        "UDC - Total number of QoE reports accepted by the external report consumer",
        "UDC - Total number of QoE reports rejected by the External Consumer",
        "UDC - Total number of failures occurred while sending reports to the External Consumer",
        "UDC - Number of CQF reports rejected due to validation failure against CQF schema",
        "UDC - Number of CQF reports rejected per second due to validation failure against CQF schema",
        "UDC - Number of CQF reports validated against CQF Schema",
        "UDC - Number of CQF reports validated against CQF Schema per second",
        "UDC - Number of CQF reports inserted successfully into the database",
        "UDC - Number of CQF reports inserted successfully into the database per second",
        "UDC - Number of CQF reports dropped due to database insertion failure",
        "UDC - Number of CQF reports dropped per second due to database insertion failure",
    ],
    [
        '""',
        "882",
        "882",
        "0",
        "0",
        "882",
        "882",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "27",
        "27",
        "27",
        "27",
        "0",
        "0",
    ],
    ["[LS:AVMP - Resources]"],
    [
        "instance",
        "AVMP - Number of MP Contexts",
        "AVMP - Number of MP Endpoints",
        "AVMP - Number of MP Bridge Endpoints",
        "AVMP - Total allocated RDP bandwidth",
        "AVMP - RDP Bandwidth allocated per client",
        "AVMP - Active Transcoders",
        "AVMP - Active Data Channels",
        "AVMP - Number of Attendees",
    ],
    ['"pbwvw-skype03.16124_avmcusvc_appdom_1"', "1", "4", "0", "0", "375000000", "0", "0", "0"],
    ['"_Total"', "1", "4", "0", "0", "750000000", "0", "0", "0"],
    ['"pbwvw-skype03.21588_asmcusvc_appdom_1"', "0", "0", "0", "0", "375000000", "0", "0", "0"],
    ["[LS:BACKUP - Common]"],
    [
        "instance",
        "BACKUP - Number of batches retrieved with no reported changes",
        "BACKUP - Number of data zip files sent to the associated backup pool successfully",
        "BACKUP - Number of cookie zip files sent to the associated backup pool successfully",
        "BACKUP - Number of data zip files which failed to be sent to the associated backup pool",
        "BACKUP - Number of cookie zip files which failed to be sent to the associated backup pool",
        "BACKUP - Number of data zip files which failed to be created",
        "BACKUP - Number of cookie zip files which failed to be created",
        "BACKUP - Number of data zip files which failed to be decompressed",
        "BACKUP - Number of cookie zip files which failed to be decompressed",
        "BACKUP - Number of misreports by local SMB cache for existent file",
        "BACKUP - Number of misreports by local SMB cache for nonexistent file",
    ],
    ['""', "78485", "7004", "14297", "0", "0", "1", "0", "0", "1", "0", "2"],
    ["[LS:MediationServer - Global Counters]"],
    [
        "instance",
        "- Current audio channels with PSM quality reporting",
        "- Total failed calls caused by unexpected interaction from the Proxy",
        "- Current number of ports opened on the gateway side",
        "- Total number of timer timeouts that are exceeding the predefined threshold",
    ],
    ['""', "1", "0", "1", "0"],
    ["[LS:ImMcu - MCU Health And Performance]"],
    [
        "instance",
        "IMMCU - HTTP Stack load",
        "IMMCU - HTTP Stack state",
        "IMMCU - Thread Pool Load",
        "IMMCU - Thread Pool Health State",
        "IMMCU - Thread Pool Unhandled Exceptions",
        "IMMCU - MCU Health State",
        "IMMCU - MCU Draining State",
        "IMMCU - MCU Health State Changed Count",
        "IMMCU - MCU Health DNS resolution failure Count",
        "IMMCU - MCU Health DNS resolution succeeded Count",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0", "0", "1907"],
    ["[LS:AVMCU - Operations]"],
    [
        "instance",
        "AVMCU - Number of Conferences",
        "AVMCU - Number of Users",
        "AVMCU - Number of Trusted Users",
        "AVMCU - Number of Multi-View Enabled Conferences",
    ],
    ['""', "1", "2", "2", "1"],
    ["[LS:XmppFederation - SIP Presence]"],
    [
        "instance",
        "XmppFederation - Subscriptions from XMPP users",
        "XmppFederation - NOTIFYs from XMPP users",
        "XmppFederation - NOTIFYs from XMPP users/sec",
        "XmppFederation - Subscriptions to XMPP users",
        "XmppFederation - NOTIFYs to XMPP users",
        "XmppFederation - NOTIFYs to XMPP users/sec",
    ],
    ['""', "0", "0", "0", "0", "0", "0"],
    ["[LS:USrv - BACKUPXDSDBStore]"],
    [
        "instance",
        "USrv - Queue Depth",
        " ",
        "USrv - Queue Latency (msec)",
        " ",
        "USrv - Sproc Latency (msec)",
        " ",
        "USrv - % Database Time",
        " ",
        "USrv - Threads Waiting for New Database Requests",
        "USrv - Threads Executing Database Operations",
        "USrv - Threads Calling Back with Database Results",
        "USrv - Blocked Client Threads",
        " ",
        "USrv - Total Deadlocks",
        "USrv - Total Dropped Requests",
        "USrv - Total Deadlock Failures",
        "USrv - Total Transaction Count Mismatch Failures",
        "USrv - Total ODBC Timeout Failures",
        "USrv - Total severe SQL errors",
        "USrv - Total fatal SQL errors",
        "USrv - Throttled requests/sec",
        "USrv - Total throttled requests",
        "USrv - Database connection status",
        "USrv - Sproc Calls/sec",
        "USrv - Total sproc calls",
    ],
    [
        '""',
        "0",
        "23929",
        "188",
        "23931",
        "242",
        "23931",
        "0",
        "0",
        "2",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "2",
        "2",
    ],
    ["[LS:USrv - SubPresence SQL calls]"],
    [
        "instance",
        "USrv - RtcSubscribePresence: calls/Sec",
        "USrv - RtcSubscribePresence: Latency (msec)",
        " ",
        "USrv - RtcSubscribePresence: calls total",
        "USrv - BSub Create calls/Sec",
        "USrv - BSub Create call Latency",
        " ",
        "USrv - Number of BSub Create calls",
        "USrv - BSub Add calls/Sec",
        "USrv - BSub Add call Latency",
        " ",
        "USrv - Number of BSub Add calls",
        "USrv - BSub Delete calls/Sec",
        "USrv - BSub Delete call Latency",
        " ",
        "USrv - Number of BSub Delete calls",
        "USrv - BSub batched notify batch size",
    ],
    [
        '""',
        "3113",
        "20360",
        "3113",
        "3113",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:USrv - REGDBStore]"],
    [
        "instance",
        "USrv - Queue Depth",
        " ",
        "USrv - Queue Latency (msec)",
        " ",
        "USrv - Sproc Latency (msec)",
        " ",
        "USrv - % Database Time",
        " ",
        "USrv - Threads Waiting for New Database Requests",
        "USrv - Threads Executing Database Operations",
        "USrv - Threads Calling Back with Database Results",
        "USrv - Blocked Client Threads",
        " ",
        "USrv - Total Deadlocks",
        "USrv - Total Dropped Requests",
        "USrv - Total Deadlock Failures",
        "USrv - Total Transaction Count Mismatch Failures",
        "USrv - Total ODBC Timeout Failures",
        "USrv - Total severe SQL errors",
        "USrv - Total fatal SQL errors",
        "USrv - Throttled requests/sec",
        "USrv - Total throttled requests",
        "USrv - Database connection status",
        "USrv - Sproc Calls/sec",
        "USrv - Total sproc calls",
    ],
    [
        '""',
        "6000",
        "501644",
        "11857",
        "515191",
        "369036",
        "515192",
        "1265030",
        "14925",
        "10",
        "0",
        "0",
        "0",
        "0",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "491262",
        "491262",
    ],
    ["[LS:WebRelay - Data Collab Web Relay Server]"],
    [
        "instance",
        "WEBRELAY - Active Sip Connections",
        "WEBRELAY - Active Sip Connections for anonymous users",
        "WEBRELAY - Active Sip Connections for authenticated users",
        "WEBRELAY - Incoming App Share Connection Request",
        "WEBRELAY - Incoming Anonymous App Share Connection Request",
        "WEBRELAY - Incoming Authenticated App Share Connection Request",
        "WEBRELAY - Sip Connection Failures",
        "WEBRELAY - Sip Connection Failures per second.",
        "WEBRELAY - Sip Local Connection Failures",
        "WEBRELAY - Sip External Connection Failures",
        "WEBRELAY - Sip Authentication Failures",
        "WEBRELAY - Sip Authentication Failures per second.",
        "WEBRELAY - Sip Authenticated User Authentication Failures",
        "WEBRELAY - Sip Anonymous User Authentication Failures",
        "WEBRELAY - Average Sip Session creation time (msec).",
        " ",
        "WEBRELAY - Active AppShare Connections",
        "WEBRELAY - Active AppShare Connections for anonymous users",
        "WEBRELAY - Active AppShare Connections for authenticated users",
        "WEBRELAY - Active Data Collaboration Connections from Data Collaboraton MCUs",
        "WEBRELAY - Active Data Collaboration Connections from clients",
        "WEBRELAY - Incoming Data Collaboration Connection Requests from clients",
        "WEBRELAY - Number of Data Collaboration client connections closed due to throttling.",
        "WEBRELAY - Number of Data Collaboration client connections closed due to throttling per second.",
        "WEBRELAY - Number of Data Collaboration server connections closed due to throttling.",
        "WEBRELAY - Number of failed Data Collaboration authentication request per second.",
        "WEBRELAY - Number of failed Data Collaboration authentication requests.",
        "WEBRELAY - Number of failed App Share session setup",
        "WEBRELAY - Number of App Share session disconnected abnormally",
        "WEBRELAY - Number of failed Data Collaboration authentication requests due to invalid authentication tokens.",
        "WEBRELAY - Number of failed Data Collaboration authentication requests due to expired authentication tokens.",
        "WEBRELAY - Number of Data Collaboration connection failures with Data Collaboration servers.",
        "WEBRELAY - Number of external Data Collaboration connection failures with Data Collaboration servers.",
        "WEBRELAY - Number of local Data Collaboration connection failures with Data Collaboration servers.",
        "WEBRELAY - Number of suspended Data Collaboration client connections.",
        "WEBRELAY - Total number of queued bytes for Data Collaboration Server Connections.",
        "WEBRELAY - Number of download for Data Collab Client page",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "8",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:DATACOLLECTION - SIP messages in the Data Collection Agent]"],
    [
        "instance",
        "UDC - Number of requests received",
        "UDC - Number of requests received per second",
        "UDC - Number of responses received",
        "UDC - Number of responses received per second",
        "UDC - Number of messages enqueued by dispatcher queue",
        "UDC - Number of messages enqueued by dispatcher queue per second",
        "UDC - Number of messages dropped by dispatcher queue",
        "UDC - Number of messages dropped by dispatcher queue per second",
    ],
    ['"pbwvw-skype03.276_rtchost_appdom_3"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_LEAVECONF"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_ACK"', "0", "0", "0", "0", "0", "0", "0", "0"],
    [
        '"pbwvw-skype03.276_rtchost_appdom_3_BACKDOORREGISTER"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_LEAVEMCU"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_13_CONFSTART"', "23", "23", "0", "0", "23", "23", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_INFO"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_ACK"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_MESSAGE"', "0", "0", "0", "0", "0", "0", "0", "0"],
    [
        '"pbwvw-skype03.276_rtchost_appdom_13_INFO"',
        "139",
        "139",
        "133",
        "133",
        "60",
        "60",
        "0",
        "0",
    ],
    ['"pbwvw-skype03.276_rtchost_appdom_13_NOTIFY"', "0", "0", "0", "0", "0", "0", "0", "0"],
    [
        '"pbwvw-skype03.276_rtchost_appdom_13_BACKDOORREGISTER"',
        "1951",
        "1951",
        "0",
        "0",
        "1951",
        "1951",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.276_rtchost_appdom_13_BYE"',
        "4195",
        "4195",
        "1192",
        "1192",
        "1508",
        "1508",
        "0",
        "0",
    ],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_CONFSTART"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_13_JOINCONF"', "97", "97", "0", "0", "97", "97", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_JOINMCU"', "0", "0", "0", "0", "0", "0", "0", "0"],
    [
        '"pbwvw-skype03.276_rtchost_appdom_13_REGISTER"',
        "12111",
        "12111",
        "12111",
        "12111",
        "3559",
        "3559",
        "0",
        "0",
    ],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_BYE"', "0", "0", "0", "0", "0", "0", "0", "0"],
    [
        '"pbwvw-skype03.276_rtchost_appdom_13_INVITE"',
        "6787",
        "6787",
        "1986",
        "1986",
        "2433",
        "2433",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.276_rtchost_appdom_13_MESSAGE"',
        "3413",
        "3413",
        "3389",
        "3389",
        "3392",
        "3392",
        "0",
        "0",
    ],
    ['"pbwvw-skype03.276_rtchost_appdom_3_INVITE"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_13_SUBSCRIBE"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_13_CONFSTOP"', "22", "22", "0", "0", "22", "22", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_13_BENOTIFY"', "18", "18", "0", "0", "18", "18", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_JOINCONF"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_OPTIONS"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_DATAMCU"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_SUBSCRIBE"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_CONFSTOP"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_BYE"', "0", "0", "0", "0", "0", "0", "0", "0"],
    [
        '"pbwvw-skype03.6256_lyssvc_appdom_1_BACKDOORSERVICE"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.276_rtchost_appdom_13_BACKDOORSERVICE"',
        "822",
        "822",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ['"pbwvw-skype03.276_rtchost_appdom_13"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_BENOTIFY"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_NOTIFY"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_CONFSTART"', "0", "0", "0", "0", "0", "0", "0", "0"],
    [
        '"pbwvw-skype03.6256_lyssvc_appdom_1_BACKDOORREGISTER"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_CHANGEROLE"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_INFO"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_13_CANCEL"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_OPTIONS"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_CANCEL"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_CANCEL"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_CHANGEROLE"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_REGISTER"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_13_CHANGEROLE"', "2", "2", "0", "0", "2", "2", "0", "0"],
    [
        '"pbwvw-skype03.276_rtchost_appdom_13_JOINMCU"',
        "268",
        "268",
        "0",
        "0",
        "268",
        "268",
        "0",
        "0",
    ],
    ['"pbwvw-skype03.276_rtchost_appdom_3_REFER"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_REGISTER"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_DATAMCU"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_SUBSCRIBE"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_13_LEAVECONF"', "95", "95", "0", "0", "95", "95", "0", "0"],
    ['"_Total"', "31886", "31886", "19071", "19071", "15111", "15111", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_SERVICE"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_13_OPTIONS"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_SERVICE"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_BENOTIFY"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_LEAVEMCU"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_13_REFER"', "0", "0", "0", "0", "0", "0", "0", "0"],
    [
        '"pbwvw-skype03.276_rtchost_appdom_13_SERVICE"',
        "1850",
        "1850",
        "260",
        "260",
        "1590",
        "1590",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.276_rtchost_appdom_3_BACKDOORSERVICE"',
        "4",
        "4",
        "0",
        "0",
        "4",
        "4",
        "0",
        "0",
    ],
    ['"pbwvw-skype03.276_rtchost_appdom_3_NOTIFY"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_MESSAGE"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_REFER"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_13_LEAVEMCU"', "89", "89", "0", "0", "89", "89", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_CONFSTOP"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_13_DATAMCU"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_JOINCONF"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_13_ACK"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1_INVITE"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_JOINMCU"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ['"pbwvw-skype03.276_rtchost_appdom_3_LEAVECONF"', "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:PDP - Core - Video]"],
    [
        "instance",
        "PDP - BW Check Requests",
        "PDP - BW Check Requests/sec",
        "PDP - Failed BW Check Requests",
        "PDP - Failed BW Check Requests/sec",
        "PDP - BW Commit Requests",
        "PDP - BW Commit Requests/sec",
        "PDP - BW Update Requests",
        "PDP - BW Update Requests/sec",
        "PDP - Failed BW Update Requests",
        "PDP - Failed BW Update Requests/sec",
        "PDP - BW Return Requests",
        "PDP - BW Return Requests/sec",
        "PDP - Active BW Reservations",
        "PDP - Congested Links",
        "PDP - Timed-out BW Reservations",
        "PDP - Timed-out BW Reservations/sec",
        "PDP - Local BW Commit Requests Not Managed",
        "PDP - Local BW Commit Requests Not Managed/sec",
        "PDP - BW Commit Requests Not Managed [IP Address Not Found]",
        "PDP - BW Commit Requests Not Managed/sec [IP Address Not Found]",
        "PDP - BW Commit Requests Not Managed [Modality Not Supported]",
        "PDP - BW Commit Requests Not Managed/sec [Modality Not Supported]",
        "PDP - BW Commit Requests with Reservation ID",
        "PDP - BW Commit Requests with Reservation ID/sec",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:USrv - Dispatcher sproc]"],
    [
        "instance",
        "USrv - RtcMessageDispatcher: calls/Sec",
        "USrv - RtcMessageDispatcher: Latency (msec)",
        " ",
        "USrv - RtcMessageDispatcher: calls total",
        "USrv - RtcQueryDirectorsByDomain: calls/Sec",
        "USrv - RtcQueryDirectorsByDomain: Latency (msec)",
        " ",
        "USrv - RtcQueryDirectorsByDomain: calls total",
    ],
    ['""', "255751", "31273", "255751", "255751", "0", "0", "0", "0"],
    ["[LS:FTA - File Transfer]"],
    [
        "instance",
        "FTA - Number of transferred status files",
        "FTA - Number of transferred status files per second",
        "FTA - Number of transferred data files",
        "FTA - Number of transferred data files per second",
        "FTA - Number of milliseconds spent transferring data files",
        "FTA - Average milliseconds spent transferring data files",
        " ",
        "FTA - Number of milliseconds spent transferring status files",
        "FTA - Average milliseconds spent transferring status files",
        "",
    ],
    [
        '""',
        "28652",
        "28652",
        "28650",
        "17190",
        "213922",
        "213922",
        "34380",
        "174656",
        "174656",
        "40347",
    ],
    ["[LS:CHAT - Persistent Chat Protocol.]"],
    [
        "instance",
        "CHAT - Avg Msg Processing Time",
        "CHAT - Avg Msg Processing Base Time",
        "CHAT - Last Msg Wait Time",
        "CHAT - Last Msg Processing Time",
        "CHAT - Last Msg Multiplexing Time",
        "CHAT - Last Server Msg Wait Time",
        "CHAT - Reply Msgs in Server",
        "CHAT - Notify Msgs in Server",
        "CHAT - Error Msgs in Server",
        "CHAT - Data Bytes Queued For Processing",
        "CHAT - Inbound Queue Size",
        "CHAT - Inbound Parsed Queue Size",
        "CHAT - Command Messages",
        "CHAT - Bytes Received/Sec",
        "CHAT - Incoming Messages/Sec",
        "CHAT - Outgoing Messages/Sec",
        "CHAT - Bytes Sent/Sec",
        "CHAT - Command Messages/Sec",
        "CHAT - Notify Messages/Sec",
        "CHAT - Reply Messages/Sec",
        "CHAT - Error Messages/Sec",
        "CHAT - Notify Messages",
        "CHAT - Reply Messages",
        "CHAT - Error Messages",
        "CHAT - Incoming Messages",
        "CHAT - Outgoing Messages",
        "CHAT - Bytes Sent",
        "CHAT - Bytes Received",
        "CHAT - Chunks/Batch",
        "CHAT - Messages/Batch",
        "CHAT - Messages in CS Queue waiting to be sent to UCMA",
        "CHAT - Messages in UCMA queue.",
        "CHAT - Message Serialization Time",
        "CHAT - Message Deserialization Time",
    ],
    [
        '""',
        "2107359",
        "34291",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "11636",
        "2332585",
        "11678",
        "15931",
        "10018148",
        "11636",
        "4297",
        "11634",
        "0",
        "4297",
        "11634",
        "0",
        "11678",
        "15931",
        "10018148",
        "2332585",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:MPPROXY - Resources]"],
    [
        "instance",
        "MPPROXY - Number of MP Contexts",
        "MPPROXY - Number of MP Endpoints",
        "MPPROXY - Number of MP Bridge Endpoints",
        "MPPROXY - Number of MP Bridge Contexts",
    ],
    ['"pbwvw-skype03.16124_avmcusvc_appdom_1"', "1", "8", "0", "0"],
    ['"_Total"', "1", "8", "0", "0"],
    ['"pbwvw-skype03.21588_asmcusvc_appdom_1"', "0", "0", "0", "0"],
    ["[LS:USrv - DBStore]"],
    [
        "instance",
        "USrv - Queue Depth",
        " ",
        "USrv - Queue Latency (msec)",
        " ",
        "USrv - Sproc Latency (msec)",
        " ",
        "USrv - % Database Time",
        " ",
        "USrv - Threads Waiting for New Database Requests",
        "USrv - Threads Executing Database Operations",
        "USrv - Threads Calling Back with Database Results",
        "USrv - Blocked Client Threads",
        " ",
        "USrv - Total Deadlocks",
        "USrv - Total Dropped Requests",
        "USrv - Total Deadlock Failures",
        "USrv - Total Transaction Count Mismatch Failures",
        "USrv - Total ODBC Timeout Failures",
        "USrv - Total severe SQL errors",
        "USrv - Total fatal SQL errors",
        "USrv - Throttled requests/sec",
        "USrv - Total throttled requests",
        "USrv - Database connection status",
        "USrv - Sproc Calls/sec",
        "USrv - Total sproc calls",
        "USrv - Database failover count",
    ],
    [
        '""',
        "399",
        "788300",
        "236030",
        "790337",
        "3602026",
        "790337",
        "2134190",
        "22110",
        "10",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "766408",
        "766408",
        "0",
    ],
    ["[LS:USrv - Publisher Locks]"],
    [
        "instance",
        "USrv - Number of failed publisher lock requests",
        "USrv - Number of failed publisher lock requests/second",
        "USrv - Number of timed out publisher lock requests",
        "USrv - Number of timed out publisher lock requests/second",
        "USrv - Number of cancelled publisher lock requests",
        "USrv - Number of cancelled publisher lock requests/second",
        "USrv - Number of deadlocked publisher lock requests",
        "USrv - Number of deadlocked publisher lock requests/second",
        "USrv - Number of compute lock requests that failed because were already held.",
        "USrv - Number of compute lock requests that failed because they were already held/second",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:SIP - DHCP]"],
    [
        "instance",
        "SIP - DHCP Requests",
        "SIP - DHCP requests /Sec",
        "SIP - DHCP Responses",
        "SIP - DHCP responses /Sec",
        "SIP - DHCP Receive Failures",
        "SIP - DHCP Receive Failures /Sec",
        "SIP - DHCP Send Failures",
        "SIP - DHCP Send Failures /Sec",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:MediationServer - Outbound Calls]"],
    [
        "instance",
        "- Current",
        "- Total established",
        "- Total attempts",
        "- Total rejected due to load",
        "- Total INVITEs sent to gateway",
        "- Active priority calls",
        "- Active media bypass calls",
        "- Total outbound media bypass calls",
    ],
    ['"_Total"', "1", "151", "246", "0", "232", "0", "0", "0"],
    [
        '"pbwva-vgate01.intern.rossmann.de;trunk=pbwva-vgate01.intern.rossmann.de"',
        "1",
        "151",
        "0",
        "0",
        "232",
        "0",
        "0",
        "0",
    ],
    ['"pbwva-vgate01.intern.rossmann.de"', "0", "0", "246", "0", "0", "0", "0", "0"],
    ["[LS:USrv - All other sprocs]"],
    [
        "instance",
        "USrv - QueryEndpoint: calls/Sec",
        "USrv - QueryEndpoint: Latency (msec)",
        " ",
        "USrv - QueryEndpoint: calls total",
        "USrv - SplQueryResourceData: calls/Sec",
        "USrv - SplQueryResourceData: Latency (msec)",
        " ",
        "USrv - SplQueryResourceData: calls total",
        "USrv - SplCheckPermissions: calls/Sec",
        "USrv - SplCheckPermissions: Latency (msec)",
        " ",
        "USrv - SplCheckPermissions: calls total",
        "USrv - RemoveEndpoint: calls/Sec",
        "USrv - RemoveEndpoint: Latency (msec)",
        " ",
        "USrv - RemoveEndpoint: calls total",
        "USrv - DisconnectEndpoint: calls/Sec",
        "USrv - DisconnectEndpoint: Latency (msec)",
        " ",
        "USrv - DisconnectEndpoint: calls total",
        "USrv - SubscribePendingPresence: calls/Sec",
        "USrv - SubscribePendingPresence: Latency (msec)",
        " ",
        "USrv - SubscribePendingPresence: calls total",
        "USrv - SubscribePermissions: calls/Sec",
        "USrv - SubscribePermissions: Latency (msec)",
        " ",
        "USrv - SubscribePermissions: calls total",
        "USrv - SubscribeContacts: calls/Sec",
        "USrv - SubscribeContacts: Latency (msec)",
        " ",
        "USrv - SubscribeContacts: calls total",
        "USrv - SubscribeProvisioning: calls/Sec",
        "USrv - SubscribeProvisioning: Latency (msec)",
        " ",
        "USrv - SubscribeProvisioning: calls total",
        "USrv - SetContact: calls/Sec",
        "USrv - SetContact: Latency (msec)",
        " ",
        "USrv - SetContact: calls total",
        "USrv - DeleteContact: calls/Sec",
        "USrv - DeleteContact: Latency (msec)",
        " ",
        "USrv - DeleteContact: calls total",
        "USrv - AddGroup: calls/Sec",
        "USrv - AddGroup: Latency (msec)",
        " ",
        "USrv - AddGroup: calls total",
        "USrv - DeleteGroup: calls/Sec",
        "USrv - DeleteGroup: Latency (msec)",
        " ",
        "USrv - DeleteGroup: calls total",
        "USrv - ModifyGroup: calls/Sec",
        "USrv - ModifyGroup: Latency (msec)",
        " ",
        "USrv - ModifyGroup: calls total",
        "USrv - SetPermission: calls/Sec",
        "USrv - SetPermission: Latency (msec)",
        " ",
        "USrv - SetPermission: calls total",
        "USrv - DeletePermission: calls/Sec",
        "USrv - DeletePermission: Latency (msec)",
        " ",
        "USrv - DeletePermission: calls total",
        "USrv - RemoveSubscription: calls/Sec",
        "USrv - RemoveSubscription: Latency (msec)",
        " ",
        "USrv - RemoveSubscription: calls total",
        "USrv - RtcDeleteBatchSubscription: calls/Sec",
        "USrv - RtcDeleteBatchSubscription: Latency (msec)",
        " ",
        "USrv - RtcDeleteBatchSubscription: calls total",
        "USrv - RtcQueryResourceAuthorization: calls/Sec",
        "USrv - RtcQueryResourceAuthorization: Latency (msec)",
        " ",
        "USrv - RtcQueryResourceAuthorization: calls total",
        "USrv - RtcGetEndpointRoute: calls/Sec",
        "USrv - RtcGetEndpointRoute: Latency (msec)",
        " ",
        "USrv - RtcGetEndpointRoute: calls total",
        "USrv - Other sprocs: calls/Sec",
        "USrv - Other sprocs: Latency (msec)",
        " ",
        "USrv - Other sprocs: calls total",
        "USrv - SplQueryCategoryInstanceInContainer: calls/Sec",
        "USrv - SplQueryCategoryInstanceInContainer: Latency (msec)",
        " ",
        "USrv - SplQueryCategoryInstanceInContainer: calls total",
        "USrv - SplQueryCategoryInstanceForSubscriber: calls/Sec",
        "USrv - SplQueryCategoryInstanceForSubscriber: Latency (msec)",
        " ",
        "USrv - SplQueryCategoryInstanceForSubscriber: calls total",
        "USrv - SplQueryUserPolicy: calls/Sec",
        "USrv - SplQueryUserPolicy: Latency (msec)",
        " ",
        "USrv - SplQueryUserPolicy: calls total",
        "USrv - RtcBatchInsertPresencePolicy: calls/Sec",
        "USrv - RtcBatchInsertPresencePolicy: Latency (msec)",
        " ",
        "USrv - RtcBatchInsertPresencePolicy: calls total",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "24690",
        "3741",
        "24690",
        "24690",
        "0",
        "0",
        "0",
        "0",
        "2805",
        "51821",
        "2805",
        "2805",
        "762",
        "1726",
        "762",
        "762",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "16016",
        "12355",
        "16016",
        "16016",
        "22274",
        "1711",
        "22274",
        "22274",
        "16",
        "172",
        "16",
        "16",
        "2",
        "63",
        "2",
        "2",
        "70",
        "191",
        "70",
        "70",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "410",
        "572",
        "410",
        "410",
        "0",
        "0",
        "0",
        "0",
        "1462",
        "83",
        "1462",
        "1462",
        "0",
        "0",
        "0",
        "0",
        "626734",
        "693835",
        "626734",
        "626734",
        "453",
        "1751",
        "453",
        "453",
        "1137",
        "11726",
        "1137",
        "1137",
        "463",
        "13",
        "463",
        "463",
        "1",
        "20",
        "1",
        "1",
    ],
    ["[LS:PDP - TURN]"],
    [
        "instance",
        "PDP - Active client connections",
        "PDP - BW Check Requests",
        "PDP - BW Check Requests/sec",
        "PDP - Invalid BW Check Requests",
        "PDP - Failed BW Check Requests",
        "PDP - Failed BW Check Requests/sec",
        "PDP - Total alternate server redirects",
        "PDP - Alternate server redirects/sec",
        "PDP - Total client connections received",
        "PDP - Client connections received/sec",
        "PDP - Client Authentication timeout failures/sec",
        "PDP - Client idle timeouts/sec",
        "PDP - Total incoming stale credential failures",
        "PDP - Incoming stale credential failures/sec",
        "PDP - Total outgoing stale credential failures",
        "PDP - Outgoing stale credential failures/sec",
        "PDP - First packet timeouts/sec",
        "PDP - Parsing errors/sec",
        "PDP - Active edge connections",
        "PDP - Total messages from edge",
        "PDP - Total server connections received",
        "PDP - Server connections received/sec",
        "PDP - server authentication timeout failures/sec",
        "PDP - Server idle timeouts/sec",
        "PDP - Intracluster broadcasts received/sec",
        "PDP - Total intracluster broadcasts received",
        "PDP - Intracluster broadcasts sent/sec",
        "PDP - Total intracluster broadcasts sent",
        "PDP - Intersite broadcasts received/sec",
        "PDP - Total intersite broadcasts received",
        "PDP - Intersite broadcasts sent/sec",
        "PDP - Total intersite broadcasts sent",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:USrv - Server Aggregation]"],
    [
        "instance",
        "USrv - Number of aggregation requests",
        "USrv - Number of aggregation requests/second",
        "USrv - Number of failed aggregation requests",
        "USrv - Number of failed aggregation requests/second",
        "USrv - Number of failed aggregation requests due to timeouts.",
        "USrv - Number of failed aggregation requests other than timeouts.",
        "USrv - Number of aggregation response",
        "USrv - Number of outgoing responses/second",
        "USrv - Number of requests in the queue",
        "USrv - Request: Latency (msec)",
        "",
    ],
    ['""', "41734", "41734", "0", "0", "0", "0", "41734", "41734", "0", "22641", "41734"],
    ["[LS:WEB - Distribution List Expansion]"],
    [
        "instance",
        "WEB - Valid User Requests",
        "WEB - Valid User Requests/sec",
        "WEB - Request Processing Time",
        " ",
        "WEB - Pending Active Directory Requests",
        "WEB - Average Active Directory Fetch time in milliseconds",
        " ",
        "WEB - Pending Requests that fetch member properties",
        "WEB - Average member properties fetch time in milliseconds",
        " ",
        "WEB - Timed out Active Directory Requests",
        "WEB - Timed out Active Directory Requests/sec",
        "WEB - Timed out Requests that fetch member properties",
        "WEB - Timed out Requests that fetch member properties/sec",
        "WEB - Soap Exceptions",
        "WEB - Soap exceptions/sec",
        "WEB - Database Errors",
        "WEB - Database Errors/sec",
        "WEB - MSODS User Requests",
        "WEB - MSODS User Requests/sec",
        "WEB - MSODS Responses that succeeded",
        "WEB - MSODS Responses that failed",
        "WEB - Average MSODS query time in milliseconds",
        " ",
        "WEB - Failed MSODS authorizations attempts",
        "WEB - Empty MSODS results received",
        "WEB - Number of empty results from AD per second",
        "WEB - Request Succeeded Count",
        "WEB - Request Success Rate (%)",
        " ",
        "WEB - Request Failed Count",
        "WEB - Request Failed Rate (%)",
        " ",
        "WEB - Request Exception Count",
        "WEB - Request Exception Rate (%)",
        "",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:SipEps - SipEps Incoming Messages]"],
    [
        "instance",
        "SipEps - Incoming Messages",
        "SipEps - Incoming Messages/sec",
        "SipEps - Failed Incoming Messages",
        "SipEps - Failed Incoming Messages/sec",
        "SipEps - Incoming ACK messages",
        "SipEps - Incoming ACK messages/sec",
        "SipEps - Incoming BYE messages",
        "SipEps - Incoming BYE messages/sec",
        "SipEps - Incoming CANCEL messages",
        "SipEps - Incoming CANCEL messages/sec",
        "SipEps - Incoming INFO messages",
        "SipEps - Incoming INFO messages/sec",
        "SipEps - Incoming INVITE messages",
        "SipEps - Incoming INVITE messages/sec",
        "SipEps - Incoming MESSAGE messages",
        "SipEps - Incoming MESSAGE messages/sec",
        "SipEps - Incoming NEGOTIATE messages",
        "SipEps - Incoming NEGOTIATE messages/sec",
        "SipEps - Incoming NOTIFY messages",
        "SipEps - Incoming NOTIFY messages/sec",
        "SipEps - Incoming OPTIONS messages",
        "SipEps - Incoming OPTIONS messages/sec",
        "SipEps - Incoming REFER messages",
        "SipEps - Incoming REFER messages/sec",
        "SipEps - Incoming REGISTER messages",
        "SipEps - Incoming REGISTER messages/sec",
        "SipEps - Incoming SERVICE messages",
        "SipEps - Incoming SERVICE messages/sec",
        "SipEps - Incoming SUBSCRIBE messages",
        "SipEps - Incoming SUBSCRIBE messages/sec",
        "SipEps - Incoming Generic Messages",
        "SipEps - Incoming Generic Messages/sec",
        "SipEps - Incoming 3xx Responses",
        "SipEps - Incoming 3xx Responses/sec",
        "SipEps - Incoming 4xx Responses",
        "SipEps - Incoming 4xx Responses/sec",
        "SipEps - Incoming 5xx Responses",
        "SipEps - Incoming 5xx Responses/sec",
        "SipEps - Incoming 6xx Responses",
        "SipEps - Incoming 6xx Responses/sec",
        "SipEps - Incoming 180(Ringing) Responses",
        "SipEps - Incoming 180(Ringing) Responses/sec",
        "SipEps - Incoming 200 Responses",
        "SipEps - Incoming 200 Responses/sec",
        "SipEps - Incoming 301(Moved Permanently) Responses",
        "SipEps - Incoming 301(Moved Permanently) Responses/sec",
        "SipEps - Incoming 302(Moved Temporarily) Responses",
        "SipEps - Incoming 302(Moved Temporarily) Responses/sec",
        "SipEps - Incoming 400(Bad Request) Responses",
        "SipEps - Incoming 400(Bad Request) Responses/sec",
        "SipEps - Incoming 401(Unauthorized) Responses",
        "SipEps - Incoming 401(Unauthorized) Responses/sec",
        "SipEps - Incoming 403(Forbidden) Responses",
        "SipEps - Incoming 403(Forbidden) Responses/sec",
        "SipEps - Incoming 404(Not Found) Responses",
        "SipEps - Incoming 404(Not Found) Responses/sec",
        "SipEps - Incoming 407(Proxy Authentication Required) Responses",
        "SipEps - Incoming 407(Proxy Authentication Required) Responses/sec",
        "SipEps - Incoming 409 Responses",
        "SipEps - Incoming 409 Responses/sec",
        "SipEps - Incoming 413(Request Entity Too Large) Responses",
        "SipEps - Incoming 413(Request Entity Too Large) Responses/sec",
        "SipEps - Incoming 421(Extension Required) Responses",
        "SipEps - Incoming 421(Extension Required) Responses/sec",
        "SipEps - Incoming 430(Flow Failed) Responses",
        "SipEps - Incoming 430(Flow Failed) Responses/sec",
        "SipEps - Incoming 480(Temporarily Unavailable) Responses",
        "SipEps - Incoming 480(Temporarily Unavailable) Responses/sec",
        "SipEps - Incoming 481(Call/Transaction Does Not Exist) Responses",
        "SipEps - Incoming 481(Call/Transaction Does Not Exist) Responses/sec",
        "SipEps - Incoming 486(Busy Here) Responses",
        "SipEps - Incoming 486(Busy Here) Responses/sec",
        "SipEps - Incoming 487(Request Terminated) Responses",
        "SipEps - Incoming 487(Request Terminated) Responses/sec",
        "SipEps - Incoming 488(Not Acceptable Here) Responses",
        "SipEps - Incoming 488(Not Acceptable Here) Responses/sec",
        "SipEps - Incoming 499 Responses",
        "SipEps - Incoming 499 Responses/sec",
        "SipEps - Incoming 500(Internal Server Error) Responses",
        "SipEps - Incoming 500(Internal Server Error) Responses/sec",
        "SipEps - Incoming 501(Not Implemented) Responses",
        "SipEps - Incoming 501(Not Implemented) Responses/sec",
        "SipEps - Incoming 503(Service Unavailable) Responses",
        "SipEps - Incoming 503(Service Unavailable) Responses/sec",
        "SipEps - Incoming 504(Server Time-out) Responses",
        "SipEps - Incoming 504(Server Time-out) Responses/sec",
        "SipEps - Incoming 599 Responses",
        "SipEps - Incoming 599 Responses/sec",
        "SipEps - Incoming 600(Busy Everywhere) Responses",
        "SipEps - Incoming 600(Busy Everywhere) Responses/sec",
        "SipEps - Incoming 603(Decline) Responses",
        "SipEps - Incoming 603(Decline) Responses/sec",
        "SipEps - Incoming 699 Responses",
        "SipEps - Incoming 699 Responses/sec",
        "SipEps - Incoming out of sequence Notifies",
        "SipEps - Incoming out of sequence Notifies/sec",
    ],
    [
        '"pbwvw-skype03.16124_avmcusvc_appdom_1"',
        "1242",
        "1242",
        "0",
        "0",
        "132",
        "132",
        "58",
        "58",
        "0",
        "0",
        "0",
        "0",
        "132",
        "132",
        "0",
        "0",
        "140",
        "140",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "186",
        "186",
        "0",
        "0",
        "3",
        "3",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "504",
        "504",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2",
        "2",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"_Total"',
        "273549",
        "273549",
        "0",
        "0",
        "683",
        "683",
        "301",
        "301",
        "65",
        "65",
        "139",
        "139",
        "683",
        "683",
        "19",
        "19",
        "1344",
        "1344",
        "5",
        "5",
        "56929",
        "56929",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "53219",
        "53219",
        "0",
        "0",
        "94",
        "94",
        "0",
        "0",
        "0",
        "0",
        "46",
        "46",
        "159075",
        "159075",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "3",
        "3",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "3",
        "3",
        "3",
        "3",
        "13",
        "13",
        "71",
        "71",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.22372_ocsappserverhost_appdom_2"',
        "6308",
        "6308",
        "0",
        "0",
        "24",
        "24",
        "12",
        "12",
        "0",
        "0",
        "20",
        "20",
        "24",
        "24",
        "0",
        "0",
        "64",
        "64",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "121",
        "121",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "6017",
        "6017",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.17128_ocsappserverhost_appdom_2"',
        "10751",
        "10751",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "456",
        "456",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "650",
        "650",
        "0",
        "0",
        "2",
        "2",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "9871",
        "9871",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2",
        "2",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.9112_mediationserversvc_appdom_1"',
        "144986",
        "144986",
        "0",
        "0",
        "437",
        "437",
        "177",
        "177",
        "65",
        "65",
        "0",
        "0",
        "437",
        "437",
        "0",
        "0",
        "488",
        "488",
        "5",
        "5",
        "56929",
        "56929",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "297",
        "297",
        "0",
        "0",
        "87",
        "87",
        "0",
        "0",
        "0",
        "0",
        "40",
        "40",
        "85027",
        "85027",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "3",
        "3",
        "0",
        "0",
        "13",
        "13",
        "71",
        "71",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.11528_immcusvc_appdom_1"',
        "323",
        "323",
        "0",
        "0",
        "16",
        "16",
        "15",
        "15",
        "0",
        "0",
        "81",
        "81",
        "16",
        "16",
        "19",
        "19",
        "44",
        "44",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "53",
        "53",
        "0",
        "0",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "100",
        "100",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.276_rtchost_appdom_9"',
        "67",
        "67",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "55",
        "55",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.13864_ocsappserverhost_appdom_2"',
        "104025",
        "104025",
        "0",
        "0",
        "12",
        "12",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "12",
        "12",
        "0",
        "0",
        "12",
        "12",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "51000",
        "51000",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "6",
        "6",
        "52977",
        "52977",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.21588_asmcusvc_appdom_1"',
        "138",
        "138",
        "0",
        "0",
        "24",
        "24",
        "15",
        "15",
        "0",
        "0",
        "0",
        "0",
        "24",
        "24",
        "0",
        "0",
        "48",
        "48",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "16",
        "16",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "26",
        "26",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.24308_ocsappserverhost_appdom_2"',
        "2082",
        "2082",
        "0",
        "0",
        "20",
        "20",
        "7",
        "7",
        "0",
        "0",
        "0",
        "0",
        "20",
        "20",
        "0",
        "0",
        "24",
        "24",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2012",
        "2012",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "1",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.24040_ocsappserverhost_appdom_2"',
        "3627",
        "3627",
        "0",
        "0",
        "18",
        "18",
        "17",
        "17",
        "0",
        "0",
        "38",
        "38",
        "18",
        "18",
        "0",
        "0",
        "68",
        "68",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "896",
        "896",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2486",
        "2486",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:USrv - Conference Sprocs]"],
    [
        "instance",
        "USrv - ConfJoinParticipant: calls/Sec",
        "USrv - ConfJoinParticipant: Latency (msec)",
        " ",
        "USrv - ConfJoinParticipant: calls total",
        "USrv - ConfJoinParticipant: calls failed",
        "USrv - ConfEndorseParticipant: calls/Sec",
        "USrv - ConfEndorseParticipant: Latency (msec)",
        " ",
        "USrv - ConfEndorseParticipant: calls total",
        "USrv - ConfEndorseParticipant: calls failed",
        "USrv - ConfLeaveParticipant: calls/Sec",
        "USrv - ConfLeaveParticipant: Latency (msec)",
        " ",
        "USrv - ConfLeaveParticipant: calls total",
        "USrv - ConfSubscribeRoster: calls/Sec",
        "USrv - ConfSubscribeRoster: Latency (msec)",
        " ",
        "USrv - ConfSubscribeRoster: calls total",
        "USrv - ConfSubscribeRoster: calls failed",
        "USrv - ConfUnSubscribeRoster: calls/Sec",
        "USrv - ConfUnSubscribeRoster: Latency (msec)",
        " ",
        "USrv - ConfUnSubscribeRoster: calls total",
        "USrv - ConfGetMcu: calls/Sec",
        "USrv - ConfGetMcu: Latency (msec)",
        " ",
        "USrv - ConfGetMcu: calls total",
        "USrv - ConfSetMcu: calls/Sec",
        "USrv - ConfSetMcu: Latency (msec)",
        " ",
        "USrv - ConfSetMcu: calls total",
        "USrv - ConfUpdateMcuParticipantState: calls/Sec",
        "USrv - ConfUpdateMcuParticipantState: Latency (msec)",
        " ",
        "USrv - ConfUpdateMcuParticipantState: calls total",
        "USrv - ConfPreprocessForDispatchToMcu: calls/Sec",
        "USrv - ConfPreprocessForDispatchToMcu: Latency (msec)",
        " ",
        "USrv - ConfPreprocessForDispatchToMcu: calls total",
        "USrv - ConfPreprocessForDispatchToMcu: calls failed",
        "USrv - ConfUpdateParticipantRole: calls/Sec",
        "USrv - ConfUpdateParticipantRole: Latency (msec)",
        " ",
        "USrv - ConfUpdateParticipantRole: calls total",
        "USrv - ConfQueryRoleInformation: calls/Sec",
        "USrv - ConfQueryRoleInformation: Latency (msec)",
        " ",
        "USrv - ConfQueryRoleInformation: calls total",
        "USrv - ConfResolveConference: calls/Sec",
        "USrv - ConfResolveConference: Latency (msec)",
        " ",
        "USrv - ConfResolveConference: calls total",
        "USrv - ConfDeleteMeetingId: calls/Sec",
        "USrv - ConfDeleteMeetingId: Latency (msec)",
        " ",
        "USrv - ConfDeleteMeetingId: calls total",
        "USrv - ConfDirMgmtQueryMeetingId: calls/Sec",
        "USrv - ConfDirMgmtQueryMeetingId: Latency (msec)",
        " ",
        "USrv - ConfDirMgmtQueryMeetingId: calls total",
        "USrv - ConfDirMgmtCheckConferences: calls/Sec",
        "USrv - ConfDirMgmtCheckConferences: Latency (msec)",
        " ",
        "USrv - ConfDirMgmtCheckConferences: calls total",
        "USrv - Other conf sprocs: calls/Sec",
        "USrv - Other conf sprocs: Latency (msec)",
        " ",
        "USrv - Other conf sprocs: calls total",
        "USrv - ConfScheduleConference: calls/Sec",
        "USrv - ConfScheduleConference: Latency (msec)",
        " ",
        "USrv - ConfScheduleConference: calls total",
        "USrv - ConfSchedGetConference: calls/Sec",
        "USrv - ConfSchedGetConference: Latency (msec)",
        " ",
        "USrv - ConfSchedGetConference: calls total",
        "USrv - ConfDeleteConference: calls/Sec",
        "USrv - ConfDeleteConference: Latency (msec)",
        " ",
        "USrv - ConfDeleteConference: calls total",
    ],
    [
        '""',
        "97",
        "1649",
        "97",
        "97",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "95",
        "212",
        "95",
        "95",
        "93",
        "279",
        "93",
        "93",
        "0",
        "81",
        "1332",
        "81",
        "81",
        "54",
        "23",
        "54",
        "54",
        "208",
        "1116",
        "208",
        "208",
        "850",
        "2777",
        "850",
        "850",
        "635",
        "82",
        "635",
        "635",
        "0",
        "2",
        "7",
        "2",
        "2",
        "44",
        "23",
        "44",
        "44",
        "12",
        "7",
        "12",
        "12",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "49",
        "49",
        "49",
        "49",
        "351841",
        "2530787",
        "351841",
        "351841",
        "12",
        "219",
        "12",
        "12",
        "166",
        "41",
        "166",
        "166",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:MCUF - MCU Factory]"],
    [
        "instance",
        "MCUF - Total GetMCU Requests Received",
        "MCUF - Total GetMCU Requests Failed",
        "MCUF - Total empty GetMCU Responses",
        "MCUF - GetMCU Requests Received/sec",
        "MCUF - Total Health Notifications Received",
        "MCUF - Total Health Notifications Failed",
        "MCUF - Health Notifications Received/sec",
        "MCUF - Total Drain Requests Received",
        "MCUF - Total Drain Requests Accepted",
        "MCUF - Total Drain Requests Rejected",
        "MCUF - Total Number of Reconnections to Fabric Pool Manager",
        "MCUF - Total Mcu Types for which we are the Master Replica",
        "MCUF - Total Mcu Types for which we are the Secondary Replica",
        "MCUF - Total Number of Health Notifications sent to other Replicas",
        "MCUF - Total Number of Health Notifications received from Master",
        "MCUF - Total GetMeetingId Requests Received",
        "MCUF - Total GetMeetingId Requests Failed",
        "MCUF - Total empty GetMeetingId Responses",
        "MCUF - GetMeetingId Requests Received/sec",
        "MCUF - Total conference directory authorities for which we are the Master Replica",
        "MCUF - Total conference directory authorities for which we are the Secondary Replica",
        "MCUF - Total DeleteMeetingId Requests Received",
        "MCUF - DeleteMeetingIds Requests Received/sec",
        "MCUF - Total number of apply conference data failures",
        "MCUF - Total DeleteMeetingId Requests Failed",
        "MCUF - Total QueryRemoteMeetingIds Failed",
        "MCUF - Query meeting id requests",
        "MCUF - Query meeting id responses",
        "MCUF - Failed query meeting id responses",
        "MCUF - Failed bulk retrieve data for replication.",
        "MCUF - Failed bulk apply data.",
        "MCUF - Failed bulk delete data.",
        "MCUF - Failed master reset state.",
        "MCUF - Failed on sync master with replicas completed.",
        "MCUF - GetMeetingId Latency (msec)",
        " ",
        "MCUF - Blob store publish batch size",
        "",
    ],
    [
        '""',
        "193",
        "0",
        "0",
        "193",
        "457338",
        "26",
        "457338",
        "0",
        "0",
        "0",
        "1",
        "6",
        "0",
        "457354",
        "0",
        "12",
        "0",
        "0",
        "12",
        "2",
        "0",
        "4",
        "4",
        "0",
        "0",
        "0",
        "0",
        "49",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "522",
        "12",
        "16",
        "16",
    ],
    ["[LS:USrv - Rich presence subscribe SQL calls]"],
    [
        "instance",
        "USrv - RtcBatchSubscribeCategoryList: calls/Sec",
        "USrv - RtcBatchSubscribeCategoryList: Latency (msec)",
        " ",
        "USrv - RtcBatchSubscribeCategoryList: calls total",
        "USrv - Average number of categories per subscribe request",
        " ",
        "USrv - Average number of users per subscribe request",
        " ",
        "USrv - RtcSubscribeSelf: calls/Sec",
        "USrv - RtcSubscribeSelf: Latency (msec)",
        " ",
        "USrv - RtcSubscribeSelf: calls total",
        "USrv - RtcQuerySelfData: calls/Sec",
        "USrv - RtcQuerySelfData: Latency (msec)",
        " ",
        "USrv - RtcQuerySelfData: calls total",
        "USrv - RtcDeleteDeliveryContext: calls/Sec",
        "USrv - RtcDeleteDeliveryContext: Latency (msec)",
        " ",
        "USrv - RtcDeleteDeliveryContext: calls total",
        "USrv - RtcDeleteDeliveryContextById: calls/Sec",
        "USrv - RtcDeleteDeliveryContextById: Latency (msec)",
        " ",
        "USrv - RtcDeleteDeliveryContextById: calls total",
        "USrv - Average number of categories per polling subscribe request",
        " ",
        "USrv - Average number of users per polling subscribe request",
        " ",
        "USrv - Wait time for a polling subscribe request in the queue.",
        " ",
        "USrv - RtcBatchQueryCategories: calls/Sec",
        "USrv - RtcBatchQueryCategories: Latency (msec)",
        " ",
        "USrv - Number of polling subscribe requests waiting to be completed.",
        " ",
        "USrv - Number of requests in the call to RtcBatchQueryCategories.",
        " ",
        "USrv - Polling subscribe requests throttled by database store throttle.",
        "USrv - Polling subscribe requests throttled by database store throttle/Sec.",
        "USrv - Polling subscribe requests throttled by polling subscribe queue throttle.",
        "USrv - Polling subscribe requests throttled by polling subscribe queue throttle/Sec.",
    ],
    [
        '""',
        "12023",
        "97272",
        "12023",
        "12023",
        "57530",
        "12028",
        "37192",
        "10263",
        "5288",
        "51575",
        "5288",
        "5288",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "3405",
        "17079",
        "3405",
        "3405",
        "342179",
        "103589",
        "103589",
        "70315",
        "40169",
        "56709",
        "56709",
        "126012",
        "56709",
        "56711",
        "56709",
        "70315",
        "56709",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:DATACOLLECTION - Dispatcher Queues in the Data Collection Agent]"],
    [
        "instance",
        "UDC - Number of Critical Messages Enqueued",
        "UDC - Number of Critical Messages Enqueued per second",
        "UDC - Number of Non-Critical Messages Enqueued",
        "UDC - Number of Non-Critical Messages Enqueued per second",
        "UDC - Number of Critical Messages Dropped",
        "UDC - Number of Critical Messages Dropped per second",
        "UDC - Number of Non-Critical Messages Dropped",
        "UDC - Number of Non-Critical Messages Dropped per second",
        "UDC - Number of Bytes Enqueued",
        "UDC - Number of Bytes Enqueued per second",
        "UDC - Number of Pending Messages",
    ],
    ['"_Total"', "0", "0", "17640", "17640", "0", "0", "0", "0", "61471893", "61471893", "0"],
    [
        '"pbwvw-skype03.6256_lyssvc_appdom_1_Message Dispatcher"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.276_rtchost_appdom_3_Message Dispatcher"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ['"pbwvw-skype03.276_rtchost_appdom_3"', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    [
        '"pbwvw-skype03.276_rtchost_appdom_3_Direct Message Dispatcher"',
        "0",
        "0",
        "11",
        "11",
        "0",
        "0",
        "0",
        "0",
        "29571",
        "29571",
        "0",
    ],
    ['"pbwvw-skype03.6256_lyssvc_appdom_1"', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    [
        '"pbwvw-skype03.276_rtchost_appdom_13_Direct Message Dispatcher"',
        "0",
        "0",
        "4204",
        "4204",
        "0",
        "0",
        "0",
        "0",
        "25577289",
        "25577289",
        "0",
    ],
    [
        '"pbwvw-skype03.276_rtchost_appdom_13_Message Dispatcher"',
        "0",
        "0",
        "13425",
        "13425",
        "0",
        "0",
        "0",
        "0",
        "35865033",
        "35865033",
        "0",
    ],
    [
        '"pbwvw-skype03.276_rtchost_appdom_13"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.6256_lyssvc_appdom_1_Direct Message Dispatcher"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:CAA - Planning]"],
    [
        "instance",
        "CAA - Total incomplete calls",
        "CAA - Total Calls Received",
        "CAA - Current calls",
        "CAA - Total calls successfully transferred to the conference",
        "CAA - Total transfer requests",
        "CAA - Total calls failed to transfer to the conference",
        "CAA - Total Video Interop Service calls that failed to transfer to the conference.",
        "CAA - Total conference URI lookup requests",
        "CAA - Current number of conference URI lookup requests",
        "CAA - Total successful conference URI lookup requests where a conference URI was resolved",
        "CAA - Total successful conference URI lookup requests where a conference URI was not resolved",
        "CAA - Total conference URI lookup requests that failed due to an error",
        "CAA - Current calls on Music-On-Hold",
        "CAA - Total calls on Music-On-Hold",
        "CAA - Current calls waiting in the Lobby",
        "CAA - Total number of calls that were placed in the lobby",
        "CAA - Total users timedout on Music-On-Hold",
        "CAA - Total calls from PSTN callers",
        "CAA - Total calls from UC client",
        "CAA - Total calls from the Video Interop Service.",
        "CAA - Total bandwidth failures",
        "CAA - Total calls asked to record name",
        "CAA - Total calls completed to record name",
        "CAA - Total calls disconnected in conference ID state",
        "CAA - Total calls disconnected in holding pen state",
        "CAA - Total calls disconnected for unknown reason",
        "CAA - Total calls disconnected while in the lobby",
        "CAA - Total calls user is accepted from the lobby",
        "CAA - Total calls requiring inter pool transfer",
        "CAA - Total calls requiring joining wave 13",
        "CAA - Total calls users did not input anything",
        "CAA - Total calls where pin was locked",
        "CAA - Total calls where pin was not set",
        "CAA - Total calls where pin was expired",
        "CAA - Total calls where authentication was skipped",
        "CAA - Total calls where authentication was asked because meeting was locked",
        "CAA - Total calls where authentication was asked because PSTN users not always allowed",
        "CAA - Total calls where authentication was asked because anonymous users not allowed",
        "CAA - Total calls where user chose to authenticate as meeting organizer",
        "CAA - Total calls where user chose to authenticate as meeting leader (non-organizer)",
        "CAA - Total calls user failed authentication three times",
        "CAA - Total calls where user failed organizer authentication three times",
        "CAA - The duration of transferring to the conference",
        "CAA - The duration of resolving the conference",
        "CAA - The duration of transferring the call to another pool.",
        "CAA - The duration of authenticating.",
        "CAA - The duration of verifying the organizer's PIN.",
        "CAA - The duration of join operation",
        "CAA - The duration of accept operation",
        "CAA - The duration of retrieving information about the conference.",
        "CAA - The duration of terminate operation",
        "CAA - The duration of pass code check.",
        "CAA - Total calls user failed to enter conference id correctly three times",
        "CAA - Total calls user failed to enter their passcode correctly three times",
        "CAA - Total Application Endpoint creation failures",
        "CAA - Total Application Endpoint termination failures",
        "CAA - Number of times retry logic was triggered",
        "CAA - Number of times retry logic was successful",
        "CAA - Number of times a transfer took more than three seconds",
        "CAA - Number of times a transfer took more than five seconds",
        "CAA - Number of times a transfer took more than eight seconds",
        "CAA - Total calls that failed inter pool transfer",
        "CAA - Total number of calls that successfully transfer to the Operator.",
        "CAA - Total number of calls that failed to transfer to the Operator.",
        "CAA - Total number of calls that attempted to transfer to the Operator.",
    ],
    [
        '""',
        "2",
        "12",
        "0",
        "10",
        "10",
        "0",
        "0",
        "12",
        "0",
        "12",
        "0",
        "0",
        "0",
        "6",
        "0",
        "0",
        "0",
        "12",
        "0",
        "0",
        "0",
        "12",
        "12",
        "0",
        "2",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "0",
        "0",
        "0",
        "684",
        "5",
        "0",
        "0",
        "0",
        "30",
        "246",
        "4",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:MEDIA - Private]"],
    [
        "instance",
        "MEDIA - Audio buffer hits/sec",
        "MEDIA - Audio router timeslice/sec",
        "MEDIA - Total conference processed/sec",
        "MEDIA - Average Conference Processing Time",
        " ",
        "MEDIA - Average Transport Processing Time",
        " ",
        "MEDIA - Number of audio channels with 20ms send ptime",
        "MEDIA - Number of audio channels with 40ms send ptime",
        "MEDIA - Number of audio channels with 60ms send ptime",
        "MEDIA - Number of audio channels with 100ms send ptime",
        "MEDIA - Number of audio channels with 200ms send ptime",
        "MEDIA - Number of audio channels with 20ms receive ptime",
        "MEDIA - Number of audio channels with 40ms receive ptime",
        "MEDIA - Number of audio channels with 60ms receive ptime",
        "MEDIA - Number of audio channels with 100ms receive ptime",
        "MEDIA - Number of audio channels with 200ms receive ptime",
        "MEDIA - Average Siren Encode Time(100ns)",
        " ",
        "MEDIA - Average Siren Decode Time(100ns)",
        " ",
        "MEDIA - Average SILK Encode Time(100ns)",
        " ",
        "MEDIA - Average SILK Decode Time(100ns)",
        " ",
        "MEDIA - Average Scale SRTP encrypt large packet Time(100ns)",
        " ",
        "MEDIA - Average Scale SRTP encrypt small packet Time(100ns)",
        " ",
        "MEDIA - Average Scale SRTP inc auth large packet Time(100ns)",
        " ",
        "MEDIA - Average Scale SRTP inc auth small packet Time(100ns)",
        " ",
        "MEDIA - Average Scale SRTP final auth large packet Time(100ns)",
        " ",
        "MEDIA - Average Scale SRTP final auth small packet Time(100ns)",
        " ",
        "MEDIA - Average Scale SRTP decrypt large packet Time(100ns)",
        " ",
        "MEDIA - Average Scale SRTP decrypt small packet Time(100ns)",
        " ",
        "MEDIA - Average SRTP auth check large packet Time(100ns)",
        " ",
        "MEDIA - Average SRTP auth check small packet Time(100ns)",
        " ",
        "MEDIA - Number of packets dropped in transport",
        "MEDIA - Average time(100ns) to send a packet",
        " ",
        "MEDIA - Average time(us) process audio router",
        " ",
        "MEDIA - Average time(us) process video router",
        " ",
        "MEDIA - Average time(us) process channel router",
        " ",
        "MEDIA - Counter1",
        "MEDIA - Counter2",
        "MEDIA - Counter3",
        "MEDIA - Counter4",
        "MEDIA - Value1",
        "MEDIA - Value2",
        "MEDIA - Value3",
        "MEDIA - Value4",
        "MEDIA - Average value1",
        " ",
        "MEDIA - Average value2",
        " ",
        "MEDIA - Average value3",
        " ",
        "MEDIA - Average value4",
        " ",
        "MEDIA - Number of audio mixes/sec",
        "MEDIA - Number of bytes sent using RMA",
        "MEDIA - Number of bytes received using RMA",
        "MEDIA - Number of RMA sent event",
        "MEDIA - Number of RMA receive event",
        "MEDIA - Maximum number of streams being audio-mixed in one mixer",
        "MEDIA - Outstanding heap allocations from MEMPOOL_STREAM",
        "MEDIA - Outstanding heap allocations from MEMPOOL_AUDIO_SOURCE",
        "MEDIA - Outstanding heap allocations from MEMPOOL_AUDIO_ENCODE",
        "MEDIA - Outstanding heap allocations from MEMPOOL_AUDIO_METADATA",
        "MEDIA - Outstanding heap allocations from MEMPOOL_RTCP",
        "MEDIA - Outstanding heap allocations from MEMPOOL_RTPEXTHEADER",
        "MEDIA - Outstanding heap allocations from MEMPOOL_RTPHEADER",
        "MEDIA - Outstanding heap allocations from MEMPOOL_TRANSPORTIOCONTEXT",
        "MEDIA - Total number of CBufferTransportIOContext objects posted",
        "MEDIA - Number of conference across core moves/sec",
        " ",
        "MEDIA - Number of conferences across core moves",
        "MEDIA - No conferences Core 1",
        "MEDIA - Conference duration on Core 1",
        "MEDIA - Conference workitem duration on Core 1",
        "MEDIA - Transport offload duration on Core 1",
        "MEDIA - No conferences Core 2",
        "MEDIA - Conference duration on Core 2",
        "MEDIA - Conference workitem duration on Core 2",
        "MEDIA - Transport offload duration on Core 2",
        "MEDIA - No conferences Core 3",
        "MEDIA - Conference duration on Core 3",
        "MEDIA - Conference workitem duration on Core 3",
        "MEDIA - Transport offload duration on Core 3",
        "MEDIA - No conferences Core 4",
        "MEDIA - Conference duration on Core 4",
        "MEDIA - Conference workitem duration on Core 4",
        "MEDIA - Transport offload duration on Core 4",
        "MEDIA - No conferences Core 5",
        "MEDIA - Conference duration on Core 5",
        "MEDIA - Conference workitem duration on Core 5",
        "MEDIA - Transport offload duration on Core 5",
        "MEDIA - No conferences Core 6",
        "MEDIA - Conference duration on Core 6",
        "MEDIA - Conference workitem duration on Core 6",
        "MEDIA - Transport offload duration on Core 6",
        "MEDIA - No conferences Core 7",
        "MEDIA - Conference duration on Core 7",
        "MEDIA - Conference workitem duration on Core 7",
        "MEDIA - Transport offload duration on Core",
        "MEDIA - No conferences Core 8",
        "MEDIA - Conference duration on Core 8",
        "MEDIA - Conference workitem duration on Core 8",
        "MEDIA - Transport offload duration on Core 8",
    ],
    [
        '"Call_Park_Service_1.0"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"_Total"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"MediationServer"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"Conferencing_Announcement_Service_1.0"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"AVMCUSvc.exe"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"ATS_1.0.100"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"Conferencing_Attendant_1.0"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"ASMCUSvc.exe"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"Reach_Server"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"Response_Group_Service"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:MASTER - Status Update]"],
    [
        "instance",
        "MASTER - Number of replica status processed",
        "MASTER - Number of replica status processed per second",
        "MASTER - Number of milliseconds spent unzipping status file from replicas",
        "MASTER - Average time in milliseconds spent unzipping status files",
        " ",
        "MASTER - Number of milliseconds spent updating replica status",
        "MASTER - Average time in milliseconds spent updating replica status",
        " ",
        "MASTER - Number of failures while updating replica status",
        "MASTER - Number of replica machines",
        "MASTER - Number of failures while quering for changes",
        "MASTER - Average time in milliseconds spent quering for changes",
        " ",
        "MASTER - Number of data files generated",
        "MASTER - Number of data files generated per second",
        "MASTER - Number of milliseconds spent zipping data files",
        "MASTER - Average time in milliseconds spent zipping data files",
        "",
    ],
    [
        '""',
        "28652",
        "0",
        "167146",
        "167146",
        "28652",
        "186677",
        "186674",
        "28652",
        "0",
        "5",
        "0",
        "106377",
        "28589",
        "0",
        "0",
        "179846",
        "179846",
        "5731",
    ],
    ["[LS:ImMcu - IMMcu Conferences]"],
    [
        "instance",
        "IMMCU - Active Conferences",
        "IMMCU - Connected Users",
        "IMMCU - Connected Dialin Users",
        "IMMCU - Connected Dialout Users",
        "IMMCU - Incoming Messages",
        "IMMCU - Incoming Messages per sec",
        "IMMCU - Outgoing Messages",
        "IMMCU - Outgoing Messages per sec",
        "IMMCU - Average Message Size",
        " ",
        "IMMCU - Message Forward Errors",
        "IMMCU - Message Forward Errors per sec",
        "IMMCU - Incoming Infos",
        "IMMCU - Incoming Infos per sec",
        "IMMCU - Outgoing Infos",
        "IMMCU - Outgoing Infos per sec",
        "IMMCU - Average Info Size",
        " ",
        "IMMCU - Info Forward Errors",
        "IMMCU - Info Forward Errors per sec",
        "IMMCU - Throttled Sip Connections",
    ],
    [
        '""',
        "1",
        "1",
        "1",
        "0",
        "19",
        "19",
        "19",
        "19",
        "13415",
        "19",
        "0",
        "0",
        "81",
        "81",
        "81",
        "81",
        "6895",
        "81",
        "0",
        "0",
        "0",
    ],
    ["[LS:XmppFederation - SIP Instant Messaging]"],
    [
        "instance",
        "XmppFederation - INVITEs received",
        "XmppFederation - INVITEs received/sec",
        "XmppFederation - INVITEs declined by the gateway",
        "XmppFederation - INVITEs declined by the gateway/sec",
        "XmppFederation - INVITEs accepted by the gateway",
        "XmppFederation - INVITEs accepted by the gateway/sec",
        "XmppFederation - INVITEs sent",
        "XmppFederation - INVITEs sent/sec",
        "XmppFederation - Response time for INVITEs sent (ms)",
        "XmppFederation - INVITEs declined remotely",
        "XmppFederation - INVITEs declined remotely/sec",
        "XmppFederation - INVITEs accepted remotely",
        "XmppFederation - INVITEs accepted remotely/sec",
        "XmppFederation - Dialogs",
        " total",
        "XmppFederation - Dialogs",
        " current",
        "XmppFederation - Messages received",
        "XmppFederation - Messages received/sec",
        "XmppFederation - Messages sent",
        "XmppFederation - Messages sent/sec",
        "XmppFederation - Success IMDNs sent",
        "XmppFederation - Success IMDNs sent/sec",
        "XmppFederation - Failure IMDNs sent",
        "XmppFederation - Failure IMDNs sent/sec",
        "XmppFederation - Other errors",
        "XmppFederation - Other errors/sec",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:SLA - Shared Line Appearance]"],
    [
        "instance",
        "SLA - Total number of times all lines were busy",
        "SLA - Total number of answered calls",
        "SLA - Total number of prior incoming calls",
        "SLA - Total number of calls put on hold",
        "SLA - Total number of instances of hold and pickup",
        "SLA - Total number of instances of hold and resume",
        "SLA - Total number of calls across all SLA Groups",
        "SLA - Total number of devices dropped",
        "SLA - Total number of times global cancel was triggered",
        "SLA - Total number of devices currently subscribed",
        "SLA - Total number of service messages received from device",
        "SLA - Total number of notification messages sent",
        "SLA - Total times SLA configuration failed to be updated",
        "SLA - Total number of missed calls",
        "SLA - Total number of missed calls disconnected",
        "SLA - Total number of missed calls sent to voicemail",
        "SLA - Total number of missed calls declined with busy signal",
        "SLA - Total number of missed calls forwarded to a new number",
        "SLA - Total number of calls to busy line sent to voicemail",
        "SLA - Total number of calls to busy line declined with busy signal",
        "SLA - Total number of calls to busy line forwarded to a new number",
    ],
    [
        '""',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:USrv - ReplicationDBStore]"],
    [
        "instance",
        "USrv - Queue Depth",
        " ",
        "USrv - Queue Latency (msec)",
        " ",
        "USrv - Sproc Latency (msec)",
        " ",
        "USrv - % Database Time",
        " ",
        "USrv - Threads Waiting for New Database Requests",
        "USrv - Threads Executing Database Operations",
        "USrv - Threads Calling Back with Database Results",
        "USrv - Blocked Client Threads",
        " ",
        "USrv - Total Deadlocks",
        "USrv - Total Dropped Requests",
        "USrv - Total Deadlock Failures",
        "USrv - Total Transaction Count Mismatch Failures",
        "USrv - Total ODBC Timeout Failures",
        "USrv - Total severe SQL errors",
        "USrv - Total fatal SQL errors",
        "USrv - Throttled requests/sec",
        "USrv - Total throttled requests",
        "USrv - Database connection status",
        "USrv - Sproc Calls/sec",
        "USrv - Total sproc calls",
    ],
    [
        '""',
        "20",
        "268552",
        "581",
        "268605",
        "18574",
        "268605",
        "800866",
        "8390",
        "20",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1",
        "268603",
        "268603",
    ],
    ["[LS:RGS - Response Group Service Call Control]"],
    [
        "instance",
        "RGS - Total number of incoming calls that were declined due to missing Referred-By header",
        "RGS - Total number of incoming calls that were declined due to conferencing attempt",
        "RGS - Total number of incoming calls that declined due to Ms-Routing-Scenario header not being valid",
        "RGS - Total number of incoming calls that were declined due to video only SDP",
        "RGS - Total number of incoming calls declined because of memory pressure",
        "RGS - Total number of incoming calls declined because of SIP headers that were not valid",
        "RGS - Total number of incoming calls declined because of high number of active calls",
        "RGS - Total number of incoming response group calls since startup",
        "RGS - Total number of incoming announcement calls since startup",
        "RGS - Current active calls",
        "RGS - Total number of incoming calls declined because of workflow creation failure",
        "RGS - Total number of incoming calls that were declined due to workflow startup failure",
        "RGS - Total number of incoming calls that were declined due to connecting error",
        "RGS - Total number of incoming calls that were declined due to connecting timeout error",
    ],
    ['""', "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"],
    ["[LS:XmppFederation - Aggregate XMPP traffic]"],
    [
        "instance",
        "XmppFederation - Inbound stanzas",
        "XmppFederation - Inbound stanzas/sec",
        "XmppFederation - Outbound stanzas",
        "XmppFederation - Outbound stanzas/sec",
    ],
    ['""', "0", "0", "0", "0"],
    ["[LS:REPLICA - Status Update]"],
    [
        "instance",
        "REPLICA - Number of status update",
        "REPLICA - Number of status update per second",
        "REPLICA - Number of data files received",
        "REPLICA - Number of data files received per second",
        "REPLICA - Number of milliseconds spent updating replica data",
        " ",
        "REPLICA - Number of failures while updating replica",
        "REPLICA - Number of milliseconds spent querying replica status",
        " ",
        "REPLICA - Number of failures while quering replica status",
        "REPLICA - Number of milliseconds spent unzipping data files from master",
        "REPLICA - Number of milliseconds spent zipping status files",
    ],
    [
        '""',
        "5731",
        "5731",
        "5730",
        "5730",
        "53541",
        "5730",
        "0",
        "3825",
        "5732",
        "1",
        "5985",
        "15172",
    ],
    ["[ASP.NET Apps v4.0.30319]"],
    ["instance", "Requests Rejected"],
    ['""', "42"],
    ["[LS:A/V Edge - UDP Counters]"],
    [
        "instance",
        "A/V Edge - Total Relay Sessions",
        "A/V Edge - Active Relay Sessions - Authenticated",
        "A/V Edge - Active Relay Sessions - Allocated Port",
        "A/V Edge - Active Relay Sessions - Data",
        "A/V Edge - Allocated Port Pool Count",
        "A/V Edge - Allocated Port Pool Miss Count",
        "A/V Edge - Allocate Requests/sec",
        "A/V Edge - Authentication Failures",
        "A/V Edge - Authentication Failures/sec",
        "A/V Edge - Allocate Requests Exceeding Port Limit",
        "A/V Edge - Allocate Requests Exceeding Port Limit/sec",
        "A/V Edge - Alternate Server Redirects",
        "A/V Edge - Alternate Server Redirects/sec",
        "A/V Edge - Client Request Errors (4xx Responses)",
        "A/V Edge - Client Request Errors/sec (4xx Responses/sec)",
        "A/V Edge - Client SetActiveDestination Request Errors",
        "A/V Edge - Client SetActiveDestination Request Errors/sec",
        "A/V Edge - Session Idle Timeouts/sec",
        "A/V Edge - Packets Received/sec",
        "A/V Edge - Packets Sent/sec",
        "A/V Edge - Average TURN Packet Latency (milliseconds)",
        " ",
        "A/V Edge - Average Data Packet Latency (milliseconds)",
        " ",
        "A/V Edge - Average TURN BW Packet Latency (milliseconds)",
        " ",
        "A/V Edge - Maximum Packet Latency (milliseconds)",
        "A/V Edge - Packets Dropped/sec",
        "A/V Edge - Packets Not Forwarded/sec",
        "A/V Edge - Average Depth of Connection Receive Queue",
        " ",
        "A/V Edge - Maximum Depth of Connection Receive Queue",
        "A/V Edge - Active Sessions Exceeding Avg Bandwidth Limit",
        "A/V Edge - Active Sessions Exceeding Peak Bandwidth Limit",
        "A/V Edge - Active Federated UDP Sessions",
        "A/V Edge - Active Federated UDP Sessions/sec",
    ],
    [
        '"_Total"',
        "1341",
        "0",
        "0",
        "0",
        "359",
        "0",
        "4037",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1365",
        "1365",
        "0",
        "0",
        "566",
        "4787149",
        "4339691",
        "0",
        "0",
        "4574243",
        "4468288",
        "0",
        "0",
        "32",
        "0",
        "9064",
        "5262978",
        "4347658",
        "71",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"Private IPv4 Network Interface"',
        "1295",
        "0",
        "0",
        "0",
        "0",
        "0",
        "3888",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1306",
        "1306",
        "0",
        "0",
        "10",
        "2177015",
        "2229477",
        "0",
        "0",
        "2229909",
        "2177015",
        "0",
        "0",
        "16",
        "0",
        "0",
        "2699627",
        "2117179",
        "49",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"Public IPv4 Network Interface"',
        "46",
        "0",
        "0",
        "0",
        "359",
        "0",
        "149",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "59",
        "59",
        "0",
        "0",
        "556",
        "2610134",
        "2110214",
        "0",
        "0",
        "2344334",
        "2291273",
        "0",
        "0",
        "16",
        "0",
        "9064",
        "2563351",
        "2230479",
        "22",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"Private IPv6 Network Interface"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"Public IPv6 Network Interface"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:A/V Edge - TCP Counters]"],
    [
        "instance",
        "A/V Edge - Total Relay Sessions",
        "A/V Edge - Active Relay Sessions - Authenticated",
        "A/V Edge - Active Relay Sessions - Allocated Port",
        "A/V Edge - Active Relay Sessions - Data",
        "A/V Edge - Allocated Port Pool Count",
        "A/V Edge - Allocated Port Pool Miss Count",
        "A/V Edge - Allocate Requests/sec",
        "A/V Edge - Authentication Failures",
        "A/V Edge - Authentication Failures/sec",
        "A/V Edge - Allocate Requests Exceeding Port Limit",
        "A/V Edge - Allocate Requests Exceeding Port Limit/sec",
        "A/V Edge - Connections Reset (TCP Parsing Error)/sec",
        "A/V Edge - Alternate Server Redirects",
        "A/V Edge - Alternate Server Redirects/sec",
        "A/V Edge - Client Request Errors (4xx Responses)",
        "A/V Edge - Client Request Errors/sec (4xx Responses/sec)",
        "A/V Edge - Client SetActiveDestination Request Errors",
        "A/V Edge - Client SetActiveDestination Request Errors/sec",
        "A/V Edge - Session Idle Timeouts/sec",
        "A/V Edge - Packets Received/sec",
        "A/V Edge - Packets Sent/sec",
        "A/V Edge - Average TURN Packet Latency (milliseconds)",
        " ",
        "A/V Edge - Average Data Packet Latency (milliseconds)",
        " ",
        "A/V Edge - Average TURN BW Packet Latency (milliseconds)",
        " ",
        "A/V Edge - Maximum Packet Latency (milliseconds)",
        "A/V Edge - Packets Dropped/sec",
        "A/V Edge - Packets Not Forwarded/sec",
        "A/V Edge - Average Depth of Connection Receive Queue",
        " ",
        "A/V Edge - Maximum Depth of Connection Receive Queue",
        "A/V Edge - Active Sessions Exceeding Avg Bandwidth Limit",
        "A/V Edge - Active Sessions Exceeding Peak Bandwidth Limit",
        "A/V Edge - Active Federated TCP Sessions",
        "A/V Edge - Active Federated TCP Sessions/sec",
        "A/V Edge - Active Federated Transcoded Sessions",
        "A/V Edge - Active Federated Transcoded Sessions/sec",
        "A/V Edge - Maximum Depth of the Bandwidth Admission Control Message Queue",
        "A/V Edge - Average Depth of the Bandwidth Admission Control Message Queue",
        " ",
        "A/V Edge - Maximum Processing Time of Bandwidth Admission Control Messages (milliseconds)",
        "A/V Edge - Average Processing Time of Bandwidth Admission Control Messages (milliseconds)",
        " ",
        "A/V Edge - Active TCP Connections under Flow Control",
        "A/V Edge - Total TCP Connections in Flow Control",
    ],
    [
        '"_Total"',
        "801",
        "0",
        "0",
        "0",
        "487",
        "0",
        "2234",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "806",
        "806",
        "0",
        "0",
        "8",
        "280120",
        "560787",
        "6256",
        "5724",
        "641279",
        "591314",
        "0",
        "0",
        "2640",
        "0",
        "30807",
        "1592179",
        "597038",
        "85",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"Private IPv4 Network Interface"',
        "771",
        "0",
        "0",
        "0",
        "0",
        "0",
        "2151",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "774",
        "774",
        "0",
        "0",
        "6",
        "114821",
        "38725",
        "5849",
        "5317",
        "117842",
        "108742",
        "0",
        "0",
        "15",
        "0",
        "1",
        "253541",
        "114059",
        "38",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"Public IPv4 Network Interface"',
        "30",
        "0",
        "0",
        "0",
        "487",
        "0",
        "83",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "32",
        "32",
        "0",
        "0",
        "2",
        "165299",
        "522062",
        "407",
        "407",
        "523437",
        "482572",
        "0",
        "0",
        "2625",
        "0",
        "30806",
        "1338638",
        "482979",
        "47",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"Private IPv6 Network Interface"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    [
        '"Public IPv6 Network Interface"',
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
    ],
    ["[LS:DATAPROXY - Server Connections]"],
    [
        "instance",
        "DATAPROXY - Sockets",
        "DATAPROXY - Server Connections Currently Active",
        "DATAPROXY - Server Connections",
        "DATAPROXY - Server Connections/sec",
        "DATAPROXY - Server Connections failed to establish.",
        "DATAPROXY - Server Connections failed to establish/sec",
        "DATAPROXY - Incoming Server Messages",
        "DATAPROXY - Incoming Server Messages/sec",
        "DATAPROXY - Outgoing Server Messages",
        "DATAPROXY - Outgoing Server Messages/sec",
        "DATAPROXY - New server connection messages",
        "DATAPROXY - New server connection messages/sec",
        "DATAPROXY - New client messages",
        "DATAPROXY - New client messages/sec",
        "DATAPROXY - Data messages from client",
        "DATAPROXY - Data messages from client/sec",
        "DATAPROXY - Client Gone Messages",
        "DATAPROXY - Client Gone Messages/sec",
        "DATAPROXY - Data messages to client",
        "DATAPROXY - Data messages to client/sec",
        "DATAPROXY - Drop client messages",
        "DATAPROXY - Drop client messages/sec",
        "DATAPROXY - Shutdown messages",
        "DATAPROXY - Shutdown messages/sec",
        "DATAPROXY - Drop client ungracefully messages",
        "DATAPROXY - Drop client ungracefully messages/sec",
        "DATAPROXY - Suspend client messages",
        "DATAPROXY - Suspend client messages/sec",
        "DATAPROXY - Resume client messages",
        "DATAPROXY - Resume client messages/sec",
        "DATAPROXY - Keep Alive messages",
        "DATAPROXY - Keep Alive messages/sec",
        "DATAPROXY - Server FQDN messages",
        "DATAPROXY - Server FQDN messages/sec",
        "DATAPROXY - Current count of server connections that are throttled",
        "DATAPROXY - Server connections disconnected due to throttling",
        "DATAPROXY - Number of data bytes received on server connections",
        "DATAPROXY - Number of bytes received on server connections per second",
        "DATAPROXY - Number of bytes sent on server connection",
        "DATAPROXY - Number of bytes sent on server connection per second",
        "DATAPROXY - Number of bytes queued on connection pool to mcu",
        "DATAPROXY - System is throttling",
    ],
    [
        '"_Total"',
        "9",
        "8",
        "16",
        "8",
        "8",
        "8",
        "16",
        "16",
        "47880",
        "47856",
        "16",
        "16",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "47864",
        "47840",
        "16",
        "16",
        "0",
        "0",
        "1360",
        "1360",
        "2598723",
        "2597451",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype04.intern.rossmann.de"',
        "0",
        "4",
        "4",
        "4",
        "0",
        "0",
        "0",
        "0",
        "23932",
        "23932",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "23932",
        "23932",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1268396",
        "1268396",
        "0",
        "0",
    ],
    [
        '"pbwvw-skype03.intern.rossmann.de"',
        "0",
        "4",
        "4",
        "4",
        "0",
        "0",
        "0",
        "0",
        "23908",
        "23908",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "23908",
        "23908",
        "0",
        "0",
        "0",
        "0",
        "0",
        "0",
        "1267124",
        "1267124",
        "0",
        "0",
        "",
        "",
    ],
]

discovery = {
    "": [(None, {})],
    "conferencing": [(None, {})],
    "data_proxy": [
        ("pbwvw-skype03.intern.rossmann.de", {}),
        ("pbwvw-skype04.intern.rossmann.de", {}),
    ],
    "edge": [
        ("Private IPv4 Network Interface", {}),
        ("Private IPv6 Network Interface", {}),
        ("Public IPv4 Network Interface", {}),
        ("Public IPv6 Network Interface", {}),
    ],
    "edge_auth": [(None, {})],
    "mcu": [(None, {})],
    "mediation_server": [(None, {})],
    "mobile": [(None, {})],
    "sip_stack": [(None, {})],
    "xmpp_proxy": [],
}

checks = {
    "": [
        (
            None,
            {
                "failed_locations_requests": {"upper": (1.0, 2.0)},
                "failed_file_requests": {"upper": (1.0, 2.0)},
                "join_failures": {"upper": (1, 2)},
                "asp_requests_rejected": {"upper": (1, 2)},
                "failed_validate_cert": {"upper": (1, 2)},
                "failed_search_requests": {"upper": (1.0, 2.0)},
                "5xx_responses": {"upper": (1.0, 2.0)},
                "timedout_ad_requests": {"upper": (0.01, 0.02)},
            },
            [
                (
                    0,
                    "Failed search requests/sec: 0.00",
                    [("failed_search_requests", 0.0, 1.0, 2.0, None, None)],
                ),
                (
                    0,
                    "Failed location requests/sec: 0.00",
                    [("failed_location_requests", 0.0, 1.0, 2.0, None, None)],
                ),
                (
                    0,
                    "Timeout AD requests/sec: 0.00",
                    [("failed_ad_requests", 0.0, 0.01, 0.02, None, None)],
                ),
                (0, "HTTP 5xx/sec: 0.00", [("http_5xx", 0.0, 1.0, 2.0, None, None)]),
                (
                    2,
                    "Requests rejected: 42 (warn/crit at 1/2)",
                    [("asp_requests_rejected", 42.0, 1, 2, None, None)],
                ),
                (
                    0,
                    "Failed file requests/sec: 0.00",
                    [("failed_file_requests", 0.0, 1.0, 2.0, None, None)],
                ),
                (0, "Join failures: 0", [("join_failures", 0.0, 1, 2, None, None)]),
                (
                    0,
                    "Failed cert validations: 0",
                    [("failed_validate_cert_calls", 0.0, 1, 2, None, None)],
                ),
            ],
        )
    ],
    "conferencing": [
        (
            None,
            {
                "create_conference_latency": {"upper": (5000, 10000)},
                "allocation_latency": {"upper": (5000, 10000)},
                "incomplete_calls": {"upper": (20, 40)},
            },
            [
                (
                    0,
                    "Incomplete calls/sec: 0.00",
                    [("caa_incomplete_calls", 0.0, 20, 40, None, None)],
                ),
                (
                    0,
                    "Create conference latency: 819 nanoseconds",
                    [
                        (
                            "usrv_create_conference_latency",
                            8.188653369338694e-07,
                            5000,
                            10000,
                            None,
                            None,
                        )
                    ],
                ),
                (
                    0,
                    "Allocation latency: 2 microseconds",
                    [("usrv_allocation_latency", 1.885229636950111e-06, 5000, 10000, None, None)],
                ),
            ],
        )
    ],
    "data_proxy": [
        (
            "pbwvw-skype03.intern.rossmann.de",
            {"throttled_connections": {"upper": (1, 2)}},
            [
                (
                    0,
                    "Server connections throttled: 0",
                    [("dataproxy_connections_throttled", 0.0, 1, 2, None, None)],
                )
            ],
        ),
        (
            "pbwvw-skype04.intern.rossmann.de",
            {"throttled_connections": {"upper": (1, 2)}},
            [
                (
                    0,
                    "Server connections throttled: 0",
                    [("dataproxy_connections_throttled", 0.0, 1, 2, None, None)],
                )
            ],
        ),
    ],
    "edge": [
        (
            "Private IPv4 Network Interface",
            {
                "allocate_requests_exceeding": {"upper": (20, 40)},
                "authentication_failures": {"upper": (20, 40)},
                "packets_dropped": {"upper": (200, 400)},
            },
            [
                (
                    0,
                    "UDP auth failures/sec: 0.00",
                    [("edge_udp_failed_auth", 0.0, 20, 40, None, None)],
                ),
                (
                    0,
                    "TCP auth failures/sec: 0.00",
                    [("edge_tcp_failed_auth", 0.0, 20, 40, None, None)],
                ),
                (
                    0,
                    "UDP allocate requests > port limit/sec: 0.00",
                    [("edge_udp_allocate_requests_exceeding_port_limit", 0.0, 20, 40, None, None)],
                ),
                (
                    0,
                    "TCP allocate requests > port limit/sec: 0.00",
                    [("edge_tcp_allocate_requests_exceeding_port_limit", 0.0, 20, 40, None, None)],
                ),
                (
                    0,
                    "UDP packets dropped/sec: 0.00",
                    [("edge_udp_packets_dropped", 0.0, 200, 400, None, None)],
                ),
                (
                    0,
                    "TCP packets dropped/sec: 0.00",
                    [("edge_tcp_packets_dropped", 0.0, 200, 400, None, None)],
                ),
            ],
        ),
        (
            "Private IPv6 Network Interface",
            {
                "allocate_requests_exceeding": {"upper": (20, 40)},
                "authentication_failures": {"upper": (20, 40)},
                "packets_dropped": {"upper": (200, 400)},
            },
            [
                (
                    0,
                    "UDP auth failures/sec: 0.00",
                    [("edge_udp_failed_auth", 0.0, 20, 40, None, None)],
                ),
                (
                    0,
                    "TCP auth failures/sec: 0.00",
                    [("edge_tcp_failed_auth", 0.0, 20, 40, None, None)],
                ),
                (
                    0,
                    "UDP allocate requests > port limit/sec: 0.00",
                    [("edge_udp_allocate_requests_exceeding_port_limit", 0.0, 20, 40, None, None)],
                ),
                (
                    0,
                    "TCP allocate requests > port limit/sec: 0.00",
                    [("edge_tcp_allocate_requests_exceeding_port_limit", 0.0, 20, 40, None, None)],
                ),
                (
                    0,
                    "UDP packets dropped/sec: 0.00",
                    [("edge_udp_packets_dropped", 0.0, 200, 400, None, None)],
                ),
                (
                    0,
                    "TCP packets dropped/sec: 0.00",
                    [("edge_tcp_packets_dropped", 0.0, 200, 400, None, None)],
                ),
            ],
        ),
        (
            "Public IPv4 Network Interface",
            {
                "allocate_requests_exceeding": {"upper": (20, 40)},
                "authentication_failures": {"upper": (20, 40)},
                "packets_dropped": {"upper": (200, 400)},
            },
            [
                (
                    0,
                    "UDP auth failures/sec: 0.00",
                    [("edge_udp_failed_auth", 0.0, 20, 40, None, None)],
                ),
                (
                    0,
                    "TCP auth failures/sec: 0.00",
                    [("edge_tcp_failed_auth", 0.0, 20, 40, None, None)],
                ),
                (
                    0,
                    "UDP allocate requests > port limit/sec: 0.00",
                    [("edge_udp_allocate_requests_exceeding_port_limit", 0.0, 20, 40, None, None)],
                ),
                (
                    0,
                    "TCP allocate requests > port limit/sec: 0.00",
                    [("edge_tcp_allocate_requests_exceeding_port_limit", 0.0, 20, 40, None, None)],
                ),
                (
                    0,
                    "UDP packets dropped/sec: 0.00",
                    [("edge_udp_packets_dropped", 0.0, 200, 400, None, None)],
                ),
                (
                    0,
                    "TCP packets dropped/sec: 0.00",
                    [("edge_tcp_packets_dropped", 0.0, 200, 400, None, None)],
                ),
            ],
        ),
        (
            "Public IPv6 Network Interface",
            {
                "allocate_requests_exceeding": {"upper": (20, 40)},
                "authentication_failures": {"upper": (20, 40)},
                "packets_dropped": {"upper": (200, 400)},
            },
            [
                (
                    0,
                    "UDP auth failures/sec: 0.00",
                    [("edge_udp_failed_auth", 0.0, 20, 40, None, None)],
                ),
                (
                    0,
                    "TCP auth failures/sec: 0.00",
                    [("edge_tcp_failed_auth", 0.0, 20, 40, None, None)],
                ),
                (
                    0,
                    "UDP allocate requests > port limit/sec: 0.00",
                    [("edge_udp_allocate_requests_exceeding_port_limit", 0.0, 20, 40, None, None)],
                ),
                (
                    0,
                    "TCP allocate requests > port limit/sec: 0.00",
                    [("edge_tcp_allocate_requests_exceeding_port_limit", 0.0, 20, 40, None, None)],
                ),
                (
                    0,
                    "UDP packets dropped/sec: 0.00",
                    [("edge_udp_packets_dropped", 0.0, 200, 400, None, None)],
                ),
                (
                    0,
                    "TCP packets dropped/sec: 0.00",
                    [("edge_tcp_packets_dropped", 0.0, 200, 400, None, None)],
                ),
            ],
        ),
    ],
    "edge_auth": [
        (
            None,
            {"bad_requests": {"upper": (20, 40)}},
            [(0, "Bad requests/sec: 0.00", [("avauth_failed_requests", 0.0, 20, 40, None, None)])],
        )
    ],
    "mcu": [
        (
            None,
            {},
            [
                (0, "DATAMCU: Normal", []),
                (0, "AVMCU: Normal", []),
                (0, "ASMCU: Normal", []),
                (0, "IMMCU: Normal", []),
            ],
        )
    ],
    "mediation_server": [
        (
            None,
            {
                "failed_calls_because_of_proxy": {"upper": (10, 20)},
                "load_call_failure_index": {"upper": (10, 20)},
                "media_connectivity_failure": {"upper": (1, 2)},
                "failed_calls_because_of_gateway": {"upper": (10, 20)},
            },
            [
                (
                    0,
                    "Load call failure index: 0",
                    [("mediation_load_call_failure_index", 0.0, 10, 20, None, None)],
                ),
                (
                    0,
                    "Failed calls because of proxy: 0",
                    [("mediation_failed_calls_because_of_proxy", 0.0, 10, 20, None, None)],
                ),
                (
                    0,
                    "Failed calls because of gateway: 0",
                    [("mediation_failed_calls_because_of_gateway", 0.0, 10, 20, None, None)],
                ),
                (
                    0,
                    "Media connectivity check failure: 0",
                    [("mediation_media_connectivity_failure", 0.0, 1, 2, None, None)],
                ),
            ],
        )
    ],
    "mobile": [
        (
            None,
            {"requests_processing": {"upper": (10000, 20000)}},
            [
                (
                    0,
                    "Android: 0 active",
                    [("ucwa_active_sessions_android", 0.0, None, None, None, None)],
                ),
                (0, "iPad: 1 active", [("ucwa_active_sessions_ipad", 1.0, None, None, None, None)]),
                (
                    0,
                    "iPhone: 1 active",
                    [("ucwa_active_sessions_iphone", 1.0, None, None, None, None)],
                ),
                (0, "Requested: 1", [("web_requests_processing", 1.0, 10000, 20000, None, None)]),
            ],
        )
    ],
    "sip_stack": [
        (
            None,
            {
                "authentication_errors": {"upper": (1, 2)},
                "timedout_incoming_messages": {"upper": (2, 4)},
                "local_503_responses": {"upper": (0.01, 0.02)},
                "outgoing_queue_delay": {"upper": (2.0, 4.0)},
                "incoming_requests_dropped": {"upper": (1.0, 2.0)},
                "queue_latency": {"upper": (0.1, 0.2)},
                "message_processing_time": {"upper": (1.0, 2.0)},
                "sproc_latency": {"upper": (0.1, 0.2)},
                "throttled_requests": {"upper": (0.2, 0.4)},
                "holding_time_incoming": {"upper": (6.0, 12.0)},
                "incoming_responses_dropped": {"upper": (1.0, 2.0)},
                "flow_controlled_connections": {"upper": (1, 2)},
                "timedout_sends": {"upper": (0.01, 0.02)},
            },
            [
                (
                    0,
                    "Avg incoming message processing time: 0.00",
                    [("sip_message_processing_time", 0.0, 1.0, 2.0, None, None)],
                ),
                (
                    0,
                    "Incoming responses dropped/sec: 0.00",
                    [("sip_incoming_responses_dropped", 0.0, 1.0, 2.0, None, None)],
                ),
                (
                    0,
                    "Incoming requests dropped/sec: 0.00",
                    [("sip_incoming_requests_dropped", 0.0, 1.0, 2.0, None, None)],
                ),
                (
                    0,
                    "Queue latency: 299 microseconds",
                    [("usrv_queue_latency", 0.00029864475533854544, 0.1, 0.2, None, None)],
                ),
                (
                    0,
                    "Sproc latency: 839 nanoseconds",
                    [("usrv_sproc_latency", 8.385077343119278e-07, 0.1, 0.2, None, None)],
                ),
                (
                    0,
                    "Throttled requests/sec: 0.00",
                    [("usrv_throttled_requests", 0.0, 0.2, 0.4, None, None)],
                ),
                (
                    0,
                    "Local 503 responses/sec: 0.00",
                    [("sip_503_responses", 0.0, 0.01, 0.02, None, None)],
                ),
                (
                    0,
                    "Incoming messages timed out: 0",
                    [("sip_incoming_messages_timed_out", 0.0, 2, 4, None, None)],
                ),
                (
                    0,
                    "Avg holding time for incoming messages: 0.00",
                    [("sip_avg_holding_time_incoming_messages", 0.0, 6.0, 12.0, None, None)],
                ),
                (
                    0,
                    "Flow-controlled connections: 0",
                    [("sip_flow_controlled_connections", 0.0, 1, 2, None, None)],
                ),
                (
                    0,
                    "Avg outgoing queue delay: 0.00",
                    [("sip_avg_outgoing_queue_delay", 0.0, 2.0, 4.0, None, None)],
                ),
                (
                    0,
                    "Sends timed out/sec: 0.00",
                    [("sip_sends_timed_out", 0.0, 0.01, 0.02, None, None)],
                ),
                (
                    0,
                    "Authentication errors/sec: 0.00",
                    [("sip_authentication_errors", 0.0, 1, 2, None, None)],
                ),
            ],
        )
    ],
}
